import { z } from 'zod';

declare type AcceptableFormRecord = Record<string, AcceptableFormValueOrNull>;

declare type AcceptableFormValue = string | number | boolean | {
    fileContent?: string;
};

declare type AcceptableFormValueOrNull = AcceptableFormValue | null;

declare type AcceptableFormValueOrNullish = AcceptableFormValueOrNull | undefined;

declare const alerts: z.ZodOptional<z.ZodArray<z.ZodObject<{
    name: z.ZodString;
    label: z.ZodString;
    description: z.ZodString;
    adaptiveResponse: z.ZodOptional<z.ZodObject<{
        task: z.ZodArray<z.ZodString, "many">;
        supportsAdhoc: z.ZodBoolean;
        supportsCloud: z.ZodBoolean;
        subject: z.ZodArray<z.ZodString, "many">;
        category: z.ZodArray<z.ZodString, "many">;
        technology: z.ZodArray<z.ZodObject<{
            version: z.ZodArray<z.ZodString, "many">;
            product: z.ZodString;
            vendor: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            version: string[];
            product: string;
            vendor: string;
        }, {
            version: string[];
            product: string;
            vendor: string;
        }>, "many">;
        drilldownUri: z.ZodOptional<z.ZodString>;
        sourcetype: z.ZodOptional<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        task: string[];
        supportsAdhoc: boolean;
        supportsCloud: boolean;
        subject: string[];
        category: string[];
        technology: {
            version: string[];
            product: string;
            vendor: string;
        }[];
        drilldownUri?: string | undefined;
        sourcetype?: string | undefined;
    }, {
        task: string[];
        supportsAdhoc: boolean;
        supportsCloud: boolean;
        subject: string[];
        category: string[];
        technology: {
            version: string[];
            product: string;
            vendor: string;
        }[];
        drilldownUri?: string | undefined;
        sourcetype?: string | undefined;
    }>>;
    entity: z.ZodOptional<z.ZodArray<z.ZodDiscriminatedUnion<"type", [z.ZodObject<{
        field: z.ZodString;
        label: z.ZodString;
        help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
            text: z.ZodString;
            links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                slug: z.ZodString;
                link: z.ZodString;
                linkText: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                slug: string;
                link: string;
                linkText: string;
            }, {
                slug: string;
                link: string;
                linkText: string;
            }>, "many">>;
            link: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        }, {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        }>]>>;
        tooltip: z.ZodOptional<z.ZodString>;
        required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
        encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
    } & {
        type: z.ZodLiteral<"text">;
        validators: z.ZodOptional<z.ZodArray<z.ZodUnion<[z.ZodObject<{
            errorMsg: z.ZodOptional<z.ZodString>;
            type: z.ZodLiteral<"number">;
            range: z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>;
            isInteger: z.ZodOptional<z.ZodBoolean>;
        }, "strip", z.ZodTypeAny, {
            type: "number";
            range: [number, number];
            errorMsg?: string | undefined;
            isInteger?: boolean | undefined;
        }, {
            type: "number";
            range: [number, number];
            errorMsg?: string | undefined;
            isInteger?: boolean | undefined;
        }>, z.ZodObject<{
            errorMsg: z.ZodOptional<z.ZodString>;
            type: z.ZodLiteral<"string">;
            minLength: z.ZodNumber;
            maxLength: z.ZodNumber;
        }, "strip", z.ZodTypeAny, {
            type: "string";
            minLength: number;
            maxLength: number;
            errorMsg?: string | undefined;
        }, {
            type: "string";
            minLength: number;
            maxLength: number;
            errorMsg?: string | undefined;
        }>, z.ZodObject<{
            errorMsg: z.ZodOptional<z.ZodString>;
            type: z.ZodLiteral<"regex">;
            pattern: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            type: "regex";
            pattern: string;
            errorMsg?: string | undefined;
        }, {
            type: "regex";
            pattern: string;
            errorMsg?: string | undefined;
        }>, z.ZodObject<{
            errorMsg: z.ZodOptional<z.ZodString>;
            type: z.ZodLiteral<"email">;
        }, "strip", z.ZodTypeAny, {
            type: "email";
            errorMsg?: string | undefined;
        }, {
            type: "email";
            errorMsg?: string | undefined;
        }>, z.ZodObject<{
            errorMsg: z.ZodOptional<z.ZodString>;
            type: z.ZodLiteral<"ipv4">;
        }, "strip", z.ZodTypeAny, {
            type: "ipv4";
            errorMsg?: string | undefined;
        }, {
            type: "ipv4";
            errorMsg?: string | undefined;
        }>, z.ZodObject<{
            errorMsg: z.ZodOptional<z.ZodString>;
            type: z.ZodLiteral<"url">;
        }, "strip", z.ZodTypeAny, {
            type: "url";
            errorMsg?: string | undefined;
        }, {
            type: "url";
            errorMsg?: string | undefined;
        }>, z.ZodObject<{
            errorMsg: z.ZodOptional<z.ZodString>;
            type: z.ZodLiteral<"date">;
        }, "strip", z.ZodTypeAny, {
            type: "date";
            errorMsg?: string | undefined;
        }, {
            type: "date";
            errorMsg?: string | undefined;
        }>]>, "many">>;
        defaultValue: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodNumber, z.ZodBoolean]>>;
        options: z.ZodOptional<z.ZodObject<{
            display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
        }, "strip", z.ZodTypeAny, {
            display?: boolean | undefined;
            disableonEdit?: boolean | undefined;
            enable?: boolean | undefined;
            requiredWhenVisible?: boolean | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
        }, {
            display?: boolean | undefined;
            disableonEdit?: boolean | undefined;
            enable?: boolean | undefined;
            requiredWhenVisible?: boolean | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
        }>>;
        modifyFieldsOnValue: z.ZodOptional<z.ZodArray<z.ZodObject<{
            fieldValue: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
            mode: z.ZodOptional<z.ZodEnum<["create", "edit", "config", "clone"]>>;
            fieldsToModify: z.ZodArray<z.ZodObject<{
                fieldId: z.ZodString;
                display: z.ZodOptional<z.ZodBoolean>;
                value: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>>;
                disabled: z.ZodOptional<z.ZodBoolean>;
                required: z.ZodOptional<z.ZodBoolean>;
                help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                    text: z.ZodString;
                    links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        slug: z.ZodString;
                        link: z.ZodString;
                        linkText: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }>, "many">>;
                    link: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }>]>>;
                label: z.ZodOptional<z.ZodString>;
                markdownMessage: z.ZodOptional<z.ZodUnion<[z.ZodObject<{
                    markdownType: z.ZodLiteral<"text">;
                    text: z.ZodString;
                    color: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                }, {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                }>, z.ZodObject<{
                    markdownType: z.ZodLiteral<"hybrid">;
                    text: z.ZodString;
                    token: z.ZodString;
                    linkText: z.ZodString;
                    link: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                }, {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                }>, z.ZodObject<{
                    markdownType: z.ZodLiteral<"link">;
                    text: z.ZodString;
                    link: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    link: string;
                    markdownType: "link";
                }, {
                    text: string;
                    link: string;
                    markdownType: "link";
                }>, z.ZodObject<{
                    markdownType: z.ZodOptional<z.ZodUndefined>;
                    text: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    markdownType?: undefined;
                }, {
                    text: string;
                    markdownType?: undefined;
                }>]>>;
            }, "strip", z.ZodTypeAny, {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }, {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }>, "many">;
        }, "strip", z.ZodTypeAny, {
            fieldValue: string | number | boolean;
            fieldsToModify: {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }[];
            mode?: "clone" | "create" | "edit" | "config" | undefined;
        }, {
            fieldValue: string | number | boolean;
            fieldsToModify: {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }[];
            mode?: "clone" | "create" | "edit" | "config" | undefined;
        }>, "many">>;
    }, "strip", z.ZodTypeAny, {
        type: "text";
        label: string;
        field: string;
        options?: {
            display?: boolean | undefined;
            disableonEdit?: boolean | undefined;
            enable?: boolean | undefined;
            requiredWhenVisible?: boolean | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
        } | undefined;
        help?: string | {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        } | undefined;
        tooltip?: string | undefined;
        required?: boolean | undefined;
        encrypted?: boolean | undefined;
        validators?: ({
            type: "number";
            range: [number, number];
            errorMsg?: string | undefined;
            isInteger?: boolean | undefined;
        } | {
            type: "string";
            minLength: number;
            maxLength: number;
            errorMsg?: string | undefined;
        } | {
            type: "regex";
            pattern: string;
            errorMsg?: string | undefined;
        } | {
            type: "email";
            errorMsg?: string | undefined;
        } | {
            type: "ipv4";
            errorMsg?: string | undefined;
        } | {
            type: "url";
            errorMsg?: string | undefined;
        } | {
            type: "date";
            errorMsg?: string | undefined;
        })[] | undefined;
        defaultValue?: string | number | boolean | undefined;
        modifyFieldsOnValue?: {
            fieldValue: string | number | boolean;
            fieldsToModify: {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }[];
            mode?: "clone" | "create" | "edit" | "config" | undefined;
        }[] | undefined;
    }, {
        type: "text";
        label: string;
        field: string;
        options?: {
            display?: boolean | undefined;
            disableonEdit?: boolean | undefined;
            enable?: boolean | undefined;
            requiredWhenVisible?: boolean | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
        } | undefined;
        help?: string | {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        } | undefined;
        tooltip?: string | undefined;
        required?: boolean | undefined;
        encrypted?: boolean | undefined;
        validators?: ({
            type: "number";
            range: [number, number];
            errorMsg?: string | undefined;
            isInteger?: boolean | undefined;
        } | {
            type: "string";
            minLength: number;
            maxLength: number;
            errorMsg?: string | undefined;
        } | {
            type: "regex";
            pattern: string;
            errorMsg?: string | undefined;
        } | {
            type: "email";
            errorMsg?: string | undefined;
        } | {
            type: "ipv4";
            errorMsg?: string | undefined;
        } | {
            type: "url";
            errorMsg?: string | undefined;
        } | {
            type: "date";
            errorMsg?: string | undefined;
        })[] | undefined;
        defaultValue?: string | number | boolean | undefined;
        modifyFieldsOnValue?: {
            fieldValue: string | number | boolean;
            fieldsToModify: {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }[];
            mode?: "clone" | "create" | "edit" | "config" | undefined;
        }[] | undefined;
    }>, z.ZodObject<{
        field: z.ZodString;
        label: z.ZodString;
        help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
            text: z.ZodString;
            links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                slug: z.ZodString;
                link: z.ZodString;
                linkText: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                slug: string;
                link: string;
                linkText: string;
            }, {
                slug: string;
                link: string;
                linkText: string;
            }>, "many">>;
            link: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        }, {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        }>]>>;
        tooltip: z.ZodOptional<z.ZodString>;
        required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
        encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
    } & {
        type: z.ZodLiteral<"textarea">;
        validators: z.ZodOptional<z.ZodArray<z.ZodUnion<[z.ZodObject<{
            errorMsg: z.ZodOptional<z.ZodString>;
            type: z.ZodLiteral<"number">;
            range: z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>;
            isInteger: z.ZodOptional<z.ZodBoolean>;
        }, "strip", z.ZodTypeAny, {
            type: "number";
            range: [number, number];
            errorMsg?: string | undefined;
            isInteger?: boolean | undefined;
        }, {
            type: "number";
            range: [number, number];
            errorMsg?: string | undefined;
            isInteger?: boolean | undefined;
        }>, z.ZodObject<{
            errorMsg: z.ZodOptional<z.ZodString>;
            type: z.ZodLiteral<"string">;
            minLength: z.ZodNumber;
            maxLength: z.ZodNumber;
        }, "strip", z.ZodTypeAny, {
            type: "string";
            minLength: number;
            maxLength: number;
            errorMsg?: string | undefined;
        }, {
            type: "string";
            minLength: number;
            maxLength: number;
            errorMsg?: string | undefined;
        }>, z.ZodObject<{
            errorMsg: z.ZodOptional<z.ZodString>;
            type: z.ZodLiteral<"regex">;
            pattern: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            type: "regex";
            pattern: string;
            errorMsg?: string | undefined;
        }, {
            type: "regex";
            pattern: string;
            errorMsg?: string | undefined;
        }>, z.ZodObject<{
            errorMsg: z.ZodOptional<z.ZodString>;
            type: z.ZodLiteral<"email">;
        }, "strip", z.ZodTypeAny, {
            type: "email";
            errorMsg?: string | undefined;
        }, {
            type: "email";
            errorMsg?: string | undefined;
        }>, z.ZodObject<{
            errorMsg: z.ZodOptional<z.ZodString>;
            type: z.ZodLiteral<"ipv4">;
        }, "strip", z.ZodTypeAny, {
            type: "ipv4";
            errorMsg?: string | undefined;
        }, {
            type: "ipv4";
            errorMsg?: string | undefined;
        }>, z.ZodObject<{
            errorMsg: z.ZodOptional<z.ZodString>;
            type: z.ZodLiteral<"url">;
        }, "strip", z.ZodTypeAny, {
            type: "url";
            errorMsg?: string | undefined;
        }, {
            type: "url";
            errorMsg?: string | undefined;
        }>, z.ZodObject<{
            errorMsg: z.ZodOptional<z.ZodString>;
            type: z.ZodLiteral<"date">;
        }, "strip", z.ZodTypeAny, {
            type: "date";
            errorMsg?: string | undefined;
        }, {
            type: "date";
            errorMsg?: string | undefined;
        }>]>, "many">>;
        defaultValue: z.ZodOptional<z.ZodString>;
        options: z.ZodOptional<z.ZodObject<{
            display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
        } & {
            rowsMin: z.ZodOptional<z.ZodNumber>;
            rowsMax: z.ZodOptional<z.ZodNumber>;
        }, "strip", z.ZodTypeAny, {
            display?: boolean | undefined;
            disableonEdit?: boolean | undefined;
            enable?: boolean | undefined;
            requiredWhenVisible?: boolean | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
            rowsMin?: number | undefined;
            rowsMax?: number | undefined;
        }, {
            display?: boolean | undefined;
            disableonEdit?: boolean | undefined;
            enable?: boolean | undefined;
            requiredWhenVisible?: boolean | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
            rowsMin?: number | undefined;
            rowsMax?: number | undefined;
        }>>;
        modifyFieldsOnValue: z.ZodOptional<z.ZodArray<z.ZodObject<{
            fieldValue: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
            mode: z.ZodOptional<z.ZodEnum<["create", "edit", "config", "clone"]>>;
            fieldsToModify: z.ZodArray<z.ZodObject<{
                fieldId: z.ZodString;
                display: z.ZodOptional<z.ZodBoolean>;
                value: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>>;
                disabled: z.ZodOptional<z.ZodBoolean>;
                required: z.ZodOptional<z.ZodBoolean>;
                help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                    text: z.ZodString;
                    links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        slug: z.ZodString;
                        link: z.ZodString;
                        linkText: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }>, "many">>;
                    link: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }>]>>;
                label: z.ZodOptional<z.ZodString>;
                markdownMessage: z.ZodOptional<z.ZodUnion<[z.ZodObject<{
                    markdownType: z.ZodLiteral<"text">;
                    text: z.ZodString;
                    color: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                }, {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                }>, z.ZodObject<{
                    markdownType: z.ZodLiteral<"hybrid">;
                    text: z.ZodString;
                    token: z.ZodString;
                    linkText: z.ZodString;
                    link: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                }, {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                }>, z.ZodObject<{
                    markdownType: z.ZodLiteral<"link">;
                    text: z.ZodString;
                    link: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    link: string;
                    markdownType: "link";
                }, {
                    text: string;
                    link: string;
                    markdownType: "link";
                }>, z.ZodObject<{
                    markdownType: z.ZodOptional<z.ZodUndefined>;
                    text: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    markdownType?: undefined;
                }, {
                    text: string;
                    markdownType?: undefined;
                }>]>>;
            }, "strip", z.ZodTypeAny, {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }, {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }>, "many">;
        }, "strip", z.ZodTypeAny, {
            fieldValue: string | number | boolean;
            fieldsToModify: {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }[];
            mode?: "clone" | "create" | "edit" | "config" | undefined;
        }, {
            fieldValue: string | number | boolean;
            fieldsToModify: {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }[];
            mode?: "clone" | "create" | "edit" | "config" | undefined;
        }>, "many">>;
    }, "strip", z.ZodTypeAny, {
        type: "textarea";
        label: string;
        field: string;
        options?: {
            display?: boolean | undefined;
            disableonEdit?: boolean | undefined;
            enable?: boolean | undefined;
            requiredWhenVisible?: boolean | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
            rowsMin?: number | undefined;
            rowsMax?: number | undefined;
        } | undefined;
        help?: string | {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        } | undefined;
        tooltip?: string | undefined;
        required?: boolean | undefined;
        encrypted?: boolean | undefined;
        validators?: ({
            type: "number";
            range: [number, number];
            errorMsg?: string | undefined;
            isInteger?: boolean | undefined;
        } | {
            type: "string";
            minLength: number;
            maxLength: number;
            errorMsg?: string | undefined;
        } | {
            type: "regex";
            pattern: string;
            errorMsg?: string | undefined;
        } | {
            type: "email";
            errorMsg?: string | undefined;
        } | {
            type: "ipv4";
            errorMsg?: string | undefined;
        } | {
            type: "url";
            errorMsg?: string | undefined;
        } | {
            type: "date";
            errorMsg?: string | undefined;
        })[] | undefined;
        defaultValue?: string | undefined;
        modifyFieldsOnValue?: {
            fieldValue: string | number | boolean;
            fieldsToModify: {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }[];
            mode?: "clone" | "create" | "edit" | "config" | undefined;
        }[] | undefined;
    }, {
        type: "textarea";
        label: string;
        field: string;
        options?: {
            display?: boolean | undefined;
            disableonEdit?: boolean | undefined;
            enable?: boolean | undefined;
            requiredWhenVisible?: boolean | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
            rowsMin?: number | undefined;
            rowsMax?: number | undefined;
        } | undefined;
        help?: string | {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        } | undefined;
        tooltip?: string | undefined;
        required?: boolean | undefined;
        encrypted?: boolean | undefined;
        validators?: ({
            type: "number";
            range: [number, number];
            errorMsg?: string | undefined;
            isInteger?: boolean | undefined;
        } | {
            type: "string";
            minLength: number;
            maxLength: number;
            errorMsg?: string | undefined;
        } | {
            type: "regex";
            pattern: string;
            errorMsg?: string | undefined;
        } | {
            type: "email";
            errorMsg?: string | undefined;
        } | {
            type: "ipv4";
            errorMsg?: string | undefined;
        } | {
            type: "url";
            errorMsg?: string | undefined;
        } | {
            type: "date";
            errorMsg?: string | undefined;
        })[] | undefined;
        defaultValue?: string | undefined;
        modifyFieldsOnValue?: {
            fieldValue: string | number | boolean;
            fieldsToModify: {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }[];
            mode?: "clone" | "create" | "edit" | "config" | undefined;
        }[] | undefined;
    }>, z.ZodObject<{
        field: z.ZodString;
        label: z.ZodString;
        help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
            text: z.ZodString;
            links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                slug: z.ZodString;
                link: z.ZodString;
                linkText: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                slug: string;
                link: string;
                linkText: string;
            }, {
                slug: string;
                link: string;
                linkText: string;
            }>, "many">>;
            link: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        }, {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        }>]>>;
        tooltip: z.ZodOptional<z.ZodString>;
        required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
        encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
    } & {
        type: z.ZodLiteral<"singleSelect">;
        validators: z.ZodOptional<z.ZodArray<z.ZodUnion<[z.ZodObject<{
            errorMsg: z.ZodOptional<z.ZodString>;
            type: z.ZodLiteral<"number">;
            range: z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>;
            isInteger: z.ZodOptional<z.ZodBoolean>;
        }, "strip", z.ZodTypeAny, {
            type: "number";
            range: [number, number];
            errorMsg?: string | undefined;
            isInteger?: boolean | undefined;
        }, {
            type: "number";
            range: [number, number];
            errorMsg?: string | undefined;
            isInteger?: boolean | undefined;
        }>, z.ZodObject<{
            errorMsg: z.ZodOptional<z.ZodString>;
            type: z.ZodLiteral<"string">;
            minLength: z.ZodNumber;
            maxLength: z.ZodNumber;
        }, "strip", z.ZodTypeAny, {
            type: "string";
            minLength: number;
            maxLength: number;
            errorMsg?: string | undefined;
        }, {
            type: "string";
            minLength: number;
            maxLength: number;
            errorMsg?: string | undefined;
        }>, z.ZodObject<{
            errorMsg: z.ZodOptional<z.ZodString>;
            type: z.ZodLiteral<"regex">;
            pattern: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            type: "regex";
            pattern: string;
            errorMsg?: string | undefined;
        }, {
            type: "regex";
            pattern: string;
            errorMsg?: string | undefined;
        }>, z.ZodObject<{
            errorMsg: z.ZodOptional<z.ZodString>;
            type: z.ZodLiteral<"email">;
        }, "strip", z.ZodTypeAny, {
            type: "email";
            errorMsg?: string | undefined;
        }, {
            type: "email";
            errorMsg?: string | undefined;
        }>, z.ZodObject<{
            errorMsg: z.ZodOptional<z.ZodString>;
            type: z.ZodLiteral<"ipv4">;
        }, "strip", z.ZodTypeAny, {
            type: "ipv4";
            errorMsg?: string | undefined;
        }, {
            type: "ipv4";
            errorMsg?: string | undefined;
        }>, z.ZodObject<{
            errorMsg: z.ZodOptional<z.ZodString>;
            type: z.ZodLiteral<"url">;
        }, "strip", z.ZodTypeAny, {
            type: "url";
            errorMsg?: string | undefined;
        }, {
            type: "url";
            errorMsg?: string | undefined;
        }>, z.ZodObject<{
            errorMsg: z.ZodOptional<z.ZodString>;
            type: z.ZodLiteral<"date">;
        }, "strip", z.ZodTypeAny, {
            type: "date";
            errorMsg?: string | undefined;
        }, {
            type: "date";
            errorMsg?: string | undefined;
        }>]>, "many">>;
        defaultValue: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodNumber, z.ZodBoolean]>>;
        options: z.ZodObject<{
            display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
        } & {
            disableSearch: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            createSearchChoice: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            referenceName: z.ZodOptional<z.ZodString>;
            endpointUrl: z.ZodOptional<z.ZodString>;
            allowList: z.ZodOptional<z.ZodString>;
            denyList: z.ZodOptional<z.ZodString>;
            labelField: z.ZodOptional<z.ZodString>;
            valueField: z.ZodOptional<z.ZodString>;
            autoCompleteFields: z.ZodOptional<z.ZodArray<z.ZodUnion<[z.ZodObject<{
                value: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                label: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                value: string | number | boolean;
                label: string;
            }, {
                value: string | number | boolean;
                label: string;
            }>, z.ZodObject<{
                label: z.ZodString;
                children: z.ZodArray<z.ZodObject<{
                    value: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                    label: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    value: string | number | boolean;
                    label: string;
                }, {
                    value: string | number | boolean;
                    label: string;
                }>, "many">;
            }, "strip", z.ZodTypeAny, {
                label: string;
                children: {
                    value: string | number | boolean;
                    label: string;
                }[];
            }, {
                label: string;
                children: {
                    value: string | number | boolean;
                    label: string;
                }[];
            }>]>, "many">>;
            dependencies: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
            items: z.ZodOptional<z.ZodArray<z.ZodObject<{
                value: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                label: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                value: string | number | boolean;
                label: string;
            }, {
                value: string | number | boolean;
                label: string;
            }>, "many">>;
        }, "strip", z.ZodTypeAny, {
            display?: boolean | undefined;
            disableonEdit?: boolean | undefined;
            enable?: boolean | undefined;
            requiredWhenVisible?: boolean | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
            disableSearch?: boolean | undefined;
            createSearchChoice?: boolean | undefined;
            referenceName?: string | undefined;
            endpointUrl?: string | undefined;
            allowList?: string | undefined;
            denyList?: string | undefined;
            labelField?: string | undefined;
            valueField?: string | undefined;
            autoCompleteFields?: ({
                value: string | number | boolean;
                label: string;
            } | {
                label: string;
                children: {
                    value: string | number | boolean;
                    label: string;
                }[];
            })[] | undefined;
            dependencies?: string[] | undefined;
            items?: {
                value: string | number | boolean;
                label: string;
            }[] | undefined;
        }, {
            display?: boolean | undefined;
            disableonEdit?: boolean | undefined;
            enable?: boolean | undefined;
            requiredWhenVisible?: boolean | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
            disableSearch?: boolean | undefined;
            createSearchChoice?: boolean | undefined;
            referenceName?: string | undefined;
            endpointUrl?: string | undefined;
            allowList?: string | undefined;
            denyList?: string | undefined;
            labelField?: string | undefined;
            valueField?: string | undefined;
            autoCompleteFields?: ({
                value: string | number | boolean;
                label: string;
            } | {
                label: string;
                children: {
                    value: string | number | boolean;
                    label: string;
                }[];
            })[] | undefined;
            dependencies?: string[] | undefined;
            items?: {
                value: string | number | boolean;
                label: string;
            }[] | undefined;
        }>;
        modifyFieldsOnValue: z.ZodOptional<z.ZodArray<z.ZodObject<{
            fieldValue: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
            mode: z.ZodOptional<z.ZodEnum<["create", "edit", "config", "clone"]>>;
            fieldsToModify: z.ZodArray<z.ZodObject<{
                fieldId: z.ZodString;
                display: z.ZodOptional<z.ZodBoolean>;
                value: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>>;
                disabled: z.ZodOptional<z.ZodBoolean>;
                required: z.ZodOptional<z.ZodBoolean>;
                help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                    text: z.ZodString;
                    links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        slug: z.ZodString;
                        link: z.ZodString;
                        linkText: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }>, "many">>;
                    link: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }>]>>;
                label: z.ZodOptional<z.ZodString>;
                markdownMessage: z.ZodOptional<z.ZodUnion<[z.ZodObject<{
                    markdownType: z.ZodLiteral<"text">;
                    text: z.ZodString;
                    color: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                }, {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                }>, z.ZodObject<{
                    markdownType: z.ZodLiteral<"hybrid">;
                    text: z.ZodString;
                    token: z.ZodString;
                    linkText: z.ZodString;
                    link: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                }, {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                }>, z.ZodObject<{
                    markdownType: z.ZodLiteral<"link">;
                    text: z.ZodString;
                    link: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    link: string;
                    markdownType: "link";
                }, {
                    text: string;
                    link: string;
                    markdownType: "link";
                }>, z.ZodObject<{
                    markdownType: z.ZodOptional<z.ZodUndefined>;
                    text: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    markdownType?: undefined;
                }, {
                    text: string;
                    markdownType?: undefined;
                }>]>>;
            }, "strip", z.ZodTypeAny, {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }, {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }>, "many">;
        }, "strip", z.ZodTypeAny, {
            fieldValue: string | number | boolean;
            fieldsToModify: {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }[];
            mode?: "clone" | "create" | "edit" | "config" | undefined;
        }, {
            fieldValue: string | number | boolean;
            fieldsToModify: {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }[];
            mode?: "clone" | "create" | "edit" | "config" | undefined;
        }>, "many">>;
    }, "strip", z.ZodTypeAny, {
        options: {
            display?: boolean | undefined;
            disableonEdit?: boolean | undefined;
            enable?: boolean | undefined;
            requiredWhenVisible?: boolean | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
            disableSearch?: boolean | undefined;
            createSearchChoice?: boolean | undefined;
            referenceName?: string | undefined;
            endpointUrl?: string | undefined;
            allowList?: string | undefined;
            denyList?: string | undefined;
            labelField?: string | undefined;
            valueField?: string | undefined;
            autoCompleteFields?: ({
                value: string | number | boolean;
                label: string;
            } | {
                label: string;
                children: {
                    value: string | number | boolean;
                    label: string;
                }[];
            })[] | undefined;
            dependencies?: string[] | undefined;
            items?: {
                value: string | number | boolean;
                label: string;
            }[] | undefined;
        };
        type: "singleSelect";
        label: string;
        field: string;
        help?: string | {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        } | undefined;
        tooltip?: string | undefined;
        required?: boolean | undefined;
        encrypted?: boolean | undefined;
        validators?: ({
            type: "number";
            range: [number, number];
            errorMsg?: string | undefined;
            isInteger?: boolean | undefined;
        } | {
            type: "string";
            minLength: number;
            maxLength: number;
            errorMsg?: string | undefined;
        } | {
            type: "regex";
            pattern: string;
            errorMsg?: string | undefined;
        } | {
            type: "email";
            errorMsg?: string | undefined;
        } | {
            type: "ipv4";
            errorMsg?: string | undefined;
        } | {
            type: "url";
            errorMsg?: string | undefined;
        } | {
            type: "date";
            errorMsg?: string | undefined;
        })[] | undefined;
        defaultValue?: string | number | boolean | undefined;
        modifyFieldsOnValue?: {
            fieldValue: string | number | boolean;
            fieldsToModify: {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }[];
            mode?: "clone" | "create" | "edit" | "config" | undefined;
        }[] | undefined;
    }, {
        options: {
            display?: boolean | undefined;
            disableonEdit?: boolean | undefined;
            enable?: boolean | undefined;
            requiredWhenVisible?: boolean | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
            disableSearch?: boolean | undefined;
            createSearchChoice?: boolean | undefined;
            referenceName?: string | undefined;
            endpointUrl?: string | undefined;
            allowList?: string | undefined;
            denyList?: string | undefined;
            labelField?: string | undefined;
            valueField?: string | undefined;
            autoCompleteFields?: ({
                value: string | number | boolean;
                label: string;
            } | {
                label: string;
                children: {
                    value: string | number | boolean;
                    label: string;
                }[];
            })[] | undefined;
            dependencies?: string[] | undefined;
            items?: {
                value: string | number | boolean;
                label: string;
            }[] | undefined;
        };
        type: "singleSelect";
        label: string;
        field: string;
        help?: string | {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        } | undefined;
        tooltip?: string | undefined;
        required?: boolean | undefined;
        encrypted?: boolean | undefined;
        validators?: ({
            type: "number";
            range: [number, number];
            errorMsg?: string | undefined;
            isInteger?: boolean | undefined;
        } | {
            type: "string";
            minLength: number;
            maxLength: number;
            errorMsg?: string | undefined;
        } | {
            type: "regex";
            pattern: string;
            errorMsg?: string | undefined;
        } | {
            type: "email";
            errorMsg?: string | undefined;
        } | {
            type: "ipv4";
            errorMsg?: string | undefined;
        } | {
            type: "url";
            errorMsg?: string | undefined;
        } | {
            type: "date";
            errorMsg?: string | undefined;
        })[] | undefined;
        defaultValue?: string | number | boolean | undefined;
        modifyFieldsOnValue?: {
            fieldValue: string | number | boolean;
            fieldsToModify: {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }[];
            mode?: "clone" | "create" | "edit" | "config" | undefined;
        }[] | undefined;
    }>, z.ZodObject<{
        field: z.ZodString;
        label: z.ZodString;
        help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
            text: z.ZodString;
            links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                slug: z.ZodString;
                link: z.ZodString;
                linkText: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                slug: string;
                link: string;
                linkText: string;
            }, {
                slug: string;
                link: string;
                linkText: string;
            }>, "many">>;
            link: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        }, {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        }>]>>;
        tooltip: z.ZodOptional<z.ZodString>;
        required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
        encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
    } & {
        type: z.ZodLiteral<"checkbox">;
        defaultValue: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodBoolean]>>;
        options: z.ZodOptional<z.ZodObject<{
            display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
        }, "strip", z.ZodTypeAny, {
            display?: boolean | undefined;
            disableonEdit?: boolean | undefined;
            enable?: boolean | undefined;
            requiredWhenVisible?: boolean | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
        }, {
            display?: boolean | undefined;
            disableonEdit?: boolean | undefined;
            enable?: boolean | undefined;
            requiredWhenVisible?: boolean | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
        }>>;
        modifyFieldsOnValue: z.ZodOptional<z.ZodArray<z.ZodObject<{
            fieldValue: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
            mode: z.ZodOptional<z.ZodEnum<["create", "edit", "config", "clone"]>>;
            fieldsToModify: z.ZodArray<z.ZodObject<{
                fieldId: z.ZodString;
                display: z.ZodOptional<z.ZodBoolean>;
                value: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>>;
                disabled: z.ZodOptional<z.ZodBoolean>;
                required: z.ZodOptional<z.ZodBoolean>;
                help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                    text: z.ZodString;
                    links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        slug: z.ZodString;
                        link: z.ZodString;
                        linkText: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }>, "many">>;
                    link: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }>]>>;
                label: z.ZodOptional<z.ZodString>;
                markdownMessage: z.ZodOptional<z.ZodUnion<[z.ZodObject<{
                    markdownType: z.ZodLiteral<"text">;
                    text: z.ZodString;
                    color: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                }, {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                }>, z.ZodObject<{
                    markdownType: z.ZodLiteral<"hybrid">;
                    text: z.ZodString;
                    token: z.ZodString;
                    linkText: z.ZodString;
                    link: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                }, {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                }>, z.ZodObject<{
                    markdownType: z.ZodLiteral<"link">;
                    text: z.ZodString;
                    link: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    link: string;
                    markdownType: "link";
                }, {
                    text: string;
                    link: string;
                    markdownType: "link";
                }>, z.ZodObject<{
                    markdownType: z.ZodOptional<z.ZodUndefined>;
                    text: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    markdownType?: undefined;
                }, {
                    text: string;
                    markdownType?: undefined;
                }>]>>;
            }, "strip", z.ZodTypeAny, {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }, {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }>, "many">;
        }, "strip", z.ZodTypeAny, {
            fieldValue: string | number | boolean;
            fieldsToModify: {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }[];
            mode?: "clone" | "create" | "edit" | "config" | undefined;
        }, {
            fieldValue: string | number | boolean;
            fieldsToModify: {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }[];
            mode?: "clone" | "create" | "edit" | "config" | undefined;
        }>, "many">>;
    }, "strip", z.ZodTypeAny, {
        type: "checkbox";
        label: string;
        field: string;
        options?: {
            display?: boolean | undefined;
            disableonEdit?: boolean | undefined;
            enable?: boolean | undefined;
            requiredWhenVisible?: boolean | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
        } | undefined;
        help?: string | {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        } | undefined;
        tooltip?: string | undefined;
        required?: boolean | undefined;
        encrypted?: boolean | undefined;
        defaultValue?: number | boolean | undefined;
        modifyFieldsOnValue?: {
            fieldValue: string | number | boolean;
            fieldsToModify: {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }[];
            mode?: "clone" | "create" | "edit" | "config" | undefined;
        }[] | undefined;
    }, {
        type: "checkbox";
        label: string;
        field: string;
        options?: {
            display?: boolean | undefined;
            disableonEdit?: boolean | undefined;
            enable?: boolean | undefined;
            requiredWhenVisible?: boolean | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
        } | undefined;
        help?: string | {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        } | undefined;
        tooltip?: string | undefined;
        required?: boolean | undefined;
        encrypted?: boolean | undefined;
        defaultValue?: number | boolean | undefined;
        modifyFieldsOnValue?: {
            fieldValue: string | number | boolean;
            fieldsToModify: {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }[];
            mode?: "clone" | "create" | "edit" | "config" | undefined;
        }[] | undefined;
    }>, z.ZodObject<{
        field: z.ZodString;
        label: z.ZodString;
        help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
            text: z.ZodString;
            links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                slug: z.ZodString;
                link: z.ZodString;
                linkText: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                slug: string;
                link: string;
                linkText: string;
            }, {
                slug: string;
                link: string;
                linkText: string;
            }>, "many">>;
            link: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        }, {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        }>]>>;
        tooltip: z.ZodOptional<z.ZodString>;
        required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
        encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
    } & {
        type: z.ZodLiteral<"radio">;
        defaultValue: z.ZodOptional<z.ZodString>;
        options: z.ZodObject<{
            display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
        } & {
            items: z.ZodArray<z.ZodObject<{
                value: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                label: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                value: string | number | boolean;
                label: string;
            }, {
                value: string | number | boolean;
                label: string;
            }>, "many">;
        }, "strip", z.ZodTypeAny, {
            items: {
                value: string | number | boolean;
                label: string;
            }[];
            display?: boolean | undefined;
            disableonEdit?: boolean | undefined;
            enable?: boolean | undefined;
            requiredWhenVisible?: boolean | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
        }, {
            items: {
                value: string | number | boolean;
                label: string;
            }[];
            display?: boolean | undefined;
            disableonEdit?: boolean | undefined;
            enable?: boolean | undefined;
            requiredWhenVisible?: boolean | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
        }>;
        modifyFieldsOnValue: z.ZodOptional<z.ZodArray<z.ZodObject<{
            fieldValue: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
            mode: z.ZodOptional<z.ZodEnum<["create", "edit", "config", "clone"]>>;
            fieldsToModify: z.ZodArray<z.ZodObject<{
                fieldId: z.ZodString;
                display: z.ZodOptional<z.ZodBoolean>;
                value: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>>;
                disabled: z.ZodOptional<z.ZodBoolean>;
                required: z.ZodOptional<z.ZodBoolean>;
                help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                    text: z.ZodString;
                    links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        slug: z.ZodString;
                        link: z.ZodString;
                        linkText: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }>, "many">>;
                    link: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }>]>>;
                label: z.ZodOptional<z.ZodString>;
                markdownMessage: z.ZodOptional<z.ZodUnion<[z.ZodObject<{
                    markdownType: z.ZodLiteral<"text">;
                    text: z.ZodString;
                    color: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                }, {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                }>, z.ZodObject<{
                    markdownType: z.ZodLiteral<"hybrid">;
                    text: z.ZodString;
                    token: z.ZodString;
                    linkText: z.ZodString;
                    link: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                }, {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                }>, z.ZodObject<{
                    markdownType: z.ZodLiteral<"link">;
                    text: z.ZodString;
                    link: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    link: string;
                    markdownType: "link";
                }, {
                    text: string;
                    link: string;
                    markdownType: "link";
                }>, z.ZodObject<{
                    markdownType: z.ZodOptional<z.ZodUndefined>;
                    text: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    markdownType?: undefined;
                }, {
                    text: string;
                    markdownType?: undefined;
                }>]>>;
            }, "strip", z.ZodTypeAny, {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }, {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }>, "many">;
        }, "strip", z.ZodTypeAny, {
            fieldValue: string | number | boolean;
            fieldsToModify: {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }[];
            mode?: "clone" | "create" | "edit" | "config" | undefined;
        }, {
            fieldValue: string | number | boolean;
            fieldsToModify: {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }[];
            mode?: "clone" | "create" | "edit" | "config" | undefined;
        }>, "many">>;
    }, "strip", z.ZodTypeAny, {
        options: {
            items: {
                value: string | number | boolean;
                label: string;
            }[];
            display?: boolean | undefined;
            disableonEdit?: boolean | undefined;
            enable?: boolean | undefined;
            requiredWhenVisible?: boolean | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
        };
        type: "radio";
        label: string;
        field: string;
        help?: string | {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        } | undefined;
        tooltip?: string | undefined;
        required?: boolean | undefined;
        encrypted?: boolean | undefined;
        defaultValue?: string | undefined;
        modifyFieldsOnValue?: {
            fieldValue: string | number | boolean;
            fieldsToModify: {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }[];
            mode?: "clone" | "create" | "edit" | "config" | undefined;
        }[] | undefined;
    }, {
        options: {
            items: {
                value: string | number | boolean;
                label: string;
            }[];
            display?: boolean | undefined;
            disableonEdit?: boolean | undefined;
            enable?: boolean | undefined;
            requiredWhenVisible?: boolean | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
        };
        type: "radio";
        label: string;
        field: string;
        help?: string | {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        } | undefined;
        tooltip?: string | undefined;
        required?: boolean | undefined;
        encrypted?: boolean | undefined;
        defaultValue?: string | undefined;
        modifyFieldsOnValue?: {
            fieldValue: string | number | boolean;
            fieldsToModify: {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }[];
            mode?: "clone" | "create" | "edit" | "config" | undefined;
        }[] | undefined;
    }>, z.ZodObject<{
        field: z.ZodString;
        label: z.ZodString;
        help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
            text: z.ZodString;
            links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                slug: z.ZodString;
                link: z.ZodString;
                linkText: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                slug: string;
                link: string;
                linkText: string;
            }, {
                slug: string;
                link: string;
                linkText: string;
            }>, "many">>;
            link: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        }, {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        }>]>>;
        tooltip: z.ZodOptional<z.ZodString>;
    } & {
        type: z.ZodLiteral<"singleSelectSplunkSearch">;
        defaultValue: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodNumber, z.ZodBoolean]>>;
        search: z.ZodOptional<z.ZodString>;
        valueField: z.ZodOptional<z.ZodString>;
        labelField: z.ZodOptional<z.ZodString>;
        options: z.ZodOptional<z.ZodObject<{
            items: z.ZodArray<z.ZodObject<{
                value: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                label: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                value: string | number | boolean;
                label: string;
            }, {
                value: string | number | boolean;
                label: string;
            }>, "many">;
        }, "strip", z.ZodTypeAny, {
            items: {
                value: string | number | boolean;
                label: string;
            }[];
        }, {
            items: {
                value: string | number | boolean;
                label: string;
            }[];
        }>>;
    }, "strip", z.ZodTypeAny, {
        type: "singleSelectSplunkSearch";
        label: string;
        field: string;
        options?: {
            items: {
                value: string | number | boolean;
                label: string;
            }[];
        } | undefined;
        help?: string | {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        } | undefined;
        tooltip?: string | undefined;
        defaultValue?: string | number | boolean | undefined;
        labelField?: string | undefined;
        valueField?: string | undefined;
        search?: string | undefined;
    }, {
        type: "singleSelectSplunkSearch";
        label: string;
        field: string;
        options?: {
            items: {
                value: string | number | boolean;
                label: string;
            }[];
        } | undefined;
        help?: string | {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        } | undefined;
        tooltip?: string | undefined;
        defaultValue?: string | number | boolean | undefined;
        labelField?: string | undefined;
        valueField?: string | undefined;
        search?: string | undefined;
    }>]>, "many">>;
}, "strip", z.ZodTypeAny, {
    name: string;
    label: string;
    description: string;
    entity?: ({
        type: "text";
        label: string;
        field: string;
        options?: {
            display?: boolean | undefined;
            disableonEdit?: boolean | undefined;
            enable?: boolean | undefined;
            requiredWhenVisible?: boolean | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
        } | undefined;
        help?: string | {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        } | undefined;
        tooltip?: string | undefined;
        required?: boolean | undefined;
        encrypted?: boolean | undefined;
        validators?: ({
            type: "number";
            range: [number, number];
            errorMsg?: string | undefined;
            isInteger?: boolean | undefined;
        } | {
            type: "string";
            minLength: number;
            maxLength: number;
            errorMsg?: string | undefined;
        } | {
            type: "regex";
            pattern: string;
            errorMsg?: string | undefined;
        } | {
            type: "email";
            errorMsg?: string | undefined;
        } | {
            type: "ipv4";
            errorMsg?: string | undefined;
        } | {
            type: "url";
            errorMsg?: string | undefined;
        } | {
            type: "date";
            errorMsg?: string | undefined;
        })[] | undefined;
        defaultValue?: string | number | boolean | undefined;
        modifyFieldsOnValue?: {
            fieldValue: string | number | boolean;
            fieldsToModify: {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }[];
            mode?: "clone" | "create" | "edit" | "config" | undefined;
        }[] | undefined;
    } | {
        type: "textarea";
        label: string;
        field: string;
        options?: {
            display?: boolean | undefined;
            disableonEdit?: boolean | undefined;
            enable?: boolean | undefined;
            requiredWhenVisible?: boolean | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
            rowsMin?: number | undefined;
            rowsMax?: number | undefined;
        } | undefined;
        help?: string | {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        } | undefined;
        tooltip?: string | undefined;
        required?: boolean | undefined;
        encrypted?: boolean | undefined;
        validators?: ({
            type: "number";
            range: [number, number];
            errorMsg?: string | undefined;
            isInteger?: boolean | undefined;
        } | {
            type: "string";
            minLength: number;
            maxLength: number;
            errorMsg?: string | undefined;
        } | {
            type: "regex";
            pattern: string;
            errorMsg?: string | undefined;
        } | {
            type: "email";
            errorMsg?: string | undefined;
        } | {
            type: "ipv4";
            errorMsg?: string | undefined;
        } | {
            type: "url";
            errorMsg?: string | undefined;
        } | {
            type: "date";
            errorMsg?: string | undefined;
        })[] | undefined;
        defaultValue?: string | undefined;
        modifyFieldsOnValue?: {
            fieldValue: string | number | boolean;
            fieldsToModify: {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }[];
            mode?: "clone" | "create" | "edit" | "config" | undefined;
        }[] | undefined;
    } | {
        options: {
            display?: boolean | undefined;
            disableonEdit?: boolean | undefined;
            enable?: boolean | undefined;
            requiredWhenVisible?: boolean | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
            disableSearch?: boolean | undefined;
            createSearchChoice?: boolean | undefined;
            referenceName?: string | undefined;
            endpointUrl?: string | undefined;
            allowList?: string | undefined;
            denyList?: string | undefined;
            labelField?: string | undefined;
            valueField?: string | undefined;
            autoCompleteFields?: ({
                value: string | number | boolean;
                label: string;
            } | {
                label: string;
                children: {
                    value: string | number | boolean;
                    label: string;
                }[];
            })[] | undefined;
            dependencies?: string[] | undefined;
            items?: {
                value: string | number | boolean;
                label: string;
            }[] | undefined;
        };
        type: "singleSelect";
        label: string;
        field: string;
        help?: string | {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        } | undefined;
        tooltip?: string | undefined;
        required?: boolean | undefined;
        encrypted?: boolean | undefined;
        validators?: ({
            type: "number";
            range: [number, number];
            errorMsg?: string | undefined;
            isInteger?: boolean | undefined;
        } | {
            type: "string";
            minLength: number;
            maxLength: number;
            errorMsg?: string | undefined;
        } | {
            type: "regex";
            pattern: string;
            errorMsg?: string | undefined;
        } | {
            type: "email";
            errorMsg?: string | undefined;
        } | {
            type: "ipv4";
            errorMsg?: string | undefined;
        } | {
            type: "url";
            errorMsg?: string | undefined;
        } | {
            type: "date";
            errorMsg?: string | undefined;
        })[] | undefined;
        defaultValue?: string | number | boolean | undefined;
        modifyFieldsOnValue?: {
            fieldValue: string | number | boolean;
            fieldsToModify: {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }[];
            mode?: "clone" | "create" | "edit" | "config" | undefined;
        }[] | undefined;
    } | {
        type: "checkbox";
        label: string;
        field: string;
        options?: {
            display?: boolean | undefined;
            disableonEdit?: boolean | undefined;
            enable?: boolean | undefined;
            requiredWhenVisible?: boolean | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
        } | undefined;
        help?: string | {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        } | undefined;
        tooltip?: string | undefined;
        required?: boolean | undefined;
        encrypted?: boolean | undefined;
        defaultValue?: number | boolean | undefined;
        modifyFieldsOnValue?: {
            fieldValue: string | number | boolean;
            fieldsToModify: {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }[];
            mode?: "clone" | "create" | "edit" | "config" | undefined;
        }[] | undefined;
    } | {
        options: {
            items: {
                value: string | number | boolean;
                label: string;
            }[];
            display?: boolean | undefined;
            disableonEdit?: boolean | undefined;
            enable?: boolean | undefined;
            requiredWhenVisible?: boolean | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
        };
        type: "radio";
        label: string;
        field: string;
        help?: string | {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        } | undefined;
        tooltip?: string | undefined;
        required?: boolean | undefined;
        encrypted?: boolean | undefined;
        defaultValue?: string | undefined;
        modifyFieldsOnValue?: {
            fieldValue: string | number | boolean;
            fieldsToModify: {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }[];
            mode?: "clone" | "create" | "edit" | "config" | undefined;
        }[] | undefined;
    } | {
        type: "singleSelectSplunkSearch";
        label: string;
        field: string;
        options?: {
            items: {
                value: string | number | boolean;
                label: string;
            }[];
        } | undefined;
        help?: string | {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        } | undefined;
        tooltip?: string | undefined;
        defaultValue?: string | number | boolean | undefined;
        labelField?: string | undefined;
        valueField?: string | undefined;
        search?: string | undefined;
    })[] | undefined;
    adaptiveResponse?: {
        task: string[];
        supportsAdhoc: boolean;
        supportsCloud: boolean;
        subject: string[];
        category: string[];
        technology: {
            version: string[];
            product: string;
            vendor: string;
        }[];
        drilldownUri?: string | undefined;
        sourcetype?: string | undefined;
    } | undefined;
}, {
    name: string;
    label: string;
    description: string;
    entity?: ({
        type: "text";
        label: string;
        field: string;
        options?: {
            display?: boolean | undefined;
            disableonEdit?: boolean | undefined;
            enable?: boolean | undefined;
            requiredWhenVisible?: boolean | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
        } | undefined;
        help?: string | {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        } | undefined;
        tooltip?: string | undefined;
        required?: boolean | undefined;
        encrypted?: boolean | undefined;
        validators?: ({
            type: "number";
            range: [number, number];
            errorMsg?: string | undefined;
            isInteger?: boolean | undefined;
        } | {
            type: "string";
            minLength: number;
            maxLength: number;
            errorMsg?: string | undefined;
        } | {
            type: "regex";
            pattern: string;
            errorMsg?: string | undefined;
        } | {
            type: "email";
            errorMsg?: string | undefined;
        } | {
            type: "ipv4";
            errorMsg?: string | undefined;
        } | {
            type: "url";
            errorMsg?: string | undefined;
        } | {
            type: "date";
            errorMsg?: string | undefined;
        })[] | undefined;
        defaultValue?: string | number | boolean | undefined;
        modifyFieldsOnValue?: {
            fieldValue: string | number | boolean;
            fieldsToModify: {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }[];
            mode?: "clone" | "create" | "edit" | "config" | undefined;
        }[] | undefined;
    } | {
        type: "textarea";
        label: string;
        field: string;
        options?: {
            display?: boolean | undefined;
            disableonEdit?: boolean | undefined;
            enable?: boolean | undefined;
            requiredWhenVisible?: boolean | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
            rowsMin?: number | undefined;
            rowsMax?: number | undefined;
        } | undefined;
        help?: string | {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        } | undefined;
        tooltip?: string | undefined;
        required?: boolean | undefined;
        encrypted?: boolean | undefined;
        validators?: ({
            type: "number";
            range: [number, number];
            errorMsg?: string | undefined;
            isInteger?: boolean | undefined;
        } | {
            type: "string";
            minLength: number;
            maxLength: number;
            errorMsg?: string | undefined;
        } | {
            type: "regex";
            pattern: string;
            errorMsg?: string | undefined;
        } | {
            type: "email";
            errorMsg?: string | undefined;
        } | {
            type: "ipv4";
            errorMsg?: string | undefined;
        } | {
            type: "url";
            errorMsg?: string | undefined;
        } | {
            type: "date";
            errorMsg?: string | undefined;
        })[] | undefined;
        defaultValue?: string | undefined;
        modifyFieldsOnValue?: {
            fieldValue: string | number | boolean;
            fieldsToModify: {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }[];
            mode?: "clone" | "create" | "edit" | "config" | undefined;
        }[] | undefined;
    } | {
        options: {
            display?: boolean | undefined;
            disableonEdit?: boolean | undefined;
            enable?: boolean | undefined;
            requiredWhenVisible?: boolean | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
            disableSearch?: boolean | undefined;
            createSearchChoice?: boolean | undefined;
            referenceName?: string | undefined;
            endpointUrl?: string | undefined;
            allowList?: string | undefined;
            denyList?: string | undefined;
            labelField?: string | undefined;
            valueField?: string | undefined;
            autoCompleteFields?: ({
                value: string | number | boolean;
                label: string;
            } | {
                label: string;
                children: {
                    value: string | number | boolean;
                    label: string;
                }[];
            })[] | undefined;
            dependencies?: string[] | undefined;
            items?: {
                value: string | number | boolean;
                label: string;
            }[] | undefined;
        };
        type: "singleSelect";
        label: string;
        field: string;
        help?: string | {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        } | undefined;
        tooltip?: string | undefined;
        required?: boolean | undefined;
        encrypted?: boolean | undefined;
        validators?: ({
            type: "number";
            range: [number, number];
            errorMsg?: string | undefined;
            isInteger?: boolean | undefined;
        } | {
            type: "string";
            minLength: number;
            maxLength: number;
            errorMsg?: string | undefined;
        } | {
            type: "regex";
            pattern: string;
            errorMsg?: string | undefined;
        } | {
            type: "email";
            errorMsg?: string | undefined;
        } | {
            type: "ipv4";
            errorMsg?: string | undefined;
        } | {
            type: "url";
            errorMsg?: string | undefined;
        } | {
            type: "date";
            errorMsg?: string | undefined;
        })[] | undefined;
        defaultValue?: string | number | boolean | undefined;
        modifyFieldsOnValue?: {
            fieldValue: string | number | boolean;
            fieldsToModify: {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }[];
            mode?: "clone" | "create" | "edit" | "config" | undefined;
        }[] | undefined;
    } | {
        type: "checkbox";
        label: string;
        field: string;
        options?: {
            display?: boolean | undefined;
            disableonEdit?: boolean | undefined;
            enable?: boolean | undefined;
            requiredWhenVisible?: boolean | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
        } | undefined;
        help?: string | {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        } | undefined;
        tooltip?: string | undefined;
        required?: boolean | undefined;
        encrypted?: boolean | undefined;
        defaultValue?: number | boolean | undefined;
        modifyFieldsOnValue?: {
            fieldValue: string | number | boolean;
            fieldsToModify: {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }[];
            mode?: "clone" | "create" | "edit" | "config" | undefined;
        }[] | undefined;
    } | {
        options: {
            items: {
                value: string | number | boolean;
                label: string;
            }[];
            display?: boolean | undefined;
            disableonEdit?: boolean | undefined;
            enable?: boolean | undefined;
            requiredWhenVisible?: boolean | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
        };
        type: "radio";
        label: string;
        field: string;
        help?: string | {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        } | undefined;
        tooltip?: string | undefined;
        required?: boolean | undefined;
        encrypted?: boolean | undefined;
        defaultValue?: string | undefined;
        modifyFieldsOnValue?: {
            fieldValue: string | number | boolean;
            fieldsToModify: {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }[];
            mode?: "clone" | "create" | "edit" | "config" | undefined;
        }[] | undefined;
    } | {
        type: "singleSelectSplunkSearch";
        label: string;
        field: string;
        options?: {
            items: {
                value: string | number | boolean;
                label: string;
            }[];
        } | undefined;
        help?: string | {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        } | undefined;
        tooltip?: string | undefined;
        defaultValue?: string | number | boolean | undefined;
        labelField?: string | undefined;
        valueField?: string | undefined;
        search?: string | undefined;
    })[] | undefined;
    adaptiveResponse?: {
        task: string[];
        supportsAdhoc: boolean;
        supportsCloud: boolean;
        subject: string[];
        category: string[];
        technology: {
            version: string[];
            product: string;
            vendor: string;
        }[];
        drilldownUri?: string | undefined;
        sourcetype?: string | undefined;
    } | undefined;
}>, "many">>;

export declare type AvaillableOAuthTypes = z.TypeOf<typeof OAuthEntity>['options']['auth_type'][number];

export declare interface BaseFormState {
    serviceName?: string;
    mode?: Mode;
    page?: StandardPages;
    stanzaName?: string;
    data: BaseFormStateData;
    errorMsg?: string;
    warningMsg?: string;
    stateModified?: boolean;
}

declare interface BaseFormStateData {
    [x: string]: {
        disabled: boolean;
        error: boolean;
        fileNameToDisplay?: string;
        value?: AcceptableFormValueOrNullish;
        display: boolean;
        markdownMessage?: MarkdownMessageProps;
        dependencyValues?: string;
        modifiedEntitiesData?: {
            help?: string;
            label?: string;
            required?: boolean;
        };
    };
}

declare interface ControlData {
    value: AcceptableFormValueOrNullish;
    mode: Mode;
    serviceName: string;
}

export declare abstract class CustomCellBase {
    protected globalConfig: GlobalConfig;
    protected el: HTMLElement;
    protected row: RowDataFields;
    protected serviceName: string;
    protected field: string;
    constructor(globalConfig: GlobalConfig, serviceName: string, el: HTMLElement, row: RowDataFields, field: string);
    abstract render(): void;
}

declare type CustomCellConstructor<T extends typeof CustomCellBase = typeof CustomCellBase> = new (...args: ConstructorParameters<T>) => CustomCellInstance<T>;

declare type CustomCellInstance<T extends typeof CustomCellBase = typeof CustomCellBase> = InstanceType<T>;

declare type CustomCellStructure = {
    component: CustomCellConstructor;
    type: 'cell';
};

export declare abstract class CustomControlBase {
    protected globalConfig: GlobalConfig;
    protected el: HTMLElement;
    protected data: ControlData;
    protected setValue: ValueSetter;
    protected util: UtilBaseForm;
    constructor(globalConfig: GlobalConfig, el: HTMLElement, data: ControlData, setValue: ValueSetter, util: UtilBaseForm);
    abstract render(): void;
    validation?(field: string, value: ControlData['value']): string | undefined;
}

declare type CustomControlConstructor<T extends typeof CustomControlBase = typeof CustomControlBase> = new (...args: ConstructorParameters<T>) => CustomControlInstance<T>;

declare type CustomControlInstance<T extends typeof CustomControlBase = typeof CustomControlBase> = InstanceType<T>;

declare type CustomControlStructure = {
    component: CustomControlConstructor;
    type: 'control';
};

declare type CustomElementsMap = Record<string, CustomHookStructure | CustomControlStructure | CustomRowStructure | CustomCellStructure | CustomMenuStructure | CustomTabStructure>;

export declare abstract class CustomHookBase {
    protected globalConfig: GlobalConfig;
    protected serviceName: string;
    protected state: BaseFormState;
    protected mode: Mode;
    protected util: UtilBaseForm;
    protected groupName?: string;
    constructor(globalConfig: GlobalConfig, serviceName: string, state: BaseFormState, mode: Mode, util: UtilBaseForm, groupName?: string);
    onCreate?(): void;
    onRender?(): void;
    onChange?(field: string, targetValue: AcceptableFormValueOrNullish, tempState: BaseFormState): void;
    onEditLoad?(): void;
    onSave?(datadict?: NullishFormRecord): Promise<boolean> | boolean;
    onSaveSuccess?(): void;
    onSaveFail?(): void;
}

declare type CustomHookConstructor<T extends typeof CustomHookBase = typeof CustomHookBase> = new (...args: ConstructorParameters<T>) => CustomHookInstance<T>;

declare type CustomHookInstance<T extends typeof CustomHookBase = typeof CustomHookBase> = InstanceType<T>;

declare type CustomHookStructure = {
    component: CustomHookConstructor;
    type: 'hook';
};

export declare abstract class CustomMenuBase {
    protected globalConfig: GlobalConfig;
    protected el: HTMLElement;
    protected setValue: (val: {
        service: string;
        input?: string;
    }) => void;
    constructor(globalConfig: GlobalConfig, el: HTMLElement, setValue: (val: {
        service: string;
        input?: string;
    }) => void);
    abstract render(): void;
}

declare type CustomMenuConstructor<T extends typeof CustomMenuBase = typeof CustomMenuBase> = new (...args: ConstructorParameters<T>) => CustomMenuInstance<T>;

declare type CustomMenuInstance<T extends typeof CustomMenuBase = typeof CustomMenuBase> = InstanceType<T>;

declare type CustomMenuStructure = {
    component: CustomMenuConstructor;
    type: 'menu';
};

export declare abstract class CustomRowBase {
    protected globalConfig: GlobalConfig;
    protected el: HTMLElement | null;
    protected row: RowDataFields;
    protected serviceName: string;
    constructor(globalConfig: GlobalConfig, serviceName: string, el: HTMLElement | null, row: RowDataFields);
    abstract render(): void;
    abstract getDLRows(): RowDataFields;
}

declare type CustomRowConstructor<T extends typeof CustomRowBase = typeof CustomRowBase> = new (...args: ConstructorParameters<T>) => CustomRowInstance<T>;

declare type CustomRowInstance<T extends typeof CustomRowBase = typeof CustomRowBase> = InstanceType<T>;

declare type CustomRowStructure = {
    component: CustomRowConstructor;
    type: 'row';
};

export declare abstract class CustomTabBase {
    protected tab: Tab;
    protected el: HTMLDivElement;
    constructor(tab: Tab, el: HTMLDivElement);
    abstract render(): void;
}

declare type CustomTabConstructor<T extends typeof CustomTabBase = typeof CustomTabBase> = new (...args: ConstructorParameters<T>) => CustomTabInstance<T>;

declare type CustomTabInstance<T extends typeof CustomTabBase = typeof CustomTabBase> = InstanceType<T>;

declare type CustomTabStructure = {
    component: CustomTabConstructor;
    type: 'tab';
};

/**
 * Custom validator function.
 * @param submittedField  the field name of the form field.
 * @param submittedValue  the value of the form field.
 * @returns  a string if the validation fails, otherwise undefined.
 */
declare type CustomValidatorFunc = (submittedField: string, submittedValue: AcceptableFormValueOrNullish) => string | boolean | undefined;

export declare type GlobalConfig = z.infer<typeof GlobalConfigSchema>;

declare const GlobalConfigSchema: z.ZodObject<{
    meta: IMetaRT;
    pages: IPagesRT;
    alerts: IAlertsRT;
}, "strip", z.ZodTypeAny, {
    meta: {
        displayName: string;
        name: string;
        restRoot: string;
        version: string;
        apiVersion?: string | undefined;
        schemaVersion?: string | undefined;
        _uccVersion?: string | undefined;
        hideUCCVersion?: boolean | undefined;
        checkForUpdates?: boolean | undefined;
        searchViewDefault?: boolean | undefined;
        isVisible?: boolean | undefined;
        supportedThemes?: string[] | undefined;
    };
    pages: {
        configuration?: {
            title: string;
            tabs: {
                name: string;
                title: string;
                options?: {
                    saveValidator?: string | undefined;
                } | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
                groups?: {
                    label: string;
                    fields: string[];
                    options?: {
                        isExpandable?: boolean | undefined;
                        expand?: boolean | undefined;
                    } | undefined;
                }[] | undefined;
                entity?: ({
                    type: "helpLink";
                    field: string;
                    options?: {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    } | undefined;
                    label?: string | undefined;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    tooltip?: string | undefined;
                    required?: false | undefined;
                } | {
                    type: "text";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    } | undefined;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: [number, number];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | {
                                text: string;
                                link?: string | undefined;
                                links?: {
                                    slug: string;
                                    link: string;
                                    linkText: string;
                                }[] | undefined;
                            } | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                text: string;
                                markdownType: "text";
                                color?: string | undefined;
                            } | {
                                text: string;
                                link: string;
                                linkText: string;
                                markdownType: "hybrid";
                                token: string;
                            } | {
                                text: string;
                                link: string;
                                markdownType: "link";
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    type: "textarea";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        rowsMin?: number | undefined;
                        rowsMax?: number | undefined;
                    } | undefined;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: [number, number];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | {
                                text: string;
                                link?: string | undefined;
                                links?: {
                                    slug: string;
                                    link: string;
                                    linkText: string;
                                }[] | undefined;
                            } | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                text: string;
                                markdownType: "text";
                                color?: string | undefined;
                            } | {
                                text: string;
                                link: string;
                                linkText: string;
                                markdownType: "hybrid";
                                token: string;
                            } | {
                                text: string;
                                link: string;
                                markdownType: "link";
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        disableSearch?: boolean | undefined;
                        createSearchChoice?: boolean | undefined;
                        referenceName?: string | undefined;
                        endpointUrl?: string | undefined;
                        allowList?: string | undefined;
                        denyList?: string | undefined;
                        labelField?: string | undefined;
                        valueField?: string | undefined;
                        autoCompleteFields?: ({
                            value: string | number | boolean;
                            label: string;
                        } | {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        })[] | undefined;
                        dependencies?: string[] | undefined;
                        items?: {
                            value: string | number | boolean;
                            label: string;
                        }[] | undefined;
                    };
                    type: "singleSelect";
                    label: string;
                    field: string;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: [number, number];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | {
                                text: string;
                                link?: string | undefined;
                                links?: {
                                    slug: string;
                                    link: string;
                                    linkText: string;
                                }[] | undefined;
                            } | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                text: string;
                                markdownType: "text";
                                color?: string | undefined;
                            } | {
                                text: string;
                                link: string;
                                linkText: string;
                                markdownType: "hybrid";
                                token: string;
                            } | {
                                text: string;
                                link: string;
                                markdownType: "link";
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        disableSearch?: boolean | undefined;
                        createSearchChoice?: boolean | undefined;
                        referenceName?: string | undefined;
                        endpointUrl?: string | undefined;
                        allowList?: string | undefined;
                        denyList?: string | undefined;
                        labelField?: string | undefined;
                        valueField?: string | undefined;
                        autoCompleteFields?: ({
                            value: string | number | boolean;
                            label: string;
                        } | {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        })[] | undefined;
                        dependencies?: string[] | undefined;
                        items?: {
                            value: string | number | boolean;
                            label: string;
                        }[] | undefined;
                        delimiter?: string | undefined;
                    };
                    type: "multipleSelect";
                    label: string;
                    field: string;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: [number, number];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | {
                                text: string;
                                link?: string | undefined;
                                links?: {
                                    slug: string;
                                    link: string;
                                    linkText: string;
                                }[] | undefined;
                            } | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                text: string;
                                markdownType: "text";
                                color?: string | undefined;
                            } | {
                                text: string;
                                link: string;
                                linkText: string;
                                markdownType: "hybrid";
                                token: string;
                            } | {
                                text: string;
                                link: string;
                                markdownType: "link";
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    type: "checkbox";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    } | undefined;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    defaultValue?: number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | {
                                text: string;
                                link?: string | undefined;
                                links?: {
                                    slug: string;
                                    link: string;
                                    linkText: string;
                                }[] | undefined;
                            } | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                text: string;
                                markdownType: "text";
                                color?: string | undefined;
                            } | {
                                text: string;
                                link: string;
                                linkText: string;
                                markdownType: "hybrid";
                                token: string;
                            } | {
                                text: string;
                                link: string;
                                markdownType: "link";
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        rows: {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                            input?: {
                                required?: boolean | undefined;
                                validators?: [{
                                    type: "number";
                                    range: [number, number];
                                    errorMsg?: string | undefined;
                                    isInteger?: boolean | undefined;
                                }] | undefined;
                                defaultValue?: number | undefined;
                            } | undefined;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        delimiter?: string | undefined;
                        groups?: {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }[] | undefined;
                    };
                    type: "checkboxGroup";
                    label: string;
                    field: string;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: [{
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }] | undefined;
                    defaultValue?: number | boolean | undefined;
                } | {
                    options: {
                        rows: {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        delimiter?: string | undefined;
                        groups?: {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }[] | undefined;
                    };
                    type: "checkboxTree";
                    label: string;
                    field: string;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: [{
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }] | undefined;
                    defaultValue?: number | boolean | undefined;
                } | {
                    options: {
                        items: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "radio";
                    label: string;
                    field: string;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | {
                                text: string;
                                link?: string | undefined;
                                links?: {
                                    slug: string;
                                    link: string;
                                    linkText: string;
                                }[] | undefined;
                            } | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                text: string;
                                markdownType: "text";
                                color?: string | undefined;
                            } | {
                                text: string;
                                link: string;
                                linkText: string;
                                markdownType: "hybrid";
                                token: string;
                            } | {
                                text: string;
                                link: string;
                                markdownType: "link";
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    type: "file";
                    label: string;
                    field: string;
                    options?: {
                        supportedFileTypes: string[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        maxFileSize?: number | undefined;
                        fileSupportMessage?: string | undefined;
                        useBase64Encoding?: boolean | undefined;
                    } | undefined;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | {
                                text: string;
                                link?: string | undefined;
                                links?: {
                                    slug: string;
                                    link: string;
                                    linkText: string;
                                }[] | undefined;
                            } | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                text: string;
                                markdownType: "text";
                                color?: string | undefined;
                            } | {
                                text: string;
                                link: string;
                                linkText: string;
                                markdownType: "hybrid";
                                token: string;
                            } | {
                                text: string;
                                link: string;
                                markdownType: "link";
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        auth_type: ("oauth" | "basic" | "oauth_client_credentials")[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        oauth?: {
                            label: string;
                            field: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            help?: string | {
                                text: string;
                                link?: string | undefined;
                                links?: {
                                    slug: string;
                                    link: string;
                                    linkText: string;
                                }[] | undefined;
                            } | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: [number, number];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | {
                                        text: string;
                                        link?: string | undefined;
                                        links?: {
                                            slug: string;
                                            link: string;
                                            linkText: string;
                                        }[] | undefined;
                                    } | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        text: string;
                                        markdownType: "text";
                                        color?: string | undefined;
                                    } | {
                                        text: string;
                                        link: string;
                                        linkText: string;
                                        markdownType: "hybrid";
                                        token: string;
                                    } | {
                                        text: string;
                                        link: string;
                                        markdownType: "link";
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }[] | undefined;
                        basic?: {
                            label: string;
                            field: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            help?: string | {
                                text: string;
                                link?: string | undefined;
                                links?: {
                                    slug: string;
                                    link: string;
                                    linkText: string;
                                }[] | undefined;
                            } | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: [number, number];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | {
                                        text: string;
                                        link?: string | undefined;
                                        links?: {
                                            slug: string;
                                            link: string;
                                            linkText: string;
                                        }[] | undefined;
                                    } | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        text: string;
                                        markdownType: "text";
                                        color?: string | undefined;
                                    } | {
                                        text: string;
                                        link: string;
                                        linkText: string;
                                        markdownType: "hybrid";
                                        token: string;
                                    } | {
                                        text: string;
                                        link: string;
                                        markdownType: "link";
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }[] | undefined;
                        oauth_client_credentials?: {
                            label: string;
                            field: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            help?: string | {
                                text: string;
                                link?: string | undefined;
                                links?: {
                                    slug: string;
                                    link: string;
                                    linkText: string;
                                }[] | undefined;
                            } | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: [number, number];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | {
                                        text: string;
                                        link?: string | undefined;
                                        links?: {
                                            slug: string;
                                            link: string;
                                            linkText: string;
                                        }[] | undefined;
                                    } | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        text: string;
                                        markdownType: "text";
                                        color?: string | undefined;
                                    } | {
                                        text: string;
                                        link: string;
                                        linkText: string;
                                        markdownType: "hybrid";
                                        token: string;
                                    } | {
                                        text: string;
                                        link: string;
                                        markdownType: "link";
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }[] | undefined;
                        auth_label?: string | undefined;
                        oauth_popup_width?: number | undefined;
                        oauth_popup_height?: number | undefined;
                        oauth_timeout?: number | undefined;
                        auth_code_endpoint?: string | undefined;
                        access_token_endpoint?: string | undefined;
                        oauth_state_enabled?: boolean | undefined;
                        auth_endpoint_token_access_type?: string | undefined;
                    };
                    type: "oauth";
                    label: string;
                    field: string;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                } | {
                    options: {
                        type: "external";
                        src: string;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "custom";
                    label: string;
                    field: string;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                })[] | undefined;
                table?: {
                    header: {
                        label: string;
                        field: string;
                        mapping?: Record<string, any> | undefined;
                        customCell?: Record<string, any> | undefined;
                    }[];
                    actions: ("clone" | "delete" | "edit")[];
                    moreInfo?: {
                        label: string;
                        field: string;
                        mapping?: Record<string, any> | undefined;
                    }[] | undefined;
                    customRow?: Record<string, any> | undefined;
                } | undefined;
                style?: "page" | "dialog" | undefined;
                hook?: Record<string, any> | undefined;
                conf?: string | undefined;
                restHandlerName?: string | undefined;
                restHandlerModule?: string | undefined;
                restHandlerClass?: string | undefined;
                customTab?: Record<string, any> | undefined;
                warning?: {
                    clone?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    create?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    edit?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    config?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                } | undefined;
                formTitle?: string | undefined;
            }[];
            description?: string | undefined;
            subDescription?: {
                text: string;
                links?: {
                    slug: string;
                    link: string;
                    linkText: string;
                }[] | undefined;
            } | undefined;
        } | undefined;
        inputs?: {
            title: string;
            services: {
                name: string;
                entity: ({
                    type: "helpLink";
                    field: string;
                    options?: {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    } | undefined;
                    label?: string | undefined;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    tooltip?: string | undefined;
                    required?: false | undefined;
                } | {
                    type: "text";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    } | undefined;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: [number, number];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | {
                                text: string;
                                link?: string | undefined;
                                links?: {
                                    slug: string;
                                    link: string;
                                    linkText: string;
                                }[] | undefined;
                            } | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                text: string;
                                markdownType: "text";
                                color?: string | undefined;
                            } | {
                                text: string;
                                link: string;
                                linkText: string;
                                markdownType: "hybrid";
                                token: string;
                            } | {
                                text: string;
                                link: string;
                                markdownType: "link";
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    type: "textarea";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        rowsMin?: number | undefined;
                        rowsMax?: number | undefined;
                    } | undefined;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: [number, number];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | {
                                text: string;
                                link?: string | undefined;
                                links?: {
                                    slug: string;
                                    link: string;
                                    linkText: string;
                                }[] | undefined;
                            } | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                text: string;
                                markdownType: "text";
                                color?: string | undefined;
                            } | {
                                text: string;
                                link: string;
                                linkText: string;
                                markdownType: "hybrid";
                                token: string;
                            } | {
                                text: string;
                                link: string;
                                markdownType: "link";
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        disableSearch?: boolean | undefined;
                        createSearchChoice?: boolean | undefined;
                        referenceName?: string | undefined;
                        endpointUrl?: string | undefined;
                        allowList?: string | undefined;
                        denyList?: string | undefined;
                        labelField?: string | undefined;
                        valueField?: string | undefined;
                        autoCompleteFields?: ({
                            value: string | number | boolean;
                            label: string;
                        } | {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        })[] | undefined;
                        dependencies?: string[] | undefined;
                        items?: {
                            value: string | number | boolean;
                            label: string;
                        }[] | undefined;
                    };
                    type: "singleSelect";
                    label: string;
                    field: string;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: [number, number];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | {
                                text: string;
                                link?: string | undefined;
                                links?: {
                                    slug: string;
                                    link: string;
                                    linkText: string;
                                }[] | undefined;
                            } | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                text: string;
                                markdownType: "text";
                                color?: string | undefined;
                            } | {
                                text: string;
                                link: string;
                                linkText: string;
                                markdownType: "hybrid";
                                token: string;
                            } | {
                                text: string;
                                link: string;
                                markdownType: "link";
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        disableSearch?: boolean | undefined;
                        createSearchChoice?: boolean | undefined;
                        referenceName?: string | undefined;
                        endpointUrl?: string | undefined;
                        allowList?: string | undefined;
                        denyList?: string | undefined;
                        labelField?: string | undefined;
                        valueField?: string | undefined;
                        autoCompleteFields?: ({
                            value: string | number | boolean;
                            label: string;
                        } | {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        })[] | undefined;
                        dependencies?: string[] | undefined;
                        items?: {
                            value: string | number | boolean;
                            label: string;
                        }[] | undefined;
                        delimiter?: string | undefined;
                    };
                    type: "multipleSelect";
                    label: string;
                    field: string;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: [number, number];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | {
                                text: string;
                                link?: string | undefined;
                                links?: {
                                    slug: string;
                                    link: string;
                                    linkText: string;
                                }[] | undefined;
                            } | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                text: string;
                                markdownType: "text";
                                color?: string | undefined;
                            } | {
                                text: string;
                                link: string;
                                linkText: string;
                                markdownType: "hybrid";
                                token: string;
                            } | {
                                text: string;
                                link: string;
                                markdownType: "link";
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    type: "checkbox";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    } | undefined;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    defaultValue?: number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | {
                                text: string;
                                link?: string | undefined;
                                links?: {
                                    slug: string;
                                    link: string;
                                    linkText: string;
                                }[] | undefined;
                            } | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                text: string;
                                markdownType: "text";
                                color?: string | undefined;
                            } | {
                                text: string;
                                link: string;
                                linkText: string;
                                markdownType: "hybrid";
                                token: string;
                            } | {
                                text: string;
                                link: string;
                                markdownType: "link";
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        rows: {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                            input?: {
                                required?: boolean | undefined;
                                validators?: [{
                                    type: "number";
                                    range: [number, number];
                                    errorMsg?: string | undefined;
                                    isInteger?: boolean | undefined;
                                }] | undefined;
                                defaultValue?: number | undefined;
                            } | undefined;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        delimiter?: string | undefined;
                        groups?: {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }[] | undefined;
                    };
                    type: "checkboxGroup";
                    label: string;
                    field: string;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: [{
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }] | undefined;
                    defaultValue?: number | boolean | undefined;
                } | {
                    options: {
                        rows: {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        delimiter?: string | undefined;
                        groups?: {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }[] | undefined;
                    };
                    type: "checkboxTree";
                    label: string;
                    field: string;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: [{
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }] | undefined;
                    defaultValue?: number | boolean | undefined;
                } | {
                    options: {
                        items: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "radio";
                    label: string;
                    field: string;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | {
                                text: string;
                                link?: string | undefined;
                                links?: {
                                    slug: string;
                                    link: string;
                                    linkText: string;
                                }[] | undefined;
                            } | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                text: string;
                                markdownType: "text";
                                color?: string | undefined;
                            } | {
                                text: string;
                                link: string;
                                linkText: string;
                                markdownType: "hybrid";
                                token: string;
                            } | {
                                text: string;
                                link: string;
                                markdownType: "link";
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    type: "file";
                    label: string;
                    field: string;
                    options?: {
                        supportedFileTypes: string[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        maxFileSize?: number | undefined;
                        fileSupportMessage?: string | undefined;
                        useBase64Encoding?: boolean | undefined;
                    } | undefined;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | {
                                text: string;
                                link?: string | undefined;
                                links?: {
                                    slug: string;
                                    link: string;
                                    linkText: string;
                                }[] | undefined;
                            } | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                text: string;
                                markdownType: "text";
                                color?: string | undefined;
                            } | {
                                text: string;
                                link: string;
                                linkText: string;
                                markdownType: "hybrid";
                                token: string;
                            } | {
                                text: string;
                                link: string;
                                markdownType: "link";
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        auth_type: ("oauth" | "basic" | "oauth_client_credentials")[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        oauth?: {
                            label: string;
                            field: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            help?: string | {
                                text: string;
                                link?: string | undefined;
                                links?: {
                                    slug: string;
                                    link: string;
                                    linkText: string;
                                }[] | undefined;
                            } | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: [number, number];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | {
                                        text: string;
                                        link?: string | undefined;
                                        links?: {
                                            slug: string;
                                            link: string;
                                            linkText: string;
                                        }[] | undefined;
                                    } | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        text: string;
                                        markdownType: "text";
                                        color?: string | undefined;
                                    } | {
                                        text: string;
                                        link: string;
                                        linkText: string;
                                        markdownType: "hybrid";
                                        token: string;
                                    } | {
                                        text: string;
                                        link: string;
                                        markdownType: "link";
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }[] | undefined;
                        basic?: {
                            label: string;
                            field: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            help?: string | {
                                text: string;
                                link?: string | undefined;
                                links?: {
                                    slug: string;
                                    link: string;
                                    linkText: string;
                                }[] | undefined;
                            } | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: [number, number];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | {
                                        text: string;
                                        link?: string | undefined;
                                        links?: {
                                            slug: string;
                                            link: string;
                                            linkText: string;
                                        }[] | undefined;
                                    } | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        text: string;
                                        markdownType: "text";
                                        color?: string | undefined;
                                    } | {
                                        text: string;
                                        link: string;
                                        linkText: string;
                                        markdownType: "hybrid";
                                        token: string;
                                    } | {
                                        text: string;
                                        link: string;
                                        markdownType: "link";
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }[] | undefined;
                        oauth_client_credentials?: {
                            label: string;
                            field: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            help?: string | {
                                text: string;
                                link?: string | undefined;
                                links?: {
                                    slug: string;
                                    link: string;
                                    linkText: string;
                                }[] | undefined;
                            } | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: [number, number];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | {
                                        text: string;
                                        link?: string | undefined;
                                        links?: {
                                            slug: string;
                                            link: string;
                                            linkText: string;
                                        }[] | undefined;
                                    } | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        text: string;
                                        markdownType: "text";
                                        color?: string | undefined;
                                    } | {
                                        text: string;
                                        link: string;
                                        linkText: string;
                                        markdownType: "hybrid";
                                        token: string;
                                    } | {
                                        text: string;
                                        link: string;
                                        markdownType: "link";
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }[] | undefined;
                        auth_label?: string | undefined;
                        oauth_popup_width?: number | undefined;
                        oauth_popup_height?: number | undefined;
                        oauth_timeout?: number | undefined;
                        auth_code_endpoint?: string | undefined;
                        access_token_endpoint?: string | undefined;
                        oauth_state_enabled?: boolean | undefined;
                        auth_endpoint_token_access_type?: string | undefined;
                    };
                    type: "oauth";
                    label: string;
                    field: string;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                } | {
                    options: {
                        type: "external";
                        src: string;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "custom";
                    label: string;
                    field: string;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                })[];
                title: string;
                table: {
                    header: {
                        label: string;
                        field: string;
                        mapping?: Record<string, any> | undefined;
                        customCell?: Record<string, any> | undefined;
                    }[];
                    actions: ("clone" | "delete" | "edit" | "search")[];
                    moreInfo?: {
                        label: string;
                        field: string;
                        mapping?: Record<string, any> | undefined;
                    }[] | undefined;
                    customRow?: Record<string, any> | undefined;
                };
                options?: {
                    saveValidator?: string | undefined;
                } | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
                groups?: {
                    label: string;
                    fields: string[];
                    options?: {
                        isExpandable?: boolean | undefined;
                        expand?: boolean | undefined;
                    } | undefined;
                }[] | undefined;
                style?: "page" | "dialog" | undefined;
                hook?: Record<string, any> | undefined;
                conf?: string | undefined;
                restHandlerName?: string | undefined;
                restHandlerModule?: string | undefined;
                restHandlerClass?: string | undefined;
                warning?: {
                    clone?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    create?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    edit?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    config?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                } | undefined;
                formTitle?: string | undefined;
                subTitle?: string | undefined;
                inputHelperModule?: string | undefined;
                disableNewInput?: boolean | undefined;
                description?: string | undefined;
                useInputToggleConfirmation?: boolean | undefined;
            }[];
            inputsUniqueAcrossSingleService?: boolean | undefined;
        } | {
            title: string;
            table: {
                header: {
                    label: string;
                    field: string;
                    mapping?: Record<string, any> | undefined;
                    customCell?: Record<string, any> | undefined;
                }[];
                actions: ("clone" | "delete" | "edit" | "search")[];
                moreInfo?: {
                    label: string;
                    field: string;
                    mapping?: Record<string, any> | undefined;
                }[] | undefined;
                customRow?: Record<string, any> | undefined;
            };
            services: {
                name: string;
                entity: ({
                    type: "helpLink";
                    field: string;
                    options?: {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    } | undefined;
                    label?: string | undefined;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    tooltip?: string | undefined;
                    required?: false | undefined;
                } | {
                    type: "text";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    } | undefined;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: [number, number];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | {
                                text: string;
                                link?: string | undefined;
                                links?: {
                                    slug: string;
                                    link: string;
                                    linkText: string;
                                }[] | undefined;
                            } | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                text: string;
                                markdownType: "text";
                                color?: string | undefined;
                            } | {
                                text: string;
                                link: string;
                                linkText: string;
                                markdownType: "hybrid";
                                token: string;
                            } | {
                                text: string;
                                link: string;
                                markdownType: "link";
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    type: "textarea";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        rowsMin?: number | undefined;
                        rowsMax?: number | undefined;
                    } | undefined;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: [number, number];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | {
                                text: string;
                                link?: string | undefined;
                                links?: {
                                    slug: string;
                                    link: string;
                                    linkText: string;
                                }[] | undefined;
                            } | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                text: string;
                                markdownType: "text";
                                color?: string | undefined;
                            } | {
                                text: string;
                                link: string;
                                linkText: string;
                                markdownType: "hybrid";
                                token: string;
                            } | {
                                text: string;
                                link: string;
                                markdownType: "link";
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        disableSearch?: boolean | undefined;
                        createSearchChoice?: boolean | undefined;
                        referenceName?: string | undefined;
                        endpointUrl?: string | undefined;
                        allowList?: string | undefined;
                        denyList?: string | undefined;
                        labelField?: string | undefined;
                        valueField?: string | undefined;
                        autoCompleteFields?: ({
                            value: string | number | boolean;
                            label: string;
                        } | {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        })[] | undefined;
                        dependencies?: string[] | undefined;
                        items?: {
                            value: string | number | boolean;
                            label: string;
                        }[] | undefined;
                    };
                    type: "singleSelect";
                    label: string;
                    field: string;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: [number, number];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | {
                                text: string;
                                link?: string | undefined;
                                links?: {
                                    slug: string;
                                    link: string;
                                    linkText: string;
                                }[] | undefined;
                            } | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                text: string;
                                markdownType: "text";
                                color?: string | undefined;
                            } | {
                                text: string;
                                link: string;
                                linkText: string;
                                markdownType: "hybrid";
                                token: string;
                            } | {
                                text: string;
                                link: string;
                                markdownType: "link";
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        disableSearch?: boolean | undefined;
                        createSearchChoice?: boolean | undefined;
                        referenceName?: string | undefined;
                        endpointUrl?: string | undefined;
                        allowList?: string | undefined;
                        denyList?: string | undefined;
                        labelField?: string | undefined;
                        valueField?: string | undefined;
                        autoCompleteFields?: ({
                            value: string | number | boolean;
                            label: string;
                        } | {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        })[] | undefined;
                        dependencies?: string[] | undefined;
                        items?: {
                            value: string | number | boolean;
                            label: string;
                        }[] | undefined;
                        delimiter?: string | undefined;
                    };
                    type: "multipleSelect";
                    label: string;
                    field: string;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: [number, number];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | {
                                text: string;
                                link?: string | undefined;
                                links?: {
                                    slug: string;
                                    link: string;
                                    linkText: string;
                                }[] | undefined;
                            } | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                text: string;
                                markdownType: "text";
                                color?: string | undefined;
                            } | {
                                text: string;
                                link: string;
                                linkText: string;
                                markdownType: "hybrid";
                                token: string;
                            } | {
                                text: string;
                                link: string;
                                markdownType: "link";
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    type: "checkbox";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    } | undefined;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    defaultValue?: number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | {
                                text: string;
                                link?: string | undefined;
                                links?: {
                                    slug: string;
                                    link: string;
                                    linkText: string;
                                }[] | undefined;
                            } | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                text: string;
                                markdownType: "text";
                                color?: string | undefined;
                            } | {
                                text: string;
                                link: string;
                                linkText: string;
                                markdownType: "hybrid";
                                token: string;
                            } | {
                                text: string;
                                link: string;
                                markdownType: "link";
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        rows: {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                            input?: {
                                required?: boolean | undefined;
                                validators?: [{
                                    type: "number";
                                    range: [number, number];
                                    errorMsg?: string | undefined;
                                    isInteger?: boolean | undefined;
                                }] | undefined;
                                defaultValue?: number | undefined;
                            } | undefined;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        delimiter?: string | undefined;
                        groups?: {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }[] | undefined;
                    };
                    type: "checkboxGroup";
                    label: string;
                    field: string;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: [{
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }] | undefined;
                    defaultValue?: number | boolean | undefined;
                } | {
                    options: {
                        rows: {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        delimiter?: string | undefined;
                        groups?: {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }[] | undefined;
                    };
                    type: "checkboxTree";
                    label: string;
                    field: string;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: [{
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }] | undefined;
                    defaultValue?: number | boolean | undefined;
                } | {
                    options: {
                        items: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "radio";
                    label: string;
                    field: string;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | {
                                text: string;
                                link?: string | undefined;
                                links?: {
                                    slug: string;
                                    link: string;
                                    linkText: string;
                                }[] | undefined;
                            } | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                text: string;
                                markdownType: "text";
                                color?: string | undefined;
                            } | {
                                text: string;
                                link: string;
                                linkText: string;
                                markdownType: "hybrid";
                                token: string;
                            } | {
                                text: string;
                                link: string;
                                markdownType: "link";
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    type: "file";
                    label: string;
                    field: string;
                    options?: {
                        supportedFileTypes: string[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        maxFileSize?: number | undefined;
                        fileSupportMessage?: string | undefined;
                        useBase64Encoding?: boolean | undefined;
                    } | undefined;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | {
                                text: string;
                                link?: string | undefined;
                                links?: {
                                    slug: string;
                                    link: string;
                                    linkText: string;
                                }[] | undefined;
                            } | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                text: string;
                                markdownType: "text";
                                color?: string | undefined;
                            } | {
                                text: string;
                                link: string;
                                linkText: string;
                                markdownType: "hybrid";
                                token: string;
                            } | {
                                text: string;
                                link: string;
                                markdownType: "link";
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        auth_type: ("oauth" | "basic" | "oauth_client_credentials")[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        oauth?: {
                            label: string;
                            field: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            help?: string | {
                                text: string;
                                link?: string | undefined;
                                links?: {
                                    slug: string;
                                    link: string;
                                    linkText: string;
                                }[] | undefined;
                            } | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: [number, number];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | {
                                        text: string;
                                        link?: string | undefined;
                                        links?: {
                                            slug: string;
                                            link: string;
                                            linkText: string;
                                        }[] | undefined;
                                    } | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        text: string;
                                        markdownType: "text";
                                        color?: string | undefined;
                                    } | {
                                        text: string;
                                        link: string;
                                        linkText: string;
                                        markdownType: "hybrid";
                                        token: string;
                                    } | {
                                        text: string;
                                        link: string;
                                        markdownType: "link";
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }[] | undefined;
                        basic?: {
                            label: string;
                            field: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            help?: string | {
                                text: string;
                                link?: string | undefined;
                                links?: {
                                    slug: string;
                                    link: string;
                                    linkText: string;
                                }[] | undefined;
                            } | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: [number, number];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | {
                                        text: string;
                                        link?: string | undefined;
                                        links?: {
                                            slug: string;
                                            link: string;
                                            linkText: string;
                                        }[] | undefined;
                                    } | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        text: string;
                                        markdownType: "text";
                                        color?: string | undefined;
                                    } | {
                                        text: string;
                                        link: string;
                                        linkText: string;
                                        markdownType: "hybrid";
                                        token: string;
                                    } | {
                                        text: string;
                                        link: string;
                                        markdownType: "link";
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }[] | undefined;
                        oauth_client_credentials?: {
                            label: string;
                            field: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            help?: string | {
                                text: string;
                                link?: string | undefined;
                                links?: {
                                    slug: string;
                                    link: string;
                                    linkText: string;
                                }[] | undefined;
                            } | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: [number, number];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | {
                                        text: string;
                                        link?: string | undefined;
                                        links?: {
                                            slug: string;
                                            link: string;
                                            linkText: string;
                                        }[] | undefined;
                                    } | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        text: string;
                                        markdownType: "text";
                                        color?: string | undefined;
                                    } | {
                                        text: string;
                                        link: string;
                                        linkText: string;
                                        markdownType: "hybrid";
                                        token: string;
                                    } | {
                                        text: string;
                                        link: string;
                                        markdownType: "link";
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }[] | undefined;
                        auth_label?: string | undefined;
                        oauth_popup_width?: number | undefined;
                        oauth_popup_height?: number | undefined;
                        oauth_timeout?: number | undefined;
                        auth_code_endpoint?: string | undefined;
                        access_token_endpoint?: string | undefined;
                        oauth_state_enabled?: boolean | undefined;
                        auth_endpoint_token_access_type?: string | undefined;
                    };
                    type: "oauth";
                    label: string;
                    field: string;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                } | {
                    options: {
                        type: "external";
                        src: string;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "custom";
                    label: string;
                    field: string;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                })[];
                title: string;
                options?: {
                    saveValidator?: string | undefined;
                } | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
                groups?: {
                    label: string;
                    fields: string[];
                    options?: {
                        isExpandable?: boolean | undefined;
                        expand?: boolean | undefined;
                    } | undefined;
                }[] | undefined;
                style?: "page" | "dialog" | undefined;
                hook?: Record<string, any> | undefined;
                conf?: string | undefined;
                restHandlerName?: string | undefined;
                restHandlerModule?: string | undefined;
                restHandlerClass?: string | undefined;
                warning?: {
                    clone?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    create?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    edit?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    config?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                } | undefined;
                formTitle?: string | undefined;
                subTitle?: string | undefined;
                inputHelperModule?: string | undefined;
                disableNewInput?: boolean | undefined;
            }[];
            description?: string | undefined;
            useInputToggleConfirmation?: boolean | undefined;
            inputsUniqueAcrossSingleService?: boolean | undefined;
            subDescription?: {
                text: string;
                links?: {
                    slug: string;
                    link: string;
                    linkText: string;
                }[] | undefined;
            } | undefined;
            menu?: {
                type: "external";
                src: string;
            } | undefined;
            groupsMenu?: {
                groupName: string;
                groupTitle: string;
                groupServices?: string[] | undefined;
            }[] | undefined;
            hideFieldId?: string | undefined;
            readonlyFieldId?: string | undefined;
        } | undefined;
        dashboard?: {
            panels: {
                name: string;
            }[];
            troubleshooting_url?: string | undefined;
            settings?: {
                custom_tab_name?: string | undefined;
            } | undefined;
        } | undefined;
    };
    alerts?: {
        name: string;
        label: string;
        description: string;
        entity?: ({
            type: "text";
            label: string;
            field: string;
            options?: {
                display?: boolean | undefined;
                disableonEdit?: boolean | undefined;
                enable?: boolean | undefined;
                requiredWhenVisible?: boolean | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
            } | undefined;
            help?: string | {
                text: string;
                link?: string | undefined;
                links?: {
                    slug: string;
                    link: string;
                    linkText: string;
                }[] | undefined;
            } | undefined;
            tooltip?: string | undefined;
            required?: boolean | undefined;
            encrypted?: boolean | undefined;
            validators?: ({
                type: "number";
                range: [number, number];
                errorMsg?: string | undefined;
                isInteger?: boolean | undefined;
            } | {
                type: "string";
                minLength: number;
                maxLength: number;
                errorMsg?: string | undefined;
            } | {
                type: "regex";
                pattern: string;
                errorMsg?: string | undefined;
            } | {
                type: "email";
                errorMsg?: string | undefined;
            } | {
                type: "ipv4";
                errorMsg?: string | undefined;
            } | {
                type: "url";
                errorMsg?: string | undefined;
            } | {
                type: "date";
                errorMsg?: string | undefined;
            })[] | undefined;
            defaultValue?: string | number | boolean | undefined;
            modifyFieldsOnValue?: {
                fieldValue: string | number | boolean;
                fieldsToModify: {
                    fieldId: string;
                    value?: string | number | boolean | undefined;
                    label?: string | undefined;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    required?: boolean | undefined;
                    display?: boolean | undefined;
                    disabled?: boolean | undefined;
                    markdownMessage?: {
                        text: string;
                        markdownType: "text";
                        color?: string | undefined;
                    } | {
                        text: string;
                        link: string;
                        linkText: string;
                        markdownType: "hybrid";
                        token: string;
                    } | {
                        text: string;
                        link: string;
                        markdownType: "link";
                    } | {
                        text: string;
                        markdownType?: undefined;
                    } | undefined;
                }[];
                mode?: "clone" | "create" | "edit" | "config" | undefined;
            }[] | undefined;
        } | {
            type: "textarea";
            label: string;
            field: string;
            options?: {
                display?: boolean | undefined;
                disableonEdit?: boolean | undefined;
                enable?: boolean | undefined;
                requiredWhenVisible?: boolean | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
                rowsMin?: number | undefined;
                rowsMax?: number | undefined;
            } | undefined;
            help?: string | {
                text: string;
                link?: string | undefined;
                links?: {
                    slug: string;
                    link: string;
                    linkText: string;
                }[] | undefined;
            } | undefined;
            tooltip?: string | undefined;
            required?: boolean | undefined;
            encrypted?: boolean | undefined;
            validators?: ({
                type: "number";
                range: [number, number];
                errorMsg?: string | undefined;
                isInteger?: boolean | undefined;
            } | {
                type: "string";
                minLength: number;
                maxLength: number;
                errorMsg?: string | undefined;
            } | {
                type: "regex";
                pattern: string;
                errorMsg?: string | undefined;
            } | {
                type: "email";
                errorMsg?: string | undefined;
            } | {
                type: "ipv4";
                errorMsg?: string | undefined;
            } | {
                type: "url";
                errorMsg?: string | undefined;
            } | {
                type: "date";
                errorMsg?: string | undefined;
            })[] | undefined;
            defaultValue?: string | undefined;
            modifyFieldsOnValue?: {
                fieldValue: string | number | boolean;
                fieldsToModify: {
                    fieldId: string;
                    value?: string | number | boolean | undefined;
                    label?: string | undefined;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    required?: boolean | undefined;
                    display?: boolean | undefined;
                    disabled?: boolean | undefined;
                    markdownMessage?: {
                        text: string;
                        markdownType: "text";
                        color?: string | undefined;
                    } | {
                        text: string;
                        link: string;
                        linkText: string;
                        markdownType: "hybrid";
                        token: string;
                    } | {
                        text: string;
                        link: string;
                        markdownType: "link";
                    } | {
                        text: string;
                        markdownType?: undefined;
                    } | undefined;
                }[];
                mode?: "clone" | "create" | "edit" | "config" | undefined;
            }[] | undefined;
        } | {
            options: {
                display?: boolean | undefined;
                disableonEdit?: boolean | undefined;
                enable?: boolean | undefined;
                requiredWhenVisible?: boolean | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
                disableSearch?: boolean | undefined;
                createSearchChoice?: boolean | undefined;
                referenceName?: string | undefined;
                endpointUrl?: string | undefined;
                allowList?: string | undefined;
                denyList?: string | undefined;
                labelField?: string | undefined;
                valueField?: string | undefined;
                autoCompleteFields?: ({
                    value: string | number | boolean;
                    label: string;
                } | {
                    label: string;
                    children: {
                        value: string | number | boolean;
                        label: string;
                    }[];
                })[] | undefined;
                dependencies?: string[] | undefined;
                items?: {
                    value: string | number | boolean;
                    label: string;
                }[] | undefined;
            };
            type: "singleSelect";
            label: string;
            field: string;
            help?: string | {
                text: string;
                link?: string | undefined;
                links?: {
                    slug: string;
                    link: string;
                    linkText: string;
                }[] | undefined;
            } | undefined;
            tooltip?: string | undefined;
            required?: boolean | undefined;
            encrypted?: boolean | undefined;
            validators?: ({
                type: "number";
                range: [number, number];
                errorMsg?: string | undefined;
                isInteger?: boolean | undefined;
            } | {
                type: "string";
                minLength: number;
                maxLength: number;
                errorMsg?: string | undefined;
            } | {
                type: "regex";
                pattern: string;
                errorMsg?: string | undefined;
            } | {
                type: "email";
                errorMsg?: string | undefined;
            } | {
                type: "ipv4";
                errorMsg?: string | undefined;
            } | {
                type: "url";
                errorMsg?: string | undefined;
            } | {
                type: "date";
                errorMsg?: string | undefined;
            })[] | undefined;
            defaultValue?: string | number | boolean | undefined;
            modifyFieldsOnValue?: {
                fieldValue: string | number | boolean;
                fieldsToModify: {
                    fieldId: string;
                    value?: string | number | boolean | undefined;
                    label?: string | undefined;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    required?: boolean | undefined;
                    display?: boolean | undefined;
                    disabled?: boolean | undefined;
                    markdownMessage?: {
                        text: string;
                        markdownType: "text";
                        color?: string | undefined;
                    } | {
                        text: string;
                        link: string;
                        linkText: string;
                        markdownType: "hybrid";
                        token: string;
                    } | {
                        text: string;
                        link: string;
                        markdownType: "link";
                    } | {
                        text: string;
                        markdownType?: undefined;
                    } | undefined;
                }[];
                mode?: "clone" | "create" | "edit" | "config" | undefined;
            }[] | undefined;
        } | {
            type: "checkbox";
            label: string;
            field: string;
            options?: {
                display?: boolean | undefined;
                disableonEdit?: boolean | undefined;
                enable?: boolean | undefined;
                requiredWhenVisible?: boolean | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
            } | undefined;
            help?: string | {
                text: string;
                link?: string | undefined;
                links?: {
                    slug: string;
                    link: string;
                    linkText: string;
                }[] | undefined;
            } | undefined;
            tooltip?: string | undefined;
            required?: boolean | undefined;
            encrypted?: boolean | undefined;
            defaultValue?: number | boolean | undefined;
            modifyFieldsOnValue?: {
                fieldValue: string | number | boolean;
                fieldsToModify: {
                    fieldId: string;
                    value?: string | number | boolean | undefined;
                    label?: string | undefined;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    required?: boolean | undefined;
                    display?: boolean | undefined;
                    disabled?: boolean | undefined;
                    markdownMessage?: {
                        text: string;
                        markdownType: "text";
                        color?: string | undefined;
                    } | {
                        text: string;
                        link: string;
                        linkText: string;
                        markdownType: "hybrid";
                        token: string;
                    } | {
                        text: string;
                        link: string;
                        markdownType: "link";
                    } | {
                        text: string;
                        markdownType?: undefined;
                    } | undefined;
                }[];
                mode?: "clone" | "create" | "edit" | "config" | undefined;
            }[] | undefined;
        } | {
            options: {
                items: {
                    value: string | number | boolean;
                    label: string;
                }[];
                display?: boolean | undefined;
                disableonEdit?: boolean | undefined;
                enable?: boolean | undefined;
                requiredWhenVisible?: boolean | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
            };
            type: "radio";
            label: string;
            field: string;
            help?: string | {
                text: string;
                link?: string | undefined;
                links?: {
                    slug: string;
                    link: string;
                    linkText: string;
                }[] | undefined;
            } | undefined;
            tooltip?: string | undefined;
            required?: boolean | undefined;
            encrypted?: boolean | undefined;
            defaultValue?: string | undefined;
            modifyFieldsOnValue?: {
                fieldValue: string | number | boolean;
                fieldsToModify: {
                    fieldId: string;
                    value?: string | number | boolean | undefined;
                    label?: string | undefined;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    required?: boolean | undefined;
                    display?: boolean | undefined;
                    disabled?: boolean | undefined;
                    markdownMessage?: {
                        text: string;
                        markdownType: "text";
                        color?: string | undefined;
                    } | {
                        text: string;
                        link: string;
                        linkText: string;
                        markdownType: "hybrid";
                        token: string;
                    } | {
                        text: string;
                        link: string;
                        markdownType: "link";
                    } | {
                        text: string;
                        markdownType?: undefined;
                    } | undefined;
                }[];
                mode?: "clone" | "create" | "edit" | "config" | undefined;
            }[] | undefined;
        } | {
            type: "singleSelectSplunkSearch";
            label: string;
            field: string;
            options?: {
                items: {
                    value: string | number | boolean;
                    label: string;
                }[];
            } | undefined;
            help?: string | {
                text: string;
                link?: string | undefined;
                links?: {
                    slug: string;
                    link: string;
                    linkText: string;
                }[] | undefined;
            } | undefined;
            tooltip?: string | undefined;
            defaultValue?: string | number | boolean | undefined;
            labelField?: string | undefined;
            valueField?: string | undefined;
            search?: string | undefined;
        })[] | undefined;
        adaptiveResponse?: {
            task: string[];
            supportsAdhoc: boolean;
            supportsCloud: boolean;
            subject: string[];
            category: string[];
            technology: {
                version: string[];
                product: string;
                vendor: string;
            }[];
            drilldownUri?: string | undefined;
            sourcetype?: string | undefined;
        } | undefined;
    }[] | undefined;
}, {
    meta: {
        displayName: string;
        name: string;
        restRoot: string;
        version: string;
        apiVersion?: string | undefined;
        schemaVersion?: string | undefined;
        _uccVersion?: string | undefined;
        hideUCCVersion?: boolean | undefined;
        checkForUpdates?: boolean | undefined;
        searchViewDefault?: boolean | undefined;
        isVisible?: boolean | undefined;
        supportedThemes?: string[] | undefined;
    };
    pages: {
        configuration?: {
            title: string;
            tabs: {
                name: string;
                title: string;
                options?: {
                    saveValidator?: string | undefined;
                } | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
                groups?: {
                    label: string;
                    fields: string[];
                    options?: {
                        isExpandable?: boolean | undefined;
                        expand?: boolean | undefined;
                    } | undefined;
                }[] | undefined;
                entity?: ({
                    type: "helpLink";
                    field: string;
                    options?: {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    } | undefined;
                    label?: string | undefined;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    tooltip?: string | undefined;
                    required?: false | undefined;
                } | {
                    type: "text";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    } | undefined;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: [number, number];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | {
                                text: string;
                                link?: string | undefined;
                                links?: {
                                    slug: string;
                                    link: string;
                                    linkText: string;
                                }[] | undefined;
                            } | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                text: string;
                                markdownType: "text";
                                color?: string | undefined;
                            } | {
                                text: string;
                                link: string;
                                linkText: string;
                                markdownType: "hybrid";
                                token: string;
                            } | {
                                text: string;
                                link: string;
                                markdownType: "link";
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    type: "textarea";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        rowsMin?: number | undefined;
                        rowsMax?: number | undefined;
                    } | undefined;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: [number, number];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | {
                                text: string;
                                link?: string | undefined;
                                links?: {
                                    slug: string;
                                    link: string;
                                    linkText: string;
                                }[] | undefined;
                            } | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                text: string;
                                markdownType: "text";
                                color?: string | undefined;
                            } | {
                                text: string;
                                link: string;
                                linkText: string;
                                markdownType: "hybrid";
                                token: string;
                            } | {
                                text: string;
                                link: string;
                                markdownType: "link";
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        disableSearch?: boolean | undefined;
                        createSearchChoice?: boolean | undefined;
                        referenceName?: string | undefined;
                        endpointUrl?: string | undefined;
                        allowList?: string | undefined;
                        denyList?: string | undefined;
                        labelField?: string | undefined;
                        valueField?: string | undefined;
                        autoCompleteFields?: ({
                            value: string | number | boolean;
                            label: string;
                        } | {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        })[] | undefined;
                        dependencies?: string[] | undefined;
                        items?: {
                            value: string | number | boolean;
                            label: string;
                        }[] | undefined;
                    };
                    type: "singleSelect";
                    label: string;
                    field: string;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: [number, number];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | {
                                text: string;
                                link?: string | undefined;
                                links?: {
                                    slug: string;
                                    link: string;
                                    linkText: string;
                                }[] | undefined;
                            } | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                text: string;
                                markdownType: "text";
                                color?: string | undefined;
                            } | {
                                text: string;
                                link: string;
                                linkText: string;
                                markdownType: "hybrid";
                                token: string;
                            } | {
                                text: string;
                                link: string;
                                markdownType: "link";
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        disableSearch?: boolean | undefined;
                        createSearchChoice?: boolean | undefined;
                        referenceName?: string | undefined;
                        endpointUrl?: string | undefined;
                        allowList?: string | undefined;
                        denyList?: string | undefined;
                        labelField?: string | undefined;
                        valueField?: string | undefined;
                        autoCompleteFields?: ({
                            value: string | number | boolean;
                            label: string;
                        } | {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        })[] | undefined;
                        dependencies?: string[] | undefined;
                        items?: {
                            value: string | number | boolean;
                            label: string;
                        }[] | undefined;
                        delimiter?: string | undefined;
                    };
                    type: "multipleSelect";
                    label: string;
                    field: string;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: [number, number];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | {
                                text: string;
                                link?: string | undefined;
                                links?: {
                                    slug: string;
                                    link: string;
                                    linkText: string;
                                }[] | undefined;
                            } | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                text: string;
                                markdownType: "text";
                                color?: string | undefined;
                            } | {
                                text: string;
                                link: string;
                                linkText: string;
                                markdownType: "hybrid";
                                token: string;
                            } | {
                                text: string;
                                link: string;
                                markdownType: "link";
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    type: "checkbox";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    } | undefined;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    defaultValue?: number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | {
                                text: string;
                                link?: string | undefined;
                                links?: {
                                    slug: string;
                                    link: string;
                                    linkText: string;
                                }[] | undefined;
                            } | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                text: string;
                                markdownType: "text";
                                color?: string | undefined;
                            } | {
                                text: string;
                                link: string;
                                linkText: string;
                                markdownType: "hybrid";
                                token: string;
                            } | {
                                text: string;
                                link: string;
                                markdownType: "link";
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        rows: {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                            input?: {
                                required?: boolean | undefined;
                                validators?: [{
                                    type: "number";
                                    range: [number, number];
                                    errorMsg?: string | undefined;
                                    isInteger?: boolean | undefined;
                                }] | undefined;
                                defaultValue?: number | undefined;
                            } | undefined;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        delimiter?: string | undefined;
                        groups?: {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }[] | undefined;
                    };
                    type: "checkboxGroup";
                    label: string;
                    field: string;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: [{
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }] | undefined;
                    defaultValue?: number | boolean | undefined;
                } | {
                    options: {
                        rows: {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        delimiter?: string | undefined;
                        groups?: {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }[] | undefined;
                    };
                    type: "checkboxTree";
                    label: string;
                    field: string;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: [{
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }] | undefined;
                    defaultValue?: number | boolean | undefined;
                } | {
                    options: {
                        items: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "radio";
                    label: string;
                    field: string;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | {
                                text: string;
                                link?: string | undefined;
                                links?: {
                                    slug: string;
                                    link: string;
                                    linkText: string;
                                }[] | undefined;
                            } | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                text: string;
                                markdownType: "text";
                                color?: string | undefined;
                            } | {
                                text: string;
                                link: string;
                                linkText: string;
                                markdownType: "hybrid";
                                token: string;
                            } | {
                                text: string;
                                link: string;
                                markdownType: "link";
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    type: "file";
                    label: string;
                    field: string;
                    options?: {
                        supportedFileTypes: string[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        maxFileSize?: number | undefined;
                        fileSupportMessage?: string | undefined;
                        useBase64Encoding?: boolean | undefined;
                    } | undefined;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | {
                                text: string;
                                link?: string | undefined;
                                links?: {
                                    slug: string;
                                    link: string;
                                    linkText: string;
                                }[] | undefined;
                            } | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                text: string;
                                markdownType: "text";
                                color?: string | undefined;
                            } | {
                                text: string;
                                link: string;
                                linkText: string;
                                markdownType: "hybrid";
                                token: string;
                            } | {
                                text: string;
                                link: string;
                                markdownType: "link";
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        auth_type: ("oauth" | "basic" | "oauth_client_credentials")[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        oauth?: {
                            label: string;
                            field: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            help?: string | {
                                text: string;
                                link?: string | undefined;
                                links?: {
                                    slug: string;
                                    link: string;
                                    linkText: string;
                                }[] | undefined;
                            } | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: [number, number];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | {
                                        text: string;
                                        link?: string | undefined;
                                        links?: {
                                            slug: string;
                                            link: string;
                                            linkText: string;
                                        }[] | undefined;
                                    } | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        text: string;
                                        markdownType: "text";
                                        color?: string | undefined;
                                    } | {
                                        text: string;
                                        link: string;
                                        linkText: string;
                                        markdownType: "hybrid";
                                        token: string;
                                    } | {
                                        text: string;
                                        link: string;
                                        markdownType: "link";
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }[] | undefined;
                        basic?: {
                            label: string;
                            field: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            help?: string | {
                                text: string;
                                link?: string | undefined;
                                links?: {
                                    slug: string;
                                    link: string;
                                    linkText: string;
                                }[] | undefined;
                            } | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: [number, number];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | {
                                        text: string;
                                        link?: string | undefined;
                                        links?: {
                                            slug: string;
                                            link: string;
                                            linkText: string;
                                        }[] | undefined;
                                    } | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        text: string;
                                        markdownType: "text";
                                        color?: string | undefined;
                                    } | {
                                        text: string;
                                        link: string;
                                        linkText: string;
                                        markdownType: "hybrid";
                                        token: string;
                                    } | {
                                        text: string;
                                        link: string;
                                        markdownType: "link";
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }[] | undefined;
                        oauth_client_credentials?: {
                            label: string;
                            field: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            help?: string | {
                                text: string;
                                link?: string | undefined;
                                links?: {
                                    slug: string;
                                    link: string;
                                    linkText: string;
                                }[] | undefined;
                            } | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: [number, number];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | {
                                        text: string;
                                        link?: string | undefined;
                                        links?: {
                                            slug: string;
                                            link: string;
                                            linkText: string;
                                        }[] | undefined;
                                    } | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        text: string;
                                        markdownType: "text";
                                        color?: string | undefined;
                                    } | {
                                        text: string;
                                        link: string;
                                        linkText: string;
                                        markdownType: "hybrid";
                                        token: string;
                                    } | {
                                        text: string;
                                        link: string;
                                        markdownType: "link";
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }[] | undefined;
                        auth_label?: string | undefined;
                        oauth_popup_width?: number | undefined;
                        oauth_popup_height?: number | undefined;
                        oauth_timeout?: number | undefined;
                        auth_code_endpoint?: string | undefined;
                        access_token_endpoint?: string | undefined;
                        oauth_state_enabled?: boolean | undefined;
                        auth_endpoint_token_access_type?: string | undefined;
                    };
                    type: "oauth";
                    label: string;
                    field: string;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                } | {
                    options: {
                        type: "external";
                        src: string;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "custom";
                    label: string;
                    field: string;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                })[] | undefined;
                table?: {
                    header: {
                        label: string;
                        field: string;
                        mapping?: Record<string, any> | undefined;
                        customCell?: Record<string, any> | undefined;
                    }[];
                    actions: ("clone" | "delete" | "edit")[];
                    moreInfo?: {
                        label: string;
                        field: string;
                        mapping?: Record<string, any> | undefined;
                    }[] | undefined;
                    customRow?: Record<string, any> | undefined;
                } | undefined;
                style?: "page" | "dialog" | undefined;
                hook?: Record<string, any> | undefined;
                conf?: string | undefined;
                restHandlerName?: string | undefined;
                restHandlerModule?: string | undefined;
                restHandlerClass?: string | undefined;
                customTab?: Record<string, any> | undefined;
                warning?: {
                    clone?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    create?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    edit?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    config?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                } | undefined;
                formTitle?: string | undefined;
            }[];
            description?: string | undefined;
            subDescription?: {
                text: string;
                links?: {
                    slug: string;
                    link: string;
                    linkText: string;
                }[] | undefined;
            } | undefined;
        } | undefined;
        inputs?: {
            title: string;
            services: {
                name: string;
                entity: ({
                    type: "helpLink";
                    field: string;
                    options?: {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    } | undefined;
                    label?: string | undefined;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    tooltip?: string | undefined;
                    required?: false | undefined;
                } | {
                    type: "text";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    } | undefined;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: [number, number];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | {
                                text: string;
                                link?: string | undefined;
                                links?: {
                                    slug: string;
                                    link: string;
                                    linkText: string;
                                }[] | undefined;
                            } | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                text: string;
                                markdownType: "text";
                                color?: string | undefined;
                            } | {
                                text: string;
                                link: string;
                                linkText: string;
                                markdownType: "hybrid";
                                token: string;
                            } | {
                                text: string;
                                link: string;
                                markdownType: "link";
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    type: "textarea";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        rowsMin?: number | undefined;
                        rowsMax?: number | undefined;
                    } | undefined;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: [number, number];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | {
                                text: string;
                                link?: string | undefined;
                                links?: {
                                    slug: string;
                                    link: string;
                                    linkText: string;
                                }[] | undefined;
                            } | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                text: string;
                                markdownType: "text";
                                color?: string | undefined;
                            } | {
                                text: string;
                                link: string;
                                linkText: string;
                                markdownType: "hybrid";
                                token: string;
                            } | {
                                text: string;
                                link: string;
                                markdownType: "link";
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        disableSearch?: boolean | undefined;
                        createSearchChoice?: boolean | undefined;
                        referenceName?: string | undefined;
                        endpointUrl?: string | undefined;
                        allowList?: string | undefined;
                        denyList?: string | undefined;
                        labelField?: string | undefined;
                        valueField?: string | undefined;
                        autoCompleteFields?: ({
                            value: string | number | boolean;
                            label: string;
                        } | {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        })[] | undefined;
                        dependencies?: string[] | undefined;
                        items?: {
                            value: string | number | boolean;
                            label: string;
                        }[] | undefined;
                    };
                    type: "singleSelect";
                    label: string;
                    field: string;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: [number, number];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | {
                                text: string;
                                link?: string | undefined;
                                links?: {
                                    slug: string;
                                    link: string;
                                    linkText: string;
                                }[] | undefined;
                            } | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                text: string;
                                markdownType: "text";
                                color?: string | undefined;
                            } | {
                                text: string;
                                link: string;
                                linkText: string;
                                markdownType: "hybrid";
                                token: string;
                            } | {
                                text: string;
                                link: string;
                                markdownType: "link";
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        disableSearch?: boolean | undefined;
                        createSearchChoice?: boolean | undefined;
                        referenceName?: string | undefined;
                        endpointUrl?: string | undefined;
                        allowList?: string | undefined;
                        denyList?: string | undefined;
                        labelField?: string | undefined;
                        valueField?: string | undefined;
                        autoCompleteFields?: ({
                            value: string | number | boolean;
                            label: string;
                        } | {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        })[] | undefined;
                        dependencies?: string[] | undefined;
                        items?: {
                            value: string | number | boolean;
                            label: string;
                        }[] | undefined;
                        delimiter?: string | undefined;
                    };
                    type: "multipleSelect";
                    label: string;
                    field: string;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: [number, number];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | {
                                text: string;
                                link?: string | undefined;
                                links?: {
                                    slug: string;
                                    link: string;
                                    linkText: string;
                                }[] | undefined;
                            } | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                text: string;
                                markdownType: "text";
                                color?: string | undefined;
                            } | {
                                text: string;
                                link: string;
                                linkText: string;
                                markdownType: "hybrid";
                                token: string;
                            } | {
                                text: string;
                                link: string;
                                markdownType: "link";
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    type: "checkbox";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    } | undefined;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    defaultValue?: number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | {
                                text: string;
                                link?: string | undefined;
                                links?: {
                                    slug: string;
                                    link: string;
                                    linkText: string;
                                }[] | undefined;
                            } | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                text: string;
                                markdownType: "text";
                                color?: string | undefined;
                            } | {
                                text: string;
                                link: string;
                                linkText: string;
                                markdownType: "hybrid";
                                token: string;
                            } | {
                                text: string;
                                link: string;
                                markdownType: "link";
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        rows: {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                            input?: {
                                required?: boolean | undefined;
                                validators?: [{
                                    type: "number";
                                    range: [number, number];
                                    errorMsg?: string | undefined;
                                    isInteger?: boolean | undefined;
                                }] | undefined;
                                defaultValue?: number | undefined;
                            } | undefined;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        delimiter?: string | undefined;
                        groups?: {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }[] | undefined;
                    };
                    type: "checkboxGroup";
                    label: string;
                    field: string;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: [{
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }] | undefined;
                    defaultValue?: number | boolean | undefined;
                } | {
                    options: {
                        rows: {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        delimiter?: string | undefined;
                        groups?: {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }[] | undefined;
                    };
                    type: "checkboxTree";
                    label: string;
                    field: string;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: [{
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }] | undefined;
                    defaultValue?: number | boolean | undefined;
                } | {
                    options: {
                        items: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "radio";
                    label: string;
                    field: string;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | {
                                text: string;
                                link?: string | undefined;
                                links?: {
                                    slug: string;
                                    link: string;
                                    linkText: string;
                                }[] | undefined;
                            } | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                text: string;
                                markdownType: "text";
                                color?: string | undefined;
                            } | {
                                text: string;
                                link: string;
                                linkText: string;
                                markdownType: "hybrid";
                                token: string;
                            } | {
                                text: string;
                                link: string;
                                markdownType: "link";
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    type: "file";
                    label: string;
                    field: string;
                    options?: {
                        supportedFileTypes: string[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        maxFileSize?: number | undefined;
                        fileSupportMessage?: string | undefined;
                        useBase64Encoding?: boolean | undefined;
                    } | undefined;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | {
                                text: string;
                                link?: string | undefined;
                                links?: {
                                    slug: string;
                                    link: string;
                                    linkText: string;
                                }[] | undefined;
                            } | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                text: string;
                                markdownType: "text";
                                color?: string | undefined;
                            } | {
                                text: string;
                                link: string;
                                linkText: string;
                                markdownType: "hybrid";
                                token: string;
                            } | {
                                text: string;
                                link: string;
                                markdownType: "link";
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        auth_type: ("oauth" | "basic" | "oauth_client_credentials")[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        oauth?: {
                            label: string;
                            field: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            help?: string | {
                                text: string;
                                link?: string | undefined;
                                links?: {
                                    slug: string;
                                    link: string;
                                    linkText: string;
                                }[] | undefined;
                            } | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: [number, number];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | {
                                        text: string;
                                        link?: string | undefined;
                                        links?: {
                                            slug: string;
                                            link: string;
                                            linkText: string;
                                        }[] | undefined;
                                    } | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        text: string;
                                        markdownType: "text";
                                        color?: string | undefined;
                                    } | {
                                        text: string;
                                        link: string;
                                        linkText: string;
                                        markdownType: "hybrid";
                                        token: string;
                                    } | {
                                        text: string;
                                        link: string;
                                        markdownType: "link";
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }[] | undefined;
                        basic?: {
                            label: string;
                            field: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            help?: string | {
                                text: string;
                                link?: string | undefined;
                                links?: {
                                    slug: string;
                                    link: string;
                                    linkText: string;
                                }[] | undefined;
                            } | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: [number, number];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | {
                                        text: string;
                                        link?: string | undefined;
                                        links?: {
                                            slug: string;
                                            link: string;
                                            linkText: string;
                                        }[] | undefined;
                                    } | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        text: string;
                                        markdownType: "text";
                                        color?: string | undefined;
                                    } | {
                                        text: string;
                                        link: string;
                                        linkText: string;
                                        markdownType: "hybrid";
                                        token: string;
                                    } | {
                                        text: string;
                                        link: string;
                                        markdownType: "link";
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }[] | undefined;
                        oauth_client_credentials?: {
                            label: string;
                            field: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            help?: string | {
                                text: string;
                                link?: string | undefined;
                                links?: {
                                    slug: string;
                                    link: string;
                                    linkText: string;
                                }[] | undefined;
                            } | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: [number, number];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | {
                                        text: string;
                                        link?: string | undefined;
                                        links?: {
                                            slug: string;
                                            link: string;
                                            linkText: string;
                                        }[] | undefined;
                                    } | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        text: string;
                                        markdownType: "text";
                                        color?: string | undefined;
                                    } | {
                                        text: string;
                                        link: string;
                                        linkText: string;
                                        markdownType: "hybrid";
                                        token: string;
                                    } | {
                                        text: string;
                                        link: string;
                                        markdownType: "link";
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }[] | undefined;
                        auth_label?: string | undefined;
                        oauth_popup_width?: number | undefined;
                        oauth_popup_height?: number | undefined;
                        oauth_timeout?: number | undefined;
                        auth_code_endpoint?: string | undefined;
                        access_token_endpoint?: string | undefined;
                        oauth_state_enabled?: boolean | undefined;
                        auth_endpoint_token_access_type?: string | undefined;
                    };
                    type: "oauth";
                    label: string;
                    field: string;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                } | {
                    options: {
                        type: "external";
                        src: string;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "custom";
                    label: string;
                    field: string;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                })[];
                title: string;
                table: {
                    header: {
                        label: string;
                        field: string;
                        mapping?: Record<string, any> | undefined;
                        customCell?: Record<string, any> | undefined;
                    }[];
                    actions: ("clone" | "delete" | "edit" | "search")[];
                    moreInfo?: {
                        label: string;
                        field: string;
                        mapping?: Record<string, any> | undefined;
                    }[] | undefined;
                    customRow?: Record<string, any> | undefined;
                };
                options?: {
                    saveValidator?: string | undefined;
                } | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
                groups?: {
                    label: string;
                    fields: string[];
                    options?: {
                        isExpandable?: boolean | undefined;
                        expand?: boolean | undefined;
                    } | undefined;
                }[] | undefined;
                style?: "page" | "dialog" | undefined;
                hook?: Record<string, any> | undefined;
                conf?: string | undefined;
                restHandlerName?: string | undefined;
                restHandlerModule?: string | undefined;
                restHandlerClass?: string | undefined;
                warning?: {
                    clone?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    create?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    edit?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    config?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                } | undefined;
                formTitle?: string | undefined;
                subTitle?: string | undefined;
                inputHelperModule?: string | undefined;
                disableNewInput?: boolean | undefined;
                description?: string | undefined;
                useInputToggleConfirmation?: boolean | undefined;
            }[];
            inputsUniqueAcrossSingleService?: boolean | undefined;
        } | {
            title: string;
            table: {
                header: {
                    label: string;
                    field: string;
                    mapping?: Record<string, any> | undefined;
                    customCell?: Record<string, any> | undefined;
                }[];
                actions: ("clone" | "delete" | "edit" | "search")[];
                moreInfo?: {
                    label: string;
                    field: string;
                    mapping?: Record<string, any> | undefined;
                }[] | undefined;
                customRow?: Record<string, any> | undefined;
            };
            services: {
                name: string;
                entity: ({
                    type: "helpLink";
                    field: string;
                    options?: {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    } | undefined;
                    label?: string | undefined;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    tooltip?: string | undefined;
                    required?: false | undefined;
                } | {
                    type: "text";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    } | undefined;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: [number, number];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | {
                                text: string;
                                link?: string | undefined;
                                links?: {
                                    slug: string;
                                    link: string;
                                    linkText: string;
                                }[] | undefined;
                            } | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                text: string;
                                markdownType: "text";
                                color?: string | undefined;
                            } | {
                                text: string;
                                link: string;
                                linkText: string;
                                markdownType: "hybrid";
                                token: string;
                            } | {
                                text: string;
                                link: string;
                                markdownType: "link";
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    type: "textarea";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        rowsMin?: number | undefined;
                        rowsMax?: number | undefined;
                    } | undefined;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: [number, number];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | {
                                text: string;
                                link?: string | undefined;
                                links?: {
                                    slug: string;
                                    link: string;
                                    linkText: string;
                                }[] | undefined;
                            } | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                text: string;
                                markdownType: "text";
                                color?: string | undefined;
                            } | {
                                text: string;
                                link: string;
                                linkText: string;
                                markdownType: "hybrid";
                                token: string;
                            } | {
                                text: string;
                                link: string;
                                markdownType: "link";
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        disableSearch?: boolean | undefined;
                        createSearchChoice?: boolean | undefined;
                        referenceName?: string | undefined;
                        endpointUrl?: string | undefined;
                        allowList?: string | undefined;
                        denyList?: string | undefined;
                        labelField?: string | undefined;
                        valueField?: string | undefined;
                        autoCompleteFields?: ({
                            value: string | number | boolean;
                            label: string;
                        } | {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        })[] | undefined;
                        dependencies?: string[] | undefined;
                        items?: {
                            value: string | number | boolean;
                            label: string;
                        }[] | undefined;
                    };
                    type: "singleSelect";
                    label: string;
                    field: string;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: [number, number];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | {
                                text: string;
                                link?: string | undefined;
                                links?: {
                                    slug: string;
                                    link: string;
                                    linkText: string;
                                }[] | undefined;
                            } | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                text: string;
                                markdownType: "text";
                                color?: string | undefined;
                            } | {
                                text: string;
                                link: string;
                                linkText: string;
                                markdownType: "hybrid";
                                token: string;
                            } | {
                                text: string;
                                link: string;
                                markdownType: "link";
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        disableSearch?: boolean | undefined;
                        createSearchChoice?: boolean | undefined;
                        referenceName?: string | undefined;
                        endpointUrl?: string | undefined;
                        allowList?: string | undefined;
                        denyList?: string | undefined;
                        labelField?: string | undefined;
                        valueField?: string | undefined;
                        autoCompleteFields?: ({
                            value: string | number | boolean;
                            label: string;
                        } | {
                            label: string;
                            children: {
                                value: string | number | boolean;
                                label: string;
                            }[];
                        })[] | undefined;
                        dependencies?: string[] | undefined;
                        items?: {
                            value: string | number | boolean;
                            label: string;
                        }[] | undefined;
                        delimiter?: string | undefined;
                    };
                    type: "multipleSelect";
                    label: string;
                    field: string;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "number";
                        range: [number, number];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    } | {
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    } | {
                        type: "email";
                        errorMsg?: string | undefined;
                    } | {
                        type: "ipv4";
                        errorMsg?: string | undefined;
                    } | {
                        type: "url";
                        errorMsg?: string | undefined;
                    } | {
                        type: "date";
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | {
                                text: string;
                                link?: string | undefined;
                                links?: {
                                    slug: string;
                                    link: string;
                                    linkText: string;
                                }[] | undefined;
                            } | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                text: string;
                                markdownType: "text";
                                color?: string | undefined;
                            } | {
                                text: string;
                                link: string;
                                linkText: string;
                                markdownType: "hybrid";
                                token: string;
                            } | {
                                text: string;
                                link: string;
                                markdownType: "link";
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    type: "checkbox";
                    label: string;
                    field: string;
                    options?: {
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    } | undefined;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    defaultValue?: number | boolean | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | {
                                text: string;
                                link?: string | undefined;
                                links?: {
                                    slug: string;
                                    link: string;
                                    linkText: string;
                                }[] | undefined;
                            } | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                text: string;
                                markdownType: "text";
                                color?: string | undefined;
                            } | {
                                text: string;
                                link: string;
                                linkText: string;
                                markdownType: "hybrid";
                                token: string;
                            } | {
                                text: string;
                                link: string;
                                markdownType: "link";
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        rows: {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                            input?: {
                                required?: boolean | undefined;
                                validators?: [{
                                    type: "number";
                                    range: [number, number];
                                    errorMsg?: string | undefined;
                                    isInteger?: boolean | undefined;
                                }] | undefined;
                                defaultValue?: number | undefined;
                            } | undefined;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        delimiter?: string | undefined;
                        groups?: {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }[] | undefined;
                    };
                    type: "checkboxGroup";
                    label: string;
                    field: string;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: [{
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }] | undefined;
                    defaultValue?: number | boolean | undefined;
                } | {
                    options: {
                        rows: {
                            field: string;
                            checkbox?: {
                                label?: string | undefined;
                                defaultValue?: boolean | undefined;
                            } | undefined;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        delimiter?: string | undefined;
                        groups?: {
                            label: string;
                            fields: string[];
                            options?: {
                                isExpandable?: boolean | undefined;
                                expand?: boolean | undefined;
                            } | undefined;
                        }[] | undefined;
                    };
                    type: "checkboxTree";
                    label: string;
                    field: string;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: [{
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    }] | undefined;
                    defaultValue?: number | boolean | undefined;
                } | {
                    options: {
                        items: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "radio";
                    label: string;
                    field: string;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | {
                                text: string;
                                link?: string | undefined;
                                links?: {
                                    slug: string;
                                    link: string;
                                    linkText: string;
                                }[] | undefined;
                            } | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                text: string;
                                markdownType: "text";
                                color?: string | undefined;
                            } | {
                                text: string;
                                link: string;
                                linkText: string;
                                markdownType: "hybrid";
                                token: string;
                            } | {
                                text: string;
                                link: string;
                                markdownType: "link";
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    type: "file";
                    label: string;
                    field: string;
                    options?: {
                        supportedFileTypes: string[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        requiredWhenVisible?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        maxFileSize?: number | undefined;
                        fileSupportMessage?: string | undefined;
                        useBase64Encoding?: boolean | undefined;
                    } | undefined;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                    modifyFieldsOnValue?: {
                        fieldValue: string | number | boolean;
                        fieldsToModify: {
                            fieldId: string;
                            value?: string | number | boolean | undefined;
                            label?: string | undefined;
                            help?: string | {
                                text: string;
                                link?: string | undefined;
                                links?: {
                                    slug: string;
                                    link: string;
                                    linkText: string;
                                }[] | undefined;
                            } | undefined;
                            required?: boolean | undefined;
                            display?: boolean | undefined;
                            disabled?: boolean | undefined;
                            markdownMessage?: {
                                text: string;
                                markdownType: "text";
                                color?: string | undefined;
                            } | {
                                text: string;
                                link: string;
                                linkText: string;
                                markdownType: "hybrid";
                                token: string;
                            } | {
                                text: string;
                                link: string;
                                markdownType: "link";
                            } | {
                                text: string;
                                markdownType?: undefined;
                            } | undefined;
                        }[];
                        mode?: "clone" | "create" | "edit" | "config" | undefined;
                    }[] | undefined;
                } | {
                    options: {
                        auth_type: ("oauth" | "basic" | "oauth_client_credentials")[];
                        display?: boolean | undefined;
                        disableonEdit?: boolean | undefined;
                        enable?: boolean | undefined;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                        oauth?: {
                            label: string;
                            field: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            help?: string | {
                                text: string;
                                link?: string | undefined;
                                links?: {
                                    slug: string;
                                    link: string;
                                    linkText: string;
                                }[] | undefined;
                            } | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: [number, number];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | {
                                        text: string;
                                        link?: string | undefined;
                                        links?: {
                                            slug: string;
                                            link: string;
                                            linkText: string;
                                        }[] | undefined;
                                    } | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        text: string;
                                        markdownType: "text";
                                        color?: string | undefined;
                                    } | {
                                        text: string;
                                        link: string;
                                        linkText: string;
                                        markdownType: "hybrid";
                                        token: string;
                                    } | {
                                        text: string;
                                        link: string;
                                        markdownType: "link";
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }[] | undefined;
                        basic?: {
                            label: string;
                            field: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            help?: string | {
                                text: string;
                                link?: string | undefined;
                                links?: {
                                    slug: string;
                                    link: string;
                                    linkText: string;
                                }[] | undefined;
                            } | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: [number, number];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | {
                                        text: string;
                                        link?: string | undefined;
                                        links?: {
                                            slug: string;
                                            link: string;
                                            linkText: string;
                                        }[] | undefined;
                                    } | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        text: string;
                                        markdownType: "text";
                                        color?: string | undefined;
                                    } | {
                                        text: string;
                                        link: string;
                                        linkText: string;
                                        markdownType: "hybrid";
                                        token: string;
                                    } | {
                                        text: string;
                                        link: string;
                                        markdownType: "link";
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }[] | undefined;
                        oauth_client_credentials?: {
                            label: string;
                            field: string;
                            oauth_field: string;
                            options?: {
                                display?: boolean | undefined;
                                disableonEdit?: boolean | undefined;
                                enable?: boolean | undefined;
                                requiredWhenVisible?: boolean | undefined;
                                hideForPlatform?: "cloud" | "enterprise" | undefined;
                            } | undefined;
                            type?: "text" | undefined;
                            help?: string | {
                                text: string;
                                link?: string | undefined;
                                links?: {
                                    slug: string;
                                    link: string;
                                    linkText: string;
                                }[] | undefined;
                            } | undefined;
                            required?: boolean | undefined;
                            encrypted?: boolean | undefined;
                            validators?: ({
                                type: "number";
                                range: [number, number];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            } | {
                                type: "string";
                                minLength: number;
                                maxLength: number;
                                errorMsg?: string | undefined;
                            } | {
                                type: "regex";
                                pattern: string;
                                errorMsg?: string | undefined;
                            } | {
                                type: "email";
                                errorMsg?: string | undefined;
                            } | {
                                type: "ipv4";
                                errorMsg?: string | undefined;
                            } | {
                                type: "url";
                                errorMsg?: string | undefined;
                            } | {
                                type: "date";
                                errorMsg?: string | undefined;
                            })[] | undefined;
                            defaultValue?: string | number | boolean | undefined;
                            modifyFieldsOnValue?: {
                                fieldValue: string | number | boolean;
                                fieldsToModify: {
                                    fieldId: string;
                                    value?: string | number | boolean | undefined;
                                    label?: string | undefined;
                                    help?: string | {
                                        text: string;
                                        link?: string | undefined;
                                        links?: {
                                            slug: string;
                                            link: string;
                                            linkText: string;
                                        }[] | undefined;
                                    } | undefined;
                                    required?: boolean | undefined;
                                    display?: boolean | undefined;
                                    disabled?: boolean | undefined;
                                    markdownMessage?: {
                                        text: string;
                                        markdownType: "text";
                                        color?: string | undefined;
                                    } | {
                                        text: string;
                                        link: string;
                                        linkText: string;
                                        markdownType: "hybrid";
                                        token: string;
                                    } | {
                                        text: string;
                                        link: string;
                                        markdownType: "link";
                                    } | {
                                        text: string;
                                        markdownType?: undefined;
                                    } | undefined;
                                }[];
                                mode?: "clone" | "create" | "edit" | "config" | undefined;
                            }[] | undefined;
                        }[] | undefined;
                        auth_label?: string | undefined;
                        oauth_popup_width?: number | undefined;
                        oauth_popup_height?: number | undefined;
                        oauth_timeout?: number | undefined;
                        auth_code_endpoint?: string | undefined;
                        access_token_endpoint?: string | undefined;
                        oauth_state_enabled?: boolean | undefined;
                        auth_endpoint_token_access_type?: string | undefined;
                    };
                    type: "oauth";
                    label: string;
                    field: string;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                    validators?: ({
                        type: "string";
                        minLength: number;
                        maxLength: number;
                        errorMsg?: string | undefined;
                    } | {
                        type: "regex";
                        pattern: string;
                        errorMsg?: string | undefined;
                    })[] | undefined;
                    defaultValue?: string | undefined;
                } | {
                    options: {
                        type: "external";
                        src: string;
                        hideForPlatform?: "cloud" | "enterprise" | undefined;
                    };
                    type: "custom";
                    label: string;
                    field: string;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    tooltip?: string | undefined;
                    required?: boolean | undefined;
                    encrypted?: boolean | undefined;
                })[];
                title: string;
                options?: {
                    saveValidator?: string | undefined;
                } | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
                groups?: {
                    label: string;
                    fields: string[];
                    options?: {
                        isExpandable?: boolean | undefined;
                        expand?: boolean | undefined;
                    } | undefined;
                }[] | undefined;
                style?: "page" | "dialog" | undefined;
                hook?: Record<string, any> | undefined;
                conf?: string | undefined;
                restHandlerName?: string | undefined;
                restHandlerModule?: string | undefined;
                restHandlerClass?: string | undefined;
                warning?: {
                    clone?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    create?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    edit?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                    config?: {
                        message: string;
                        alwaysDisplay?: boolean | undefined;
                    } | undefined;
                } | undefined;
                formTitle?: string | undefined;
                subTitle?: string | undefined;
                inputHelperModule?: string | undefined;
                disableNewInput?: boolean | undefined;
            }[];
            description?: string | undefined;
            useInputToggleConfirmation?: boolean | undefined;
            inputsUniqueAcrossSingleService?: boolean | undefined;
            subDescription?: {
                text: string;
                links?: {
                    slug: string;
                    link: string;
                    linkText: string;
                }[] | undefined;
            } | undefined;
            menu?: {
                type: "external";
                src: string;
            } | undefined;
            groupsMenu?: {
                groupName: string;
                groupTitle: string;
                groupServices?: string[] | undefined;
            }[] | undefined;
            hideFieldId?: string | undefined;
            readonlyFieldId?: string | undefined;
        } | undefined;
        dashboard?: {
            panels: {
                name: string;
            }[];
            troubleshooting_url?: string | undefined;
            settings?: {
                custom_tab_name?: string | undefined;
            } | undefined;
        } | undefined;
    };
    alerts?: {
        name: string;
        label: string;
        description: string;
        entity?: ({
            type: "text";
            label: string;
            field: string;
            options?: {
                display?: boolean | undefined;
                disableonEdit?: boolean | undefined;
                enable?: boolean | undefined;
                requiredWhenVisible?: boolean | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
            } | undefined;
            help?: string | {
                text: string;
                link?: string | undefined;
                links?: {
                    slug: string;
                    link: string;
                    linkText: string;
                }[] | undefined;
            } | undefined;
            tooltip?: string | undefined;
            required?: boolean | undefined;
            encrypted?: boolean | undefined;
            validators?: ({
                type: "number";
                range: [number, number];
                errorMsg?: string | undefined;
                isInteger?: boolean | undefined;
            } | {
                type: "string";
                minLength: number;
                maxLength: number;
                errorMsg?: string | undefined;
            } | {
                type: "regex";
                pattern: string;
                errorMsg?: string | undefined;
            } | {
                type: "email";
                errorMsg?: string | undefined;
            } | {
                type: "ipv4";
                errorMsg?: string | undefined;
            } | {
                type: "url";
                errorMsg?: string | undefined;
            } | {
                type: "date";
                errorMsg?: string | undefined;
            })[] | undefined;
            defaultValue?: string | number | boolean | undefined;
            modifyFieldsOnValue?: {
                fieldValue: string | number | boolean;
                fieldsToModify: {
                    fieldId: string;
                    value?: string | number | boolean | undefined;
                    label?: string | undefined;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    required?: boolean | undefined;
                    display?: boolean | undefined;
                    disabled?: boolean | undefined;
                    markdownMessage?: {
                        text: string;
                        markdownType: "text";
                        color?: string | undefined;
                    } | {
                        text: string;
                        link: string;
                        linkText: string;
                        markdownType: "hybrid";
                        token: string;
                    } | {
                        text: string;
                        link: string;
                        markdownType: "link";
                    } | {
                        text: string;
                        markdownType?: undefined;
                    } | undefined;
                }[];
                mode?: "clone" | "create" | "edit" | "config" | undefined;
            }[] | undefined;
        } | {
            type: "textarea";
            label: string;
            field: string;
            options?: {
                display?: boolean | undefined;
                disableonEdit?: boolean | undefined;
                enable?: boolean | undefined;
                requiredWhenVisible?: boolean | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
                rowsMin?: number | undefined;
                rowsMax?: number | undefined;
            } | undefined;
            help?: string | {
                text: string;
                link?: string | undefined;
                links?: {
                    slug: string;
                    link: string;
                    linkText: string;
                }[] | undefined;
            } | undefined;
            tooltip?: string | undefined;
            required?: boolean | undefined;
            encrypted?: boolean | undefined;
            validators?: ({
                type: "number";
                range: [number, number];
                errorMsg?: string | undefined;
                isInteger?: boolean | undefined;
            } | {
                type: "string";
                minLength: number;
                maxLength: number;
                errorMsg?: string | undefined;
            } | {
                type: "regex";
                pattern: string;
                errorMsg?: string | undefined;
            } | {
                type: "email";
                errorMsg?: string | undefined;
            } | {
                type: "ipv4";
                errorMsg?: string | undefined;
            } | {
                type: "url";
                errorMsg?: string | undefined;
            } | {
                type: "date";
                errorMsg?: string | undefined;
            })[] | undefined;
            defaultValue?: string | undefined;
            modifyFieldsOnValue?: {
                fieldValue: string | number | boolean;
                fieldsToModify: {
                    fieldId: string;
                    value?: string | number | boolean | undefined;
                    label?: string | undefined;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    required?: boolean | undefined;
                    display?: boolean | undefined;
                    disabled?: boolean | undefined;
                    markdownMessage?: {
                        text: string;
                        markdownType: "text";
                        color?: string | undefined;
                    } | {
                        text: string;
                        link: string;
                        linkText: string;
                        markdownType: "hybrid";
                        token: string;
                    } | {
                        text: string;
                        link: string;
                        markdownType: "link";
                    } | {
                        text: string;
                        markdownType?: undefined;
                    } | undefined;
                }[];
                mode?: "clone" | "create" | "edit" | "config" | undefined;
            }[] | undefined;
        } | {
            options: {
                display?: boolean | undefined;
                disableonEdit?: boolean | undefined;
                enable?: boolean | undefined;
                requiredWhenVisible?: boolean | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
                disableSearch?: boolean | undefined;
                createSearchChoice?: boolean | undefined;
                referenceName?: string | undefined;
                endpointUrl?: string | undefined;
                allowList?: string | undefined;
                denyList?: string | undefined;
                labelField?: string | undefined;
                valueField?: string | undefined;
                autoCompleteFields?: ({
                    value: string | number | boolean;
                    label: string;
                } | {
                    label: string;
                    children: {
                        value: string | number | boolean;
                        label: string;
                    }[];
                })[] | undefined;
                dependencies?: string[] | undefined;
                items?: {
                    value: string | number | boolean;
                    label: string;
                }[] | undefined;
            };
            type: "singleSelect";
            label: string;
            field: string;
            help?: string | {
                text: string;
                link?: string | undefined;
                links?: {
                    slug: string;
                    link: string;
                    linkText: string;
                }[] | undefined;
            } | undefined;
            tooltip?: string | undefined;
            required?: boolean | undefined;
            encrypted?: boolean | undefined;
            validators?: ({
                type: "number";
                range: [number, number];
                errorMsg?: string | undefined;
                isInteger?: boolean | undefined;
            } | {
                type: "string";
                minLength: number;
                maxLength: number;
                errorMsg?: string | undefined;
            } | {
                type: "regex";
                pattern: string;
                errorMsg?: string | undefined;
            } | {
                type: "email";
                errorMsg?: string | undefined;
            } | {
                type: "ipv4";
                errorMsg?: string | undefined;
            } | {
                type: "url";
                errorMsg?: string | undefined;
            } | {
                type: "date";
                errorMsg?: string | undefined;
            })[] | undefined;
            defaultValue?: string | number | boolean | undefined;
            modifyFieldsOnValue?: {
                fieldValue: string | number | boolean;
                fieldsToModify: {
                    fieldId: string;
                    value?: string | number | boolean | undefined;
                    label?: string | undefined;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    required?: boolean | undefined;
                    display?: boolean | undefined;
                    disabled?: boolean | undefined;
                    markdownMessage?: {
                        text: string;
                        markdownType: "text";
                        color?: string | undefined;
                    } | {
                        text: string;
                        link: string;
                        linkText: string;
                        markdownType: "hybrid";
                        token: string;
                    } | {
                        text: string;
                        link: string;
                        markdownType: "link";
                    } | {
                        text: string;
                        markdownType?: undefined;
                    } | undefined;
                }[];
                mode?: "clone" | "create" | "edit" | "config" | undefined;
            }[] | undefined;
        } | {
            type: "checkbox";
            label: string;
            field: string;
            options?: {
                display?: boolean | undefined;
                disableonEdit?: boolean | undefined;
                enable?: boolean | undefined;
                requiredWhenVisible?: boolean | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
            } | undefined;
            help?: string | {
                text: string;
                link?: string | undefined;
                links?: {
                    slug: string;
                    link: string;
                    linkText: string;
                }[] | undefined;
            } | undefined;
            tooltip?: string | undefined;
            required?: boolean | undefined;
            encrypted?: boolean | undefined;
            defaultValue?: number | boolean | undefined;
            modifyFieldsOnValue?: {
                fieldValue: string | number | boolean;
                fieldsToModify: {
                    fieldId: string;
                    value?: string | number | boolean | undefined;
                    label?: string | undefined;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    required?: boolean | undefined;
                    display?: boolean | undefined;
                    disabled?: boolean | undefined;
                    markdownMessage?: {
                        text: string;
                        markdownType: "text";
                        color?: string | undefined;
                    } | {
                        text: string;
                        link: string;
                        linkText: string;
                        markdownType: "hybrid";
                        token: string;
                    } | {
                        text: string;
                        link: string;
                        markdownType: "link";
                    } | {
                        text: string;
                        markdownType?: undefined;
                    } | undefined;
                }[];
                mode?: "clone" | "create" | "edit" | "config" | undefined;
            }[] | undefined;
        } | {
            options: {
                items: {
                    value: string | number | boolean;
                    label: string;
                }[];
                display?: boolean | undefined;
                disableonEdit?: boolean | undefined;
                enable?: boolean | undefined;
                requiredWhenVisible?: boolean | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
            };
            type: "radio";
            label: string;
            field: string;
            help?: string | {
                text: string;
                link?: string | undefined;
                links?: {
                    slug: string;
                    link: string;
                    linkText: string;
                }[] | undefined;
            } | undefined;
            tooltip?: string | undefined;
            required?: boolean | undefined;
            encrypted?: boolean | undefined;
            defaultValue?: string | undefined;
            modifyFieldsOnValue?: {
                fieldValue: string | number | boolean;
                fieldsToModify: {
                    fieldId: string;
                    value?: string | number | boolean | undefined;
                    label?: string | undefined;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    required?: boolean | undefined;
                    display?: boolean | undefined;
                    disabled?: boolean | undefined;
                    markdownMessage?: {
                        text: string;
                        markdownType: "text";
                        color?: string | undefined;
                    } | {
                        text: string;
                        link: string;
                        linkText: string;
                        markdownType: "hybrid";
                        token: string;
                    } | {
                        text: string;
                        link: string;
                        markdownType: "link";
                    } | {
                        text: string;
                        markdownType?: undefined;
                    } | undefined;
                }[];
                mode?: "clone" | "create" | "edit" | "config" | undefined;
            }[] | undefined;
        } | {
            type: "singleSelectSplunkSearch";
            label: string;
            field: string;
            options?: {
                items: {
                    value: string | number | boolean;
                    label: string;
                }[];
            } | undefined;
            help?: string | {
                text: string;
                link?: string | undefined;
                links?: {
                    slug: string;
                    link: string;
                    linkText: string;
                }[] | undefined;
            } | undefined;
            tooltip?: string | undefined;
            defaultValue?: string | number | boolean | undefined;
            labelField?: string | undefined;
            valueField?: string | undefined;
            search?: string | undefined;
        })[] | undefined;
        adaptiveResponse?: {
            task: string[];
            supportsAdhoc: boolean;
            supportsCloud: boolean;
            subject: string[];
            category: string[];
            technology: {
                version: string[];
                product: string;
                vendor: string;
            }[];
            drilldownUri?: string | undefined;
            sourcetype?: string | undefined;
        } | undefined;
    }[] | undefined;
}>;

declare type IAlerts = z.output<typeof alerts>;

declare type IAlertsIn = z.input<typeof alerts>;

declare interface IAlertsRT extends z.ZodType<IAlerts, z.ZodTypeDef, IAlertsIn> {
}

declare type IMeta = z.output<typeof meta>;

declare type IMetaIn = z.input<typeof meta>;

declare interface IMetaRT extends z.ZodType<IMeta, z.ZodTypeDef, IMetaIn> {
}

declare type IPages = z.output<typeof pages>;

declare type IPagesIn = z.input<typeof pages>;

declare interface IPagesRT extends z.ZodType<IPages, z.ZodTypeDef, IPagesIn> {
}

declare type MarkdownMessageProps = z.infer<typeof MarkdownMessageType>;

declare const MarkdownMessageType: z.ZodUnion<[z.ZodObject<{
    markdownType: z.ZodLiteral<"text">;
    text: z.ZodString;
    color: z.ZodOptional<z.ZodString>;
}, "strip", z.ZodTypeAny, {
    text: string;
    markdownType: "text";
    color?: string | undefined;
}, {
    text: string;
    markdownType: "text";
    color?: string | undefined;
}>, z.ZodObject<{
    markdownType: z.ZodLiteral<"hybrid">;
    text: z.ZodString;
    token: z.ZodString;
    linkText: z.ZodString;
    link: z.ZodString;
}, "strip", z.ZodTypeAny, {
    text: string;
    link: string;
    linkText: string;
    markdownType: "hybrid";
    token: string;
}, {
    text: string;
    link: string;
    linkText: string;
    markdownType: "hybrid";
    token: string;
}>, z.ZodObject<{
    markdownType: z.ZodLiteral<"link">;
    text: z.ZodString;
    link: z.ZodString;
}, "strip", z.ZodTypeAny, {
    text: string;
    link: string;
    markdownType: "link";
}, {
    text: string;
    link: string;
    markdownType: "link";
}>, z.ZodObject<{
    markdownType: z.ZodOptional<z.ZodUndefined>;
    text: z.ZodString;
}, "strip", z.ZodTypeAny, {
    text: string;
    markdownType?: undefined;
}, {
    text: string;
    markdownType?: undefined;
}>]>;

declare const meta: z.ZodObject<{
    displayName: z.ZodString;
    name: z.ZodString;
    restRoot: z.ZodString;
    apiVersion: z.ZodOptional<z.ZodString>;
    version: z.ZodString;
    schemaVersion: z.ZodOptional<z.ZodString>;
    _uccVersion: z.ZodOptional<z.ZodString>;
    hideUCCVersion: z.ZodOptional<z.ZodBoolean>;
    checkForUpdates: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
    searchViewDefault: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
    isVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
    supportedThemes: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
}, "strip", z.ZodTypeAny, {
    displayName: string;
    name: string;
    restRoot: string;
    version: string;
    apiVersion?: string | undefined;
    schemaVersion?: string | undefined;
    _uccVersion?: string | undefined;
    hideUCCVersion?: boolean | undefined;
    checkForUpdates?: boolean | undefined;
    searchViewDefault?: boolean | undefined;
    isVisible?: boolean | undefined;
    supportedThemes?: string[] | undefined;
}, {
    displayName: string;
    name: string;
    restRoot: string;
    version: string;
    apiVersion?: string | undefined;
    schemaVersion?: string | undefined;
    _uccVersion?: string | undefined;
    hideUCCVersion?: boolean | undefined;
    checkForUpdates?: boolean | undefined;
    searchViewDefault?: boolean | undefined;
    isVisible?: boolean | undefined;
    supportedThemes?: string[] | undefined;
}>;

declare type meta = z.infer<typeof meta>;

export declare type Mode = typeof MODE_CLONE | typeof MODE_CREATE | typeof MODE_DELETE | typeof MODE_EDIT | typeof MODE_CONFIG;

declare const MODE_CLONE = "clone";

declare const MODE_CONFIG = "config";

declare const MODE_CREATE = "create";

declare const MODE_DELETE = "delete";

declare const MODE_EDIT = "edit";

export declare type NullishFormRecord = Record<string, AcceptableFormValueOrNullish>;

declare const OAuthEntity: z.ZodObject<{
    field: z.ZodString;
    label: z.ZodString;
    help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
        text: z.ZodString;
        links: z.ZodOptional<z.ZodArray<z.ZodObject<{
            slug: z.ZodString;
            link: z.ZodString;
            linkText: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            slug: string;
            link: string;
            linkText: string;
        }, {
            slug: string;
            link: string;
            linkText: string;
        }>, "many">>;
        link: z.ZodOptional<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        text: string;
        link?: string | undefined;
        links?: {
            slug: string;
            link: string;
            linkText: string;
        }[] | undefined;
    }, {
        text: string;
        link?: string | undefined;
        links?: {
            slug: string;
            link: string;
            linkText: string;
        }[] | undefined;
    }>]>>;
    tooltip: z.ZodOptional<z.ZodString>;
    required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
    encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
} & {
    type: z.ZodLiteral<"oauth">;
    defaultValue: z.ZodOptional<z.ZodString>;
    validators: z.ZodOptional<z.ZodArray<z.ZodUnion<[z.ZodObject<{
        errorMsg: z.ZodOptional<z.ZodString>;
        type: z.ZodLiteral<"string">;
        minLength: z.ZodNumber;
        maxLength: z.ZodNumber;
    }, "strip", z.ZodTypeAny, {
        type: "string";
        minLength: number;
        maxLength: number;
        errorMsg?: string | undefined;
    }, {
        type: "string";
        minLength: number;
        maxLength: number;
        errorMsg?: string | undefined;
    }>, z.ZodObject<{
        errorMsg: z.ZodOptional<z.ZodString>;
        type: z.ZodLiteral<"regex">;
        pattern: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        type: "regex";
        pattern: string;
        errorMsg?: string | undefined;
    }, {
        type: "regex";
        pattern: string;
        errorMsg?: string | undefined;
    }>]>, "many">>;
    options: z.ZodObject<Omit<{
        display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
        disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
        enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
        requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
        hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
    }, "requiredWhenVisible"> & {
        auth_type: z.ZodArray<z.ZodUnion<[z.ZodLiteral<"basic">, z.ZodLiteral<"oauth">, z.ZodLiteral<"oauth_client_credentials">]>, "many">;
        basic: z.ZodOptional<z.ZodArray<z.ZodObject<{
            oauth_field: z.ZodString;
            label: z.ZodString;
            field: z.ZodString;
            type: z.ZodOptional<z.ZodDefault<z.ZodLiteral<"text">>>;
            help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                text: z.ZodString;
                links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                    slug: z.ZodString;
                    link: z.ZodString;
                    linkText: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    slug: string;
                    link: string;
                    linkText: string;
                }, {
                    slug: string;
                    link: string;
                    linkText: string;
                }>, "many">>;
                link: z.ZodOptional<z.ZodString>;
            }, "strip", z.ZodTypeAny, {
                text: string;
                link?: string | undefined;
                links?: {
                    slug: string;
                    link: string;
                    linkText: string;
                }[] | undefined;
            }, {
                text: string;
                link?: string | undefined;
                links?: {
                    slug: string;
                    link: string;
                    linkText: string;
                }[] | undefined;
            }>]>>;
            encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            defaultValue: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodNumber, z.ZodBoolean]>>;
            options: z.ZodOptional<z.ZodObject<{
                display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
            }, "strip", z.ZodTypeAny, {
                display?: boolean | undefined;
                disableonEdit?: boolean | undefined;
                enable?: boolean | undefined;
                requiredWhenVisible?: boolean | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
            }, {
                display?: boolean | undefined;
                disableonEdit?: boolean | undefined;
                enable?: boolean | undefined;
                requiredWhenVisible?: boolean | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
            }>>;
            modifyFieldsOnValue: z.ZodOptional<z.ZodArray<z.ZodObject<{
                fieldValue: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                mode: z.ZodOptional<z.ZodEnum<["create", "edit", "config", "clone"]>>;
                fieldsToModify: z.ZodArray<z.ZodObject<{
                    fieldId: z.ZodString;
                    display: z.ZodOptional<z.ZodBoolean>;
                    value: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>>;
                    disabled: z.ZodOptional<z.ZodBoolean>;
                    required: z.ZodOptional<z.ZodBoolean>;
                    help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                        text: z.ZodString;
                        links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                            slug: z.ZodString;
                            link: z.ZodString;
                            linkText: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            slug: string;
                            link: string;
                            linkText: string;
                        }, {
                            slug: string;
                            link: string;
                            linkText: string;
                        }>, "many">>;
                        link: z.ZodOptional<z.ZodString>;
                    }, "strip", z.ZodTypeAny, {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    }, {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    }>]>>;
                    label: z.ZodOptional<z.ZodString>;
                    markdownMessage: z.ZodOptional<z.ZodUnion<[z.ZodObject<{
                        markdownType: z.ZodLiteral<"text">;
                        text: z.ZodString;
                        color: z.ZodOptional<z.ZodString>;
                    }, "strip", z.ZodTypeAny, {
                        text: string;
                        markdownType: "text";
                        color?: string | undefined;
                    }, {
                        text: string;
                        markdownType: "text";
                        color?: string | undefined;
                    }>, z.ZodObject<{
                        markdownType: z.ZodLiteral<"hybrid">;
                        text: z.ZodString;
                        token: z.ZodString;
                        linkText: z.ZodString;
                        link: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        text: string;
                        link: string;
                        linkText: string;
                        markdownType: "hybrid";
                        token: string;
                    }, {
                        text: string;
                        link: string;
                        linkText: string;
                        markdownType: "hybrid";
                        token: string;
                    }>, z.ZodObject<{
                        markdownType: z.ZodLiteral<"link">;
                        text: z.ZodString;
                        link: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        text: string;
                        link: string;
                        markdownType: "link";
                    }, {
                        text: string;
                        link: string;
                        markdownType: "link";
                    }>, z.ZodObject<{
                        markdownType: z.ZodOptional<z.ZodUndefined>;
                        text: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        text: string;
                        markdownType?: undefined;
                    }, {
                        text: string;
                        markdownType?: undefined;
                    }>]>>;
                }, "strip", z.ZodTypeAny, {
                    fieldId: string;
                    value?: string | number | boolean | undefined;
                    label?: string | undefined;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    required?: boolean | undefined;
                    display?: boolean | undefined;
                    disabled?: boolean | undefined;
                    markdownMessage?: {
                        text: string;
                        markdownType: "text";
                        color?: string | undefined;
                    } | {
                        text: string;
                        link: string;
                        linkText: string;
                        markdownType: "hybrid";
                        token: string;
                    } | {
                        text: string;
                        link: string;
                        markdownType: "link";
                    } | {
                        text: string;
                        markdownType?: undefined;
                    } | undefined;
                }, {
                    fieldId: string;
                    value?: string | number | boolean | undefined;
                    label?: string | undefined;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    required?: boolean | undefined;
                    display?: boolean | undefined;
                    disabled?: boolean | undefined;
                    markdownMessage?: {
                        text: string;
                        markdownType: "text";
                        color?: string | undefined;
                    } | {
                        text: string;
                        link: string;
                        linkText: string;
                        markdownType: "hybrid";
                        token: string;
                    } | {
                        text: string;
                        link: string;
                        markdownType: "link";
                    } | {
                        text: string;
                        markdownType?: undefined;
                    } | undefined;
                }>, "many">;
            }, "strip", z.ZodTypeAny, {
                fieldValue: string | number | boolean;
                fieldsToModify: {
                    fieldId: string;
                    value?: string | number | boolean | undefined;
                    label?: string | undefined;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    required?: boolean | undefined;
                    display?: boolean | undefined;
                    disabled?: boolean | undefined;
                    markdownMessage?: {
                        text: string;
                        markdownType: "text";
                        color?: string | undefined;
                    } | {
                        text: string;
                        link: string;
                        linkText: string;
                        markdownType: "hybrid";
                        token: string;
                    } | {
                        text: string;
                        link: string;
                        markdownType: "link";
                    } | {
                        text: string;
                        markdownType?: undefined;
                    } | undefined;
                }[];
                mode?: "clone" | "create" | "edit" | "config" | undefined;
            }, {
                fieldValue: string | number | boolean;
                fieldsToModify: {
                    fieldId: string;
                    value?: string | number | boolean | undefined;
                    label?: string | undefined;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    required?: boolean | undefined;
                    display?: boolean | undefined;
                    disabled?: boolean | undefined;
                    markdownMessage?: {
                        text: string;
                        markdownType: "text";
                        color?: string | undefined;
                    } | {
                        text: string;
                        link: string;
                        linkText: string;
                        markdownType: "hybrid";
                        token: string;
                    } | {
                        text: string;
                        link: string;
                        markdownType: "link";
                    } | {
                        text: string;
                        markdownType?: undefined;
                    } | undefined;
                }[];
                mode?: "clone" | "create" | "edit" | "config" | undefined;
            }>, "many">>;
            validators: z.ZodOptional<z.ZodArray<z.ZodUnion<[z.ZodObject<{
                errorMsg: z.ZodOptional<z.ZodString>;
                type: z.ZodLiteral<"number">;
                range: z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>;
                isInteger: z.ZodOptional<z.ZodBoolean>;
            }, "strip", z.ZodTypeAny, {
                type: "number";
                range: [number, number];
                errorMsg?: string | undefined;
                isInteger?: boolean | undefined;
            }, {
                type: "number";
                range: [number, number];
                errorMsg?: string | undefined;
                isInteger?: boolean | undefined;
            }>, z.ZodObject<{
                errorMsg: z.ZodOptional<z.ZodString>;
                type: z.ZodLiteral<"string">;
                minLength: z.ZodNumber;
                maxLength: z.ZodNumber;
            }, "strip", z.ZodTypeAny, {
                type: "string";
                minLength: number;
                maxLength: number;
                errorMsg?: string | undefined;
            }, {
                type: "string";
                minLength: number;
                maxLength: number;
                errorMsg?: string | undefined;
            }>, z.ZodObject<{
                errorMsg: z.ZodOptional<z.ZodString>;
                type: z.ZodLiteral<"regex">;
                pattern: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                type: "regex";
                pattern: string;
                errorMsg?: string | undefined;
            }, {
                type: "regex";
                pattern: string;
                errorMsg?: string | undefined;
            }>, z.ZodObject<{
                errorMsg: z.ZodOptional<z.ZodString>;
                type: z.ZodLiteral<"email">;
            }, "strip", z.ZodTypeAny, {
                type: "email";
                errorMsg?: string | undefined;
            }, {
                type: "email";
                errorMsg?: string | undefined;
            }>, z.ZodObject<{
                errorMsg: z.ZodOptional<z.ZodString>;
                type: z.ZodLiteral<"ipv4">;
            }, "strip", z.ZodTypeAny, {
                type: "ipv4";
                errorMsg?: string | undefined;
            }, {
                type: "ipv4";
                errorMsg?: string | undefined;
            }>, z.ZodObject<{
                errorMsg: z.ZodOptional<z.ZodString>;
                type: z.ZodLiteral<"url">;
            }, "strip", z.ZodTypeAny, {
                type: "url";
                errorMsg?: string | undefined;
            }, {
                type: "url";
                errorMsg?: string | undefined;
            }>, z.ZodObject<{
                errorMsg: z.ZodOptional<z.ZodString>;
                type: z.ZodLiteral<"date">;
            }, "strip", z.ZodTypeAny, {
                type: "date";
                errorMsg?: string | undefined;
            }, {
                type: "date";
                errorMsg?: string | undefined;
            }>]>, "many">>;
        }, "strip", z.ZodTypeAny, {
            label: string;
            field: string;
            oauth_field: string;
            options?: {
                display?: boolean | undefined;
                disableonEdit?: boolean | undefined;
                enable?: boolean | undefined;
                requiredWhenVisible?: boolean | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
            } | undefined;
            type?: "text" | undefined;
            help?: string | {
                text: string;
                link?: string | undefined;
                links?: {
                    slug: string;
                    link: string;
                    linkText: string;
                }[] | undefined;
            } | undefined;
            required?: boolean | undefined;
            encrypted?: boolean | undefined;
            validators?: ({
                type: "number";
                range: [number, number];
                errorMsg?: string | undefined;
                isInteger?: boolean | undefined;
            } | {
                type: "string";
                minLength: number;
                maxLength: number;
                errorMsg?: string | undefined;
            } | {
                type: "regex";
                pattern: string;
                errorMsg?: string | undefined;
            } | {
                type: "email";
                errorMsg?: string | undefined;
            } | {
                type: "ipv4";
                errorMsg?: string | undefined;
            } | {
                type: "url";
                errorMsg?: string | undefined;
            } | {
                type: "date";
                errorMsg?: string | undefined;
            })[] | undefined;
            defaultValue?: string | number | boolean | undefined;
            modifyFieldsOnValue?: {
                fieldValue: string | number | boolean;
                fieldsToModify: {
                    fieldId: string;
                    value?: string | number | boolean | undefined;
                    label?: string | undefined;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    required?: boolean | undefined;
                    display?: boolean | undefined;
                    disabled?: boolean | undefined;
                    markdownMessage?: {
                        text: string;
                        markdownType: "text";
                        color?: string | undefined;
                    } | {
                        text: string;
                        link: string;
                        linkText: string;
                        markdownType: "hybrid";
                        token: string;
                    } | {
                        text: string;
                        link: string;
                        markdownType: "link";
                    } | {
                        text: string;
                        markdownType?: undefined;
                    } | undefined;
                }[];
                mode?: "clone" | "create" | "edit" | "config" | undefined;
            }[] | undefined;
        }, {
            label: string;
            field: string;
            oauth_field: string;
            options?: {
                display?: boolean | undefined;
                disableonEdit?: boolean | undefined;
                enable?: boolean | undefined;
                requiredWhenVisible?: boolean | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
            } | undefined;
            type?: "text" | undefined;
            help?: string | {
                text: string;
                link?: string | undefined;
                links?: {
                    slug: string;
                    link: string;
                    linkText: string;
                }[] | undefined;
            } | undefined;
            required?: boolean | undefined;
            encrypted?: boolean | undefined;
            validators?: ({
                type: "number";
                range: [number, number];
                errorMsg?: string | undefined;
                isInteger?: boolean | undefined;
            } | {
                type: "string";
                minLength: number;
                maxLength: number;
                errorMsg?: string | undefined;
            } | {
                type: "regex";
                pattern: string;
                errorMsg?: string | undefined;
            } | {
                type: "email";
                errorMsg?: string | undefined;
            } | {
                type: "ipv4";
                errorMsg?: string | undefined;
            } | {
                type: "url";
                errorMsg?: string | undefined;
            } | {
                type: "date";
                errorMsg?: string | undefined;
            })[] | undefined;
            defaultValue?: string | number | boolean | undefined;
            modifyFieldsOnValue?: {
                fieldValue: string | number | boolean;
                fieldsToModify: {
                    fieldId: string;
                    value?: string | number | boolean | undefined;
                    label?: string | undefined;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    required?: boolean | undefined;
                    display?: boolean | undefined;
                    disabled?: boolean | undefined;
                    markdownMessage?: {
                        text: string;
                        markdownType: "text";
                        color?: string | undefined;
                    } | {
                        text: string;
                        link: string;
                        linkText: string;
                        markdownType: "hybrid";
                        token: string;
                    } | {
                        text: string;
                        link: string;
                        markdownType: "link";
                    } | {
                        text: string;
                        markdownType?: undefined;
                    } | undefined;
                }[];
                mode?: "clone" | "create" | "edit" | "config" | undefined;
            }[] | undefined;
        }>, "many">>;
        oauth: z.ZodOptional<z.ZodArray<z.ZodObject<{
            oauth_field: z.ZodString;
            label: z.ZodString;
            field: z.ZodString;
            type: z.ZodOptional<z.ZodDefault<z.ZodLiteral<"text">>>;
            help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                text: z.ZodString;
                links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                    slug: z.ZodString;
                    link: z.ZodString;
                    linkText: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    slug: string;
                    link: string;
                    linkText: string;
                }, {
                    slug: string;
                    link: string;
                    linkText: string;
                }>, "many">>;
                link: z.ZodOptional<z.ZodString>;
            }, "strip", z.ZodTypeAny, {
                text: string;
                link?: string | undefined;
                links?: {
                    slug: string;
                    link: string;
                    linkText: string;
                }[] | undefined;
            }, {
                text: string;
                link?: string | undefined;
                links?: {
                    slug: string;
                    link: string;
                    linkText: string;
                }[] | undefined;
            }>]>>;
            encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            defaultValue: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodNumber, z.ZodBoolean]>>;
            options: z.ZodOptional<z.ZodObject<{
                display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
            }, "strip", z.ZodTypeAny, {
                display?: boolean | undefined;
                disableonEdit?: boolean | undefined;
                enable?: boolean | undefined;
                requiredWhenVisible?: boolean | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
            }, {
                display?: boolean | undefined;
                disableonEdit?: boolean | undefined;
                enable?: boolean | undefined;
                requiredWhenVisible?: boolean | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
            }>>;
            modifyFieldsOnValue: z.ZodOptional<z.ZodArray<z.ZodObject<{
                fieldValue: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                mode: z.ZodOptional<z.ZodEnum<["create", "edit", "config", "clone"]>>;
                fieldsToModify: z.ZodArray<z.ZodObject<{
                    fieldId: z.ZodString;
                    display: z.ZodOptional<z.ZodBoolean>;
                    value: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>>;
                    disabled: z.ZodOptional<z.ZodBoolean>;
                    required: z.ZodOptional<z.ZodBoolean>;
                    help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                        text: z.ZodString;
                        links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                            slug: z.ZodString;
                            link: z.ZodString;
                            linkText: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            slug: string;
                            link: string;
                            linkText: string;
                        }, {
                            slug: string;
                            link: string;
                            linkText: string;
                        }>, "many">>;
                        link: z.ZodOptional<z.ZodString>;
                    }, "strip", z.ZodTypeAny, {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    }, {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    }>]>>;
                    label: z.ZodOptional<z.ZodString>;
                    markdownMessage: z.ZodOptional<z.ZodUnion<[z.ZodObject<{
                        markdownType: z.ZodLiteral<"text">;
                        text: z.ZodString;
                        color: z.ZodOptional<z.ZodString>;
                    }, "strip", z.ZodTypeAny, {
                        text: string;
                        markdownType: "text";
                        color?: string | undefined;
                    }, {
                        text: string;
                        markdownType: "text";
                        color?: string | undefined;
                    }>, z.ZodObject<{
                        markdownType: z.ZodLiteral<"hybrid">;
                        text: z.ZodString;
                        token: z.ZodString;
                        linkText: z.ZodString;
                        link: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        text: string;
                        link: string;
                        linkText: string;
                        markdownType: "hybrid";
                        token: string;
                    }, {
                        text: string;
                        link: string;
                        linkText: string;
                        markdownType: "hybrid";
                        token: string;
                    }>, z.ZodObject<{
                        markdownType: z.ZodLiteral<"link">;
                        text: z.ZodString;
                        link: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        text: string;
                        link: string;
                        markdownType: "link";
                    }, {
                        text: string;
                        link: string;
                        markdownType: "link";
                    }>, z.ZodObject<{
                        markdownType: z.ZodOptional<z.ZodUndefined>;
                        text: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        text: string;
                        markdownType?: undefined;
                    }, {
                        text: string;
                        markdownType?: undefined;
                    }>]>>;
                }, "strip", z.ZodTypeAny, {
                    fieldId: string;
                    value?: string | number | boolean | undefined;
                    label?: string | undefined;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    required?: boolean | undefined;
                    display?: boolean | undefined;
                    disabled?: boolean | undefined;
                    markdownMessage?: {
                        text: string;
                        markdownType: "text";
                        color?: string | undefined;
                    } | {
                        text: string;
                        link: string;
                        linkText: string;
                        markdownType: "hybrid";
                        token: string;
                    } | {
                        text: string;
                        link: string;
                        markdownType: "link";
                    } | {
                        text: string;
                        markdownType?: undefined;
                    } | undefined;
                }, {
                    fieldId: string;
                    value?: string | number | boolean | undefined;
                    label?: string | undefined;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    required?: boolean | undefined;
                    display?: boolean | undefined;
                    disabled?: boolean | undefined;
                    markdownMessage?: {
                        text: string;
                        markdownType: "text";
                        color?: string | undefined;
                    } | {
                        text: string;
                        link: string;
                        linkText: string;
                        markdownType: "hybrid";
                        token: string;
                    } | {
                        text: string;
                        link: string;
                        markdownType: "link";
                    } | {
                        text: string;
                        markdownType?: undefined;
                    } | undefined;
                }>, "many">;
            }, "strip", z.ZodTypeAny, {
                fieldValue: string | number | boolean;
                fieldsToModify: {
                    fieldId: string;
                    value?: string | number | boolean | undefined;
                    label?: string | undefined;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    required?: boolean | undefined;
                    display?: boolean | undefined;
                    disabled?: boolean | undefined;
                    markdownMessage?: {
                        text: string;
                        markdownType: "text";
                        color?: string | undefined;
                    } | {
                        text: string;
                        link: string;
                        linkText: string;
                        markdownType: "hybrid";
                        token: string;
                    } | {
                        text: string;
                        link: string;
                        markdownType: "link";
                    } | {
                        text: string;
                        markdownType?: undefined;
                    } | undefined;
                }[];
                mode?: "clone" | "create" | "edit" | "config" | undefined;
            }, {
                fieldValue: string | number | boolean;
                fieldsToModify: {
                    fieldId: string;
                    value?: string | number | boolean | undefined;
                    label?: string | undefined;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    required?: boolean | undefined;
                    display?: boolean | undefined;
                    disabled?: boolean | undefined;
                    markdownMessage?: {
                        text: string;
                        markdownType: "text";
                        color?: string | undefined;
                    } | {
                        text: string;
                        link: string;
                        linkText: string;
                        markdownType: "hybrid";
                        token: string;
                    } | {
                        text: string;
                        link: string;
                        markdownType: "link";
                    } | {
                        text: string;
                        markdownType?: undefined;
                    } | undefined;
                }[];
                mode?: "clone" | "create" | "edit" | "config" | undefined;
            }>, "many">>;
            validators: z.ZodOptional<z.ZodArray<z.ZodUnion<[z.ZodObject<{
                errorMsg: z.ZodOptional<z.ZodString>;
                type: z.ZodLiteral<"number">;
                range: z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>;
                isInteger: z.ZodOptional<z.ZodBoolean>;
            }, "strip", z.ZodTypeAny, {
                type: "number";
                range: [number, number];
                errorMsg?: string | undefined;
                isInteger?: boolean | undefined;
            }, {
                type: "number";
                range: [number, number];
                errorMsg?: string | undefined;
                isInteger?: boolean | undefined;
            }>, z.ZodObject<{
                errorMsg: z.ZodOptional<z.ZodString>;
                type: z.ZodLiteral<"string">;
                minLength: z.ZodNumber;
                maxLength: z.ZodNumber;
            }, "strip", z.ZodTypeAny, {
                type: "string";
                minLength: number;
                maxLength: number;
                errorMsg?: string | undefined;
            }, {
                type: "string";
                minLength: number;
                maxLength: number;
                errorMsg?: string | undefined;
            }>, z.ZodObject<{
                errorMsg: z.ZodOptional<z.ZodString>;
                type: z.ZodLiteral<"regex">;
                pattern: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                type: "regex";
                pattern: string;
                errorMsg?: string | undefined;
            }, {
                type: "regex";
                pattern: string;
                errorMsg?: string | undefined;
            }>, z.ZodObject<{
                errorMsg: z.ZodOptional<z.ZodString>;
                type: z.ZodLiteral<"email">;
            }, "strip", z.ZodTypeAny, {
                type: "email";
                errorMsg?: string | undefined;
            }, {
                type: "email";
                errorMsg?: string | undefined;
            }>, z.ZodObject<{
                errorMsg: z.ZodOptional<z.ZodString>;
                type: z.ZodLiteral<"ipv4">;
            }, "strip", z.ZodTypeAny, {
                type: "ipv4";
                errorMsg?: string | undefined;
            }, {
                type: "ipv4";
                errorMsg?: string | undefined;
            }>, z.ZodObject<{
                errorMsg: z.ZodOptional<z.ZodString>;
                type: z.ZodLiteral<"url">;
            }, "strip", z.ZodTypeAny, {
                type: "url";
                errorMsg?: string | undefined;
            }, {
                type: "url";
                errorMsg?: string | undefined;
            }>, z.ZodObject<{
                errorMsg: z.ZodOptional<z.ZodString>;
                type: z.ZodLiteral<"date">;
            }, "strip", z.ZodTypeAny, {
                type: "date";
                errorMsg?: string | undefined;
            }, {
                type: "date";
                errorMsg?: string | undefined;
            }>]>, "many">>;
        }, "strip", z.ZodTypeAny, {
            label: string;
            field: string;
            oauth_field: string;
            options?: {
                display?: boolean | undefined;
                disableonEdit?: boolean | undefined;
                enable?: boolean | undefined;
                requiredWhenVisible?: boolean | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
            } | undefined;
            type?: "text" | undefined;
            help?: string | {
                text: string;
                link?: string | undefined;
                links?: {
                    slug: string;
                    link: string;
                    linkText: string;
                }[] | undefined;
            } | undefined;
            required?: boolean | undefined;
            encrypted?: boolean | undefined;
            validators?: ({
                type: "number";
                range: [number, number];
                errorMsg?: string | undefined;
                isInteger?: boolean | undefined;
            } | {
                type: "string";
                minLength: number;
                maxLength: number;
                errorMsg?: string | undefined;
            } | {
                type: "regex";
                pattern: string;
                errorMsg?: string | undefined;
            } | {
                type: "email";
                errorMsg?: string | undefined;
            } | {
                type: "ipv4";
                errorMsg?: string | undefined;
            } | {
                type: "url";
                errorMsg?: string | undefined;
            } | {
                type: "date";
                errorMsg?: string | undefined;
            })[] | undefined;
            defaultValue?: string | number | boolean | undefined;
            modifyFieldsOnValue?: {
                fieldValue: string | number | boolean;
                fieldsToModify: {
                    fieldId: string;
                    value?: string | number | boolean | undefined;
                    label?: string | undefined;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    required?: boolean | undefined;
                    display?: boolean | undefined;
                    disabled?: boolean | undefined;
                    markdownMessage?: {
                        text: string;
                        markdownType: "text";
                        color?: string | undefined;
                    } | {
                        text: string;
                        link: string;
                        linkText: string;
                        markdownType: "hybrid";
                        token: string;
                    } | {
                        text: string;
                        link: string;
                        markdownType: "link";
                    } | {
                        text: string;
                        markdownType?: undefined;
                    } | undefined;
                }[];
                mode?: "clone" | "create" | "edit" | "config" | undefined;
            }[] | undefined;
        }, {
            label: string;
            field: string;
            oauth_field: string;
            options?: {
                display?: boolean | undefined;
                disableonEdit?: boolean | undefined;
                enable?: boolean | undefined;
                requiredWhenVisible?: boolean | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
            } | undefined;
            type?: "text" | undefined;
            help?: string | {
                text: string;
                link?: string | undefined;
                links?: {
                    slug: string;
                    link: string;
                    linkText: string;
                }[] | undefined;
            } | undefined;
            required?: boolean | undefined;
            encrypted?: boolean | undefined;
            validators?: ({
                type: "number";
                range: [number, number];
                errorMsg?: string | undefined;
                isInteger?: boolean | undefined;
            } | {
                type: "string";
                minLength: number;
                maxLength: number;
                errorMsg?: string | undefined;
            } | {
                type: "regex";
                pattern: string;
                errorMsg?: string | undefined;
            } | {
                type: "email";
                errorMsg?: string | undefined;
            } | {
                type: "ipv4";
                errorMsg?: string | undefined;
            } | {
                type: "url";
                errorMsg?: string | undefined;
            } | {
                type: "date";
                errorMsg?: string | undefined;
            })[] | undefined;
            defaultValue?: string | number | boolean | undefined;
            modifyFieldsOnValue?: {
                fieldValue: string | number | boolean;
                fieldsToModify: {
                    fieldId: string;
                    value?: string | number | boolean | undefined;
                    label?: string | undefined;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    required?: boolean | undefined;
                    display?: boolean | undefined;
                    disabled?: boolean | undefined;
                    markdownMessage?: {
                        text: string;
                        markdownType: "text";
                        color?: string | undefined;
                    } | {
                        text: string;
                        link: string;
                        linkText: string;
                        markdownType: "hybrid";
                        token: string;
                    } | {
                        text: string;
                        link: string;
                        markdownType: "link";
                    } | {
                        text: string;
                        markdownType?: undefined;
                    } | undefined;
                }[];
                mode?: "clone" | "create" | "edit" | "config" | undefined;
            }[] | undefined;
        }>, "many">>;
        oauth_client_credentials: z.ZodOptional<z.ZodArray<z.ZodObject<{
            oauth_field: z.ZodString;
            label: z.ZodString;
            field: z.ZodString;
            type: z.ZodOptional<z.ZodDefault<z.ZodLiteral<"text">>>;
            help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                text: z.ZodString;
                links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                    slug: z.ZodString;
                    link: z.ZodString;
                    linkText: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    slug: string;
                    link: string;
                    linkText: string;
                }, {
                    slug: string;
                    link: string;
                    linkText: string;
                }>, "many">>;
                link: z.ZodOptional<z.ZodString>;
            }, "strip", z.ZodTypeAny, {
                text: string;
                link?: string | undefined;
                links?: {
                    slug: string;
                    link: string;
                    linkText: string;
                }[] | undefined;
            }, {
                text: string;
                link?: string | undefined;
                links?: {
                    slug: string;
                    link: string;
                    linkText: string;
                }[] | undefined;
            }>]>>;
            encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            defaultValue: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodNumber, z.ZodBoolean]>>;
            options: z.ZodOptional<z.ZodObject<{
                display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
            }, "strip", z.ZodTypeAny, {
                display?: boolean | undefined;
                disableonEdit?: boolean | undefined;
                enable?: boolean | undefined;
                requiredWhenVisible?: boolean | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
            }, {
                display?: boolean | undefined;
                disableonEdit?: boolean | undefined;
                enable?: boolean | undefined;
                requiredWhenVisible?: boolean | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
            }>>;
            modifyFieldsOnValue: z.ZodOptional<z.ZodArray<z.ZodObject<{
                fieldValue: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                mode: z.ZodOptional<z.ZodEnum<["create", "edit", "config", "clone"]>>;
                fieldsToModify: z.ZodArray<z.ZodObject<{
                    fieldId: z.ZodString;
                    display: z.ZodOptional<z.ZodBoolean>;
                    value: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>>;
                    disabled: z.ZodOptional<z.ZodBoolean>;
                    required: z.ZodOptional<z.ZodBoolean>;
                    help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                        text: z.ZodString;
                        links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                            slug: z.ZodString;
                            link: z.ZodString;
                            linkText: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            slug: string;
                            link: string;
                            linkText: string;
                        }, {
                            slug: string;
                            link: string;
                            linkText: string;
                        }>, "many">>;
                        link: z.ZodOptional<z.ZodString>;
                    }, "strip", z.ZodTypeAny, {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    }, {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    }>]>>;
                    label: z.ZodOptional<z.ZodString>;
                    markdownMessage: z.ZodOptional<z.ZodUnion<[z.ZodObject<{
                        markdownType: z.ZodLiteral<"text">;
                        text: z.ZodString;
                        color: z.ZodOptional<z.ZodString>;
                    }, "strip", z.ZodTypeAny, {
                        text: string;
                        markdownType: "text";
                        color?: string | undefined;
                    }, {
                        text: string;
                        markdownType: "text";
                        color?: string | undefined;
                    }>, z.ZodObject<{
                        markdownType: z.ZodLiteral<"hybrid">;
                        text: z.ZodString;
                        token: z.ZodString;
                        linkText: z.ZodString;
                        link: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        text: string;
                        link: string;
                        linkText: string;
                        markdownType: "hybrid";
                        token: string;
                    }, {
                        text: string;
                        link: string;
                        linkText: string;
                        markdownType: "hybrid";
                        token: string;
                    }>, z.ZodObject<{
                        markdownType: z.ZodLiteral<"link">;
                        text: z.ZodString;
                        link: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        text: string;
                        link: string;
                        markdownType: "link";
                    }, {
                        text: string;
                        link: string;
                        markdownType: "link";
                    }>, z.ZodObject<{
                        markdownType: z.ZodOptional<z.ZodUndefined>;
                        text: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        text: string;
                        markdownType?: undefined;
                    }, {
                        text: string;
                        markdownType?: undefined;
                    }>]>>;
                }, "strip", z.ZodTypeAny, {
                    fieldId: string;
                    value?: string | number | boolean | undefined;
                    label?: string | undefined;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    required?: boolean | undefined;
                    display?: boolean | undefined;
                    disabled?: boolean | undefined;
                    markdownMessage?: {
                        text: string;
                        markdownType: "text";
                        color?: string | undefined;
                    } | {
                        text: string;
                        link: string;
                        linkText: string;
                        markdownType: "hybrid";
                        token: string;
                    } | {
                        text: string;
                        link: string;
                        markdownType: "link";
                    } | {
                        text: string;
                        markdownType?: undefined;
                    } | undefined;
                }, {
                    fieldId: string;
                    value?: string | number | boolean | undefined;
                    label?: string | undefined;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    required?: boolean | undefined;
                    display?: boolean | undefined;
                    disabled?: boolean | undefined;
                    markdownMessage?: {
                        text: string;
                        markdownType: "text";
                        color?: string | undefined;
                    } | {
                        text: string;
                        link: string;
                        linkText: string;
                        markdownType: "hybrid";
                        token: string;
                    } | {
                        text: string;
                        link: string;
                        markdownType: "link";
                    } | {
                        text: string;
                        markdownType?: undefined;
                    } | undefined;
                }>, "many">;
            }, "strip", z.ZodTypeAny, {
                fieldValue: string | number | boolean;
                fieldsToModify: {
                    fieldId: string;
                    value?: string | number | boolean | undefined;
                    label?: string | undefined;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    required?: boolean | undefined;
                    display?: boolean | undefined;
                    disabled?: boolean | undefined;
                    markdownMessage?: {
                        text: string;
                        markdownType: "text";
                        color?: string | undefined;
                    } | {
                        text: string;
                        link: string;
                        linkText: string;
                        markdownType: "hybrid";
                        token: string;
                    } | {
                        text: string;
                        link: string;
                        markdownType: "link";
                    } | {
                        text: string;
                        markdownType?: undefined;
                    } | undefined;
                }[];
                mode?: "clone" | "create" | "edit" | "config" | undefined;
            }, {
                fieldValue: string | number | boolean;
                fieldsToModify: {
                    fieldId: string;
                    value?: string | number | boolean | undefined;
                    label?: string | undefined;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    required?: boolean | undefined;
                    display?: boolean | undefined;
                    disabled?: boolean | undefined;
                    markdownMessage?: {
                        text: string;
                        markdownType: "text";
                        color?: string | undefined;
                    } | {
                        text: string;
                        link: string;
                        linkText: string;
                        markdownType: "hybrid";
                        token: string;
                    } | {
                        text: string;
                        link: string;
                        markdownType: "link";
                    } | {
                        text: string;
                        markdownType?: undefined;
                    } | undefined;
                }[];
                mode?: "clone" | "create" | "edit" | "config" | undefined;
            }>, "many">>;
            validators: z.ZodOptional<z.ZodArray<z.ZodUnion<[z.ZodObject<{
                errorMsg: z.ZodOptional<z.ZodString>;
                type: z.ZodLiteral<"number">;
                range: z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>;
                isInteger: z.ZodOptional<z.ZodBoolean>;
            }, "strip", z.ZodTypeAny, {
                type: "number";
                range: [number, number];
                errorMsg?: string | undefined;
                isInteger?: boolean | undefined;
            }, {
                type: "number";
                range: [number, number];
                errorMsg?: string | undefined;
                isInteger?: boolean | undefined;
            }>, z.ZodObject<{
                errorMsg: z.ZodOptional<z.ZodString>;
                type: z.ZodLiteral<"string">;
                minLength: z.ZodNumber;
                maxLength: z.ZodNumber;
            }, "strip", z.ZodTypeAny, {
                type: "string";
                minLength: number;
                maxLength: number;
                errorMsg?: string | undefined;
            }, {
                type: "string";
                minLength: number;
                maxLength: number;
                errorMsg?: string | undefined;
            }>, z.ZodObject<{
                errorMsg: z.ZodOptional<z.ZodString>;
                type: z.ZodLiteral<"regex">;
                pattern: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                type: "regex";
                pattern: string;
                errorMsg?: string | undefined;
            }, {
                type: "regex";
                pattern: string;
                errorMsg?: string | undefined;
            }>, z.ZodObject<{
                errorMsg: z.ZodOptional<z.ZodString>;
                type: z.ZodLiteral<"email">;
            }, "strip", z.ZodTypeAny, {
                type: "email";
                errorMsg?: string | undefined;
            }, {
                type: "email";
                errorMsg?: string | undefined;
            }>, z.ZodObject<{
                errorMsg: z.ZodOptional<z.ZodString>;
                type: z.ZodLiteral<"ipv4">;
            }, "strip", z.ZodTypeAny, {
                type: "ipv4";
                errorMsg?: string | undefined;
            }, {
                type: "ipv4";
                errorMsg?: string | undefined;
            }>, z.ZodObject<{
                errorMsg: z.ZodOptional<z.ZodString>;
                type: z.ZodLiteral<"url">;
            }, "strip", z.ZodTypeAny, {
                type: "url";
                errorMsg?: string | undefined;
            }, {
                type: "url";
                errorMsg?: string | undefined;
            }>, z.ZodObject<{
                errorMsg: z.ZodOptional<z.ZodString>;
                type: z.ZodLiteral<"date">;
            }, "strip", z.ZodTypeAny, {
                type: "date";
                errorMsg?: string | undefined;
            }, {
                type: "date";
                errorMsg?: string | undefined;
            }>]>, "many">>;
        }, "strip", z.ZodTypeAny, {
            label: string;
            field: string;
            oauth_field: string;
            options?: {
                display?: boolean | undefined;
                disableonEdit?: boolean | undefined;
                enable?: boolean | undefined;
                requiredWhenVisible?: boolean | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
            } | undefined;
            type?: "text" | undefined;
            help?: string | {
                text: string;
                link?: string | undefined;
                links?: {
                    slug: string;
                    link: string;
                    linkText: string;
                }[] | undefined;
            } | undefined;
            required?: boolean | undefined;
            encrypted?: boolean | undefined;
            validators?: ({
                type: "number";
                range: [number, number];
                errorMsg?: string | undefined;
                isInteger?: boolean | undefined;
            } | {
                type: "string";
                minLength: number;
                maxLength: number;
                errorMsg?: string | undefined;
            } | {
                type: "regex";
                pattern: string;
                errorMsg?: string | undefined;
            } | {
                type: "email";
                errorMsg?: string | undefined;
            } | {
                type: "ipv4";
                errorMsg?: string | undefined;
            } | {
                type: "url";
                errorMsg?: string | undefined;
            } | {
                type: "date";
                errorMsg?: string | undefined;
            })[] | undefined;
            defaultValue?: string | number | boolean | undefined;
            modifyFieldsOnValue?: {
                fieldValue: string | number | boolean;
                fieldsToModify: {
                    fieldId: string;
                    value?: string | number | boolean | undefined;
                    label?: string | undefined;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    required?: boolean | undefined;
                    display?: boolean | undefined;
                    disabled?: boolean | undefined;
                    markdownMessage?: {
                        text: string;
                        markdownType: "text";
                        color?: string | undefined;
                    } | {
                        text: string;
                        link: string;
                        linkText: string;
                        markdownType: "hybrid";
                        token: string;
                    } | {
                        text: string;
                        link: string;
                        markdownType: "link";
                    } | {
                        text: string;
                        markdownType?: undefined;
                    } | undefined;
                }[];
                mode?: "clone" | "create" | "edit" | "config" | undefined;
            }[] | undefined;
        }, {
            label: string;
            field: string;
            oauth_field: string;
            options?: {
                display?: boolean | undefined;
                disableonEdit?: boolean | undefined;
                enable?: boolean | undefined;
                requiredWhenVisible?: boolean | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
            } | undefined;
            type?: "text" | undefined;
            help?: string | {
                text: string;
                link?: string | undefined;
                links?: {
                    slug: string;
                    link: string;
                    linkText: string;
                }[] | undefined;
            } | undefined;
            required?: boolean | undefined;
            encrypted?: boolean | undefined;
            validators?: ({
                type: "number";
                range: [number, number];
                errorMsg?: string | undefined;
                isInteger?: boolean | undefined;
            } | {
                type: "string";
                minLength: number;
                maxLength: number;
                errorMsg?: string | undefined;
            } | {
                type: "regex";
                pattern: string;
                errorMsg?: string | undefined;
            } | {
                type: "email";
                errorMsg?: string | undefined;
            } | {
                type: "ipv4";
                errorMsg?: string | undefined;
            } | {
                type: "url";
                errorMsg?: string | undefined;
            } | {
                type: "date";
                errorMsg?: string | undefined;
            })[] | undefined;
            defaultValue?: string | number | boolean | undefined;
            modifyFieldsOnValue?: {
                fieldValue: string | number | boolean;
                fieldsToModify: {
                    fieldId: string;
                    value?: string | number | boolean | undefined;
                    label?: string | undefined;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    required?: boolean | undefined;
                    display?: boolean | undefined;
                    disabled?: boolean | undefined;
                    markdownMessage?: {
                        text: string;
                        markdownType: "text";
                        color?: string | undefined;
                    } | {
                        text: string;
                        link: string;
                        linkText: string;
                        markdownType: "hybrid";
                        token: string;
                    } | {
                        text: string;
                        link: string;
                        markdownType: "link";
                    } | {
                        text: string;
                        markdownType?: undefined;
                    } | undefined;
                }[];
                mode?: "clone" | "create" | "edit" | "config" | undefined;
            }[] | undefined;
        }>, "many">>;
        auth_label: z.ZodOptional<z.ZodString>;
        oauth_popup_width: z.ZodOptional<z.ZodNumber>;
        oauth_popup_height: z.ZodOptional<z.ZodNumber>;
        oauth_timeout: z.ZodOptional<z.ZodNumber>;
        auth_code_endpoint: z.ZodOptional<z.ZodString>;
        access_token_endpoint: z.ZodOptional<z.ZodString>;
        oauth_state_enabled: z.ZodOptional<z.ZodBoolean>;
        auth_endpoint_token_access_type: z.ZodOptional<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        auth_type: ("oauth" | "basic" | "oauth_client_credentials")[];
        display?: boolean | undefined;
        disableonEdit?: boolean | undefined;
        enable?: boolean | undefined;
        hideForPlatform?: "cloud" | "enterprise" | undefined;
        oauth?: {
            label: string;
            field: string;
            oauth_field: string;
            options?: {
                display?: boolean | undefined;
                disableonEdit?: boolean | undefined;
                enable?: boolean | undefined;
                requiredWhenVisible?: boolean | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
            } | undefined;
            type?: "text" | undefined;
            help?: string | {
                text: string;
                link?: string | undefined;
                links?: {
                    slug: string;
                    link: string;
                    linkText: string;
                }[] | undefined;
            } | undefined;
            required?: boolean | undefined;
            encrypted?: boolean | undefined;
            validators?: ({
                type: "number";
                range: [number, number];
                errorMsg?: string | undefined;
                isInteger?: boolean | undefined;
            } | {
                type: "string";
                minLength: number;
                maxLength: number;
                errorMsg?: string | undefined;
            } | {
                type: "regex";
                pattern: string;
                errorMsg?: string | undefined;
            } | {
                type: "email";
                errorMsg?: string | undefined;
            } | {
                type: "ipv4";
                errorMsg?: string | undefined;
            } | {
                type: "url";
                errorMsg?: string | undefined;
            } | {
                type: "date";
                errorMsg?: string | undefined;
            })[] | undefined;
            defaultValue?: string | number | boolean | undefined;
            modifyFieldsOnValue?: {
                fieldValue: string | number | boolean;
                fieldsToModify: {
                    fieldId: string;
                    value?: string | number | boolean | undefined;
                    label?: string | undefined;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    required?: boolean | undefined;
                    display?: boolean | undefined;
                    disabled?: boolean | undefined;
                    markdownMessage?: {
                        text: string;
                        markdownType: "text";
                        color?: string | undefined;
                    } | {
                        text: string;
                        link: string;
                        linkText: string;
                        markdownType: "hybrid";
                        token: string;
                    } | {
                        text: string;
                        link: string;
                        markdownType: "link";
                    } | {
                        text: string;
                        markdownType?: undefined;
                    } | undefined;
                }[];
                mode?: "clone" | "create" | "edit" | "config" | undefined;
            }[] | undefined;
        }[] | undefined;
        basic?: {
            label: string;
            field: string;
            oauth_field: string;
            options?: {
                display?: boolean | undefined;
                disableonEdit?: boolean | undefined;
                enable?: boolean | undefined;
                requiredWhenVisible?: boolean | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
            } | undefined;
            type?: "text" | undefined;
            help?: string | {
                text: string;
                link?: string | undefined;
                links?: {
                    slug: string;
                    link: string;
                    linkText: string;
                }[] | undefined;
            } | undefined;
            required?: boolean | undefined;
            encrypted?: boolean | undefined;
            validators?: ({
                type: "number";
                range: [number, number];
                errorMsg?: string | undefined;
                isInteger?: boolean | undefined;
            } | {
                type: "string";
                minLength: number;
                maxLength: number;
                errorMsg?: string | undefined;
            } | {
                type: "regex";
                pattern: string;
                errorMsg?: string | undefined;
            } | {
                type: "email";
                errorMsg?: string | undefined;
            } | {
                type: "ipv4";
                errorMsg?: string | undefined;
            } | {
                type: "url";
                errorMsg?: string | undefined;
            } | {
                type: "date";
                errorMsg?: string | undefined;
            })[] | undefined;
            defaultValue?: string | number | boolean | undefined;
            modifyFieldsOnValue?: {
                fieldValue: string | number | boolean;
                fieldsToModify: {
                    fieldId: string;
                    value?: string | number | boolean | undefined;
                    label?: string | undefined;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    required?: boolean | undefined;
                    display?: boolean | undefined;
                    disabled?: boolean | undefined;
                    markdownMessage?: {
                        text: string;
                        markdownType: "text";
                        color?: string | undefined;
                    } | {
                        text: string;
                        link: string;
                        linkText: string;
                        markdownType: "hybrid";
                        token: string;
                    } | {
                        text: string;
                        link: string;
                        markdownType: "link";
                    } | {
                        text: string;
                        markdownType?: undefined;
                    } | undefined;
                }[];
                mode?: "clone" | "create" | "edit" | "config" | undefined;
            }[] | undefined;
        }[] | undefined;
        oauth_client_credentials?: {
            label: string;
            field: string;
            oauth_field: string;
            options?: {
                display?: boolean | undefined;
                disableonEdit?: boolean | undefined;
                enable?: boolean | undefined;
                requiredWhenVisible?: boolean | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
            } | undefined;
            type?: "text" | undefined;
            help?: string | {
                text: string;
                link?: string | undefined;
                links?: {
                    slug: string;
                    link: string;
                    linkText: string;
                }[] | undefined;
            } | undefined;
            required?: boolean | undefined;
            encrypted?: boolean | undefined;
            validators?: ({
                type: "number";
                range: [number, number];
                errorMsg?: string | undefined;
                isInteger?: boolean | undefined;
            } | {
                type: "string";
                minLength: number;
                maxLength: number;
                errorMsg?: string | undefined;
            } | {
                type: "regex";
                pattern: string;
                errorMsg?: string | undefined;
            } | {
                type: "email";
                errorMsg?: string | undefined;
            } | {
                type: "ipv4";
                errorMsg?: string | undefined;
            } | {
                type: "url";
                errorMsg?: string | undefined;
            } | {
                type: "date";
                errorMsg?: string | undefined;
            })[] | undefined;
            defaultValue?: string | number | boolean | undefined;
            modifyFieldsOnValue?: {
                fieldValue: string | number | boolean;
                fieldsToModify: {
                    fieldId: string;
                    value?: string | number | boolean | undefined;
                    label?: string | undefined;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    required?: boolean | undefined;
                    display?: boolean | undefined;
                    disabled?: boolean | undefined;
                    markdownMessage?: {
                        text: string;
                        markdownType: "text";
                        color?: string | undefined;
                    } | {
                        text: string;
                        link: string;
                        linkText: string;
                        markdownType: "hybrid";
                        token: string;
                    } | {
                        text: string;
                        link: string;
                        markdownType: "link";
                    } | {
                        text: string;
                        markdownType?: undefined;
                    } | undefined;
                }[];
                mode?: "clone" | "create" | "edit" | "config" | undefined;
            }[] | undefined;
        }[] | undefined;
        auth_label?: string | undefined;
        oauth_popup_width?: number | undefined;
        oauth_popup_height?: number | undefined;
        oauth_timeout?: number | undefined;
        auth_code_endpoint?: string | undefined;
        access_token_endpoint?: string | undefined;
        oauth_state_enabled?: boolean | undefined;
        auth_endpoint_token_access_type?: string | undefined;
    }, {
        auth_type: ("oauth" | "basic" | "oauth_client_credentials")[];
        display?: boolean | undefined;
        disableonEdit?: boolean | undefined;
        enable?: boolean | undefined;
        hideForPlatform?: "cloud" | "enterprise" | undefined;
        oauth?: {
            label: string;
            field: string;
            oauth_field: string;
            options?: {
                display?: boolean | undefined;
                disableonEdit?: boolean | undefined;
                enable?: boolean | undefined;
                requiredWhenVisible?: boolean | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
            } | undefined;
            type?: "text" | undefined;
            help?: string | {
                text: string;
                link?: string | undefined;
                links?: {
                    slug: string;
                    link: string;
                    linkText: string;
                }[] | undefined;
            } | undefined;
            required?: boolean | undefined;
            encrypted?: boolean | undefined;
            validators?: ({
                type: "number";
                range: [number, number];
                errorMsg?: string | undefined;
                isInteger?: boolean | undefined;
            } | {
                type: "string";
                minLength: number;
                maxLength: number;
                errorMsg?: string | undefined;
            } | {
                type: "regex";
                pattern: string;
                errorMsg?: string | undefined;
            } | {
                type: "email";
                errorMsg?: string | undefined;
            } | {
                type: "ipv4";
                errorMsg?: string | undefined;
            } | {
                type: "url";
                errorMsg?: string | undefined;
            } | {
                type: "date";
                errorMsg?: string | undefined;
            })[] | undefined;
            defaultValue?: string | number | boolean | undefined;
            modifyFieldsOnValue?: {
                fieldValue: string | number | boolean;
                fieldsToModify: {
                    fieldId: string;
                    value?: string | number | boolean | undefined;
                    label?: string | undefined;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    required?: boolean | undefined;
                    display?: boolean | undefined;
                    disabled?: boolean | undefined;
                    markdownMessage?: {
                        text: string;
                        markdownType: "text";
                        color?: string | undefined;
                    } | {
                        text: string;
                        link: string;
                        linkText: string;
                        markdownType: "hybrid";
                        token: string;
                    } | {
                        text: string;
                        link: string;
                        markdownType: "link";
                    } | {
                        text: string;
                        markdownType?: undefined;
                    } | undefined;
                }[];
                mode?: "clone" | "create" | "edit" | "config" | undefined;
            }[] | undefined;
        }[] | undefined;
        basic?: {
            label: string;
            field: string;
            oauth_field: string;
            options?: {
                display?: boolean | undefined;
                disableonEdit?: boolean | undefined;
                enable?: boolean | undefined;
                requiredWhenVisible?: boolean | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
            } | undefined;
            type?: "text" | undefined;
            help?: string | {
                text: string;
                link?: string | undefined;
                links?: {
                    slug: string;
                    link: string;
                    linkText: string;
                }[] | undefined;
            } | undefined;
            required?: boolean | undefined;
            encrypted?: boolean | undefined;
            validators?: ({
                type: "number";
                range: [number, number];
                errorMsg?: string | undefined;
                isInteger?: boolean | undefined;
            } | {
                type: "string";
                minLength: number;
                maxLength: number;
                errorMsg?: string | undefined;
            } | {
                type: "regex";
                pattern: string;
                errorMsg?: string | undefined;
            } | {
                type: "email";
                errorMsg?: string | undefined;
            } | {
                type: "ipv4";
                errorMsg?: string | undefined;
            } | {
                type: "url";
                errorMsg?: string | undefined;
            } | {
                type: "date";
                errorMsg?: string | undefined;
            })[] | undefined;
            defaultValue?: string | number | boolean | undefined;
            modifyFieldsOnValue?: {
                fieldValue: string | number | boolean;
                fieldsToModify: {
                    fieldId: string;
                    value?: string | number | boolean | undefined;
                    label?: string | undefined;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    required?: boolean | undefined;
                    display?: boolean | undefined;
                    disabled?: boolean | undefined;
                    markdownMessage?: {
                        text: string;
                        markdownType: "text";
                        color?: string | undefined;
                    } | {
                        text: string;
                        link: string;
                        linkText: string;
                        markdownType: "hybrid";
                        token: string;
                    } | {
                        text: string;
                        link: string;
                        markdownType: "link";
                    } | {
                        text: string;
                        markdownType?: undefined;
                    } | undefined;
                }[];
                mode?: "clone" | "create" | "edit" | "config" | undefined;
            }[] | undefined;
        }[] | undefined;
        oauth_client_credentials?: {
            label: string;
            field: string;
            oauth_field: string;
            options?: {
                display?: boolean | undefined;
                disableonEdit?: boolean | undefined;
                enable?: boolean | undefined;
                requiredWhenVisible?: boolean | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
            } | undefined;
            type?: "text" | undefined;
            help?: string | {
                text: string;
                link?: string | undefined;
                links?: {
                    slug: string;
                    link: string;
                    linkText: string;
                }[] | undefined;
            } | undefined;
            required?: boolean | undefined;
            encrypted?: boolean | undefined;
            validators?: ({
                type: "number";
                range: [number, number];
                errorMsg?: string | undefined;
                isInteger?: boolean | undefined;
            } | {
                type: "string";
                minLength: number;
                maxLength: number;
                errorMsg?: string | undefined;
            } | {
                type: "regex";
                pattern: string;
                errorMsg?: string | undefined;
            } | {
                type: "email";
                errorMsg?: string | undefined;
            } | {
                type: "ipv4";
                errorMsg?: string | undefined;
            } | {
                type: "url";
                errorMsg?: string | undefined;
            } | {
                type: "date";
                errorMsg?: string | undefined;
            })[] | undefined;
            defaultValue?: string | number | boolean | undefined;
            modifyFieldsOnValue?: {
                fieldValue: string | number | boolean;
                fieldsToModify: {
                    fieldId: string;
                    value?: string | number | boolean | undefined;
                    label?: string | undefined;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    required?: boolean | undefined;
                    display?: boolean | undefined;
                    disabled?: boolean | undefined;
                    markdownMessage?: {
                        text: string;
                        markdownType: "text";
                        color?: string | undefined;
                    } | {
                        text: string;
                        link: string;
                        linkText: string;
                        markdownType: "hybrid";
                        token: string;
                    } | {
                        text: string;
                        link: string;
                        markdownType: "link";
                    } | {
                        text: string;
                        markdownType?: undefined;
                    } | undefined;
                }[];
                mode?: "clone" | "create" | "edit" | "config" | undefined;
            }[] | undefined;
        }[] | undefined;
        auth_label?: string | undefined;
        oauth_popup_width?: number | undefined;
        oauth_popup_height?: number | undefined;
        oauth_timeout?: number | undefined;
        auth_code_endpoint?: string | undefined;
        access_token_endpoint?: string | undefined;
        oauth_state_enabled?: boolean | undefined;
        auth_endpoint_token_access_type?: string | undefined;
    }>;
}, "strip", z.ZodTypeAny, {
    options: {
        auth_type: ("oauth" | "basic" | "oauth_client_credentials")[];
        display?: boolean | undefined;
        disableonEdit?: boolean | undefined;
        enable?: boolean | undefined;
        hideForPlatform?: "cloud" | "enterprise" | undefined;
        oauth?: {
            label: string;
            field: string;
            oauth_field: string;
            options?: {
                display?: boolean | undefined;
                disableonEdit?: boolean | undefined;
                enable?: boolean | undefined;
                requiredWhenVisible?: boolean | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
            } | undefined;
            type?: "text" | undefined;
            help?: string | {
                text: string;
                link?: string | undefined;
                links?: {
                    slug: string;
                    link: string;
                    linkText: string;
                }[] | undefined;
            } | undefined;
            required?: boolean | undefined;
            encrypted?: boolean | undefined;
            validators?: ({
                type: "number";
                range: [number, number];
                errorMsg?: string | undefined;
                isInteger?: boolean | undefined;
            } | {
                type: "string";
                minLength: number;
                maxLength: number;
                errorMsg?: string | undefined;
            } | {
                type: "regex";
                pattern: string;
                errorMsg?: string | undefined;
            } | {
                type: "email";
                errorMsg?: string | undefined;
            } | {
                type: "ipv4";
                errorMsg?: string | undefined;
            } | {
                type: "url";
                errorMsg?: string | undefined;
            } | {
                type: "date";
                errorMsg?: string | undefined;
            })[] | undefined;
            defaultValue?: string | number | boolean | undefined;
            modifyFieldsOnValue?: {
                fieldValue: string | number | boolean;
                fieldsToModify: {
                    fieldId: string;
                    value?: string | number | boolean | undefined;
                    label?: string | undefined;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    required?: boolean | undefined;
                    display?: boolean | undefined;
                    disabled?: boolean | undefined;
                    markdownMessage?: {
                        text: string;
                        markdownType: "text";
                        color?: string | undefined;
                    } | {
                        text: string;
                        link: string;
                        linkText: string;
                        markdownType: "hybrid";
                        token: string;
                    } | {
                        text: string;
                        link: string;
                        markdownType: "link";
                    } | {
                        text: string;
                        markdownType?: undefined;
                    } | undefined;
                }[];
                mode?: "clone" | "create" | "edit" | "config" | undefined;
            }[] | undefined;
        }[] | undefined;
        basic?: {
            label: string;
            field: string;
            oauth_field: string;
            options?: {
                display?: boolean | undefined;
                disableonEdit?: boolean | undefined;
                enable?: boolean | undefined;
                requiredWhenVisible?: boolean | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
            } | undefined;
            type?: "text" | undefined;
            help?: string | {
                text: string;
                link?: string | undefined;
                links?: {
                    slug: string;
                    link: string;
                    linkText: string;
                }[] | undefined;
            } | undefined;
            required?: boolean | undefined;
            encrypted?: boolean | undefined;
            validators?: ({
                type: "number";
                range: [number, number];
                errorMsg?: string | undefined;
                isInteger?: boolean | undefined;
            } | {
                type: "string";
                minLength: number;
                maxLength: number;
                errorMsg?: string | undefined;
            } | {
                type: "regex";
                pattern: string;
                errorMsg?: string | undefined;
            } | {
                type: "email";
                errorMsg?: string | undefined;
            } | {
                type: "ipv4";
                errorMsg?: string | undefined;
            } | {
                type: "url";
                errorMsg?: string | undefined;
            } | {
                type: "date";
                errorMsg?: string | undefined;
            })[] | undefined;
            defaultValue?: string | number | boolean | undefined;
            modifyFieldsOnValue?: {
                fieldValue: string | number | boolean;
                fieldsToModify: {
                    fieldId: string;
                    value?: string | number | boolean | undefined;
                    label?: string | undefined;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    required?: boolean | undefined;
                    display?: boolean | undefined;
                    disabled?: boolean | undefined;
                    markdownMessage?: {
                        text: string;
                        markdownType: "text";
                        color?: string | undefined;
                    } | {
                        text: string;
                        link: string;
                        linkText: string;
                        markdownType: "hybrid";
                        token: string;
                    } | {
                        text: string;
                        link: string;
                        markdownType: "link";
                    } | {
                        text: string;
                        markdownType?: undefined;
                    } | undefined;
                }[];
                mode?: "clone" | "create" | "edit" | "config" | undefined;
            }[] | undefined;
        }[] | undefined;
        oauth_client_credentials?: {
            label: string;
            field: string;
            oauth_field: string;
            options?: {
                display?: boolean | undefined;
                disableonEdit?: boolean | undefined;
                enable?: boolean | undefined;
                requiredWhenVisible?: boolean | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
            } | undefined;
            type?: "text" | undefined;
            help?: string | {
                text: string;
                link?: string | undefined;
                links?: {
                    slug: string;
                    link: string;
                    linkText: string;
                }[] | undefined;
            } | undefined;
            required?: boolean | undefined;
            encrypted?: boolean | undefined;
            validators?: ({
                type: "number";
                range: [number, number];
                errorMsg?: string | undefined;
                isInteger?: boolean | undefined;
            } | {
                type: "string";
                minLength: number;
                maxLength: number;
                errorMsg?: string | undefined;
            } | {
                type: "regex";
                pattern: string;
                errorMsg?: string | undefined;
            } | {
                type: "email";
                errorMsg?: string | undefined;
            } | {
                type: "ipv4";
                errorMsg?: string | undefined;
            } | {
                type: "url";
                errorMsg?: string | undefined;
            } | {
                type: "date";
                errorMsg?: string | undefined;
            })[] | undefined;
            defaultValue?: string | number | boolean | undefined;
            modifyFieldsOnValue?: {
                fieldValue: string | number | boolean;
                fieldsToModify: {
                    fieldId: string;
                    value?: string | number | boolean | undefined;
                    label?: string | undefined;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    required?: boolean | undefined;
                    display?: boolean | undefined;
                    disabled?: boolean | undefined;
                    markdownMessage?: {
                        text: string;
                        markdownType: "text";
                        color?: string | undefined;
                    } | {
                        text: string;
                        link: string;
                        linkText: string;
                        markdownType: "hybrid";
                        token: string;
                    } | {
                        text: string;
                        link: string;
                        markdownType: "link";
                    } | {
                        text: string;
                        markdownType?: undefined;
                    } | undefined;
                }[];
                mode?: "clone" | "create" | "edit" | "config" | undefined;
            }[] | undefined;
        }[] | undefined;
        auth_label?: string | undefined;
        oauth_popup_width?: number | undefined;
        oauth_popup_height?: number | undefined;
        oauth_timeout?: number | undefined;
        auth_code_endpoint?: string | undefined;
        access_token_endpoint?: string | undefined;
        oauth_state_enabled?: boolean | undefined;
        auth_endpoint_token_access_type?: string | undefined;
    };
    type: "oauth";
    label: string;
    field: string;
    help?: string | {
        text: string;
        link?: string | undefined;
        links?: {
            slug: string;
            link: string;
            linkText: string;
        }[] | undefined;
    } | undefined;
    tooltip?: string | undefined;
    required?: boolean | undefined;
    encrypted?: boolean | undefined;
    validators?: ({
        type: "string";
        minLength: number;
        maxLength: number;
        errorMsg?: string | undefined;
    } | {
        type: "regex";
        pattern: string;
        errorMsg?: string | undefined;
    })[] | undefined;
    defaultValue?: string | undefined;
}, {
    options: {
        auth_type: ("oauth" | "basic" | "oauth_client_credentials")[];
        display?: boolean | undefined;
        disableonEdit?: boolean | undefined;
        enable?: boolean | undefined;
        hideForPlatform?: "cloud" | "enterprise" | undefined;
        oauth?: {
            label: string;
            field: string;
            oauth_field: string;
            options?: {
                display?: boolean | undefined;
                disableonEdit?: boolean | undefined;
                enable?: boolean | undefined;
                requiredWhenVisible?: boolean | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
            } | undefined;
            type?: "text" | undefined;
            help?: string | {
                text: string;
                link?: string | undefined;
                links?: {
                    slug: string;
                    link: string;
                    linkText: string;
                }[] | undefined;
            } | undefined;
            required?: boolean | undefined;
            encrypted?: boolean | undefined;
            validators?: ({
                type: "number";
                range: [number, number];
                errorMsg?: string | undefined;
                isInteger?: boolean | undefined;
            } | {
                type: "string";
                minLength: number;
                maxLength: number;
                errorMsg?: string | undefined;
            } | {
                type: "regex";
                pattern: string;
                errorMsg?: string | undefined;
            } | {
                type: "email";
                errorMsg?: string | undefined;
            } | {
                type: "ipv4";
                errorMsg?: string | undefined;
            } | {
                type: "url";
                errorMsg?: string | undefined;
            } | {
                type: "date";
                errorMsg?: string | undefined;
            })[] | undefined;
            defaultValue?: string | number | boolean | undefined;
            modifyFieldsOnValue?: {
                fieldValue: string | number | boolean;
                fieldsToModify: {
                    fieldId: string;
                    value?: string | number | boolean | undefined;
                    label?: string | undefined;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    required?: boolean | undefined;
                    display?: boolean | undefined;
                    disabled?: boolean | undefined;
                    markdownMessage?: {
                        text: string;
                        markdownType: "text";
                        color?: string | undefined;
                    } | {
                        text: string;
                        link: string;
                        linkText: string;
                        markdownType: "hybrid";
                        token: string;
                    } | {
                        text: string;
                        link: string;
                        markdownType: "link";
                    } | {
                        text: string;
                        markdownType?: undefined;
                    } | undefined;
                }[];
                mode?: "clone" | "create" | "edit" | "config" | undefined;
            }[] | undefined;
        }[] | undefined;
        basic?: {
            label: string;
            field: string;
            oauth_field: string;
            options?: {
                display?: boolean | undefined;
                disableonEdit?: boolean | undefined;
                enable?: boolean | undefined;
                requiredWhenVisible?: boolean | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
            } | undefined;
            type?: "text" | undefined;
            help?: string | {
                text: string;
                link?: string | undefined;
                links?: {
                    slug: string;
                    link: string;
                    linkText: string;
                }[] | undefined;
            } | undefined;
            required?: boolean | undefined;
            encrypted?: boolean | undefined;
            validators?: ({
                type: "number";
                range: [number, number];
                errorMsg?: string | undefined;
                isInteger?: boolean | undefined;
            } | {
                type: "string";
                minLength: number;
                maxLength: number;
                errorMsg?: string | undefined;
            } | {
                type: "regex";
                pattern: string;
                errorMsg?: string | undefined;
            } | {
                type: "email";
                errorMsg?: string | undefined;
            } | {
                type: "ipv4";
                errorMsg?: string | undefined;
            } | {
                type: "url";
                errorMsg?: string | undefined;
            } | {
                type: "date";
                errorMsg?: string | undefined;
            })[] | undefined;
            defaultValue?: string | number | boolean | undefined;
            modifyFieldsOnValue?: {
                fieldValue: string | number | boolean;
                fieldsToModify: {
                    fieldId: string;
                    value?: string | number | boolean | undefined;
                    label?: string | undefined;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    required?: boolean | undefined;
                    display?: boolean | undefined;
                    disabled?: boolean | undefined;
                    markdownMessage?: {
                        text: string;
                        markdownType: "text";
                        color?: string | undefined;
                    } | {
                        text: string;
                        link: string;
                        linkText: string;
                        markdownType: "hybrid";
                        token: string;
                    } | {
                        text: string;
                        link: string;
                        markdownType: "link";
                    } | {
                        text: string;
                        markdownType?: undefined;
                    } | undefined;
                }[];
                mode?: "clone" | "create" | "edit" | "config" | undefined;
            }[] | undefined;
        }[] | undefined;
        oauth_client_credentials?: {
            label: string;
            field: string;
            oauth_field: string;
            options?: {
                display?: boolean | undefined;
                disableonEdit?: boolean | undefined;
                enable?: boolean | undefined;
                requiredWhenVisible?: boolean | undefined;
                hideForPlatform?: "cloud" | "enterprise" | undefined;
            } | undefined;
            type?: "text" | undefined;
            help?: string | {
                text: string;
                link?: string | undefined;
                links?: {
                    slug: string;
                    link: string;
                    linkText: string;
                }[] | undefined;
            } | undefined;
            required?: boolean | undefined;
            encrypted?: boolean | undefined;
            validators?: ({
                type: "number";
                range: [number, number];
                errorMsg?: string | undefined;
                isInteger?: boolean | undefined;
            } | {
                type: "string";
                minLength: number;
                maxLength: number;
                errorMsg?: string | undefined;
            } | {
                type: "regex";
                pattern: string;
                errorMsg?: string | undefined;
            } | {
                type: "email";
                errorMsg?: string | undefined;
            } | {
                type: "ipv4";
                errorMsg?: string | undefined;
            } | {
                type: "url";
                errorMsg?: string | undefined;
            } | {
                type: "date";
                errorMsg?: string | undefined;
            })[] | undefined;
            defaultValue?: string | number | boolean | undefined;
            modifyFieldsOnValue?: {
                fieldValue: string | number | boolean;
                fieldsToModify: {
                    fieldId: string;
                    value?: string | number | boolean | undefined;
                    label?: string | undefined;
                    help?: string | {
                        text: string;
                        link?: string | undefined;
                        links?: {
                            slug: string;
                            link: string;
                            linkText: string;
                        }[] | undefined;
                    } | undefined;
                    required?: boolean | undefined;
                    display?: boolean | undefined;
                    disabled?: boolean | undefined;
                    markdownMessage?: {
                        text: string;
                        markdownType: "text";
                        color?: string | undefined;
                    } | {
                        text: string;
                        link: string;
                        linkText: string;
                        markdownType: "hybrid";
                        token: string;
                    } | {
                        text: string;
                        link: string;
                        markdownType: "link";
                    } | {
                        text: string;
                        markdownType?: undefined;
                    } | undefined;
                }[];
                mode?: "clone" | "create" | "edit" | "config" | undefined;
            }[] | undefined;
        }[] | undefined;
        auth_label?: string | undefined;
        oauth_popup_width?: number | undefined;
        oauth_popup_height?: number | undefined;
        oauth_timeout?: number | undefined;
        auth_code_endpoint?: string | undefined;
        access_token_endpoint?: string | undefined;
        oauth_state_enabled?: boolean | undefined;
        auth_endpoint_token_access_type?: string | undefined;
    };
    type: "oauth";
    label: string;
    field: string;
    help?: string | {
        text: string;
        link?: string | undefined;
        links?: {
            slug: string;
            link: string;
            linkText: string;
        }[] | undefined;
    } | undefined;
    tooltip?: string | undefined;
    required?: boolean | undefined;
    encrypted?: boolean | undefined;
    validators?: ({
        type: "string";
        minLength: number;
        maxLength: number;
        errorMsg?: string | undefined;
    } | {
        type: "regex";
        pattern: string;
        errorMsg?: string | undefined;
    })[] | undefined;
    defaultValue?: string | undefined;
}>;

declare const pages: z.ZodObject<{
    configuration: z.ZodOptional<z.ZodObject<{
        title: z.ZodString;
        description: z.ZodOptional<z.ZodString>;
        subDescription: z.ZodOptional<z.ZodObject<{
            text: z.ZodString;
            links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                slug: z.ZodString;
                link: z.ZodString;
                linkText: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                slug: string;
                link: string;
                linkText: string;
            }, {
                slug: string;
                link: string;
                linkText: string;
            }>, "many">>;
        }, "strip", z.ZodTypeAny, {
            text: string;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        }, {
            text: string;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        }>>;
        tabs: z.ZodArray<z.ZodObject<{
            entity: z.ZodOptional<z.ZodArray<z.ZodDiscriminatedUnion<"type", [z.ZodObject<{
                field: z.ZodString;
                help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                    text: z.ZodString;
                    links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        slug: z.ZodString;
                        link: z.ZodString;
                        linkText: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }>, "many">>;
                    link: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }>]>>;
                tooltip: z.ZodOptional<z.ZodString>;
            } & {
                type: z.ZodLiteral<"helpLink">;
                label: z.ZodOptional<z.ZodString>;
                options: z.ZodOptional<z.ZodObject<{
                    text: z.ZodString;
                    links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        slug: z.ZodString;
                        link: z.ZodString;
                        linkText: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }>, "many">>;
                    link: z.ZodOptional<z.ZodString>;
                } & {
                    hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                }, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                }>>;
                required: z.ZodOptional<z.ZodDefault<z.ZodLiteral<false>>>;
            }, "strip", z.ZodTypeAny, {
                type: "helpLink";
                field: string;
                options?: {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: false | undefined;
            }, {
                type: "helpLink";
                field: string;
                options?: {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: false | undefined;
            }>, z.ZodObject<{
                field: z.ZodString;
                label: z.ZodString;
                help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                    text: z.ZodString;
                    links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        slug: z.ZodString;
                        link: z.ZodString;
                        linkText: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }>, "many">>;
                    link: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }>]>>;
                tooltip: z.ZodOptional<z.ZodString>;
                required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            } & {
                type: z.ZodLiteral<"text">;
                validators: z.ZodOptional<z.ZodArray<z.ZodUnion<[z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"number">;
                    range: z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>;
                    isInteger: z.ZodOptional<z.ZodBoolean>;
                }, "strip", z.ZodTypeAny, {
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                }, {
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"string">;
                    minLength: z.ZodNumber;
                    maxLength: z.ZodNumber;
                }, "strip", z.ZodTypeAny, {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                }, {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"regex">;
                    pattern: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }, {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"email">;
                }, "strip", z.ZodTypeAny, {
                    type: "email";
                    errorMsg?: string | undefined;
                }, {
                    type: "email";
                    errorMsg?: string | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"ipv4">;
                }, "strip", z.ZodTypeAny, {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                }, {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"url">;
                }, "strip", z.ZodTypeAny, {
                    type: "url";
                    errorMsg?: string | undefined;
                }, {
                    type: "url";
                    errorMsg?: string | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"date">;
                }, "strip", z.ZodTypeAny, {
                    type: "date";
                    errorMsg?: string | undefined;
                }, {
                    type: "date";
                    errorMsg?: string | undefined;
                }>]>, "many">>;
                defaultValue: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodNumber, z.ZodBoolean]>>;
                options: z.ZodOptional<z.ZodObject<{
                    display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
                }, "strip", z.ZodTypeAny, {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                }, {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                }>>;
                modifyFieldsOnValue: z.ZodOptional<z.ZodArray<z.ZodObject<{
                    fieldValue: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                    mode: z.ZodOptional<z.ZodEnum<["create", "edit", "config", "clone"]>>;
                    fieldsToModify: z.ZodArray<z.ZodObject<{
                        fieldId: z.ZodString;
                        display: z.ZodOptional<z.ZodBoolean>;
                        value: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>>;
                        disabled: z.ZodOptional<z.ZodBoolean>;
                        required: z.ZodOptional<z.ZodBoolean>;
                        help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                            text: z.ZodString;
                            links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                slug: z.ZodString;
                                link: z.ZodString;
                                linkText: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                slug: string;
                                link: string;
                                linkText: string;
                            }, {
                                slug: string;
                                link: string;
                                linkText: string;
                            }>, "many">>;
                            link: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        }, {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        }>]>>;
                        label: z.ZodOptional<z.ZodString>;
                        markdownMessage: z.ZodOptional<z.ZodUnion<[z.ZodObject<{
                            markdownType: z.ZodLiteral<"text">;
                            text: z.ZodString;
                            color: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        }, {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        }>, z.ZodObject<{
                            markdownType: z.ZodLiteral<"hybrid">;
                            text: z.ZodString;
                            token: z.ZodString;
                            linkText: z.ZodString;
                            link: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        }, {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        }>, z.ZodObject<{
                            markdownType: z.ZodLiteral<"link">;
                            text: z.ZodString;
                            link: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            link: string;
                            markdownType: "link";
                        }, {
                            text: string;
                            link: string;
                            markdownType: "link";
                        }>, z.ZodObject<{
                            markdownType: z.ZodOptional<z.ZodUndefined>;
                            text: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            markdownType?: undefined;
                        }, {
                            text: string;
                            markdownType?: undefined;
                        }>]>>;
                    }, "strip", z.ZodTypeAny, {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }, {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }>, "many">;
                }, "strip", z.ZodTypeAny, {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }, {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }>, "many">>;
            }, "strip", z.ZodTypeAny, {
                type: "text";
                label: string;
                field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            }, {
                type: "text";
                label: string;
                field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            }>, z.ZodObject<{
                field: z.ZodString;
                label: z.ZodString;
                help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                    text: z.ZodString;
                    links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        slug: z.ZodString;
                        link: z.ZodString;
                        linkText: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }>, "many">>;
                    link: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }>]>>;
                tooltip: z.ZodOptional<z.ZodString>;
                required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            } & {
                type: z.ZodLiteral<"textarea">;
                validators: z.ZodOptional<z.ZodArray<z.ZodUnion<[z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"number">;
                    range: z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>;
                    isInteger: z.ZodOptional<z.ZodBoolean>;
                }, "strip", z.ZodTypeAny, {
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                }, {
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"string">;
                    minLength: z.ZodNumber;
                    maxLength: z.ZodNumber;
                }, "strip", z.ZodTypeAny, {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                }, {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"regex">;
                    pattern: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }, {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"email">;
                }, "strip", z.ZodTypeAny, {
                    type: "email";
                    errorMsg?: string | undefined;
                }, {
                    type: "email";
                    errorMsg?: string | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"ipv4">;
                }, "strip", z.ZodTypeAny, {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                }, {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"url">;
                }, "strip", z.ZodTypeAny, {
                    type: "url";
                    errorMsg?: string | undefined;
                }, {
                    type: "url";
                    errorMsg?: string | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"date">;
                }, "strip", z.ZodTypeAny, {
                    type: "date";
                    errorMsg?: string | undefined;
                }, {
                    type: "date";
                    errorMsg?: string | undefined;
                }>]>, "many">>;
                defaultValue: z.ZodOptional<z.ZodString>;
                options: z.ZodOptional<z.ZodObject<{
                    display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
                } & {
                    rowsMin: z.ZodOptional<z.ZodNumber>;
                    rowsMax: z.ZodOptional<z.ZodNumber>;
                }, "strip", z.ZodTypeAny, {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    rowsMin?: number | undefined;
                    rowsMax?: number | undefined;
                }, {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    rowsMin?: number | undefined;
                    rowsMax?: number | undefined;
                }>>;
                modifyFieldsOnValue: z.ZodOptional<z.ZodArray<z.ZodObject<{
                    fieldValue: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                    mode: z.ZodOptional<z.ZodEnum<["create", "edit", "config", "clone"]>>;
                    fieldsToModify: z.ZodArray<z.ZodObject<{
                        fieldId: z.ZodString;
                        display: z.ZodOptional<z.ZodBoolean>;
                        value: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>>;
                        disabled: z.ZodOptional<z.ZodBoolean>;
                        required: z.ZodOptional<z.ZodBoolean>;
                        help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                            text: z.ZodString;
                            links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                slug: z.ZodString;
                                link: z.ZodString;
                                linkText: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                slug: string;
                                link: string;
                                linkText: string;
                            }, {
                                slug: string;
                                link: string;
                                linkText: string;
                            }>, "many">>;
                            link: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        }, {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        }>]>>;
                        label: z.ZodOptional<z.ZodString>;
                        markdownMessage: z.ZodOptional<z.ZodUnion<[z.ZodObject<{
                            markdownType: z.ZodLiteral<"text">;
                            text: z.ZodString;
                            color: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        }, {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        }>, z.ZodObject<{
                            markdownType: z.ZodLiteral<"hybrid">;
                            text: z.ZodString;
                            token: z.ZodString;
                            linkText: z.ZodString;
                            link: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        }, {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        }>, z.ZodObject<{
                            markdownType: z.ZodLiteral<"link">;
                            text: z.ZodString;
                            link: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            link: string;
                            markdownType: "link";
                        }, {
                            text: string;
                            link: string;
                            markdownType: "link";
                        }>, z.ZodObject<{
                            markdownType: z.ZodOptional<z.ZodUndefined>;
                            text: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            markdownType?: undefined;
                        }, {
                            text: string;
                            markdownType?: undefined;
                        }>]>>;
                    }, "strip", z.ZodTypeAny, {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }, {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }>, "many">;
                }, "strip", z.ZodTypeAny, {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }, {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }>, "many">>;
            }, "strip", z.ZodTypeAny, {
                type: "textarea";
                label: string;
                field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    rowsMin?: number | undefined;
                    rowsMax?: number | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            }, {
                type: "textarea";
                label: string;
                field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    rowsMin?: number | undefined;
                    rowsMax?: number | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            }>, z.ZodObject<{
                field: z.ZodString;
                label: z.ZodString;
                help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                    text: z.ZodString;
                    links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        slug: z.ZodString;
                        link: z.ZodString;
                        linkText: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }>, "many">>;
                    link: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }>]>>;
                tooltip: z.ZodOptional<z.ZodString>;
                required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            } & {
                type: z.ZodLiteral<"singleSelect">;
                validators: z.ZodOptional<z.ZodArray<z.ZodUnion<[z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"number">;
                    range: z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>;
                    isInteger: z.ZodOptional<z.ZodBoolean>;
                }, "strip", z.ZodTypeAny, {
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                }, {
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"string">;
                    minLength: z.ZodNumber;
                    maxLength: z.ZodNumber;
                }, "strip", z.ZodTypeAny, {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                }, {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"regex">;
                    pattern: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }, {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"email">;
                }, "strip", z.ZodTypeAny, {
                    type: "email";
                    errorMsg?: string | undefined;
                }, {
                    type: "email";
                    errorMsg?: string | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"ipv4">;
                }, "strip", z.ZodTypeAny, {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                }, {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"url">;
                }, "strip", z.ZodTypeAny, {
                    type: "url";
                    errorMsg?: string | undefined;
                }, {
                    type: "url";
                    errorMsg?: string | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"date">;
                }, "strip", z.ZodTypeAny, {
                    type: "date";
                    errorMsg?: string | undefined;
                }, {
                    type: "date";
                    errorMsg?: string | undefined;
                }>]>, "many">>;
                defaultValue: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodNumber, z.ZodBoolean]>>;
                options: z.ZodObject<{
                    display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
                } & {
                    disableSearch: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    createSearchChoice: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    referenceName: z.ZodOptional<z.ZodString>;
                    endpointUrl: z.ZodOptional<z.ZodString>;
                    allowList: z.ZodOptional<z.ZodString>;
                    denyList: z.ZodOptional<z.ZodString>;
                    labelField: z.ZodOptional<z.ZodString>;
                    valueField: z.ZodOptional<z.ZodString>;
                    autoCompleteFields: z.ZodOptional<z.ZodArray<z.ZodUnion<[z.ZodObject<{
                        value: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                        label: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        value: string | number | boolean;
                        label: string;
                    }, {
                        value: string | number | boolean;
                        label: string;
                    }>, z.ZodObject<{
                        label: z.ZodString;
                        children: z.ZodArray<z.ZodObject<{
                            value: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                            label: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            value: string | number | boolean;
                            label: string;
                        }, {
                            value: string | number | boolean;
                            label: string;
                        }>, "many">;
                    }, "strip", z.ZodTypeAny, {
                        label: string;
                        children: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                    }, {
                        label: string;
                        children: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                    }>]>, "many">>;
                    dependencies: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                    items: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        value: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                        label: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        value: string | number | boolean;
                        label: string;
                    }, {
                        value: string | number | boolean;
                        label: string;
                    }>, "many">>;
                }, "strip", z.ZodTypeAny, {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    disableSearch?: boolean | undefined;
                    createSearchChoice?: boolean | undefined;
                    referenceName?: string | undefined;
                    endpointUrl?: string | undefined;
                    allowList?: string | undefined;
                    denyList?: string | undefined;
                    labelField?: string | undefined;
                    valueField?: string | undefined;
                    autoCompleteFields?: ({
                        value: string | number | boolean;
                        label: string;
                    } | {
                        label: string;
                        children: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                    })[] | undefined;
                    dependencies?: string[] | undefined;
                    items?: {
                        value: string | number | boolean;
                        label: string;
                    }[] | undefined;
                }, {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    disableSearch?: boolean | undefined;
                    createSearchChoice?: boolean | undefined;
                    referenceName?: string | undefined;
                    endpointUrl?: string | undefined;
                    allowList?: string | undefined;
                    denyList?: string | undefined;
                    labelField?: string | undefined;
                    valueField?: string | undefined;
                    autoCompleteFields?: ({
                        value: string | number | boolean;
                        label: string;
                    } | {
                        label: string;
                        children: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                    })[] | undefined;
                    dependencies?: string[] | undefined;
                    items?: {
                        value: string | number | boolean;
                        label: string;
                    }[] | undefined;
                }>;
                modifyFieldsOnValue: z.ZodOptional<z.ZodArray<z.ZodObject<{
                    fieldValue: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                    mode: z.ZodOptional<z.ZodEnum<["create", "edit", "config", "clone"]>>;
                    fieldsToModify: z.ZodArray<z.ZodObject<{
                        fieldId: z.ZodString;
                        display: z.ZodOptional<z.ZodBoolean>;
                        value: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>>;
                        disabled: z.ZodOptional<z.ZodBoolean>;
                        required: z.ZodOptional<z.ZodBoolean>;
                        help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                            text: z.ZodString;
                            links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                slug: z.ZodString;
                                link: z.ZodString;
                                linkText: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                slug: string;
                                link: string;
                                linkText: string;
                            }, {
                                slug: string;
                                link: string;
                                linkText: string;
                            }>, "many">>;
                            link: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        }, {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        }>]>>;
                        label: z.ZodOptional<z.ZodString>;
                        markdownMessage: z.ZodOptional<z.ZodUnion<[z.ZodObject<{
                            markdownType: z.ZodLiteral<"text">;
                            text: z.ZodString;
                            color: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        }, {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        }>, z.ZodObject<{
                            markdownType: z.ZodLiteral<"hybrid">;
                            text: z.ZodString;
                            token: z.ZodString;
                            linkText: z.ZodString;
                            link: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        }, {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        }>, z.ZodObject<{
                            markdownType: z.ZodLiteral<"link">;
                            text: z.ZodString;
                            link: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            link: string;
                            markdownType: "link";
                        }, {
                            text: string;
                            link: string;
                            markdownType: "link";
                        }>, z.ZodObject<{
                            markdownType: z.ZodOptional<z.ZodUndefined>;
                            text: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            markdownType?: undefined;
                        }, {
                            text: string;
                            markdownType?: undefined;
                        }>]>>;
                    }, "strip", z.ZodTypeAny, {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }, {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }>, "many">;
                }, "strip", z.ZodTypeAny, {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }, {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }>, "many">>;
            }, "strip", z.ZodTypeAny, {
                options: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    disableSearch?: boolean | undefined;
                    createSearchChoice?: boolean | undefined;
                    referenceName?: string | undefined;
                    endpointUrl?: string | undefined;
                    allowList?: string | undefined;
                    denyList?: string | undefined;
                    labelField?: string | undefined;
                    valueField?: string | undefined;
                    autoCompleteFields?: ({
                        value: string | number | boolean;
                        label: string;
                    } | {
                        label: string;
                        children: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                    })[] | undefined;
                    dependencies?: string[] | undefined;
                    items?: {
                        value: string | number | boolean;
                        label: string;
                    }[] | undefined;
                };
                type: "singleSelect";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            }, {
                options: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    disableSearch?: boolean | undefined;
                    createSearchChoice?: boolean | undefined;
                    referenceName?: string | undefined;
                    endpointUrl?: string | undefined;
                    allowList?: string | undefined;
                    denyList?: string | undefined;
                    labelField?: string | undefined;
                    valueField?: string | undefined;
                    autoCompleteFields?: ({
                        value: string | number | boolean;
                        label: string;
                    } | {
                        label: string;
                        children: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                    })[] | undefined;
                    dependencies?: string[] | undefined;
                    items?: {
                        value: string | number | boolean;
                        label: string;
                    }[] | undefined;
                };
                type: "singleSelect";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            }>, z.ZodObject<{
                field: z.ZodString;
                label: z.ZodString;
                help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                    text: z.ZodString;
                    links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        slug: z.ZodString;
                        link: z.ZodString;
                        linkText: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }>, "many">>;
                    link: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }>]>>;
                tooltip: z.ZodOptional<z.ZodString>;
                required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            } & {
                type: z.ZodLiteral<"multipleSelect">;
                validators: z.ZodOptional<z.ZodArray<z.ZodUnion<[z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"number">;
                    range: z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>;
                    isInteger: z.ZodOptional<z.ZodBoolean>;
                }, "strip", z.ZodTypeAny, {
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                }, {
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"string">;
                    minLength: z.ZodNumber;
                    maxLength: z.ZodNumber;
                }, "strip", z.ZodTypeAny, {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                }, {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"regex">;
                    pattern: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }, {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"email">;
                }, "strip", z.ZodTypeAny, {
                    type: "email";
                    errorMsg?: string | undefined;
                }, {
                    type: "email";
                    errorMsg?: string | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"ipv4">;
                }, "strip", z.ZodTypeAny, {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                }, {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"url">;
                }, "strip", z.ZodTypeAny, {
                    type: "url";
                    errorMsg?: string | undefined;
                }, {
                    type: "url";
                    errorMsg?: string | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"date">;
                }, "strip", z.ZodTypeAny, {
                    type: "date";
                    errorMsg?: string | undefined;
                }, {
                    type: "date";
                    errorMsg?: string | undefined;
                }>]>, "many">>;
                defaultValue: z.ZodOptional<z.ZodString>;
                options: z.ZodObject<{
                    display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
                } & {
                    disableSearch: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    createSearchChoice: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    referenceName: z.ZodOptional<z.ZodString>;
                    endpointUrl: z.ZodOptional<z.ZodString>;
                    allowList: z.ZodOptional<z.ZodString>;
                    denyList: z.ZodOptional<z.ZodString>;
                    labelField: z.ZodOptional<z.ZodString>;
                    valueField: z.ZodOptional<z.ZodString>;
                    autoCompleteFields: z.ZodOptional<z.ZodArray<z.ZodUnion<[z.ZodObject<{
                        value: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                        label: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        value: string | number | boolean;
                        label: string;
                    }, {
                        value: string | number | boolean;
                        label: string;
                    }>, z.ZodObject<{
                        label: z.ZodString;
                        children: z.ZodArray<z.ZodObject<{
                            value: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                            label: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            value: string | number | boolean;
                            label: string;
                        }, {
                            value: string | number | boolean;
                            label: string;
                        }>, "many">;
                    }, "strip", z.ZodTypeAny, {
                        label: string;
                        children: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                    }, {
                        label: string;
                        children: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                    }>]>, "many">>;
                    dependencies: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                    items: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        value: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                        label: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        value: string | number | boolean;
                        label: string;
                    }, {
                        value: string | number | boolean;
                        label: string;
                    }>, "many">>;
                } & {
                    delimiter: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    disableSearch?: boolean | undefined;
                    createSearchChoice?: boolean | undefined;
                    referenceName?: string | undefined;
                    endpointUrl?: string | undefined;
                    allowList?: string | undefined;
                    denyList?: string | undefined;
                    labelField?: string | undefined;
                    valueField?: string | undefined;
                    autoCompleteFields?: ({
                        value: string | number | boolean;
                        label: string;
                    } | {
                        label: string;
                        children: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                    })[] | undefined;
                    dependencies?: string[] | undefined;
                    items?: {
                        value: string | number | boolean;
                        label: string;
                    }[] | undefined;
                    delimiter?: string | undefined;
                }, {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    disableSearch?: boolean | undefined;
                    createSearchChoice?: boolean | undefined;
                    referenceName?: string | undefined;
                    endpointUrl?: string | undefined;
                    allowList?: string | undefined;
                    denyList?: string | undefined;
                    labelField?: string | undefined;
                    valueField?: string | undefined;
                    autoCompleteFields?: ({
                        value: string | number | boolean;
                        label: string;
                    } | {
                        label: string;
                        children: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                    })[] | undefined;
                    dependencies?: string[] | undefined;
                    items?: {
                        value: string | number | boolean;
                        label: string;
                    }[] | undefined;
                    delimiter?: string | undefined;
                }>;
                modifyFieldsOnValue: z.ZodOptional<z.ZodArray<z.ZodObject<{
                    fieldValue: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                    mode: z.ZodOptional<z.ZodEnum<["create", "edit", "config", "clone"]>>;
                    fieldsToModify: z.ZodArray<z.ZodObject<{
                        fieldId: z.ZodString;
                        display: z.ZodOptional<z.ZodBoolean>;
                        value: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>>;
                        disabled: z.ZodOptional<z.ZodBoolean>;
                        required: z.ZodOptional<z.ZodBoolean>;
                        help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                            text: z.ZodString;
                            links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                slug: z.ZodString;
                                link: z.ZodString;
                                linkText: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                slug: string;
                                link: string;
                                linkText: string;
                            }, {
                                slug: string;
                                link: string;
                                linkText: string;
                            }>, "many">>;
                            link: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        }, {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        }>]>>;
                        label: z.ZodOptional<z.ZodString>;
                        markdownMessage: z.ZodOptional<z.ZodUnion<[z.ZodObject<{
                            markdownType: z.ZodLiteral<"text">;
                            text: z.ZodString;
                            color: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        }, {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        }>, z.ZodObject<{
                            markdownType: z.ZodLiteral<"hybrid">;
                            text: z.ZodString;
                            token: z.ZodString;
                            linkText: z.ZodString;
                            link: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        }, {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        }>, z.ZodObject<{
                            markdownType: z.ZodLiteral<"link">;
                            text: z.ZodString;
                            link: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            link: string;
                            markdownType: "link";
                        }, {
                            text: string;
                            link: string;
                            markdownType: "link";
                        }>, z.ZodObject<{
                            markdownType: z.ZodOptional<z.ZodUndefined>;
                            text: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            markdownType?: undefined;
                        }, {
                            text: string;
                            markdownType?: undefined;
                        }>]>>;
                    }, "strip", z.ZodTypeAny, {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }, {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }>, "many">;
                }, "strip", z.ZodTypeAny, {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }, {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }>, "many">>;
            }, "strip", z.ZodTypeAny, {
                options: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    disableSearch?: boolean | undefined;
                    createSearchChoice?: boolean | undefined;
                    referenceName?: string | undefined;
                    endpointUrl?: string | undefined;
                    allowList?: string | undefined;
                    denyList?: string | undefined;
                    labelField?: string | undefined;
                    valueField?: string | undefined;
                    autoCompleteFields?: ({
                        value: string | number | boolean;
                        label: string;
                    } | {
                        label: string;
                        children: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                    })[] | undefined;
                    dependencies?: string[] | undefined;
                    items?: {
                        value: string | number | boolean;
                        label: string;
                    }[] | undefined;
                    delimiter?: string | undefined;
                };
                type: "multipleSelect";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            }, {
                options: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    disableSearch?: boolean | undefined;
                    createSearchChoice?: boolean | undefined;
                    referenceName?: string | undefined;
                    endpointUrl?: string | undefined;
                    allowList?: string | undefined;
                    denyList?: string | undefined;
                    labelField?: string | undefined;
                    valueField?: string | undefined;
                    autoCompleteFields?: ({
                        value: string | number | boolean;
                        label: string;
                    } | {
                        label: string;
                        children: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                    })[] | undefined;
                    dependencies?: string[] | undefined;
                    items?: {
                        value: string | number | boolean;
                        label: string;
                    }[] | undefined;
                    delimiter?: string | undefined;
                };
                type: "multipleSelect";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            }>, z.ZodObject<{
                field: z.ZodString;
                label: z.ZodString;
                help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                    text: z.ZodString;
                    links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        slug: z.ZodString;
                        link: z.ZodString;
                        linkText: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }>, "many">>;
                    link: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }>]>>;
                tooltip: z.ZodOptional<z.ZodString>;
                required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            } & {
                type: z.ZodLiteral<"checkbox">;
                defaultValue: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodBoolean]>>;
                options: z.ZodOptional<z.ZodObject<{
                    display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
                }, "strip", z.ZodTypeAny, {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                }, {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                }>>;
                modifyFieldsOnValue: z.ZodOptional<z.ZodArray<z.ZodObject<{
                    fieldValue: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                    mode: z.ZodOptional<z.ZodEnum<["create", "edit", "config", "clone"]>>;
                    fieldsToModify: z.ZodArray<z.ZodObject<{
                        fieldId: z.ZodString;
                        display: z.ZodOptional<z.ZodBoolean>;
                        value: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>>;
                        disabled: z.ZodOptional<z.ZodBoolean>;
                        required: z.ZodOptional<z.ZodBoolean>;
                        help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                            text: z.ZodString;
                            links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                slug: z.ZodString;
                                link: z.ZodString;
                                linkText: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                slug: string;
                                link: string;
                                linkText: string;
                            }, {
                                slug: string;
                                link: string;
                                linkText: string;
                            }>, "many">>;
                            link: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        }, {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        }>]>>;
                        label: z.ZodOptional<z.ZodString>;
                        markdownMessage: z.ZodOptional<z.ZodUnion<[z.ZodObject<{
                            markdownType: z.ZodLiteral<"text">;
                            text: z.ZodString;
                            color: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        }, {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        }>, z.ZodObject<{
                            markdownType: z.ZodLiteral<"hybrid">;
                            text: z.ZodString;
                            token: z.ZodString;
                            linkText: z.ZodString;
                            link: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        }, {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        }>, z.ZodObject<{
                            markdownType: z.ZodLiteral<"link">;
                            text: z.ZodString;
                            link: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            link: string;
                            markdownType: "link";
                        }, {
                            text: string;
                            link: string;
                            markdownType: "link";
                        }>, z.ZodObject<{
                            markdownType: z.ZodOptional<z.ZodUndefined>;
                            text: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            markdownType?: undefined;
                        }, {
                            text: string;
                            markdownType?: undefined;
                        }>]>>;
                    }, "strip", z.ZodTypeAny, {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }, {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }>, "many">;
                }, "strip", z.ZodTypeAny, {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }, {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }>, "many">>;
            }, "strip", z.ZodTypeAny, {
                type: "checkbox";
                label: string;
                field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                defaultValue?: number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            }, {
                type: "checkbox";
                label: string;
                field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                defaultValue?: number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            }>, z.ZodObject<{
                field: z.ZodString;
                label: z.ZodString;
                help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                    text: z.ZodString;
                    links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        slug: z.ZodString;
                        link: z.ZodString;
                        linkText: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }>, "many">>;
                    link: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }>]>>;
                tooltip: z.ZodOptional<z.ZodString>;
                required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            } & {
                type: z.ZodLiteral<"checkboxGroup">;
                validators: z.ZodOptional<z.ZodTuple<[z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"regex">;
                    pattern: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }, {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }>], null>>;
                defaultValue: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodBoolean]>>;
                options: z.ZodObject<{
                    display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
                } & {
                    delimiter: z.ZodOptional<z.ZodString>;
                    groups: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        label: z.ZodString;
                        fields: z.ZodArray<z.ZodString, "many">;
                        options: z.ZodOptional<z.ZodObject<{
                            isExpandable: z.ZodOptional<z.ZodBoolean>;
                            expand: z.ZodOptional<z.ZodBoolean>;
                        }, "strip", z.ZodTypeAny, {
                            isExpandable?: boolean | undefined;
                            expand?: boolean | undefined;
                        }, {
                            isExpandable?: boolean | undefined;
                            expand?: boolean | undefined;
                        }>>;
                    }, "strip", z.ZodTypeAny, {
                        label: string;
                        fields: string[];
                        options?: {
                            isExpandable?: boolean | undefined;
                            expand?: boolean | undefined;
                        } | undefined;
                    }, {
                        label: string;
                        fields: string[];
                        options?: {
                            isExpandable?: boolean | undefined;
                            expand?: boolean | undefined;
                        } | undefined;
                    }>, "many">>;
                    rows: z.ZodArray<z.ZodObject<{
                        field: z.ZodString;
                        checkbox: z.ZodOptional<z.ZodObject<{
                            label: z.ZodOptional<z.ZodString>;
                            defaultValue: z.ZodOptional<z.ZodBoolean>;
                        }, "strip", z.ZodTypeAny, {
                            label?: string | undefined;
                            defaultValue?: boolean | undefined;
                        }, {
                            label?: string | undefined;
                            defaultValue?: boolean | undefined;
                        }>>;
                        input: z.ZodOptional<z.ZodObject<{
                            defaultValue: z.ZodOptional<z.ZodNumber>;
                            validators: z.ZodOptional<z.ZodTuple<[z.ZodObject<{
                                errorMsg: z.ZodOptional<z.ZodString>;
                                type: z.ZodLiteral<"number">;
                                range: z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>;
                                isInteger: z.ZodOptional<z.ZodBoolean>;
                            }, "strip", z.ZodTypeAny, {
                                type: "number";
                                range: [number, number];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            }, {
                                type: "number";
                                range: [number, number];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            }>], null>>;
                            required: z.ZodOptional<z.ZodBoolean>;
                        }, "strip", z.ZodTypeAny, {
                            required?: boolean | undefined;
                            validators?: [{
                                type: "number";
                                range: [number, number];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            }] | undefined;
                            defaultValue?: number | undefined;
                        }, {
                            required?: boolean | undefined;
                            validators?: [{
                                type: "number";
                                range: [number, number];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            }] | undefined;
                            defaultValue?: number | undefined;
                        }>>;
                    }, "strip", z.ZodTypeAny, {
                        field: string;
                        checkbox?: {
                            label?: string | undefined;
                            defaultValue?: boolean | undefined;
                        } | undefined;
                        input?: {
                            required?: boolean | undefined;
                            validators?: [{
                                type: "number";
                                range: [number, number];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            }] | undefined;
                            defaultValue?: number | undefined;
                        } | undefined;
                    }, {
                        field: string;
                        checkbox?: {
                            label?: string | undefined;
                            defaultValue?: boolean | undefined;
                        } | undefined;
                        input?: {
                            required?: boolean | undefined;
                            validators?: [{
                                type: "number";
                                range: [number, number];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            }] | undefined;
                            defaultValue?: number | undefined;
                        } | undefined;
                    }>, "many">;
                }, "strip", z.ZodTypeAny, {
                    rows: {
                        field: string;
                        checkbox?: {
                            label?: string | undefined;
                            defaultValue?: boolean | undefined;
                        } | undefined;
                        input?: {
                            required?: boolean | undefined;
                            validators?: [{
                                type: "number";
                                range: [number, number];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            }] | undefined;
                            defaultValue?: number | undefined;
                        } | undefined;
                    }[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    delimiter?: string | undefined;
                    groups?: {
                        label: string;
                        fields: string[];
                        options?: {
                            isExpandable?: boolean | undefined;
                            expand?: boolean | undefined;
                        } | undefined;
                    }[] | undefined;
                }, {
                    rows: {
                        field: string;
                        checkbox?: {
                            label?: string | undefined;
                            defaultValue?: boolean | undefined;
                        } | undefined;
                        input?: {
                            required?: boolean | undefined;
                            validators?: [{
                                type: "number";
                                range: [number, number];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            }] | undefined;
                            defaultValue?: number | undefined;
                        } | undefined;
                    }[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    delimiter?: string | undefined;
                    groups?: {
                        label: string;
                        fields: string[];
                        options?: {
                            isExpandable?: boolean | undefined;
                            expand?: boolean | undefined;
                        } | undefined;
                    }[] | undefined;
                }>;
            }, "strip", z.ZodTypeAny, {
                options: {
                    rows: {
                        field: string;
                        checkbox?: {
                            label?: string | undefined;
                            defaultValue?: boolean | undefined;
                        } | undefined;
                        input?: {
                            required?: boolean | undefined;
                            validators?: [{
                                type: "number";
                                range: [number, number];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            }] | undefined;
                            defaultValue?: number | undefined;
                        } | undefined;
                    }[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    delimiter?: string | undefined;
                    groups?: {
                        label: string;
                        fields: string[];
                        options?: {
                            isExpandable?: boolean | undefined;
                            expand?: boolean | undefined;
                        } | undefined;
                    }[] | undefined;
                };
                type: "checkboxGroup";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: [{
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }] | undefined;
                defaultValue?: number | boolean | undefined;
            }, {
                options: {
                    rows: {
                        field: string;
                        checkbox?: {
                            label?: string | undefined;
                            defaultValue?: boolean | undefined;
                        } | undefined;
                        input?: {
                            required?: boolean | undefined;
                            validators?: [{
                                type: "number";
                                range: [number, number];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            }] | undefined;
                            defaultValue?: number | undefined;
                        } | undefined;
                    }[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    delimiter?: string | undefined;
                    groups?: {
                        label: string;
                        fields: string[];
                        options?: {
                            isExpandable?: boolean | undefined;
                            expand?: boolean | undefined;
                        } | undefined;
                    }[] | undefined;
                };
                type: "checkboxGroup";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: [{
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }] | undefined;
                defaultValue?: number | boolean | undefined;
            }>, z.ZodObject<{
                field: z.ZodString;
                label: z.ZodString;
                help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                    text: z.ZodString;
                    links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        slug: z.ZodString;
                        link: z.ZodString;
                        linkText: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }>, "many">>;
                    link: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }>]>>;
                tooltip: z.ZodOptional<z.ZodString>;
                required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            } & {
                type: z.ZodLiteral<"checkboxTree">;
                validators: z.ZodOptional<z.ZodTuple<[z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"regex">;
                    pattern: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }, {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }>], null>>;
                defaultValue: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodBoolean]>>;
                options: z.ZodObject<{
                    display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
                } & {
                    delimiter: z.ZodOptional<z.ZodString>;
                    groups: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        label: z.ZodString;
                        fields: z.ZodArray<z.ZodString, "many">;
                        options: z.ZodOptional<z.ZodObject<{
                            isExpandable: z.ZodOptional<z.ZodBoolean>;
                            expand: z.ZodOptional<z.ZodBoolean>;
                        }, "strip", z.ZodTypeAny, {
                            isExpandable?: boolean | undefined;
                            expand?: boolean | undefined;
                        }, {
                            isExpandable?: boolean | undefined;
                            expand?: boolean | undefined;
                        }>>;
                    }, "strip", z.ZodTypeAny, {
                        label: string;
                        fields: string[];
                        options?: {
                            isExpandable?: boolean | undefined;
                            expand?: boolean | undefined;
                        } | undefined;
                    }, {
                        label: string;
                        fields: string[];
                        options?: {
                            isExpandable?: boolean | undefined;
                            expand?: boolean | undefined;
                        } | undefined;
                    }>, "many">>;
                    rows: z.ZodArray<z.ZodObject<{
                        field: z.ZodString;
                        checkbox: z.ZodOptional<z.ZodObject<{
                            label: z.ZodOptional<z.ZodString>;
                            defaultValue: z.ZodOptional<z.ZodBoolean>;
                        }, "strip", z.ZodTypeAny, {
                            label?: string | undefined;
                            defaultValue?: boolean | undefined;
                        }, {
                            label?: string | undefined;
                            defaultValue?: boolean | undefined;
                        }>>;
                    }, "strip", z.ZodTypeAny, {
                        field: string;
                        checkbox?: {
                            label?: string | undefined;
                            defaultValue?: boolean | undefined;
                        } | undefined;
                    }, {
                        field: string;
                        checkbox?: {
                            label?: string | undefined;
                            defaultValue?: boolean | undefined;
                        } | undefined;
                    }>, "many">;
                }, "strip", z.ZodTypeAny, {
                    rows: {
                        field: string;
                        checkbox?: {
                            label?: string | undefined;
                            defaultValue?: boolean | undefined;
                        } | undefined;
                    }[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    delimiter?: string | undefined;
                    groups?: {
                        label: string;
                        fields: string[];
                        options?: {
                            isExpandable?: boolean | undefined;
                            expand?: boolean | undefined;
                        } | undefined;
                    }[] | undefined;
                }, {
                    rows: {
                        field: string;
                        checkbox?: {
                            label?: string | undefined;
                            defaultValue?: boolean | undefined;
                        } | undefined;
                    }[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    delimiter?: string | undefined;
                    groups?: {
                        label: string;
                        fields: string[];
                        options?: {
                            isExpandable?: boolean | undefined;
                            expand?: boolean | undefined;
                        } | undefined;
                    }[] | undefined;
                }>;
            }, "strip", z.ZodTypeAny, {
                options: {
                    rows: {
                        field: string;
                        checkbox?: {
                            label?: string | undefined;
                            defaultValue?: boolean | undefined;
                        } | undefined;
                    }[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    delimiter?: string | undefined;
                    groups?: {
                        label: string;
                        fields: string[];
                        options?: {
                            isExpandable?: boolean | undefined;
                            expand?: boolean | undefined;
                        } | undefined;
                    }[] | undefined;
                };
                type: "checkboxTree";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: [{
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }] | undefined;
                defaultValue?: number | boolean | undefined;
            }, {
                options: {
                    rows: {
                        field: string;
                        checkbox?: {
                            label?: string | undefined;
                            defaultValue?: boolean | undefined;
                        } | undefined;
                    }[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    delimiter?: string | undefined;
                    groups?: {
                        label: string;
                        fields: string[];
                        options?: {
                            isExpandable?: boolean | undefined;
                            expand?: boolean | undefined;
                        } | undefined;
                    }[] | undefined;
                };
                type: "checkboxTree";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: [{
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }] | undefined;
                defaultValue?: number | boolean | undefined;
            }>, z.ZodObject<{
                field: z.ZodString;
                label: z.ZodString;
                help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                    text: z.ZodString;
                    links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        slug: z.ZodString;
                        link: z.ZodString;
                        linkText: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }>, "many">>;
                    link: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }>]>>;
                tooltip: z.ZodOptional<z.ZodString>;
                required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            } & {
                type: z.ZodLiteral<"radio">;
                defaultValue: z.ZodOptional<z.ZodString>;
                options: z.ZodObject<{
                    display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
                } & {
                    items: z.ZodArray<z.ZodObject<{
                        value: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                        label: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        value: string | number | boolean;
                        label: string;
                    }, {
                        value: string | number | boolean;
                        label: string;
                    }>, "many">;
                }, "strip", z.ZodTypeAny, {
                    items: {
                        value: string | number | boolean;
                        label: string;
                    }[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                }, {
                    items: {
                        value: string | number | boolean;
                        label: string;
                    }[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                }>;
                modifyFieldsOnValue: z.ZodOptional<z.ZodArray<z.ZodObject<{
                    fieldValue: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                    mode: z.ZodOptional<z.ZodEnum<["create", "edit", "config", "clone"]>>;
                    fieldsToModify: z.ZodArray<z.ZodObject<{
                        fieldId: z.ZodString;
                        display: z.ZodOptional<z.ZodBoolean>;
                        value: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>>;
                        disabled: z.ZodOptional<z.ZodBoolean>;
                        required: z.ZodOptional<z.ZodBoolean>;
                        help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                            text: z.ZodString;
                            links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                slug: z.ZodString;
                                link: z.ZodString;
                                linkText: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                slug: string;
                                link: string;
                                linkText: string;
                            }, {
                                slug: string;
                                link: string;
                                linkText: string;
                            }>, "many">>;
                            link: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        }, {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        }>]>>;
                        label: z.ZodOptional<z.ZodString>;
                        markdownMessage: z.ZodOptional<z.ZodUnion<[z.ZodObject<{
                            markdownType: z.ZodLiteral<"text">;
                            text: z.ZodString;
                            color: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        }, {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        }>, z.ZodObject<{
                            markdownType: z.ZodLiteral<"hybrid">;
                            text: z.ZodString;
                            token: z.ZodString;
                            linkText: z.ZodString;
                            link: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        }, {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        }>, z.ZodObject<{
                            markdownType: z.ZodLiteral<"link">;
                            text: z.ZodString;
                            link: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            link: string;
                            markdownType: "link";
                        }, {
                            text: string;
                            link: string;
                            markdownType: "link";
                        }>, z.ZodObject<{
                            markdownType: z.ZodOptional<z.ZodUndefined>;
                            text: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            markdownType?: undefined;
                        }, {
                            text: string;
                            markdownType?: undefined;
                        }>]>>;
                    }, "strip", z.ZodTypeAny, {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }, {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }>, "many">;
                }, "strip", z.ZodTypeAny, {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }, {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }>, "many">>;
            }, "strip", z.ZodTypeAny, {
                options: {
                    items: {
                        value: string | number | boolean;
                        label: string;
                    }[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                };
                type: "radio";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            }, {
                options: {
                    items: {
                        value: string | number | boolean;
                        label: string;
                    }[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                };
                type: "radio";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            }>, z.ZodObject<{
                field: z.ZodString;
                label: z.ZodString;
                help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                    text: z.ZodString;
                    links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        slug: z.ZodString;
                        link: z.ZodString;
                        linkText: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }>, "many">>;
                    link: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }>]>>;
                tooltip: z.ZodOptional<z.ZodString>;
                required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            } & {
                type: z.ZodLiteral<"file">;
                defaultValue: z.ZodOptional<z.ZodString>;
                validators: z.ZodOptional<z.ZodArray<z.ZodUnion<[z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"string">;
                    minLength: z.ZodNumber;
                    maxLength: z.ZodNumber;
                }, "strip", z.ZodTypeAny, {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                }, {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"regex">;
                    pattern: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }, {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }>]>, "many">>;
                options: z.ZodOptional<z.ZodObject<{
                    display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
                } & {
                    maxFileSize: z.ZodOptional<z.ZodNumber>;
                    fileSupportMessage: z.ZodOptional<z.ZodString>;
                    supportedFileTypes: z.ZodArray<z.ZodString, "many">;
                    useBase64Encoding: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                }, "strip", z.ZodTypeAny, {
                    supportedFileTypes: string[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    maxFileSize?: number | undefined;
                    fileSupportMessage?: string | undefined;
                    useBase64Encoding?: boolean | undefined;
                }, {
                    supportedFileTypes: string[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    maxFileSize?: number | undefined;
                    fileSupportMessage?: string | undefined;
                    useBase64Encoding?: boolean | undefined;
                }>>;
                modifyFieldsOnValue: z.ZodOptional<z.ZodArray<z.ZodObject<{
                    fieldValue: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                    mode: z.ZodOptional<z.ZodEnum<["create", "edit", "config", "clone"]>>;
                    fieldsToModify: z.ZodArray<z.ZodObject<{
                        fieldId: z.ZodString;
                        display: z.ZodOptional<z.ZodBoolean>;
                        value: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>>;
                        disabled: z.ZodOptional<z.ZodBoolean>;
                        required: z.ZodOptional<z.ZodBoolean>;
                        help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                            text: z.ZodString;
                            links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                slug: z.ZodString;
                                link: z.ZodString;
                                linkText: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                slug: string;
                                link: string;
                                linkText: string;
                            }, {
                                slug: string;
                                link: string;
                                linkText: string;
                            }>, "many">>;
                            link: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        }, {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        }>]>>;
                        label: z.ZodOptional<z.ZodString>;
                        markdownMessage: z.ZodOptional<z.ZodUnion<[z.ZodObject<{
                            markdownType: z.ZodLiteral<"text">;
                            text: z.ZodString;
                            color: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        }, {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        }>, z.ZodObject<{
                            markdownType: z.ZodLiteral<"hybrid">;
                            text: z.ZodString;
                            token: z.ZodString;
                            linkText: z.ZodString;
                            link: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        }, {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        }>, z.ZodObject<{
                            markdownType: z.ZodLiteral<"link">;
                            text: z.ZodString;
                            link: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            link: string;
                            markdownType: "link";
                        }, {
                            text: string;
                            link: string;
                            markdownType: "link";
                        }>, z.ZodObject<{
                            markdownType: z.ZodOptional<z.ZodUndefined>;
                            text: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            markdownType?: undefined;
                        }, {
                            text: string;
                            markdownType?: undefined;
                        }>]>>;
                    }, "strip", z.ZodTypeAny, {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }, {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }>, "many">;
                }, "strip", z.ZodTypeAny, {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }, {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }>, "many">>;
            }, "strip", z.ZodTypeAny, {
                type: "file";
                label: string;
                field: string;
                options?: {
                    supportedFileTypes: string[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    maxFileSize?: number | undefined;
                    fileSupportMessage?: string | undefined;
                    useBase64Encoding?: boolean | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            }, {
                type: "file";
                label: string;
                field: string;
                options?: {
                    supportedFileTypes: string[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    maxFileSize?: number | undefined;
                    fileSupportMessage?: string | undefined;
                    useBase64Encoding?: boolean | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            }>, z.ZodObject<{
                field: z.ZodString;
                label: z.ZodString;
                help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                    text: z.ZodString;
                    links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        slug: z.ZodString;
                        link: z.ZodString;
                        linkText: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }>, "many">>;
                    link: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }>]>>;
                tooltip: z.ZodOptional<z.ZodString>;
                required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            } & {
                type: z.ZodLiteral<"oauth">;
                defaultValue: z.ZodOptional<z.ZodString>;
                validators: z.ZodOptional<z.ZodArray<z.ZodUnion<[z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"string">;
                    minLength: z.ZodNumber;
                    maxLength: z.ZodNumber;
                }, "strip", z.ZodTypeAny, {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                }, {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"regex">;
                    pattern: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }, {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }>]>, "many">>;
                options: z.ZodObject<Omit<{
                    display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
                }, "requiredWhenVisible"> & {
                    auth_type: z.ZodArray<z.ZodUnion<[z.ZodLiteral<"basic">, z.ZodLiteral<"oauth">, z.ZodLiteral<"oauth_client_credentials">]>, "many">;
                    basic: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        oauth_field: z.ZodString;
                        label: z.ZodString;
                        field: z.ZodString;
                        type: z.ZodOptional<z.ZodDefault<z.ZodLiteral<"text">>>;
                        help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                            text: z.ZodString;
                            links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                slug: z.ZodString;
                                link: z.ZodString;
                                linkText: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                slug: string;
                                link: string;
                                linkText: string;
                            }, {
                                slug: string;
                                link: string;
                                linkText: string;
                            }>, "many">>;
                            link: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        }, {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        }>]>>;
                        encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        defaultValue: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodNumber, z.ZodBoolean]>>;
                        options: z.ZodOptional<z.ZodObject<{
                            display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                            disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                            enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                            requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                            hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
                        }, "strip", z.ZodTypeAny, {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        }, {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        }>>;
                        modifyFieldsOnValue: z.ZodOptional<z.ZodArray<z.ZodObject<{
                            fieldValue: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                            mode: z.ZodOptional<z.ZodEnum<["create", "edit", "config", "clone"]>>;
                            fieldsToModify: z.ZodArray<z.ZodObject<{
                                fieldId: z.ZodString;
                                display: z.ZodOptional<z.ZodBoolean>;
                                value: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>>;
                                disabled: z.ZodOptional<z.ZodBoolean>;
                                required: z.ZodOptional<z.ZodBoolean>;
                                help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                                    text: z.ZodString;
                                    links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                        slug: z.ZodString;
                                        link: z.ZodString;
                                        linkText: z.ZodString;
                                    }, "strip", z.ZodTypeAny, {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }, {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }>, "many">>;
                                    link: z.ZodOptional<z.ZodString>;
                                }, "strip", z.ZodTypeAny, {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                }, {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                }>]>>;
                                label: z.ZodOptional<z.ZodString>;
                                markdownMessage: z.ZodOptional<z.ZodUnion<[z.ZodObject<{
                                    markdownType: z.ZodLiteral<"text">;
                                    text: z.ZodString;
                                    color: z.ZodOptional<z.ZodString>;
                                }, "strip", z.ZodTypeAny, {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                }, {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                }>, z.ZodObject<{
                                    markdownType: z.ZodLiteral<"hybrid">;
                                    text: z.ZodString;
                                    token: z.ZodString;
                                    linkText: z.ZodString;
                                    link: z.ZodString;
                                }, "strip", z.ZodTypeAny, {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                }, {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                }>, z.ZodObject<{
                                    markdownType: z.ZodLiteral<"link">;
                                    text: z.ZodString;
                                    link: z.ZodString;
                                }, "strip", z.ZodTypeAny, {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                }, {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                }>, z.ZodObject<{
                                    markdownType: z.ZodOptional<z.ZodUndefined>;
                                    text: z.ZodString;
                                }, "strip", z.ZodTypeAny, {
                                    text: string;
                                    markdownType?: undefined;
                                }, {
                                    text: string;
                                    markdownType?: undefined;
                                }>]>>;
                            }, "strip", z.ZodTypeAny, {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }, {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }>, "many">;
                        }, "strip", z.ZodTypeAny, {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }, {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }>, "many">>;
                        validators: z.ZodOptional<z.ZodArray<z.ZodUnion<[z.ZodObject<{
                            errorMsg: z.ZodOptional<z.ZodString>;
                            type: z.ZodLiteral<"number">;
                            range: z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>;
                            isInteger: z.ZodOptional<z.ZodBoolean>;
                        }, "strip", z.ZodTypeAny, {
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        }, {
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        }>, z.ZodObject<{
                            errorMsg: z.ZodOptional<z.ZodString>;
                            type: z.ZodLiteral<"string">;
                            minLength: z.ZodNumber;
                            maxLength: z.ZodNumber;
                        }, "strip", z.ZodTypeAny, {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        }, {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        }>, z.ZodObject<{
                            errorMsg: z.ZodOptional<z.ZodString>;
                            type: z.ZodLiteral<"regex">;
                            pattern: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        }, {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        }>, z.ZodObject<{
                            errorMsg: z.ZodOptional<z.ZodString>;
                            type: z.ZodLiteral<"email">;
                        }, "strip", z.ZodTypeAny, {
                            type: "email";
                            errorMsg?: string | undefined;
                        }, {
                            type: "email";
                            errorMsg?: string | undefined;
                        }>, z.ZodObject<{
                            errorMsg: z.ZodOptional<z.ZodString>;
                            type: z.ZodLiteral<"ipv4">;
                        }, "strip", z.ZodTypeAny, {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        }, {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        }>, z.ZodObject<{
                            errorMsg: z.ZodOptional<z.ZodString>;
                            type: z.ZodLiteral<"url">;
                        }, "strip", z.ZodTypeAny, {
                            type: "url";
                            errorMsg?: string | undefined;
                        }, {
                            type: "url";
                            errorMsg?: string | undefined;
                        }>, z.ZodObject<{
                            errorMsg: z.ZodOptional<z.ZodString>;
                            type: z.ZodLiteral<"date">;
                        }, "strip", z.ZodTypeAny, {
                            type: "date";
                            errorMsg?: string | undefined;
                        }, {
                            type: "date";
                            errorMsg?: string | undefined;
                        }>]>, "many">>;
                    }, "strip", z.ZodTypeAny, {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }, {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }>, "many">>;
                    oauth: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        oauth_field: z.ZodString;
                        label: z.ZodString;
                        field: z.ZodString;
                        type: z.ZodOptional<z.ZodDefault<z.ZodLiteral<"text">>>;
                        help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                            text: z.ZodString;
                            links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                slug: z.ZodString;
                                link: z.ZodString;
                                linkText: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                slug: string;
                                link: string;
                                linkText: string;
                            }, {
                                slug: string;
                                link: string;
                                linkText: string;
                            }>, "many">>;
                            link: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        }, {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        }>]>>;
                        encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        defaultValue: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodNumber, z.ZodBoolean]>>;
                        options: z.ZodOptional<z.ZodObject<{
                            display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                            disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                            enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                            requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                            hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
                        }, "strip", z.ZodTypeAny, {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        }, {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        }>>;
                        modifyFieldsOnValue: z.ZodOptional<z.ZodArray<z.ZodObject<{
                            fieldValue: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                            mode: z.ZodOptional<z.ZodEnum<["create", "edit", "config", "clone"]>>;
                            fieldsToModify: z.ZodArray<z.ZodObject<{
                                fieldId: z.ZodString;
                                display: z.ZodOptional<z.ZodBoolean>;
                                value: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>>;
                                disabled: z.ZodOptional<z.ZodBoolean>;
                                required: z.ZodOptional<z.ZodBoolean>;
                                help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                                    text: z.ZodString;
                                    links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                        slug: z.ZodString;
                                        link: z.ZodString;
                                        linkText: z.ZodString;
                                    }, "strip", z.ZodTypeAny, {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }, {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }>, "many">>;
                                    link: z.ZodOptional<z.ZodString>;
                                }, "strip", z.ZodTypeAny, {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                }, {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                }>]>>;
                                label: z.ZodOptional<z.ZodString>;
                                markdownMessage: z.ZodOptional<z.ZodUnion<[z.ZodObject<{
                                    markdownType: z.ZodLiteral<"text">;
                                    text: z.ZodString;
                                    color: z.ZodOptional<z.ZodString>;
                                }, "strip", z.ZodTypeAny, {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                }, {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                }>, z.ZodObject<{
                                    markdownType: z.ZodLiteral<"hybrid">;
                                    text: z.ZodString;
                                    token: z.ZodString;
                                    linkText: z.ZodString;
                                    link: z.ZodString;
                                }, "strip", z.ZodTypeAny, {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                }, {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                }>, z.ZodObject<{
                                    markdownType: z.ZodLiteral<"link">;
                                    text: z.ZodString;
                                    link: z.ZodString;
                                }, "strip", z.ZodTypeAny, {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                }, {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                }>, z.ZodObject<{
                                    markdownType: z.ZodOptional<z.ZodUndefined>;
                                    text: z.ZodString;
                                }, "strip", z.ZodTypeAny, {
                                    text: string;
                                    markdownType?: undefined;
                                }, {
                                    text: string;
                                    markdownType?: undefined;
                                }>]>>;
                            }, "strip", z.ZodTypeAny, {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }, {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }>, "many">;
                        }, "strip", z.ZodTypeAny, {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }, {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }>, "many">>;
                        validators: z.ZodOptional<z.ZodArray<z.ZodUnion<[z.ZodObject<{
                            errorMsg: z.ZodOptional<z.ZodString>;
                            type: z.ZodLiteral<"number">;
                            range: z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>;
                            isInteger: z.ZodOptional<z.ZodBoolean>;
                        }, "strip", z.ZodTypeAny, {
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        }, {
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        }>, z.ZodObject<{
                            errorMsg: z.ZodOptional<z.ZodString>;
                            type: z.ZodLiteral<"string">;
                            minLength: z.ZodNumber;
                            maxLength: z.ZodNumber;
                        }, "strip", z.ZodTypeAny, {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        }, {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        }>, z.ZodObject<{
                            errorMsg: z.ZodOptional<z.ZodString>;
                            type: z.ZodLiteral<"regex">;
                            pattern: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        }, {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        }>, z.ZodObject<{
                            errorMsg: z.ZodOptional<z.ZodString>;
                            type: z.ZodLiteral<"email">;
                        }, "strip", z.ZodTypeAny, {
                            type: "email";
                            errorMsg?: string | undefined;
                        }, {
                            type: "email";
                            errorMsg?: string | undefined;
                        }>, z.ZodObject<{
                            errorMsg: z.ZodOptional<z.ZodString>;
                            type: z.ZodLiteral<"ipv4">;
                        }, "strip", z.ZodTypeAny, {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        }, {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        }>, z.ZodObject<{
                            errorMsg: z.ZodOptional<z.ZodString>;
                            type: z.ZodLiteral<"url">;
                        }, "strip", z.ZodTypeAny, {
                            type: "url";
                            errorMsg?: string | undefined;
                        }, {
                            type: "url";
                            errorMsg?: string | undefined;
                        }>, z.ZodObject<{
                            errorMsg: z.ZodOptional<z.ZodString>;
                            type: z.ZodLiteral<"date">;
                        }, "strip", z.ZodTypeAny, {
                            type: "date";
                            errorMsg?: string | undefined;
                        }, {
                            type: "date";
                            errorMsg?: string | undefined;
                        }>]>, "many">>;
                    }, "strip", z.ZodTypeAny, {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }, {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }>, "many">>;
                    oauth_client_credentials: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        oauth_field: z.ZodString;
                        label: z.ZodString;
                        field: z.ZodString;
                        type: z.ZodOptional<z.ZodDefault<z.ZodLiteral<"text">>>;
                        help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                            text: z.ZodString;
                            links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                slug: z.ZodString;
                                link: z.ZodString;
                                linkText: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                slug: string;
                                link: string;
                                linkText: string;
                            }, {
                                slug: string;
                                link: string;
                                linkText: string;
                            }>, "many">>;
                            link: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        }, {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        }>]>>;
                        encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        defaultValue: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodNumber, z.ZodBoolean]>>;
                        options: z.ZodOptional<z.ZodObject<{
                            display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                            disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                            enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                            requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                            hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
                        }, "strip", z.ZodTypeAny, {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        }, {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        }>>;
                        modifyFieldsOnValue: z.ZodOptional<z.ZodArray<z.ZodObject<{
                            fieldValue: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                            mode: z.ZodOptional<z.ZodEnum<["create", "edit", "config", "clone"]>>;
                            fieldsToModify: z.ZodArray<z.ZodObject<{
                                fieldId: z.ZodString;
                                display: z.ZodOptional<z.ZodBoolean>;
                                value: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>>;
                                disabled: z.ZodOptional<z.ZodBoolean>;
                                required: z.ZodOptional<z.ZodBoolean>;
                                help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                                    text: z.ZodString;
                                    links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                        slug: z.ZodString;
                                        link: z.ZodString;
                                        linkText: z.ZodString;
                                    }, "strip", z.ZodTypeAny, {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }, {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }>, "many">>;
                                    link: z.ZodOptional<z.ZodString>;
                                }, "strip", z.ZodTypeAny, {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                }, {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                }>]>>;
                                label: z.ZodOptional<z.ZodString>;
                                markdownMessage: z.ZodOptional<z.ZodUnion<[z.ZodObject<{
                                    markdownType: z.ZodLiteral<"text">;
                                    text: z.ZodString;
                                    color: z.ZodOptional<z.ZodString>;
                                }, "strip", z.ZodTypeAny, {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                }, {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                }>, z.ZodObject<{
                                    markdownType: z.ZodLiteral<"hybrid">;
                                    text: z.ZodString;
                                    token: z.ZodString;
                                    linkText: z.ZodString;
                                    link: z.ZodString;
                                }, "strip", z.ZodTypeAny, {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                }, {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                }>, z.ZodObject<{
                                    markdownType: z.ZodLiteral<"link">;
                                    text: z.ZodString;
                                    link: z.ZodString;
                                }, "strip", z.ZodTypeAny, {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                }, {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                }>, z.ZodObject<{
                                    markdownType: z.ZodOptional<z.ZodUndefined>;
                                    text: z.ZodString;
                                }, "strip", z.ZodTypeAny, {
                                    text: string;
                                    markdownType?: undefined;
                                }, {
                                    text: string;
                                    markdownType?: undefined;
                                }>]>>;
                            }, "strip", z.ZodTypeAny, {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }, {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }>, "many">;
                        }, "strip", z.ZodTypeAny, {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }, {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }>, "many">>;
                        validators: z.ZodOptional<z.ZodArray<z.ZodUnion<[z.ZodObject<{
                            errorMsg: z.ZodOptional<z.ZodString>;
                            type: z.ZodLiteral<"number">;
                            range: z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>;
                            isInteger: z.ZodOptional<z.ZodBoolean>;
                        }, "strip", z.ZodTypeAny, {
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        }, {
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        }>, z.ZodObject<{
                            errorMsg: z.ZodOptional<z.ZodString>;
                            type: z.ZodLiteral<"string">;
                            minLength: z.ZodNumber;
                            maxLength: z.ZodNumber;
                        }, "strip", z.ZodTypeAny, {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        }, {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        }>, z.ZodObject<{
                            errorMsg: z.ZodOptional<z.ZodString>;
                            type: z.ZodLiteral<"regex">;
                            pattern: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        }, {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        }>, z.ZodObject<{
                            errorMsg: z.ZodOptional<z.ZodString>;
                            type: z.ZodLiteral<"email">;
                        }, "strip", z.ZodTypeAny, {
                            type: "email";
                            errorMsg?: string | undefined;
                        }, {
                            type: "email";
                            errorMsg?: string | undefined;
                        }>, z.ZodObject<{
                            errorMsg: z.ZodOptional<z.ZodString>;
                            type: z.ZodLiteral<"ipv4">;
                        }, "strip", z.ZodTypeAny, {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        }, {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        }>, z.ZodObject<{
                            errorMsg: z.ZodOptional<z.ZodString>;
                            type: z.ZodLiteral<"url">;
                        }, "strip", z.ZodTypeAny, {
                            type: "url";
                            errorMsg?: string | undefined;
                        }, {
                            type: "url";
                            errorMsg?: string | undefined;
                        }>, z.ZodObject<{
                            errorMsg: z.ZodOptional<z.ZodString>;
                            type: z.ZodLiteral<"date">;
                        }, "strip", z.ZodTypeAny, {
                            type: "date";
                            errorMsg?: string | undefined;
                        }, {
                            type: "date";
                            errorMsg?: string | undefined;
                        }>]>, "many">>;
                    }, "strip", z.ZodTypeAny, {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }, {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }>, "many">>;
                    auth_label: z.ZodOptional<z.ZodString>;
                    oauth_popup_width: z.ZodOptional<z.ZodNumber>;
                    oauth_popup_height: z.ZodOptional<z.ZodNumber>;
                    oauth_timeout: z.ZodOptional<z.ZodNumber>;
                    auth_code_endpoint: z.ZodOptional<z.ZodString>;
                    access_token_endpoint: z.ZodOptional<z.ZodString>;
                    oauth_state_enabled: z.ZodOptional<z.ZodBoolean>;
                    auth_endpoint_token_access_type: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    auth_type: ("oauth" | "basic" | "oauth_client_credentials")[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    oauth?: {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }[] | undefined;
                    basic?: {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }[] | undefined;
                    oauth_client_credentials?: {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }[] | undefined;
                    auth_label?: string | undefined;
                    oauth_popup_width?: number | undefined;
                    oauth_popup_height?: number | undefined;
                    oauth_timeout?: number | undefined;
                    auth_code_endpoint?: string | undefined;
                    access_token_endpoint?: string | undefined;
                    oauth_state_enabled?: boolean | undefined;
                    auth_endpoint_token_access_type?: string | undefined;
                }, {
                    auth_type: ("oauth" | "basic" | "oauth_client_credentials")[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    oauth?: {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }[] | undefined;
                    basic?: {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }[] | undefined;
                    oauth_client_credentials?: {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }[] | undefined;
                    auth_label?: string | undefined;
                    oauth_popup_width?: number | undefined;
                    oauth_popup_height?: number | undefined;
                    oauth_timeout?: number | undefined;
                    auth_code_endpoint?: string | undefined;
                    access_token_endpoint?: string | undefined;
                    oauth_state_enabled?: boolean | undefined;
                    auth_endpoint_token_access_type?: string | undefined;
                }>;
            }, "strip", z.ZodTypeAny, {
                options: {
                    auth_type: ("oauth" | "basic" | "oauth_client_credentials")[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    oauth?: {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }[] | undefined;
                    basic?: {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }[] | undefined;
                    oauth_client_credentials?: {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }[] | undefined;
                    auth_label?: string | undefined;
                    oauth_popup_width?: number | undefined;
                    oauth_popup_height?: number | undefined;
                    oauth_timeout?: number | undefined;
                    auth_code_endpoint?: string | undefined;
                    access_token_endpoint?: string | undefined;
                    oauth_state_enabled?: boolean | undefined;
                    auth_endpoint_token_access_type?: string | undefined;
                };
                type: "oauth";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
            }, {
                options: {
                    auth_type: ("oauth" | "basic" | "oauth_client_credentials")[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    oauth?: {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }[] | undefined;
                    basic?: {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }[] | undefined;
                    oauth_client_credentials?: {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }[] | undefined;
                    auth_label?: string | undefined;
                    oauth_popup_width?: number | undefined;
                    oauth_popup_height?: number | undefined;
                    oauth_timeout?: number | undefined;
                    auth_code_endpoint?: string | undefined;
                    access_token_endpoint?: string | undefined;
                    oauth_state_enabled?: boolean | undefined;
                    auth_endpoint_token_access_type?: string | undefined;
                };
                type: "oauth";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
            }>, z.ZodObject<{
                field: z.ZodString;
                label: z.ZodString;
                help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                    text: z.ZodString;
                    links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        slug: z.ZodString;
                        link: z.ZodString;
                        linkText: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }>, "many">>;
                    link: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }>]>>;
                tooltip: z.ZodOptional<z.ZodString>;
                required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            } & {
                type: z.ZodLiteral<"custom">;
                options: z.ZodObject<{
                    type: z.ZodLiteral<"external">;
                    src: z.ZodString;
                    hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
                }, "strip", z.ZodTypeAny, {
                    type: "external";
                    src: string;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                }, {
                    type: "external";
                    src: string;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                }>;
            }, "strip", z.ZodTypeAny, {
                options: {
                    type: "external";
                    src: string;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                };
                type: "custom";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
            }, {
                options: {
                    type: "external";
                    src: string;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                };
                type: "custom";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
            }>]>, "many">>;
            name: z.ZodString;
            title: z.ZodString;
            options: z.ZodOptional<z.ZodObject<{
                saveValidator: z.ZodOptional<z.ZodString>;
            }, "strip", z.ZodTypeAny, {
                saveValidator?: string | undefined;
            }, {
                saveValidator?: string | undefined;
            }>>;
            table: z.ZodOptional<z.ZodObject<{
                moreInfo: z.ZodOptional<z.ZodArray<z.ZodObject<{
                    field: z.ZodString;
                    label: z.ZodString;
                    mapping: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>;
                }, "strip", z.ZodTypeAny, {
                    label: string;
                    field: string;
                    mapping?: Record<string, any> | undefined;
                }, {
                    label: string;
                    field: string;
                    mapping?: Record<string, any> | undefined;
                }>, "many">>;
                header: z.ZodArray<z.ZodObject<{
                    field: z.ZodString;
                    label: z.ZodString;
                    mapping: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>;
                    customCell: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>;
                }, "strip", z.ZodTypeAny, {
                    label: string;
                    field: string;
                    mapping?: Record<string, any> | undefined;
                    customCell?: Record<string, any> | undefined;
                }, {
                    label: string;
                    field: string;
                    mapping?: Record<string, any> | undefined;
                    customCell?: Record<string, any> | undefined;
                }>, "many">;
                customRow: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>;
            } & {
                actions: z.ZodArray<z.ZodEnum<["edit", "delete", "clone"]>, "many">;
            }, "strip", z.ZodTypeAny, {
                header: {
                    label: string;
                    field: string;
                    mapping?: Record<string, any> | undefined;
                    customCell?: Record<string, any> | undefined;
                }[];
                actions: ("clone" | "delete" | "edit")[];
                moreInfo?: {
                    label: string;
                    field: string;
                    mapping?: Record<string, any> | undefined;
                }[] | undefined;
                customRow?: Record<string, any> | undefined;
            }, {
                header: {
                    label: string;
                    field: string;
                    mapping?: Record<string, any> | undefined;
                    customCell?: Record<string, any> | undefined;
                }[];
                actions: ("clone" | "delete" | "edit")[];
                moreInfo?: {
                    label: string;
                    field: string;
                    mapping?: Record<string, any> | undefined;
                }[] | undefined;
                customRow?: Record<string, any> | undefined;
            }>>;
            style: z.ZodOptional<z.ZodEnum<["page", "dialog"]>>;
            hook: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>;
            conf: z.ZodOptional<z.ZodString>;
            restHandlerName: z.ZodOptional<z.ZodString>;
            restHandlerModule: z.ZodOptional<z.ZodString>;
            restHandlerClass: z.ZodOptional<z.ZodString>;
            customTab: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>;
            warning: z.ZodOptional<z.ZodObject<{
                create: z.ZodOptional<z.ZodObject<{
                    message: z.ZodString;
                    alwaysDisplay: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                }, "strip", z.ZodTypeAny, {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                }, {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                }>>;
                edit: z.ZodOptional<z.ZodObject<{
                    message: z.ZodString;
                    alwaysDisplay: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                }, "strip", z.ZodTypeAny, {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                }, {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                }>>;
                config: z.ZodOptional<z.ZodObject<{
                    message: z.ZodString;
                    alwaysDisplay: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                }, "strip", z.ZodTypeAny, {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                }, {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                }>>;
                clone: z.ZodOptional<z.ZodObject<{
                    message: z.ZodString;
                    alwaysDisplay: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                }, "strip", z.ZodTypeAny, {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                }, {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                }>>;
            }, "strip", z.ZodTypeAny, {
                clone?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
                create?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
                edit?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
                config?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
            }, {
                clone?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
                create?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
                edit?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
                config?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
            }>>;
            hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
            groups: z.ZodOptional<z.ZodArray<z.ZodObject<{
                options: z.ZodOptional<z.ZodObject<{
                    isExpandable: z.ZodOptional<z.ZodBoolean>;
                    expand: z.ZodOptional<z.ZodBoolean>;
                }, "strip", z.ZodTypeAny, {
                    isExpandable?: boolean | undefined;
                    expand?: boolean | undefined;
                }, {
                    isExpandable?: boolean | undefined;
                    expand?: boolean | undefined;
                }>>;
                label: z.ZodString;
                fields: z.ZodArray<z.ZodString, "many">;
            }, "strip", z.ZodTypeAny, {
                label: string;
                fields: string[];
                options?: {
                    isExpandable?: boolean | undefined;
                    expand?: boolean | undefined;
                } | undefined;
            }, {
                label: string;
                fields: string[];
                options?: {
                    isExpandable?: boolean | undefined;
                    expand?: boolean | undefined;
                } | undefined;
            }>, "many">>;
            formTitle: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            name: string;
            title: string;
            options?: {
                saveValidator?: string | undefined;
            } | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
            groups?: {
                label: string;
                fields: string[];
                options?: {
                    isExpandable?: boolean | undefined;
                    expand?: boolean | undefined;
                } | undefined;
            }[] | undefined;
            entity?: ({
                type: "helpLink";
                field: string;
                options?: {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: false | undefined;
            } | {
                type: "text";
                label: string;
                field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                type: "textarea";
                label: string;
                field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    rowsMin?: number | undefined;
                    rowsMax?: number | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                options: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    disableSearch?: boolean | undefined;
                    createSearchChoice?: boolean | undefined;
                    referenceName?: string | undefined;
                    endpointUrl?: string | undefined;
                    allowList?: string | undefined;
                    denyList?: string | undefined;
                    labelField?: string | undefined;
                    valueField?: string | undefined;
                    autoCompleteFields?: ({
                        value: string | number | boolean;
                        label: string;
                    } | {
                        label: string;
                        children: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                    })[] | undefined;
                    dependencies?: string[] | undefined;
                    items?: {
                        value: string | number | boolean;
                        label: string;
                    }[] | undefined;
                };
                type: "singleSelect";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                options: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    disableSearch?: boolean | undefined;
                    createSearchChoice?: boolean | undefined;
                    referenceName?: string | undefined;
                    endpointUrl?: string | undefined;
                    allowList?: string | undefined;
                    denyList?: string | undefined;
                    labelField?: string | undefined;
                    valueField?: string | undefined;
                    autoCompleteFields?: ({
                        value: string | number | boolean;
                        label: string;
                    } | {
                        label: string;
                        children: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                    })[] | undefined;
                    dependencies?: string[] | undefined;
                    items?: {
                        value: string | number | boolean;
                        label: string;
                    }[] | undefined;
                    delimiter?: string | undefined;
                };
                type: "multipleSelect";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                type: "checkbox";
                label: string;
                field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                defaultValue?: number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                options: {
                    rows: {
                        field: string;
                        checkbox?: {
                            label?: string | undefined;
                            defaultValue?: boolean | undefined;
                        } | undefined;
                        input?: {
                            required?: boolean | undefined;
                            validators?: [{
                                type: "number";
                                range: [number, number];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            }] | undefined;
                            defaultValue?: number | undefined;
                        } | undefined;
                    }[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    delimiter?: string | undefined;
                    groups?: {
                        label: string;
                        fields: string[];
                        options?: {
                            isExpandable?: boolean | undefined;
                            expand?: boolean | undefined;
                        } | undefined;
                    }[] | undefined;
                };
                type: "checkboxGroup";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: [{
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }] | undefined;
                defaultValue?: number | boolean | undefined;
            } | {
                options: {
                    rows: {
                        field: string;
                        checkbox?: {
                            label?: string | undefined;
                            defaultValue?: boolean | undefined;
                        } | undefined;
                    }[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    delimiter?: string | undefined;
                    groups?: {
                        label: string;
                        fields: string[];
                        options?: {
                            isExpandable?: boolean | undefined;
                            expand?: boolean | undefined;
                        } | undefined;
                    }[] | undefined;
                };
                type: "checkboxTree";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: [{
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }] | undefined;
                defaultValue?: number | boolean | undefined;
            } | {
                options: {
                    items: {
                        value: string | number | boolean;
                        label: string;
                    }[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                };
                type: "radio";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                type: "file";
                label: string;
                field: string;
                options?: {
                    supportedFileTypes: string[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    maxFileSize?: number | undefined;
                    fileSupportMessage?: string | undefined;
                    useBase64Encoding?: boolean | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                options: {
                    auth_type: ("oauth" | "basic" | "oauth_client_credentials")[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    oauth?: {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }[] | undefined;
                    basic?: {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }[] | undefined;
                    oauth_client_credentials?: {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }[] | undefined;
                    auth_label?: string | undefined;
                    oauth_popup_width?: number | undefined;
                    oauth_popup_height?: number | undefined;
                    oauth_timeout?: number | undefined;
                    auth_code_endpoint?: string | undefined;
                    access_token_endpoint?: string | undefined;
                    oauth_state_enabled?: boolean | undefined;
                    auth_endpoint_token_access_type?: string | undefined;
                };
                type: "oauth";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
            } | {
                options: {
                    type: "external";
                    src: string;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                };
                type: "custom";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
            })[] | undefined;
            table?: {
                header: {
                    label: string;
                    field: string;
                    mapping?: Record<string, any> | undefined;
                    customCell?: Record<string, any> | undefined;
                }[];
                actions: ("clone" | "delete" | "edit")[];
                moreInfo?: {
                    label: string;
                    field: string;
                    mapping?: Record<string, any> | undefined;
                }[] | undefined;
                customRow?: Record<string, any> | undefined;
            } | undefined;
            style?: "page" | "dialog" | undefined;
            hook?: Record<string, any> | undefined;
            conf?: string | undefined;
            restHandlerName?: string | undefined;
            restHandlerModule?: string | undefined;
            restHandlerClass?: string | undefined;
            customTab?: Record<string, any> | undefined;
            warning?: {
                clone?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
                create?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
                edit?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
                config?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
            } | undefined;
            formTitle?: string | undefined;
        }, {
            name: string;
            title: string;
            options?: {
                saveValidator?: string | undefined;
            } | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
            groups?: {
                label: string;
                fields: string[];
                options?: {
                    isExpandable?: boolean | undefined;
                    expand?: boolean | undefined;
                } | undefined;
            }[] | undefined;
            entity?: ({
                type: "helpLink";
                field: string;
                options?: {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: false | undefined;
            } | {
                type: "text";
                label: string;
                field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                type: "textarea";
                label: string;
                field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    rowsMin?: number | undefined;
                    rowsMax?: number | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                options: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    disableSearch?: boolean | undefined;
                    createSearchChoice?: boolean | undefined;
                    referenceName?: string | undefined;
                    endpointUrl?: string | undefined;
                    allowList?: string | undefined;
                    denyList?: string | undefined;
                    labelField?: string | undefined;
                    valueField?: string | undefined;
                    autoCompleteFields?: ({
                        value: string | number | boolean;
                        label: string;
                    } | {
                        label: string;
                        children: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                    })[] | undefined;
                    dependencies?: string[] | undefined;
                    items?: {
                        value: string | number | boolean;
                        label: string;
                    }[] | undefined;
                };
                type: "singleSelect";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                options: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    disableSearch?: boolean | undefined;
                    createSearchChoice?: boolean | undefined;
                    referenceName?: string | undefined;
                    endpointUrl?: string | undefined;
                    allowList?: string | undefined;
                    denyList?: string | undefined;
                    labelField?: string | undefined;
                    valueField?: string | undefined;
                    autoCompleteFields?: ({
                        value: string | number | boolean;
                        label: string;
                    } | {
                        label: string;
                        children: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                    })[] | undefined;
                    dependencies?: string[] | undefined;
                    items?: {
                        value: string | number | boolean;
                        label: string;
                    }[] | undefined;
                    delimiter?: string | undefined;
                };
                type: "multipleSelect";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                type: "checkbox";
                label: string;
                field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                defaultValue?: number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                options: {
                    rows: {
                        field: string;
                        checkbox?: {
                            label?: string | undefined;
                            defaultValue?: boolean | undefined;
                        } | undefined;
                        input?: {
                            required?: boolean | undefined;
                            validators?: [{
                                type: "number";
                                range: [number, number];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            }] | undefined;
                            defaultValue?: number | undefined;
                        } | undefined;
                    }[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    delimiter?: string | undefined;
                    groups?: {
                        label: string;
                        fields: string[];
                        options?: {
                            isExpandable?: boolean | undefined;
                            expand?: boolean | undefined;
                        } | undefined;
                    }[] | undefined;
                };
                type: "checkboxGroup";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: [{
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }] | undefined;
                defaultValue?: number | boolean | undefined;
            } | {
                options: {
                    rows: {
                        field: string;
                        checkbox?: {
                            label?: string | undefined;
                            defaultValue?: boolean | undefined;
                        } | undefined;
                    }[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    delimiter?: string | undefined;
                    groups?: {
                        label: string;
                        fields: string[];
                        options?: {
                            isExpandable?: boolean | undefined;
                            expand?: boolean | undefined;
                        } | undefined;
                    }[] | undefined;
                };
                type: "checkboxTree";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: [{
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }] | undefined;
                defaultValue?: number | boolean | undefined;
            } | {
                options: {
                    items: {
                        value: string | number | boolean;
                        label: string;
                    }[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                };
                type: "radio";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                type: "file";
                label: string;
                field: string;
                options?: {
                    supportedFileTypes: string[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    maxFileSize?: number | undefined;
                    fileSupportMessage?: string | undefined;
                    useBase64Encoding?: boolean | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                options: {
                    auth_type: ("oauth" | "basic" | "oauth_client_credentials")[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    oauth?: {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }[] | undefined;
                    basic?: {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }[] | undefined;
                    oauth_client_credentials?: {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }[] | undefined;
                    auth_label?: string | undefined;
                    oauth_popup_width?: number | undefined;
                    oauth_popup_height?: number | undefined;
                    oauth_timeout?: number | undefined;
                    auth_code_endpoint?: string | undefined;
                    access_token_endpoint?: string | undefined;
                    oauth_state_enabled?: boolean | undefined;
                    auth_endpoint_token_access_type?: string | undefined;
                };
                type: "oauth";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
            } | {
                options: {
                    type: "external";
                    src: string;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                };
                type: "custom";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
            })[] | undefined;
            table?: {
                header: {
                    label: string;
                    field: string;
                    mapping?: Record<string, any> | undefined;
                    customCell?: Record<string, any> | undefined;
                }[];
                actions: ("clone" | "delete" | "edit")[];
                moreInfo?: {
                    label: string;
                    field: string;
                    mapping?: Record<string, any> | undefined;
                }[] | undefined;
                customRow?: Record<string, any> | undefined;
            } | undefined;
            style?: "page" | "dialog" | undefined;
            hook?: Record<string, any> | undefined;
            conf?: string | undefined;
            restHandlerName?: string | undefined;
            restHandlerModule?: string | undefined;
            restHandlerClass?: string | undefined;
            customTab?: Record<string, any> | undefined;
            warning?: {
                clone?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
                create?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
                edit?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
                config?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
            } | undefined;
            formTitle?: string | undefined;
        }>, "many">;
    }, "strip", z.ZodTypeAny, {
        title: string;
        tabs: {
            name: string;
            title: string;
            options?: {
                saveValidator?: string | undefined;
            } | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
            groups?: {
                label: string;
                fields: string[];
                options?: {
                    isExpandable?: boolean | undefined;
                    expand?: boolean | undefined;
                } | undefined;
            }[] | undefined;
            entity?: ({
                type: "helpLink";
                field: string;
                options?: {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: false | undefined;
            } | {
                type: "text";
                label: string;
                field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                type: "textarea";
                label: string;
                field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    rowsMin?: number | undefined;
                    rowsMax?: number | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                options: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    disableSearch?: boolean | undefined;
                    createSearchChoice?: boolean | undefined;
                    referenceName?: string | undefined;
                    endpointUrl?: string | undefined;
                    allowList?: string | undefined;
                    denyList?: string | undefined;
                    labelField?: string | undefined;
                    valueField?: string | undefined;
                    autoCompleteFields?: ({
                        value: string | number | boolean;
                        label: string;
                    } | {
                        label: string;
                        children: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                    })[] | undefined;
                    dependencies?: string[] | undefined;
                    items?: {
                        value: string | number | boolean;
                        label: string;
                    }[] | undefined;
                };
                type: "singleSelect";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                options: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    disableSearch?: boolean | undefined;
                    createSearchChoice?: boolean | undefined;
                    referenceName?: string | undefined;
                    endpointUrl?: string | undefined;
                    allowList?: string | undefined;
                    denyList?: string | undefined;
                    labelField?: string | undefined;
                    valueField?: string | undefined;
                    autoCompleteFields?: ({
                        value: string | number | boolean;
                        label: string;
                    } | {
                        label: string;
                        children: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                    })[] | undefined;
                    dependencies?: string[] | undefined;
                    items?: {
                        value: string | number | boolean;
                        label: string;
                    }[] | undefined;
                    delimiter?: string | undefined;
                };
                type: "multipleSelect";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                type: "checkbox";
                label: string;
                field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                defaultValue?: number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                options: {
                    rows: {
                        field: string;
                        checkbox?: {
                            label?: string | undefined;
                            defaultValue?: boolean | undefined;
                        } | undefined;
                        input?: {
                            required?: boolean | undefined;
                            validators?: [{
                                type: "number";
                                range: [number, number];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            }] | undefined;
                            defaultValue?: number | undefined;
                        } | undefined;
                    }[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    delimiter?: string | undefined;
                    groups?: {
                        label: string;
                        fields: string[];
                        options?: {
                            isExpandable?: boolean | undefined;
                            expand?: boolean | undefined;
                        } | undefined;
                    }[] | undefined;
                };
                type: "checkboxGroup";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: [{
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }] | undefined;
                defaultValue?: number | boolean | undefined;
            } | {
                options: {
                    rows: {
                        field: string;
                        checkbox?: {
                            label?: string | undefined;
                            defaultValue?: boolean | undefined;
                        } | undefined;
                    }[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    delimiter?: string | undefined;
                    groups?: {
                        label: string;
                        fields: string[];
                        options?: {
                            isExpandable?: boolean | undefined;
                            expand?: boolean | undefined;
                        } | undefined;
                    }[] | undefined;
                };
                type: "checkboxTree";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: [{
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }] | undefined;
                defaultValue?: number | boolean | undefined;
            } | {
                options: {
                    items: {
                        value: string | number | boolean;
                        label: string;
                    }[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                };
                type: "radio";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                type: "file";
                label: string;
                field: string;
                options?: {
                    supportedFileTypes: string[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    maxFileSize?: number | undefined;
                    fileSupportMessage?: string | undefined;
                    useBase64Encoding?: boolean | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                options: {
                    auth_type: ("oauth" | "basic" | "oauth_client_credentials")[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    oauth?: {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }[] | undefined;
                    basic?: {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }[] | undefined;
                    oauth_client_credentials?: {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }[] | undefined;
                    auth_label?: string | undefined;
                    oauth_popup_width?: number | undefined;
                    oauth_popup_height?: number | undefined;
                    oauth_timeout?: number | undefined;
                    auth_code_endpoint?: string | undefined;
                    access_token_endpoint?: string | undefined;
                    oauth_state_enabled?: boolean | undefined;
                    auth_endpoint_token_access_type?: string | undefined;
                };
                type: "oauth";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
            } | {
                options: {
                    type: "external";
                    src: string;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                };
                type: "custom";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
            })[] | undefined;
            table?: {
                header: {
                    label: string;
                    field: string;
                    mapping?: Record<string, any> | undefined;
                    customCell?: Record<string, any> | undefined;
                }[];
                actions: ("clone" | "delete" | "edit")[];
                moreInfo?: {
                    label: string;
                    field: string;
                    mapping?: Record<string, any> | undefined;
                }[] | undefined;
                customRow?: Record<string, any> | undefined;
            } | undefined;
            style?: "page" | "dialog" | undefined;
            hook?: Record<string, any> | undefined;
            conf?: string | undefined;
            restHandlerName?: string | undefined;
            restHandlerModule?: string | undefined;
            restHandlerClass?: string | undefined;
            customTab?: Record<string, any> | undefined;
            warning?: {
                clone?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
                create?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
                edit?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
                config?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
            } | undefined;
            formTitle?: string | undefined;
        }[];
        description?: string | undefined;
        subDescription?: {
            text: string;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        } | undefined;
    }, {
        title: string;
        tabs: {
            name: string;
            title: string;
            options?: {
                saveValidator?: string | undefined;
            } | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
            groups?: {
                label: string;
                fields: string[];
                options?: {
                    isExpandable?: boolean | undefined;
                    expand?: boolean | undefined;
                } | undefined;
            }[] | undefined;
            entity?: ({
                type: "helpLink";
                field: string;
                options?: {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: false | undefined;
            } | {
                type: "text";
                label: string;
                field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                type: "textarea";
                label: string;
                field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    rowsMin?: number | undefined;
                    rowsMax?: number | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                options: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    disableSearch?: boolean | undefined;
                    createSearchChoice?: boolean | undefined;
                    referenceName?: string | undefined;
                    endpointUrl?: string | undefined;
                    allowList?: string | undefined;
                    denyList?: string | undefined;
                    labelField?: string | undefined;
                    valueField?: string | undefined;
                    autoCompleteFields?: ({
                        value: string | number | boolean;
                        label: string;
                    } | {
                        label: string;
                        children: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                    })[] | undefined;
                    dependencies?: string[] | undefined;
                    items?: {
                        value: string | number | boolean;
                        label: string;
                    }[] | undefined;
                };
                type: "singleSelect";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                options: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    disableSearch?: boolean | undefined;
                    createSearchChoice?: boolean | undefined;
                    referenceName?: string | undefined;
                    endpointUrl?: string | undefined;
                    allowList?: string | undefined;
                    denyList?: string | undefined;
                    labelField?: string | undefined;
                    valueField?: string | undefined;
                    autoCompleteFields?: ({
                        value: string | number | boolean;
                        label: string;
                    } | {
                        label: string;
                        children: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                    })[] | undefined;
                    dependencies?: string[] | undefined;
                    items?: {
                        value: string | number | boolean;
                        label: string;
                    }[] | undefined;
                    delimiter?: string | undefined;
                };
                type: "multipleSelect";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                type: "checkbox";
                label: string;
                field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                defaultValue?: number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                options: {
                    rows: {
                        field: string;
                        checkbox?: {
                            label?: string | undefined;
                            defaultValue?: boolean | undefined;
                        } | undefined;
                        input?: {
                            required?: boolean | undefined;
                            validators?: [{
                                type: "number";
                                range: [number, number];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            }] | undefined;
                            defaultValue?: number | undefined;
                        } | undefined;
                    }[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    delimiter?: string | undefined;
                    groups?: {
                        label: string;
                        fields: string[];
                        options?: {
                            isExpandable?: boolean | undefined;
                            expand?: boolean | undefined;
                        } | undefined;
                    }[] | undefined;
                };
                type: "checkboxGroup";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: [{
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }] | undefined;
                defaultValue?: number | boolean | undefined;
            } | {
                options: {
                    rows: {
                        field: string;
                        checkbox?: {
                            label?: string | undefined;
                            defaultValue?: boolean | undefined;
                        } | undefined;
                    }[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    delimiter?: string | undefined;
                    groups?: {
                        label: string;
                        fields: string[];
                        options?: {
                            isExpandable?: boolean | undefined;
                            expand?: boolean | undefined;
                        } | undefined;
                    }[] | undefined;
                };
                type: "checkboxTree";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: [{
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }] | undefined;
                defaultValue?: number | boolean | undefined;
            } | {
                options: {
                    items: {
                        value: string | number | boolean;
                        label: string;
                    }[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                };
                type: "radio";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                type: "file";
                label: string;
                field: string;
                options?: {
                    supportedFileTypes: string[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    maxFileSize?: number | undefined;
                    fileSupportMessage?: string | undefined;
                    useBase64Encoding?: boolean | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                options: {
                    auth_type: ("oauth" | "basic" | "oauth_client_credentials")[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    oauth?: {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }[] | undefined;
                    basic?: {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }[] | undefined;
                    oauth_client_credentials?: {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }[] | undefined;
                    auth_label?: string | undefined;
                    oauth_popup_width?: number | undefined;
                    oauth_popup_height?: number | undefined;
                    oauth_timeout?: number | undefined;
                    auth_code_endpoint?: string | undefined;
                    access_token_endpoint?: string | undefined;
                    oauth_state_enabled?: boolean | undefined;
                    auth_endpoint_token_access_type?: string | undefined;
                };
                type: "oauth";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
            } | {
                options: {
                    type: "external";
                    src: string;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                };
                type: "custom";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
            })[] | undefined;
            table?: {
                header: {
                    label: string;
                    field: string;
                    mapping?: Record<string, any> | undefined;
                    customCell?: Record<string, any> | undefined;
                }[];
                actions: ("clone" | "delete" | "edit")[];
                moreInfo?: {
                    label: string;
                    field: string;
                    mapping?: Record<string, any> | undefined;
                }[] | undefined;
                customRow?: Record<string, any> | undefined;
            } | undefined;
            style?: "page" | "dialog" | undefined;
            hook?: Record<string, any> | undefined;
            conf?: string | undefined;
            restHandlerName?: string | undefined;
            restHandlerModule?: string | undefined;
            restHandlerClass?: string | undefined;
            customTab?: Record<string, any> | undefined;
            warning?: {
                clone?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
                create?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
                edit?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
                config?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
            } | undefined;
            formTitle?: string | undefined;
        }[];
        description?: string | undefined;
        subDescription?: {
            text: string;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        } | undefined;
    }>>;
    inputs: z.ZodOptional<z.ZodUnion<[z.ZodObject<{
        title: z.ZodString;
        services: z.ZodArray<z.ZodObject<{
            name: z.ZodString;
            title: z.ZodString;
            subTitle: z.ZodOptional<z.ZodString>;
            entity: z.ZodArray<z.ZodDiscriminatedUnion<"type", [z.ZodObject<{
                field: z.ZodString;
                help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                    text: z.ZodString;
                    links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        slug: z.ZodString;
                        link: z.ZodString;
                        linkText: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }>, "many">>;
                    link: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }>]>>;
                tooltip: z.ZodOptional<z.ZodString>;
            } & {
                type: z.ZodLiteral<"helpLink">;
                label: z.ZodOptional<z.ZodString>;
                options: z.ZodOptional<z.ZodObject<{
                    text: z.ZodString;
                    links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        slug: z.ZodString;
                        link: z.ZodString;
                        linkText: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }>, "many">>;
                    link: z.ZodOptional<z.ZodString>;
                } & {
                    hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                }, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                }>>;
                required: z.ZodOptional<z.ZodDefault<z.ZodLiteral<false>>>;
            }, "strip", z.ZodTypeAny, {
                type: "helpLink";
                field: string;
                options?: {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: false | undefined;
            }, {
                type: "helpLink";
                field: string;
                options?: {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: false | undefined;
            }>, z.ZodObject<{
                field: z.ZodString;
                label: z.ZodString;
                help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                    text: z.ZodString;
                    links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        slug: z.ZodString;
                        link: z.ZodString;
                        linkText: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }>, "many">>;
                    link: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }>]>>;
                tooltip: z.ZodOptional<z.ZodString>;
                required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            } & {
                type: z.ZodLiteral<"text">;
                validators: z.ZodOptional<z.ZodArray<z.ZodUnion<[z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"number">;
                    range: z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>;
                    isInteger: z.ZodOptional<z.ZodBoolean>;
                }, "strip", z.ZodTypeAny, {
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                }, {
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"string">;
                    minLength: z.ZodNumber;
                    maxLength: z.ZodNumber;
                }, "strip", z.ZodTypeAny, {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                }, {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"regex">;
                    pattern: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }, {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"email">;
                }, "strip", z.ZodTypeAny, {
                    type: "email";
                    errorMsg?: string | undefined;
                }, {
                    type: "email";
                    errorMsg?: string | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"ipv4">;
                }, "strip", z.ZodTypeAny, {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                }, {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"url">;
                }, "strip", z.ZodTypeAny, {
                    type: "url";
                    errorMsg?: string | undefined;
                }, {
                    type: "url";
                    errorMsg?: string | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"date">;
                }, "strip", z.ZodTypeAny, {
                    type: "date";
                    errorMsg?: string | undefined;
                }, {
                    type: "date";
                    errorMsg?: string | undefined;
                }>]>, "many">>;
                defaultValue: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodNumber, z.ZodBoolean]>>;
                options: z.ZodOptional<z.ZodObject<{
                    display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
                }, "strip", z.ZodTypeAny, {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                }, {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                }>>;
                modifyFieldsOnValue: z.ZodOptional<z.ZodArray<z.ZodObject<{
                    fieldValue: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                    mode: z.ZodOptional<z.ZodEnum<["create", "edit", "config", "clone"]>>;
                    fieldsToModify: z.ZodArray<z.ZodObject<{
                        fieldId: z.ZodString;
                        display: z.ZodOptional<z.ZodBoolean>;
                        value: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>>;
                        disabled: z.ZodOptional<z.ZodBoolean>;
                        required: z.ZodOptional<z.ZodBoolean>;
                        help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                            text: z.ZodString;
                            links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                slug: z.ZodString;
                                link: z.ZodString;
                                linkText: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                slug: string;
                                link: string;
                                linkText: string;
                            }, {
                                slug: string;
                                link: string;
                                linkText: string;
                            }>, "many">>;
                            link: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        }, {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        }>]>>;
                        label: z.ZodOptional<z.ZodString>;
                        markdownMessage: z.ZodOptional<z.ZodUnion<[z.ZodObject<{
                            markdownType: z.ZodLiteral<"text">;
                            text: z.ZodString;
                            color: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        }, {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        }>, z.ZodObject<{
                            markdownType: z.ZodLiteral<"hybrid">;
                            text: z.ZodString;
                            token: z.ZodString;
                            linkText: z.ZodString;
                            link: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        }, {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        }>, z.ZodObject<{
                            markdownType: z.ZodLiteral<"link">;
                            text: z.ZodString;
                            link: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            link: string;
                            markdownType: "link";
                        }, {
                            text: string;
                            link: string;
                            markdownType: "link";
                        }>, z.ZodObject<{
                            markdownType: z.ZodOptional<z.ZodUndefined>;
                            text: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            markdownType?: undefined;
                        }, {
                            text: string;
                            markdownType?: undefined;
                        }>]>>;
                    }, "strip", z.ZodTypeAny, {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }, {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }>, "many">;
                }, "strip", z.ZodTypeAny, {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }, {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }>, "many">>;
            }, "strip", z.ZodTypeAny, {
                type: "text";
                label: string;
                field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            }, {
                type: "text";
                label: string;
                field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            }>, z.ZodObject<{
                field: z.ZodString;
                label: z.ZodString;
                help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                    text: z.ZodString;
                    links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        slug: z.ZodString;
                        link: z.ZodString;
                        linkText: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }>, "many">>;
                    link: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }>]>>;
                tooltip: z.ZodOptional<z.ZodString>;
                required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            } & {
                type: z.ZodLiteral<"textarea">;
                validators: z.ZodOptional<z.ZodArray<z.ZodUnion<[z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"number">;
                    range: z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>;
                    isInteger: z.ZodOptional<z.ZodBoolean>;
                }, "strip", z.ZodTypeAny, {
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                }, {
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"string">;
                    minLength: z.ZodNumber;
                    maxLength: z.ZodNumber;
                }, "strip", z.ZodTypeAny, {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                }, {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"regex">;
                    pattern: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }, {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"email">;
                }, "strip", z.ZodTypeAny, {
                    type: "email";
                    errorMsg?: string | undefined;
                }, {
                    type: "email";
                    errorMsg?: string | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"ipv4">;
                }, "strip", z.ZodTypeAny, {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                }, {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"url">;
                }, "strip", z.ZodTypeAny, {
                    type: "url";
                    errorMsg?: string | undefined;
                }, {
                    type: "url";
                    errorMsg?: string | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"date">;
                }, "strip", z.ZodTypeAny, {
                    type: "date";
                    errorMsg?: string | undefined;
                }, {
                    type: "date";
                    errorMsg?: string | undefined;
                }>]>, "many">>;
                defaultValue: z.ZodOptional<z.ZodString>;
                options: z.ZodOptional<z.ZodObject<{
                    display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
                } & {
                    rowsMin: z.ZodOptional<z.ZodNumber>;
                    rowsMax: z.ZodOptional<z.ZodNumber>;
                }, "strip", z.ZodTypeAny, {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    rowsMin?: number | undefined;
                    rowsMax?: number | undefined;
                }, {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    rowsMin?: number | undefined;
                    rowsMax?: number | undefined;
                }>>;
                modifyFieldsOnValue: z.ZodOptional<z.ZodArray<z.ZodObject<{
                    fieldValue: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                    mode: z.ZodOptional<z.ZodEnum<["create", "edit", "config", "clone"]>>;
                    fieldsToModify: z.ZodArray<z.ZodObject<{
                        fieldId: z.ZodString;
                        display: z.ZodOptional<z.ZodBoolean>;
                        value: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>>;
                        disabled: z.ZodOptional<z.ZodBoolean>;
                        required: z.ZodOptional<z.ZodBoolean>;
                        help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                            text: z.ZodString;
                            links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                slug: z.ZodString;
                                link: z.ZodString;
                                linkText: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                slug: string;
                                link: string;
                                linkText: string;
                            }, {
                                slug: string;
                                link: string;
                                linkText: string;
                            }>, "many">>;
                            link: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        }, {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        }>]>>;
                        label: z.ZodOptional<z.ZodString>;
                        markdownMessage: z.ZodOptional<z.ZodUnion<[z.ZodObject<{
                            markdownType: z.ZodLiteral<"text">;
                            text: z.ZodString;
                            color: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        }, {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        }>, z.ZodObject<{
                            markdownType: z.ZodLiteral<"hybrid">;
                            text: z.ZodString;
                            token: z.ZodString;
                            linkText: z.ZodString;
                            link: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        }, {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        }>, z.ZodObject<{
                            markdownType: z.ZodLiteral<"link">;
                            text: z.ZodString;
                            link: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            link: string;
                            markdownType: "link";
                        }, {
                            text: string;
                            link: string;
                            markdownType: "link";
                        }>, z.ZodObject<{
                            markdownType: z.ZodOptional<z.ZodUndefined>;
                            text: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            markdownType?: undefined;
                        }, {
                            text: string;
                            markdownType?: undefined;
                        }>]>>;
                    }, "strip", z.ZodTypeAny, {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }, {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }>, "many">;
                }, "strip", z.ZodTypeAny, {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }, {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }>, "many">>;
            }, "strip", z.ZodTypeAny, {
                type: "textarea";
                label: string;
                field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    rowsMin?: number | undefined;
                    rowsMax?: number | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            }, {
                type: "textarea";
                label: string;
                field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    rowsMin?: number | undefined;
                    rowsMax?: number | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            }>, z.ZodObject<{
                field: z.ZodString;
                label: z.ZodString;
                help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                    text: z.ZodString;
                    links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        slug: z.ZodString;
                        link: z.ZodString;
                        linkText: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }>, "many">>;
                    link: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }>]>>;
                tooltip: z.ZodOptional<z.ZodString>;
                required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            } & {
                type: z.ZodLiteral<"singleSelect">;
                validators: z.ZodOptional<z.ZodArray<z.ZodUnion<[z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"number">;
                    range: z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>;
                    isInteger: z.ZodOptional<z.ZodBoolean>;
                }, "strip", z.ZodTypeAny, {
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                }, {
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"string">;
                    minLength: z.ZodNumber;
                    maxLength: z.ZodNumber;
                }, "strip", z.ZodTypeAny, {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                }, {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"regex">;
                    pattern: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }, {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"email">;
                }, "strip", z.ZodTypeAny, {
                    type: "email";
                    errorMsg?: string | undefined;
                }, {
                    type: "email";
                    errorMsg?: string | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"ipv4">;
                }, "strip", z.ZodTypeAny, {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                }, {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"url">;
                }, "strip", z.ZodTypeAny, {
                    type: "url";
                    errorMsg?: string | undefined;
                }, {
                    type: "url";
                    errorMsg?: string | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"date">;
                }, "strip", z.ZodTypeAny, {
                    type: "date";
                    errorMsg?: string | undefined;
                }, {
                    type: "date";
                    errorMsg?: string | undefined;
                }>]>, "many">>;
                defaultValue: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodNumber, z.ZodBoolean]>>;
                options: z.ZodObject<{
                    display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
                } & {
                    disableSearch: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    createSearchChoice: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    referenceName: z.ZodOptional<z.ZodString>;
                    endpointUrl: z.ZodOptional<z.ZodString>;
                    allowList: z.ZodOptional<z.ZodString>;
                    denyList: z.ZodOptional<z.ZodString>;
                    labelField: z.ZodOptional<z.ZodString>;
                    valueField: z.ZodOptional<z.ZodString>;
                    autoCompleteFields: z.ZodOptional<z.ZodArray<z.ZodUnion<[z.ZodObject<{
                        value: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                        label: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        value: string | number | boolean;
                        label: string;
                    }, {
                        value: string | number | boolean;
                        label: string;
                    }>, z.ZodObject<{
                        label: z.ZodString;
                        children: z.ZodArray<z.ZodObject<{
                            value: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                            label: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            value: string | number | boolean;
                            label: string;
                        }, {
                            value: string | number | boolean;
                            label: string;
                        }>, "many">;
                    }, "strip", z.ZodTypeAny, {
                        label: string;
                        children: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                    }, {
                        label: string;
                        children: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                    }>]>, "many">>;
                    dependencies: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                    items: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        value: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                        label: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        value: string | number | boolean;
                        label: string;
                    }, {
                        value: string | number | boolean;
                        label: string;
                    }>, "many">>;
                }, "strip", z.ZodTypeAny, {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    disableSearch?: boolean | undefined;
                    createSearchChoice?: boolean | undefined;
                    referenceName?: string | undefined;
                    endpointUrl?: string | undefined;
                    allowList?: string | undefined;
                    denyList?: string | undefined;
                    labelField?: string | undefined;
                    valueField?: string | undefined;
                    autoCompleteFields?: ({
                        value: string | number | boolean;
                        label: string;
                    } | {
                        label: string;
                        children: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                    })[] | undefined;
                    dependencies?: string[] | undefined;
                    items?: {
                        value: string | number | boolean;
                        label: string;
                    }[] | undefined;
                }, {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    disableSearch?: boolean | undefined;
                    createSearchChoice?: boolean | undefined;
                    referenceName?: string | undefined;
                    endpointUrl?: string | undefined;
                    allowList?: string | undefined;
                    denyList?: string | undefined;
                    labelField?: string | undefined;
                    valueField?: string | undefined;
                    autoCompleteFields?: ({
                        value: string | number | boolean;
                        label: string;
                    } | {
                        label: string;
                        children: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                    })[] | undefined;
                    dependencies?: string[] | undefined;
                    items?: {
                        value: string | number | boolean;
                        label: string;
                    }[] | undefined;
                }>;
                modifyFieldsOnValue: z.ZodOptional<z.ZodArray<z.ZodObject<{
                    fieldValue: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                    mode: z.ZodOptional<z.ZodEnum<["create", "edit", "config", "clone"]>>;
                    fieldsToModify: z.ZodArray<z.ZodObject<{
                        fieldId: z.ZodString;
                        display: z.ZodOptional<z.ZodBoolean>;
                        value: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>>;
                        disabled: z.ZodOptional<z.ZodBoolean>;
                        required: z.ZodOptional<z.ZodBoolean>;
                        help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                            text: z.ZodString;
                            links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                slug: z.ZodString;
                                link: z.ZodString;
                                linkText: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                slug: string;
                                link: string;
                                linkText: string;
                            }, {
                                slug: string;
                                link: string;
                                linkText: string;
                            }>, "many">>;
                            link: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        }, {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        }>]>>;
                        label: z.ZodOptional<z.ZodString>;
                        markdownMessage: z.ZodOptional<z.ZodUnion<[z.ZodObject<{
                            markdownType: z.ZodLiteral<"text">;
                            text: z.ZodString;
                            color: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        }, {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        }>, z.ZodObject<{
                            markdownType: z.ZodLiteral<"hybrid">;
                            text: z.ZodString;
                            token: z.ZodString;
                            linkText: z.ZodString;
                            link: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        }, {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        }>, z.ZodObject<{
                            markdownType: z.ZodLiteral<"link">;
                            text: z.ZodString;
                            link: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            link: string;
                            markdownType: "link";
                        }, {
                            text: string;
                            link: string;
                            markdownType: "link";
                        }>, z.ZodObject<{
                            markdownType: z.ZodOptional<z.ZodUndefined>;
                            text: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            markdownType?: undefined;
                        }, {
                            text: string;
                            markdownType?: undefined;
                        }>]>>;
                    }, "strip", z.ZodTypeAny, {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }, {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }>, "many">;
                }, "strip", z.ZodTypeAny, {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }, {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }>, "many">>;
            }, "strip", z.ZodTypeAny, {
                options: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    disableSearch?: boolean | undefined;
                    createSearchChoice?: boolean | undefined;
                    referenceName?: string | undefined;
                    endpointUrl?: string | undefined;
                    allowList?: string | undefined;
                    denyList?: string | undefined;
                    labelField?: string | undefined;
                    valueField?: string | undefined;
                    autoCompleteFields?: ({
                        value: string | number | boolean;
                        label: string;
                    } | {
                        label: string;
                        children: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                    })[] | undefined;
                    dependencies?: string[] | undefined;
                    items?: {
                        value: string | number | boolean;
                        label: string;
                    }[] | undefined;
                };
                type: "singleSelect";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            }, {
                options: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    disableSearch?: boolean | undefined;
                    createSearchChoice?: boolean | undefined;
                    referenceName?: string | undefined;
                    endpointUrl?: string | undefined;
                    allowList?: string | undefined;
                    denyList?: string | undefined;
                    labelField?: string | undefined;
                    valueField?: string | undefined;
                    autoCompleteFields?: ({
                        value: string | number | boolean;
                        label: string;
                    } | {
                        label: string;
                        children: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                    })[] | undefined;
                    dependencies?: string[] | undefined;
                    items?: {
                        value: string | number | boolean;
                        label: string;
                    }[] | undefined;
                };
                type: "singleSelect";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            }>, z.ZodObject<{
                field: z.ZodString;
                label: z.ZodString;
                help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                    text: z.ZodString;
                    links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        slug: z.ZodString;
                        link: z.ZodString;
                        linkText: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }>, "many">>;
                    link: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }>]>>;
                tooltip: z.ZodOptional<z.ZodString>;
                required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            } & {
                type: z.ZodLiteral<"multipleSelect">;
                validators: z.ZodOptional<z.ZodArray<z.ZodUnion<[z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"number">;
                    range: z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>;
                    isInteger: z.ZodOptional<z.ZodBoolean>;
                }, "strip", z.ZodTypeAny, {
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                }, {
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"string">;
                    minLength: z.ZodNumber;
                    maxLength: z.ZodNumber;
                }, "strip", z.ZodTypeAny, {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                }, {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"regex">;
                    pattern: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }, {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"email">;
                }, "strip", z.ZodTypeAny, {
                    type: "email";
                    errorMsg?: string | undefined;
                }, {
                    type: "email";
                    errorMsg?: string | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"ipv4">;
                }, "strip", z.ZodTypeAny, {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                }, {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"url">;
                }, "strip", z.ZodTypeAny, {
                    type: "url";
                    errorMsg?: string | undefined;
                }, {
                    type: "url";
                    errorMsg?: string | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"date">;
                }, "strip", z.ZodTypeAny, {
                    type: "date";
                    errorMsg?: string | undefined;
                }, {
                    type: "date";
                    errorMsg?: string | undefined;
                }>]>, "many">>;
                defaultValue: z.ZodOptional<z.ZodString>;
                options: z.ZodObject<{
                    display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
                } & {
                    disableSearch: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    createSearchChoice: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    referenceName: z.ZodOptional<z.ZodString>;
                    endpointUrl: z.ZodOptional<z.ZodString>;
                    allowList: z.ZodOptional<z.ZodString>;
                    denyList: z.ZodOptional<z.ZodString>;
                    labelField: z.ZodOptional<z.ZodString>;
                    valueField: z.ZodOptional<z.ZodString>;
                    autoCompleteFields: z.ZodOptional<z.ZodArray<z.ZodUnion<[z.ZodObject<{
                        value: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                        label: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        value: string | number | boolean;
                        label: string;
                    }, {
                        value: string | number | boolean;
                        label: string;
                    }>, z.ZodObject<{
                        label: z.ZodString;
                        children: z.ZodArray<z.ZodObject<{
                            value: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                            label: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            value: string | number | boolean;
                            label: string;
                        }, {
                            value: string | number | boolean;
                            label: string;
                        }>, "many">;
                    }, "strip", z.ZodTypeAny, {
                        label: string;
                        children: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                    }, {
                        label: string;
                        children: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                    }>]>, "many">>;
                    dependencies: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                    items: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        value: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                        label: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        value: string | number | boolean;
                        label: string;
                    }, {
                        value: string | number | boolean;
                        label: string;
                    }>, "many">>;
                } & {
                    delimiter: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    disableSearch?: boolean | undefined;
                    createSearchChoice?: boolean | undefined;
                    referenceName?: string | undefined;
                    endpointUrl?: string | undefined;
                    allowList?: string | undefined;
                    denyList?: string | undefined;
                    labelField?: string | undefined;
                    valueField?: string | undefined;
                    autoCompleteFields?: ({
                        value: string | number | boolean;
                        label: string;
                    } | {
                        label: string;
                        children: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                    })[] | undefined;
                    dependencies?: string[] | undefined;
                    items?: {
                        value: string | number | boolean;
                        label: string;
                    }[] | undefined;
                    delimiter?: string | undefined;
                }, {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    disableSearch?: boolean | undefined;
                    createSearchChoice?: boolean | undefined;
                    referenceName?: string | undefined;
                    endpointUrl?: string | undefined;
                    allowList?: string | undefined;
                    denyList?: string | undefined;
                    labelField?: string | undefined;
                    valueField?: string | undefined;
                    autoCompleteFields?: ({
                        value: string | number | boolean;
                        label: string;
                    } | {
                        label: string;
                        children: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                    })[] | undefined;
                    dependencies?: string[] | undefined;
                    items?: {
                        value: string | number | boolean;
                        label: string;
                    }[] | undefined;
                    delimiter?: string | undefined;
                }>;
                modifyFieldsOnValue: z.ZodOptional<z.ZodArray<z.ZodObject<{
                    fieldValue: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                    mode: z.ZodOptional<z.ZodEnum<["create", "edit", "config", "clone"]>>;
                    fieldsToModify: z.ZodArray<z.ZodObject<{
                        fieldId: z.ZodString;
                        display: z.ZodOptional<z.ZodBoolean>;
                        value: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>>;
                        disabled: z.ZodOptional<z.ZodBoolean>;
                        required: z.ZodOptional<z.ZodBoolean>;
                        help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                            text: z.ZodString;
                            links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                slug: z.ZodString;
                                link: z.ZodString;
                                linkText: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                slug: string;
                                link: string;
                                linkText: string;
                            }, {
                                slug: string;
                                link: string;
                                linkText: string;
                            }>, "many">>;
                            link: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        }, {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        }>]>>;
                        label: z.ZodOptional<z.ZodString>;
                        markdownMessage: z.ZodOptional<z.ZodUnion<[z.ZodObject<{
                            markdownType: z.ZodLiteral<"text">;
                            text: z.ZodString;
                            color: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        }, {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        }>, z.ZodObject<{
                            markdownType: z.ZodLiteral<"hybrid">;
                            text: z.ZodString;
                            token: z.ZodString;
                            linkText: z.ZodString;
                            link: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        }, {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        }>, z.ZodObject<{
                            markdownType: z.ZodLiteral<"link">;
                            text: z.ZodString;
                            link: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            link: string;
                            markdownType: "link";
                        }, {
                            text: string;
                            link: string;
                            markdownType: "link";
                        }>, z.ZodObject<{
                            markdownType: z.ZodOptional<z.ZodUndefined>;
                            text: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            markdownType?: undefined;
                        }, {
                            text: string;
                            markdownType?: undefined;
                        }>]>>;
                    }, "strip", z.ZodTypeAny, {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }, {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }>, "many">;
                }, "strip", z.ZodTypeAny, {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }, {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }>, "many">>;
            }, "strip", z.ZodTypeAny, {
                options: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    disableSearch?: boolean | undefined;
                    createSearchChoice?: boolean | undefined;
                    referenceName?: string | undefined;
                    endpointUrl?: string | undefined;
                    allowList?: string | undefined;
                    denyList?: string | undefined;
                    labelField?: string | undefined;
                    valueField?: string | undefined;
                    autoCompleteFields?: ({
                        value: string | number | boolean;
                        label: string;
                    } | {
                        label: string;
                        children: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                    })[] | undefined;
                    dependencies?: string[] | undefined;
                    items?: {
                        value: string | number | boolean;
                        label: string;
                    }[] | undefined;
                    delimiter?: string | undefined;
                };
                type: "multipleSelect";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            }, {
                options: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    disableSearch?: boolean | undefined;
                    createSearchChoice?: boolean | undefined;
                    referenceName?: string | undefined;
                    endpointUrl?: string | undefined;
                    allowList?: string | undefined;
                    denyList?: string | undefined;
                    labelField?: string | undefined;
                    valueField?: string | undefined;
                    autoCompleteFields?: ({
                        value: string | number | boolean;
                        label: string;
                    } | {
                        label: string;
                        children: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                    })[] | undefined;
                    dependencies?: string[] | undefined;
                    items?: {
                        value: string | number | boolean;
                        label: string;
                    }[] | undefined;
                    delimiter?: string | undefined;
                };
                type: "multipleSelect";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            }>, z.ZodObject<{
                field: z.ZodString;
                label: z.ZodString;
                help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                    text: z.ZodString;
                    links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        slug: z.ZodString;
                        link: z.ZodString;
                        linkText: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }>, "many">>;
                    link: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }>]>>;
                tooltip: z.ZodOptional<z.ZodString>;
                required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            } & {
                type: z.ZodLiteral<"checkbox">;
                defaultValue: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodBoolean]>>;
                options: z.ZodOptional<z.ZodObject<{
                    display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
                }, "strip", z.ZodTypeAny, {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                }, {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                }>>;
                modifyFieldsOnValue: z.ZodOptional<z.ZodArray<z.ZodObject<{
                    fieldValue: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                    mode: z.ZodOptional<z.ZodEnum<["create", "edit", "config", "clone"]>>;
                    fieldsToModify: z.ZodArray<z.ZodObject<{
                        fieldId: z.ZodString;
                        display: z.ZodOptional<z.ZodBoolean>;
                        value: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>>;
                        disabled: z.ZodOptional<z.ZodBoolean>;
                        required: z.ZodOptional<z.ZodBoolean>;
                        help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                            text: z.ZodString;
                            links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                slug: z.ZodString;
                                link: z.ZodString;
                                linkText: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                slug: string;
                                link: string;
                                linkText: string;
                            }, {
                                slug: string;
                                link: string;
                                linkText: string;
                            }>, "many">>;
                            link: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        }, {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        }>]>>;
                        label: z.ZodOptional<z.ZodString>;
                        markdownMessage: z.ZodOptional<z.ZodUnion<[z.ZodObject<{
                            markdownType: z.ZodLiteral<"text">;
                            text: z.ZodString;
                            color: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        }, {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        }>, z.ZodObject<{
                            markdownType: z.ZodLiteral<"hybrid">;
                            text: z.ZodString;
                            token: z.ZodString;
                            linkText: z.ZodString;
                            link: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        }, {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        }>, z.ZodObject<{
                            markdownType: z.ZodLiteral<"link">;
                            text: z.ZodString;
                            link: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            link: string;
                            markdownType: "link";
                        }, {
                            text: string;
                            link: string;
                            markdownType: "link";
                        }>, z.ZodObject<{
                            markdownType: z.ZodOptional<z.ZodUndefined>;
                            text: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            markdownType?: undefined;
                        }, {
                            text: string;
                            markdownType?: undefined;
                        }>]>>;
                    }, "strip", z.ZodTypeAny, {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }, {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }>, "many">;
                }, "strip", z.ZodTypeAny, {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }, {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }>, "many">>;
            }, "strip", z.ZodTypeAny, {
                type: "checkbox";
                label: string;
                field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                defaultValue?: number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            }, {
                type: "checkbox";
                label: string;
                field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                defaultValue?: number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            }>, z.ZodObject<{
                field: z.ZodString;
                label: z.ZodString;
                help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                    text: z.ZodString;
                    links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        slug: z.ZodString;
                        link: z.ZodString;
                        linkText: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }>, "many">>;
                    link: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }>]>>;
                tooltip: z.ZodOptional<z.ZodString>;
                required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            } & {
                type: z.ZodLiteral<"checkboxGroup">;
                validators: z.ZodOptional<z.ZodTuple<[z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"regex">;
                    pattern: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }, {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }>], null>>;
                defaultValue: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodBoolean]>>;
                options: z.ZodObject<{
                    display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
                } & {
                    delimiter: z.ZodOptional<z.ZodString>;
                    groups: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        label: z.ZodString;
                        fields: z.ZodArray<z.ZodString, "many">;
                        options: z.ZodOptional<z.ZodObject<{
                            isExpandable: z.ZodOptional<z.ZodBoolean>;
                            expand: z.ZodOptional<z.ZodBoolean>;
                        }, "strip", z.ZodTypeAny, {
                            isExpandable?: boolean | undefined;
                            expand?: boolean | undefined;
                        }, {
                            isExpandable?: boolean | undefined;
                            expand?: boolean | undefined;
                        }>>;
                    }, "strip", z.ZodTypeAny, {
                        label: string;
                        fields: string[];
                        options?: {
                            isExpandable?: boolean | undefined;
                            expand?: boolean | undefined;
                        } | undefined;
                    }, {
                        label: string;
                        fields: string[];
                        options?: {
                            isExpandable?: boolean | undefined;
                            expand?: boolean | undefined;
                        } | undefined;
                    }>, "many">>;
                    rows: z.ZodArray<z.ZodObject<{
                        field: z.ZodString;
                        checkbox: z.ZodOptional<z.ZodObject<{
                            label: z.ZodOptional<z.ZodString>;
                            defaultValue: z.ZodOptional<z.ZodBoolean>;
                        }, "strip", z.ZodTypeAny, {
                            label?: string | undefined;
                            defaultValue?: boolean | undefined;
                        }, {
                            label?: string | undefined;
                            defaultValue?: boolean | undefined;
                        }>>;
                        input: z.ZodOptional<z.ZodObject<{
                            defaultValue: z.ZodOptional<z.ZodNumber>;
                            validators: z.ZodOptional<z.ZodTuple<[z.ZodObject<{
                                errorMsg: z.ZodOptional<z.ZodString>;
                                type: z.ZodLiteral<"number">;
                                range: z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>;
                                isInteger: z.ZodOptional<z.ZodBoolean>;
                            }, "strip", z.ZodTypeAny, {
                                type: "number";
                                range: [number, number];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            }, {
                                type: "number";
                                range: [number, number];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            }>], null>>;
                            required: z.ZodOptional<z.ZodBoolean>;
                        }, "strip", z.ZodTypeAny, {
                            required?: boolean | undefined;
                            validators?: [{
                                type: "number";
                                range: [number, number];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            }] | undefined;
                            defaultValue?: number | undefined;
                        }, {
                            required?: boolean | undefined;
                            validators?: [{
                                type: "number";
                                range: [number, number];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            }] | undefined;
                            defaultValue?: number | undefined;
                        }>>;
                    }, "strip", z.ZodTypeAny, {
                        field: string;
                        checkbox?: {
                            label?: string | undefined;
                            defaultValue?: boolean | undefined;
                        } | undefined;
                        input?: {
                            required?: boolean | undefined;
                            validators?: [{
                                type: "number";
                                range: [number, number];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            }] | undefined;
                            defaultValue?: number | undefined;
                        } | undefined;
                    }, {
                        field: string;
                        checkbox?: {
                            label?: string | undefined;
                            defaultValue?: boolean | undefined;
                        } | undefined;
                        input?: {
                            required?: boolean | undefined;
                            validators?: [{
                                type: "number";
                                range: [number, number];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            }] | undefined;
                            defaultValue?: number | undefined;
                        } | undefined;
                    }>, "many">;
                }, "strip", z.ZodTypeAny, {
                    rows: {
                        field: string;
                        checkbox?: {
                            label?: string | undefined;
                            defaultValue?: boolean | undefined;
                        } | undefined;
                        input?: {
                            required?: boolean | undefined;
                            validators?: [{
                                type: "number";
                                range: [number, number];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            }] | undefined;
                            defaultValue?: number | undefined;
                        } | undefined;
                    }[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    delimiter?: string | undefined;
                    groups?: {
                        label: string;
                        fields: string[];
                        options?: {
                            isExpandable?: boolean | undefined;
                            expand?: boolean | undefined;
                        } | undefined;
                    }[] | undefined;
                }, {
                    rows: {
                        field: string;
                        checkbox?: {
                            label?: string | undefined;
                            defaultValue?: boolean | undefined;
                        } | undefined;
                        input?: {
                            required?: boolean | undefined;
                            validators?: [{
                                type: "number";
                                range: [number, number];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            }] | undefined;
                            defaultValue?: number | undefined;
                        } | undefined;
                    }[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    delimiter?: string | undefined;
                    groups?: {
                        label: string;
                        fields: string[];
                        options?: {
                            isExpandable?: boolean | undefined;
                            expand?: boolean | undefined;
                        } | undefined;
                    }[] | undefined;
                }>;
            }, "strip", z.ZodTypeAny, {
                options: {
                    rows: {
                        field: string;
                        checkbox?: {
                            label?: string | undefined;
                            defaultValue?: boolean | undefined;
                        } | undefined;
                        input?: {
                            required?: boolean | undefined;
                            validators?: [{
                                type: "number";
                                range: [number, number];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            }] | undefined;
                            defaultValue?: number | undefined;
                        } | undefined;
                    }[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    delimiter?: string | undefined;
                    groups?: {
                        label: string;
                        fields: string[];
                        options?: {
                            isExpandable?: boolean | undefined;
                            expand?: boolean | undefined;
                        } | undefined;
                    }[] | undefined;
                };
                type: "checkboxGroup";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: [{
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }] | undefined;
                defaultValue?: number | boolean | undefined;
            }, {
                options: {
                    rows: {
                        field: string;
                        checkbox?: {
                            label?: string | undefined;
                            defaultValue?: boolean | undefined;
                        } | undefined;
                        input?: {
                            required?: boolean | undefined;
                            validators?: [{
                                type: "number";
                                range: [number, number];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            }] | undefined;
                            defaultValue?: number | undefined;
                        } | undefined;
                    }[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    delimiter?: string | undefined;
                    groups?: {
                        label: string;
                        fields: string[];
                        options?: {
                            isExpandable?: boolean | undefined;
                            expand?: boolean | undefined;
                        } | undefined;
                    }[] | undefined;
                };
                type: "checkboxGroup";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: [{
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }] | undefined;
                defaultValue?: number | boolean | undefined;
            }>, z.ZodObject<{
                field: z.ZodString;
                label: z.ZodString;
                help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                    text: z.ZodString;
                    links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        slug: z.ZodString;
                        link: z.ZodString;
                        linkText: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }>, "many">>;
                    link: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }>]>>;
                tooltip: z.ZodOptional<z.ZodString>;
                required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            } & {
                type: z.ZodLiteral<"checkboxTree">;
                validators: z.ZodOptional<z.ZodTuple<[z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"regex">;
                    pattern: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }, {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }>], null>>;
                defaultValue: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodBoolean]>>;
                options: z.ZodObject<{
                    display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
                } & {
                    delimiter: z.ZodOptional<z.ZodString>;
                    groups: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        label: z.ZodString;
                        fields: z.ZodArray<z.ZodString, "many">;
                        options: z.ZodOptional<z.ZodObject<{
                            isExpandable: z.ZodOptional<z.ZodBoolean>;
                            expand: z.ZodOptional<z.ZodBoolean>;
                        }, "strip", z.ZodTypeAny, {
                            isExpandable?: boolean | undefined;
                            expand?: boolean | undefined;
                        }, {
                            isExpandable?: boolean | undefined;
                            expand?: boolean | undefined;
                        }>>;
                    }, "strip", z.ZodTypeAny, {
                        label: string;
                        fields: string[];
                        options?: {
                            isExpandable?: boolean | undefined;
                            expand?: boolean | undefined;
                        } | undefined;
                    }, {
                        label: string;
                        fields: string[];
                        options?: {
                            isExpandable?: boolean | undefined;
                            expand?: boolean | undefined;
                        } | undefined;
                    }>, "many">>;
                    rows: z.ZodArray<z.ZodObject<{
                        field: z.ZodString;
                        checkbox: z.ZodOptional<z.ZodObject<{
                            label: z.ZodOptional<z.ZodString>;
                            defaultValue: z.ZodOptional<z.ZodBoolean>;
                        }, "strip", z.ZodTypeAny, {
                            label?: string | undefined;
                            defaultValue?: boolean | undefined;
                        }, {
                            label?: string | undefined;
                            defaultValue?: boolean | undefined;
                        }>>;
                    }, "strip", z.ZodTypeAny, {
                        field: string;
                        checkbox?: {
                            label?: string | undefined;
                            defaultValue?: boolean | undefined;
                        } | undefined;
                    }, {
                        field: string;
                        checkbox?: {
                            label?: string | undefined;
                            defaultValue?: boolean | undefined;
                        } | undefined;
                    }>, "many">;
                }, "strip", z.ZodTypeAny, {
                    rows: {
                        field: string;
                        checkbox?: {
                            label?: string | undefined;
                            defaultValue?: boolean | undefined;
                        } | undefined;
                    }[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    delimiter?: string | undefined;
                    groups?: {
                        label: string;
                        fields: string[];
                        options?: {
                            isExpandable?: boolean | undefined;
                            expand?: boolean | undefined;
                        } | undefined;
                    }[] | undefined;
                }, {
                    rows: {
                        field: string;
                        checkbox?: {
                            label?: string | undefined;
                            defaultValue?: boolean | undefined;
                        } | undefined;
                    }[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    delimiter?: string | undefined;
                    groups?: {
                        label: string;
                        fields: string[];
                        options?: {
                            isExpandable?: boolean | undefined;
                            expand?: boolean | undefined;
                        } | undefined;
                    }[] | undefined;
                }>;
            }, "strip", z.ZodTypeAny, {
                options: {
                    rows: {
                        field: string;
                        checkbox?: {
                            label?: string | undefined;
                            defaultValue?: boolean | undefined;
                        } | undefined;
                    }[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    delimiter?: string | undefined;
                    groups?: {
                        label: string;
                        fields: string[];
                        options?: {
                            isExpandable?: boolean | undefined;
                            expand?: boolean | undefined;
                        } | undefined;
                    }[] | undefined;
                };
                type: "checkboxTree";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: [{
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }] | undefined;
                defaultValue?: number | boolean | undefined;
            }, {
                options: {
                    rows: {
                        field: string;
                        checkbox?: {
                            label?: string | undefined;
                            defaultValue?: boolean | undefined;
                        } | undefined;
                    }[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    delimiter?: string | undefined;
                    groups?: {
                        label: string;
                        fields: string[];
                        options?: {
                            isExpandable?: boolean | undefined;
                            expand?: boolean | undefined;
                        } | undefined;
                    }[] | undefined;
                };
                type: "checkboxTree";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: [{
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }] | undefined;
                defaultValue?: number | boolean | undefined;
            }>, z.ZodObject<{
                field: z.ZodString;
                label: z.ZodString;
                help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                    text: z.ZodString;
                    links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        slug: z.ZodString;
                        link: z.ZodString;
                        linkText: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }>, "many">>;
                    link: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }>]>>;
                tooltip: z.ZodOptional<z.ZodString>;
                required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            } & {
                type: z.ZodLiteral<"radio">;
                defaultValue: z.ZodOptional<z.ZodString>;
                options: z.ZodObject<{
                    display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
                } & {
                    items: z.ZodArray<z.ZodObject<{
                        value: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                        label: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        value: string | number | boolean;
                        label: string;
                    }, {
                        value: string | number | boolean;
                        label: string;
                    }>, "many">;
                }, "strip", z.ZodTypeAny, {
                    items: {
                        value: string | number | boolean;
                        label: string;
                    }[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                }, {
                    items: {
                        value: string | number | boolean;
                        label: string;
                    }[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                }>;
                modifyFieldsOnValue: z.ZodOptional<z.ZodArray<z.ZodObject<{
                    fieldValue: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                    mode: z.ZodOptional<z.ZodEnum<["create", "edit", "config", "clone"]>>;
                    fieldsToModify: z.ZodArray<z.ZodObject<{
                        fieldId: z.ZodString;
                        display: z.ZodOptional<z.ZodBoolean>;
                        value: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>>;
                        disabled: z.ZodOptional<z.ZodBoolean>;
                        required: z.ZodOptional<z.ZodBoolean>;
                        help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                            text: z.ZodString;
                            links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                slug: z.ZodString;
                                link: z.ZodString;
                                linkText: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                slug: string;
                                link: string;
                                linkText: string;
                            }, {
                                slug: string;
                                link: string;
                                linkText: string;
                            }>, "many">>;
                            link: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        }, {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        }>]>>;
                        label: z.ZodOptional<z.ZodString>;
                        markdownMessage: z.ZodOptional<z.ZodUnion<[z.ZodObject<{
                            markdownType: z.ZodLiteral<"text">;
                            text: z.ZodString;
                            color: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        }, {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        }>, z.ZodObject<{
                            markdownType: z.ZodLiteral<"hybrid">;
                            text: z.ZodString;
                            token: z.ZodString;
                            linkText: z.ZodString;
                            link: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        }, {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        }>, z.ZodObject<{
                            markdownType: z.ZodLiteral<"link">;
                            text: z.ZodString;
                            link: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            link: string;
                            markdownType: "link";
                        }, {
                            text: string;
                            link: string;
                            markdownType: "link";
                        }>, z.ZodObject<{
                            markdownType: z.ZodOptional<z.ZodUndefined>;
                            text: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            markdownType?: undefined;
                        }, {
                            text: string;
                            markdownType?: undefined;
                        }>]>>;
                    }, "strip", z.ZodTypeAny, {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }, {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }>, "many">;
                }, "strip", z.ZodTypeAny, {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }, {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }>, "many">>;
            }, "strip", z.ZodTypeAny, {
                options: {
                    items: {
                        value: string | number | boolean;
                        label: string;
                    }[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                };
                type: "radio";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            }, {
                options: {
                    items: {
                        value: string | number | boolean;
                        label: string;
                    }[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                };
                type: "radio";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            }>, z.ZodObject<{
                field: z.ZodString;
                label: z.ZodString;
                help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                    text: z.ZodString;
                    links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        slug: z.ZodString;
                        link: z.ZodString;
                        linkText: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }>, "many">>;
                    link: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }>]>>;
                tooltip: z.ZodOptional<z.ZodString>;
                required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            } & {
                type: z.ZodLiteral<"file">;
                defaultValue: z.ZodOptional<z.ZodString>;
                validators: z.ZodOptional<z.ZodArray<z.ZodUnion<[z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"string">;
                    minLength: z.ZodNumber;
                    maxLength: z.ZodNumber;
                }, "strip", z.ZodTypeAny, {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                }, {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"regex">;
                    pattern: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }, {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }>]>, "many">>;
                options: z.ZodOptional<z.ZodObject<{
                    display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
                } & {
                    maxFileSize: z.ZodOptional<z.ZodNumber>;
                    fileSupportMessage: z.ZodOptional<z.ZodString>;
                    supportedFileTypes: z.ZodArray<z.ZodString, "many">;
                    useBase64Encoding: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                }, "strip", z.ZodTypeAny, {
                    supportedFileTypes: string[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    maxFileSize?: number | undefined;
                    fileSupportMessage?: string | undefined;
                    useBase64Encoding?: boolean | undefined;
                }, {
                    supportedFileTypes: string[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    maxFileSize?: number | undefined;
                    fileSupportMessage?: string | undefined;
                    useBase64Encoding?: boolean | undefined;
                }>>;
                modifyFieldsOnValue: z.ZodOptional<z.ZodArray<z.ZodObject<{
                    fieldValue: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                    mode: z.ZodOptional<z.ZodEnum<["create", "edit", "config", "clone"]>>;
                    fieldsToModify: z.ZodArray<z.ZodObject<{
                        fieldId: z.ZodString;
                        display: z.ZodOptional<z.ZodBoolean>;
                        value: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>>;
                        disabled: z.ZodOptional<z.ZodBoolean>;
                        required: z.ZodOptional<z.ZodBoolean>;
                        help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                            text: z.ZodString;
                            links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                slug: z.ZodString;
                                link: z.ZodString;
                                linkText: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                slug: string;
                                link: string;
                                linkText: string;
                            }, {
                                slug: string;
                                link: string;
                                linkText: string;
                            }>, "many">>;
                            link: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        }, {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        }>]>>;
                        label: z.ZodOptional<z.ZodString>;
                        markdownMessage: z.ZodOptional<z.ZodUnion<[z.ZodObject<{
                            markdownType: z.ZodLiteral<"text">;
                            text: z.ZodString;
                            color: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        }, {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        }>, z.ZodObject<{
                            markdownType: z.ZodLiteral<"hybrid">;
                            text: z.ZodString;
                            token: z.ZodString;
                            linkText: z.ZodString;
                            link: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        }, {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        }>, z.ZodObject<{
                            markdownType: z.ZodLiteral<"link">;
                            text: z.ZodString;
                            link: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            link: string;
                            markdownType: "link";
                        }, {
                            text: string;
                            link: string;
                            markdownType: "link";
                        }>, z.ZodObject<{
                            markdownType: z.ZodOptional<z.ZodUndefined>;
                            text: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            markdownType?: undefined;
                        }, {
                            text: string;
                            markdownType?: undefined;
                        }>]>>;
                    }, "strip", z.ZodTypeAny, {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }, {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }>, "many">;
                }, "strip", z.ZodTypeAny, {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }, {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }>, "many">>;
            }, "strip", z.ZodTypeAny, {
                type: "file";
                label: string;
                field: string;
                options?: {
                    supportedFileTypes: string[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    maxFileSize?: number | undefined;
                    fileSupportMessage?: string | undefined;
                    useBase64Encoding?: boolean | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            }, {
                type: "file";
                label: string;
                field: string;
                options?: {
                    supportedFileTypes: string[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    maxFileSize?: number | undefined;
                    fileSupportMessage?: string | undefined;
                    useBase64Encoding?: boolean | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            }>, z.ZodObject<{
                field: z.ZodString;
                label: z.ZodString;
                help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                    text: z.ZodString;
                    links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        slug: z.ZodString;
                        link: z.ZodString;
                        linkText: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }>, "many">>;
                    link: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }>]>>;
                tooltip: z.ZodOptional<z.ZodString>;
                required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            } & {
                type: z.ZodLiteral<"oauth">;
                defaultValue: z.ZodOptional<z.ZodString>;
                validators: z.ZodOptional<z.ZodArray<z.ZodUnion<[z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"string">;
                    minLength: z.ZodNumber;
                    maxLength: z.ZodNumber;
                }, "strip", z.ZodTypeAny, {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                }, {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"regex">;
                    pattern: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }, {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }>]>, "many">>;
                options: z.ZodObject<Omit<{
                    display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
                }, "requiredWhenVisible"> & {
                    auth_type: z.ZodArray<z.ZodUnion<[z.ZodLiteral<"basic">, z.ZodLiteral<"oauth">, z.ZodLiteral<"oauth_client_credentials">]>, "many">;
                    basic: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        oauth_field: z.ZodString;
                        label: z.ZodString;
                        field: z.ZodString;
                        type: z.ZodOptional<z.ZodDefault<z.ZodLiteral<"text">>>;
                        help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                            text: z.ZodString;
                            links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                slug: z.ZodString;
                                link: z.ZodString;
                                linkText: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                slug: string;
                                link: string;
                                linkText: string;
                            }, {
                                slug: string;
                                link: string;
                                linkText: string;
                            }>, "many">>;
                            link: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        }, {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        }>]>>;
                        encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        defaultValue: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodNumber, z.ZodBoolean]>>;
                        options: z.ZodOptional<z.ZodObject<{
                            display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                            disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                            enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                            requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                            hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
                        }, "strip", z.ZodTypeAny, {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        }, {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        }>>;
                        modifyFieldsOnValue: z.ZodOptional<z.ZodArray<z.ZodObject<{
                            fieldValue: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                            mode: z.ZodOptional<z.ZodEnum<["create", "edit", "config", "clone"]>>;
                            fieldsToModify: z.ZodArray<z.ZodObject<{
                                fieldId: z.ZodString;
                                display: z.ZodOptional<z.ZodBoolean>;
                                value: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>>;
                                disabled: z.ZodOptional<z.ZodBoolean>;
                                required: z.ZodOptional<z.ZodBoolean>;
                                help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                                    text: z.ZodString;
                                    links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                        slug: z.ZodString;
                                        link: z.ZodString;
                                        linkText: z.ZodString;
                                    }, "strip", z.ZodTypeAny, {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }, {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }>, "many">>;
                                    link: z.ZodOptional<z.ZodString>;
                                }, "strip", z.ZodTypeAny, {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                }, {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                }>]>>;
                                label: z.ZodOptional<z.ZodString>;
                                markdownMessage: z.ZodOptional<z.ZodUnion<[z.ZodObject<{
                                    markdownType: z.ZodLiteral<"text">;
                                    text: z.ZodString;
                                    color: z.ZodOptional<z.ZodString>;
                                }, "strip", z.ZodTypeAny, {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                }, {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                }>, z.ZodObject<{
                                    markdownType: z.ZodLiteral<"hybrid">;
                                    text: z.ZodString;
                                    token: z.ZodString;
                                    linkText: z.ZodString;
                                    link: z.ZodString;
                                }, "strip", z.ZodTypeAny, {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                }, {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                }>, z.ZodObject<{
                                    markdownType: z.ZodLiteral<"link">;
                                    text: z.ZodString;
                                    link: z.ZodString;
                                }, "strip", z.ZodTypeAny, {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                }, {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                }>, z.ZodObject<{
                                    markdownType: z.ZodOptional<z.ZodUndefined>;
                                    text: z.ZodString;
                                }, "strip", z.ZodTypeAny, {
                                    text: string;
                                    markdownType?: undefined;
                                }, {
                                    text: string;
                                    markdownType?: undefined;
                                }>]>>;
                            }, "strip", z.ZodTypeAny, {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }, {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }>, "many">;
                        }, "strip", z.ZodTypeAny, {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }, {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }>, "many">>;
                        validators: z.ZodOptional<z.ZodArray<z.ZodUnion<[z.ZodObject<{
                            errorMsg: z.ZodOptional<z.ZodString>;
                            type: z.ZodLiteral<"number">;
                            range: z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>;
                            isInteger: z.ZodOptional<z.ZodBoolean>;
                        }, "strip", z.ZodTypeAny, {
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        }, {
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        }>, z.ZodObject<{
                            errorMsg: z.ZodOptional<z.ZodString>;
                            type: z.ZodLiteral<"string">;
                            minLength: z.ZodNumber;
                            maxLength: z.ZodNumber;
                        }, "strip", z.ZodTypeAny, {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        }, {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        }>, z.ZodObject<{
                            errorMsg: z.ZodOptional<z.ZodString>;
                            type: z.ZodLiteral<"regex">;
                            pattern: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        }, {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        }>, z.ZodObject<{
                            errorMsg: z.ZodOptional<z.ZodString>;
                            type: z.ZodLiteral<"email">;
                        }, "strip", z.ZodTypeAny, {
                            type: "email";
                            errorMsg?: string | undefined;
                        }, {
                            type: "email";
                            errorMsg?: string | undefined;
                        }>, z.ZodObject<{
                            errorMsg: z.ZodOptional<z.ZodString>;
                            type: z.ZodLiteral<"ipv4">;
                        }, "strip", z.ZodTypeAny, {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        }, {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        }>, z.ZodObject<{
                            errorMsg: z.ZodOptional<z.ZodString>;
                            type: z.ZodLiteral<"url">;
                        }, "strip", z.ZodTypeAny, {
                            type: "url";
                            errorMsg?: string | undefined;
                        }, {
                            type: "url";
                            errorMsg?: string | undefined;
                        }>, z.ZodObject<{
                            errorMsg: z.ZodOptional<z.ZodString>;
                            type: z.ZodLiteral<"date">;
                        }, "strip", z.ZodTypeAny, {
                            type: "date";
                            errorMsg?: string | undefined;
                        }, {
                            type: "date";
                            errorMsg?: string | undefined;
                        }>]>, "many">>;
                    }, "strip", z.ZodTypeAny, {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }, {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }>, "many">>;
                    oauth: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        oauth_field: z.ZodString;
                        label: z.ZodString;
                        field: z.ZodString;
                        type: z.ZodOptional<z.ZodDefault<z.ZodLiteral<"text">>>;
                        help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                            text: z.ZodString;
                            links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                slug: z.ZodString;
                                link: z.ZodString;
                                linkText: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                slug: string;
                                link: string;
                                linkText: string;
                            }, {
                                slug: string;
                                link: string;
                                linkText: string;
                            }>, "many">>;
                            link: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        }, {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        }>]>>;
                        encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        defaultValue: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodNumber, z.ZodBoolean]>>;
                        options: z.ZodOptional<z.ZodObject<{
                            display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                            disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                            enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                            requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                            hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
                        }, "strip", z.ZodTypeAny, {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        }, {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        }>>;
                        modifyFieldsOnValue: z.ZodOptional<z.ZodArray<z.ZodObject<{
                            fieldValue: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                            mode: z.ZodOptional<z.ZodEnum<["create", "edit", "config", "clone"]>>;
                            fieldsToModify: z.ZodArray<z.ZodObject<{
                                fieldId: z.ZodString;
                                display: z.ZodOptional<z.ZodBoolean>;
                                value: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>>;
                                disabled: z.ZodOptional<z.ZodBoolean>;
                                required: z.ZodOptional<z.ZodBoolean>;
                                help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                                    text: z.ZodString;
                                    links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                        slug: z.ZodString;
                                        link: z.ZodString;
                                        linkText: z.ZodString;
                                    }, "strip", z.ZodTypeAny, {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }, {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }>, "many">>;
                                    link: z.ZodOptional<z.ZodString>;
                                }, "strip", z.ZodTypeAny, {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                }, {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                }>]>>;
                                label: z.ZodOptional<z.ZodString>;
                                markdownMessage: z.ZodOptional<z.ZodUnion<[z.ZodObject<{
                                    markdownType: z.ZodLiteral<"text">;
                                    text: z.ZodString;
                                    color: z.ZodOptional<z.ZodString>;
                                }, "strip", z.ZodTypeAny, {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                }, {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                }>, z.ZodObject<{
                                    markdownType: z.ZodLiteral<"hybrid">;
                                    text: z.ZodString;
                                    token: z.ZodString;
                                    linkText: z.ZodString;
                                    link: z.ZodString;
                                }, "strip", z.ZodTypeAny, {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                }, {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                }>, z.ZodObject<{
                                    markdownType: z.ZodLiteral<"link">;
                                    text: z.ZodString;
                                    link: z.ZodString;
                                }, "strip", z.ZodTypeAny, {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                }, {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                }>, z.ZodObject<{
                                    markdownType: z.ZodOptional<z.ZodUndefined>;
                                    text: z.ZodString;
                                }, "strip", z.ZodTypeAny, {
                                    text: string;
                                    markdownType?: undefined;
                                }, {
                                    text: string;
                                    markdownType?: undefined;
                                }>]>>;
                            }, "strip", z.ZodTypeAny, {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }, {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }>, "many">;
                        }, "strip", z.ZodTypeAny, {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }, {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }>, "many">>;
                        validators: z.ZodOptional<z.ZodArray<z.ZodUnion<[z.ZodObject<{
                            errorMsg: z.ZodOptional<z.ZodString>;
                            type: z.ZodLiteral<"number">;
                            range: z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>;
                            isInteger: z.ZodOptional<z.ZodBoolean>;
                        }, "strip", z.ZodTypeAny, {
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        }, {
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        }>, z.ZodObject<{
                            errorMsg: z.ZodOptional<z.ZodString>;
                            type: z.ZodLiteral<"string">;
                            minLength: z.ZodNumber;
                            maxLength: z.ZodNumber;
                        }, "strip", z.ZodTypeAny, {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        }, {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        }>, z.ZodObject<{
                            errorMsg: z.ZodOptional<z.ZodString>;
                            type: z.ZodLiteral<"regex">;
                            pattern: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        }, {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        }>, z.ZodObject<{
                            errorMsg: z.ZodOptional<z.ZodString>;
                            type: z.ZodLiteral<"email">;
                        }, "strip", z.ZodTypeAny, {
                            type: "email";
                            errorMsg?: string | undefined;
                        }, {
                            type: "email";
                            errorMsg?: string | undefined;
                        }>, z.ZodObject<{
                            errorMsg: z.ZodOptional<z.ZodString>;
                            type: z.ZodLiteral<"ipv4">;
                        }, "strip", z.ZodTypeAny, {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        }, {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        }>, z.ZodObject<{
                            errorMsg: z.ZodOptional<z.ZodString>;
                            type: z.ZodLiteral<"url">;
                        }, "strip", z.ZodTypeAny, {
                            type: "url";
                            errorMsg?: string | undefined;
                        }, {
                            type: "url";
                            errorMsg?: string | undefined;
                        }>, z.ZodObject<{
                            errorMsg: z.ZodOptional<z.ZodString>;
                            type: z.ZodLiteral<"date">;
                        }, "strip", z.ZodTypeAny, {
                            type: "date";
                            errorMsg?: string | undefined;
                        }, {
                            type: "date";
                            errorMsg?: string | undefined;
                        }>]>, "many">>;
                    }, "strip", z.ZodTypeAny, {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }, {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }>, "many">>;
                    oauth_client_credentials: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        oauth_field: z.ZodString;
                        label: z.ZodString;
                        field: z.ZodString;
                        type: z.ZodOptional<z.ZodDefault<z.ZodLiteral<"text">>>;
                        help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                            text: z.ZodString;
                            links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                slug: z.ZodString;
                                link: z.ZodString;
                                linkText: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                slug: string;
                                link: string;
                                linkText: string;
                            }, {
                                slug: string;
                                link: string;
                                linkText: string;
                            }>, "many">>;
                            link: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        }, {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        }>]>>;
                        encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        defaultValue: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodNumber, z.ZodBoolean]>>;
                        options: z.ZodOptional<z.ZodObject<{
                            display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                            disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                            enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                            requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                            hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
                        }, "strip", z.ZodTypeAny, {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        }, {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        }>>;
                        modifyFieldsOnValue: z.ZodOptional<z.ZodArray<z.ZodObject<{
                            fieldValue: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                            mode: z.ZodOptional<z.ZodEnum<["create", "edit", "config", "clone"]>>;
                            fieldsToModify: z.ZodArray<z.ZodObject<{
                                fieldId: z.ZodString;
                                display: z.ZodOptional<z.ZodBoolean>;
                                value: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>>;
                                disabled: z.ZodOptional<z.ZodBoolean>;
                                required: z.ZodOptional<z.ZodBoolean>;
                                help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                                    text: z.ZodString;
                                    links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                        slug: z.ZodString;
                                        link: z.ZodString;
                                        linkText: z.ZodString;
                                    }, "strip", z.ZodTypeAny, {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }, {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }>, "many">>;
                                    link: z.ZodOptional<z.ZodString>;
                                }, "strip", z.ZodTypeAny, {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                }, {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                }>]>>;
                                label: z.ZodOptional<z.ZodString>;
                                markdownMessage: z.ZodOptional<z.ZodUnion<[z.ZodObject<{
                                    markdownType: z.ZodLiteral<"text">;
                                    text: z.ZodString;
                                    color: z.ZodOptional<z.ZodString>;
                                }, "strip", z.ZodTypeAny, {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                }, {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                }>, z.ZodObject<{
                                    markdownType: z.ZodLiteral<"hybrid">;
                                    text: z.ZodString;
                                    token: z.ZodString;
                                    linkText: z.ZodString;
                                    link: z.ZodString;
                                }, "strip", z.ZodTypeAny, {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                }, {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                }>, z.ZodObject<{
                                    markdownType: z.ZodLiteral<"link">;
                                    text: z.ZodString;
                                    link: z.ZodString;
                                }, "strip", z.ZodTypeAny, {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                }, {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                }>, z.ZodObject<{
                                    markdownType: z.ZodOptional<z.ZodUndefined>;
                                    text: z.ZodString;
                                }, "strip", z.ZodTypeAny, {
                                    text: string;
                                    markdownType?: undefined;
                                }, {
                                    text: string;
                                    markdownType?: undefined;
                                }>]>>;
                            }, "strip", z.ZodTypeAny, {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }, {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }>, "many">;
                        }, "strip", z.ZodTypeAny, {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }, {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }>, "many">>;
                        validators: z.ZodOptional<z.ZodArray<z.ZodUnion<[z.ZodObject<{
                            errorMsg: z.ZodOptional<z.ZodString>;
                            type: z.ZodLiteral<"number">;
                            range: z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>;
                            isInteger: z.ZodOptional<z.ZodBoolean>;
                        }, "strip", z.ZodTypeAny, {
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        }, {
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        }>, z.ZodObject<{
                            errorMsg: z.ZodOptional<z.ZodString>;
                            type: z.ZodLiteral<"string">;
                            minLength: z.ZodNumber;
                            maxLength: z.ZodNumber;
                        }, "strip", z.ZodTypeAny, {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        }, {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        }>, z.ZodObject<{
                            errorMsg: z.ZodOptional<z.ZodString>;
                            type: z.ZodLiteral<"regex">;
                            pattern: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        }, {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        }>, z.ZodObject<{
                            errorMsg: z.ZodOptional<z.ZodString>;
                            type: z.ZodLiteral<"email">;
                        }, "strip", z.ZodTypeAny, {
                            type: "email";
                            errorMsg?: string | undefined;
                        }, {
                            type: "email";
                            errorMsg?: string | undefined;
                        }>, z.ZodObject<{
                            errorMsg: z.ZodOptional<z.ZodString>;
                            type: z.ZodLiteral<"ipv4">;
                        }, "strip", z.ZodTypeAny, {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        }, {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        }>, z.ZodObject<{
                            errorMsg: z.ZodOptional<z.ZodString>;
                            type: z.ZodLiteral<"url">;
                        }, "strip", z.ZodTypeAny, {
                            type: "url";
                            errorMsg?: string | undefined;
                        }, {
                            type: "url";
                            errorMsg?: string | undefined;
                        }>, z.ZodObject<{
                            errorMsg: z.ZodOptional<z.ZodString>;
                            type: z.ZodLiteral<"date">;
                        }, "strip", z.ZodTypeAny, {
                            type: "date";
                            errorMsg?: string | undefined;
                        }, {
                            type: "date";
                            errorMsg?: string | undefined;
                        }>]>, "many">>;
                    }, "strip", z.ZodTypeAny, {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }, {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }>, "many">>;
                    auth_label: z.ZodOptional<z.ZodString>;
                    oauth_popup_width: z.ZodOptional<z.ZodNumber>;
                    oauth_popup_height: z.ZodOptional<z.ZodNumber>;
                    oauth_timeout: z.ZodOptional<z.ZodNumber>;
                    auth_code_endpoint: z.ZodOptional<z.ZodString>;
                    access_token_endpoint: z.ZodOptional<z.ZodString>;
                    oauth_state_enabled: z.ZodOptional<z.ZodBoolean>;
                    auth_endpoint_token_access_type: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    auth_type: ("oauth" | "basic" | "oauth_client_credentials")[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    oauth?: {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }[] | undefined;
                    basic?: {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }[] | undefined;
                    oauth_client_credentials?: {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }[] | undefined;
                    auth_label?: string | undefined;
                    oauth_popup_width?: number | undefined;
                    oauth_popup_height?: number | undefined;
                    oauth_timeout?: number | undefined;
                    auth_code_endpoint?: string | undefined;
                    access_token_endpoint?: string | undefined;
                    oauth_state_enabled?: boolean | undefined;
                    auth_endpoint_token_access_type?: string | undefined;
                }, {
                    auth_type: ("oauth" | "basic" | "oauth_client_credentials")[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    oauth?: {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }[] | undefined;
                    basic?: {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }[] | undefined;
                    oauth_client_credentials?: {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }[] | undefined;
                    auth_label?: string | undefined;
                    oauth_popup_width?: number | undefined;
                    oauth_popup_height?: number | undefined;
                    oauth_timeout?: number | undefined;
                    auth_code_endpoint?: string | undefined;
                    access_token_endpoint?: string | undefined;
                    oauth_state_enabled?: boolean | undefined;
                    auth_endpoint_token_access_type?: string | undefined;
                }>;
            }, "strip", z.ZodTypeAny, {
                options: {
                    auth_type: ("oauth" | "basic" | "oauth_client_credentials")[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    oauth?: {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }[] | undefined;
                    basic?: {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }[] | undefined;
                    oauth_client_credentials?: {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }[] | undefined;
                    auth_label?: string | undefined;
                    oauth_popup_width?: number | undefined;
                    oauth_popup_height?: number | undefined;
                    oauth_timeout?: number | undefined;
                    auth_code_endpoint?: string | undefined;
                    access_token_endpoint?: string | undefined;
                    oauth_state_enabled?: boolean | undefined;
                    auth_endpoint_token_access_type?: string | undefined;
                };
                type: "oauth";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
            }, {
                options: {
                    auth_type: ("oauth" | "basic" | "oauth_client_credentials")[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    oauth?: {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }[] | undefined;
                    basic?: {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }[] | undefined;
                    oauth_client_credentials?: {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }[] | undefined;
                    auth_label?: string | undefined;
                    oauth_popup_width?: number | undefined;
                    oauth_popup_height?: number | undefined;
                    oauth_timeout?: number | undefined;
                    auth_code_endpoint?: string | undefined;
                    access_token_endpoint?: string | undefined;
                    oauth_state_enabled?: boolean | undefined;
                    auth_endpoint_token_access_type?: string | undefined;
                };
                type: "oauth";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
            }>, z.ZodObject<{
                field: z.ZodString;
                label: z.ZodString;
                help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                    text: z.ZodString;
                    links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        slug: z.ZodString;
                        link: z.ZodString;
                        linkText: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }>, "many">>;
                    link: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }>]>>;
                tooltip: z.ZodOptional<z.ZodString>;
                required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            } & {
                type: z.ZodLiteral<"custom">;
                options: z.ZodObject<{
                    type: z.ZodLiteral<"external">;
                    src: z.ZodString;
                    hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
                }, "strip", z.ZodTypeAny, {
                    type: "external";
                    src: string;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                }, {
                    type: "external";
                    src: string;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                }>;
            }, "strip", z.ZodTypeAny, {
                options: {
                    type: "external";
                    src: string;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                };
                type: "custom";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
            }, {
                options: {
                    type: "external";
                    src: string;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                };
                type: "custom";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
            }>]>, "many">;
            options: z.ZodOptional<z.ZodObject<{
                saveValidator: z.ZodOptional<z.ZodString>;
            }, "strip", z.ZodTypeAny, {
                saveValidator?: string | undefined;
            }, {
                saveValidator?: string | undefined;
            }>>;
            groups: z.ZodOptional<z.ZodArray<z.ZodObject<{
                options: z.ZodOptional<z.ZodObject<{
                    isExpandable: z.ZodOptional<z.ZodBoolean>;
                    expand: z.ZodOptional<z.ZodBoolean>;
                }, "strip", z.ZodTypeAny, {
                    isExpandable?: boolean | undefined;
                    expand?: boolean | undefined;
                }, {
                    isExpandable?: boolean | undefined;
                    expand?: boolean | undefined;
                }>>;
                label: z.ZodString;
                fields: z.ZodArray<z.ZodString, "many">;
            }, "strip", z.ZodTypeAny, {
                label: string;
                fields: string[];
                options?: {
                    isExpandable?: boolean | undefined;
                    expand?: boolean | undefined;
                } | undefined;
            }, {
                label: string;
                fields: string[];
                options?: {
                    isExpandable?: boolean | undefined;
                    expand?: boolean | undefined;
                } | undefined;
            }>, "many">>;
            style: z.ZodOptional<z.ZodEnum<["page", "dialog"]>>;
            hook: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>;
            conf: z.ZodOptional<z.ZodString>;
            restHandlerName: z.ZodOptional<z.ZodString>;
            restHandlerModule: z.ZodOptional<z.ZodString>;
            restHandlerClass: z.ZodOptional<z.ZodString>;
            warning: z.ZodOptional<z.ZodObject<{
                create: z.ZodOptional<z.ZodObject<{
                    message: z.ZodString;
                    alwaysDisplay: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                }, "strip", z.ZodTypeAny, {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                }, {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                }>>;
                edit: z.ZodOptional<z.ZodObject<{
                    message: z.ZodString;
                    alwaysDisplay: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                }, "strip", z.ZodTypeAny, {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                }, {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                }>>;
                config: z.ZodOptional<z.ZodObject<{
                    message: z.ZodString;
                    alwaysDisplay: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                }, "strip", z.ZodTypeAny, {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                }, {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                }>>;
                clone: z.ZodOptional<z.ZodObject<{
                    message: z.ZodString;
                    alwaysDisplay: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                }, "strip", z.ZodTypeAny, {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                }, {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                }>>;
            }, "strip", z.ZodTypeAny, {
                clone?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
                create?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
                edit?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
                config?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
            }, {
                clone?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
                create?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
                edit?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
                config?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
            }>>;
            inputHelperModule: z.ZodOptional<z.ZodString>;
            disableNewInput: z.ZodOptional<z.ZodBoolean>;
            hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
            formTitle: z.ZodOptional<z.ZodString>;
        } & {
            description: z.ZodOptional<z.ZodString>;
            table: z.ZodObject<{
                moreInfo: z.ZodOptional<z.ZodArray<z.ZodObject<{
                    field: z.ZodString;
                    label: z.ZodString;
                    mapping: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>;
                }, "strip", z.ZodTypeAny, {
                    label: string;
                    field: string;
                    mapping?: Record<string, any> | undefined;
                }, {
                    label: string;
                    field: string;
                    mapping?: Record<string, any> | undefined;
                }>, "many">>;
                header: z.ZodArray<z.ZodObject<{
                    field: z.ZodString;
                    label: z.ZodString;
                    mapping: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>;
                    customCell: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>;
                }, "strip", z.ZodTypeAny, {
                    label: string;
                    field: string;
                    mapping?: Record<string, any> | undefined;
                    customCell?: Record<string, any> | undefined;
                }, {
                    label: string;
                    field: string;
                    mapping?: Record<string, any> | undefined;
                    customCell?: Record<string, any> | undefined;
                }>, "many">;
                customRow: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>;
                actions: z.ZodArray<z.ZodEnum<["edit", "delete", "clone", "search"]>, "many">;
            }, "strip", z.ZodTypeAny, {
                header: {
                    label: string;
                    field: string;
                    mapping?: Record<string, any> | undefined;
                    customCell?: Record<string, any> | undefined;
                }[];
                actions: ("clone" | "delete" | "edit" | "search")[];
                moreInfo?: {
                    label: string;
                    field: string;
                    mapping?: Record<string, any> | undefined;
                }[] | undefined;
                customRow?: Record<string, any> | undefined;
            }, {
                header: {
                    label: string;
                    field: string;
                    mapping?: Record<string, any> | undefined;
                    customCell?: Record<string, any> | undefined;
                }[];
                actions: ("clone" | "delete" | "edit" | "search")[];
                moreInfo?: {
                    label: string;
                    field: string;
                    mapping?: Record<string, any> | undefined;
                }[] | undefined;
                customRow?: Record<string, any> | undefined;
            }>;
            useInputToggleConfirmation: z.ZodOptional<z.ZodBoolean>;
        }, "strip", z.ZodTypeAny, {
            name: string;
            entity: ({
                type: "helpLink";
                field: string;
                options?: {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: false | undefined;
            } | {
                type: "text";
                label: string;
                field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                type: "textarea";
                label: string;
                field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    rowsMin?: number | undefined;
                    rowsMax?: number | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                options: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    disableSearch?: boolean | undefined;
                    createSearchChoice?: boolean | undefined;
                    referenceName?: string | undefined;
                    endpointUrl?: string | undefined;
                    allowList?: string | undefined;
                    denyList?: string | undefined;
                    labelField?: string | undefined;
                    valueField?: string | undefined;
                    autoCompleteFields?: ({
                        value: string | number | boolean;
                        label: string;
                    } | {
                        label: string;
                        children: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                    })[] | undefined;
                    dependencies?: string[] | undefined;
                    items?: {
                        value: string | number | boolean;
                        label: string;
                    }[] | undefined;
                };
                type: "singleSelect";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                options: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    disableSearch?: boolean | undefined;
                    createSearchChoice?: boolean | undefined;
                    referenceName?: string | undefined;
                    endpointUrl?: string | undefined;
                    allowList?: string | undefined;
                    denyList?: string | undefined;
                    labelField?: string | undefined;
                    valueField?: string | undefined;
                    autoCompleteFields?: ({
                        value: string | number | boolean;
                        label: string;
                    } | {
                        label: string;
                        children: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                    })[] | undefined;
                    dependencies?: string[] | undefined;
                    items?: {
                        value: string | number | boolean;
                        label: string;
                    }[] | undefined;
                    delimiter?: string | undefined;
                };
                type: "multipleSelect";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                type: "checkbox";
                label: string;
                field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                defaultValue?: number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                options: {
                    rows: {
                        field: string;
                        checkbox?: {
                            label?: string | undefined;
                            defaultValue?: boolean | undefined;
                        } | undefined;
                        input?: {
                            required?: boolean | undefined;
                            validators?: [{
                                type: "number";
                                range: [number, number];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            }] | undefined;
                            defaultValue?: number | undefined;
                        } | undefined;
                    }[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    delimiter?: string | undefined;
                    groups?: {
                        label: string;
                        fields: string[];
                        options?: {
                            isExpandable?: boolean | undefined;
                            expand?: boolean | undefined;
                        } | undefined;
                    }[] | undefined;
                };
                type: "checkboxGroup";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: [{
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }] | undefined;
                defaultValue?: number | boolean | undefined;
            } | {
                options: {
                    rows: {
                        field: string;
                        checkbox?: {
                            label?: string | undefined;
                            defaultValue?: boolean | undefined;
                        } | undefined;
                    }[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    delimiter?: string | undefined;
                    groups?: {
                        label: string;
                        fields: string[];
                        options?: {
                            isExpandable?: boolean | undefined;
                            expand?: boolean | undefined;
                        } | undefined;
                    }[] | undefined;
                };
                type: "checkboxTree";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: [{
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }] | undefined;
                defaultValue?: number | boolean | undefined;
            } | {
                options: {
                    items: {
                        value: string | number | boolean;
                        label: string;
                    }[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                };
                type: "radio";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                type: "file";
                label: string;
                field: string;
                options?: {
                    supportedFileTypes: string[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    maxFileSize?: number | undefined;
                    fileSupportMessage?: string | undefined;
                    useBase64Encoding?: boolean | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                options: {
                    auth_type: ("oauth" | "basic" | "oauth_client_credentials")[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    oauth?: {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }[] | undefined;
                    basic?: {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }[] | undefined;
                    oauth_client_credentials?: {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }[] | undefined;
                    auth_label?: string | undefined;
                    oauth_popup_width?: number | undefined;
                    oauth_popup_height?: number | undefined;
                    oauth_timeout?: number | undefined;
                    auth_code_endpoint?: string | undefined;
                    access_token_endpoint?: string | undefined;
                    oauth_state_enabled?: boolean | undefined;
                    auth_endpoint_token_access_type?: string | undefined;
                };
                type: "oauth";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
            } | {
                options: {
                    type: "external";
                    src: string;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                };
                type: "custom";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
            })[];
            title: string;
            table: {
                header: {
                    label: string;
                    field: string;
                    mapping?: Record<string, any> | undefined;
                    customCell?: Record<string, any> | undefined;
                }[];
                actions: ("clone" | "delete" | "edit" | "search")[];
                moreInfo?: {
                    label: string;
                    field: string;
                    mapping?: Record<string, any> | undefined;
                }[] | undefined;
                customRow?: Record<string, any> | undefined;
            };
            options?: {
                saveValidator?: string | undefined;
            } | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
            groups?: {
                label: string;
                fields: string[];
                options?: {
                    isExpandable?: boolean | undefined;
                    expand?: boolean | undefined;
                } | undefined;
            }[] | undefined;
            style?: "page" | "dialog" | undefined;
            hook?: Record<string, any> | undefined;
            conf?: string | undefined;
            restHandlerName?: string | undefined;
            restHandlerModule?: string | undefined;
            restHandlerClass?: string | undefined;
            warning?: {
                clone?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
                create?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
                edit?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
                config?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
            } | undefined;
            formTitle?: string | undefined;
            subTitle?: string | undefined;
            inputHelperModule?: string | undefined;
            disableNewInput?: boolean | undefined;
            description?: string | undefined;
            useInputToggleConfirmation?: boolean | undefined;
        }, {
            name: string;
            entity: ({
                type: "helpLink";
                field: string;
                options?: {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: false | undefined;
            } | {
                type: "text";
                label: string;
                field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                type: "textarea";
                label: string;
                field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    rowsMin?: number | undefined;
                    rowsMax?: number | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                options: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    disableSearch?: boolean | undefined;
                    createSearchChoice?: boolean | undefined;
                    referenceName?: string | undefined;
                    endpointUrl?: string | undefined;
                    allowList?: string | undefined;
                    denyList?: string | undefined;
                    labelField?: string | undefined;
                    valueField?: string | undefined;
                    autoCompleteFields?: ({
                        value: string | number | boolean;
                        label: string;
                    } | {
                        label: string;
                        children: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                    })[] | undefined;
                    dependencies?: string[] | undefined;
                    items?: {
                        value: string | number | boolean;
                        label: string;
                    }[] | undefined;
                };
                type: "singleSelect";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                options: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    disableSearch?: boolean | undefined;
                    createSearchChoice?: boolean | undefined;
                    referenceName?: string | undefined;
                    endpointUrl?: string | undefined;
                    allowList?: string | undefined;
                    denyList?: string | undefined;
                    labelField?: string | undefined;
                    valueField?: string | undefined;
                    autoCompleteFields?: ({
                        value: string | number | boolean;
                        label: string;
                    } | {
                        label: string;
                        children: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                    })[] | undefined;
                    dependencies?: string[] | undefined;
                    items?: {
                        value: string | number | boolean;
                        label: string;
                    }[] | undefined;
                    delimiter?: string | undefined;
                };
                type: "multipleSelect";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                type: "checkbox";
                label: string;
                field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                defaultValue?: number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                options: {
                    rows: {
                        field: string;
                        checkbox?: {
                            label?: string | undefined;
                            defaultValue?: boolean | undefined;
                        } | undefined;
                        input?: {
                            required?: boolean | undefined;
                            validators?: [{
                                type: "number";
                                range: [number, number];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            }] | undefined;
                            defaultValue?: number | undefined;
                        } | undefined;
                    }[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    delimiter?: string | undefined;
                    groups?: {
                        label: string;
                        fields: string[];
                        options?: {
                            isExpandable?: boolean | undefined;
                            expand?: boolean | undefined;
                        } | undefined;
                    }[] | undefined;
                };
                type: "checkboxGroup";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: [{
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }] | undefined;
                defaultValue?: number | boolean | undefined;
            } | {
                options: {
                    rows: {
                        field: string;
                        checkbox?: {
                            label?: string | undefined;
                            defaultValue?: boolean | undefined;
                        } | undefined;
                    }[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    delimiter?: string | undefined;
                    groups?: {
                        label: string;
                        fields: string[];
                        options?: {
                            isExpandable?: boolean | undefined;
                            expand?: boolean | undefined;
                        } | undefined;
                    }[] | undefined;
                };
                type: "checkboxTree";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: [{
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }] | undefined;
                defaultValue?: number | boolean | undefined;
            } | {
                options: {
                    items: {
                        value: string | number | boolean;
                        label: string;
                    }[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                };
                type: "radio";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                type: "file";
                label: string;
                field: string;
                options?: {
                    supportedFileTypes: string[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    maxFileSize?: number | undefined;
                    fileSupportMessage?: string | undefined;
                    useBase64Encoding?: boolean | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                options: {
                    auth_type: ("oauth" | "basic" | "oauth_client_credentials")[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    oauth?: {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }[] | undefined;
                    basic?: {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }[] | undefined;
                    oauth_client_credentials?: {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }[] | undefined;
                    auth_label?: string | undefined;
                    oauth_popup_width?: number | undefined;
                    oauth_popup_height?: number | undefined;
                    oauth_timeout?: number | undefined;
                    auth_code_endpoint?: string | undefined;
                    access_token_endpoint?: string | undefined;
                    oauth_state_enabled?: boolean | undefined;
                    auth_endpoint_token_access_type?: string | undefined;
                };
                type: "oauth";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
            } | {
                options: {
                    type: "external";
                    src: string;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                };
                type: "custom";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
            })[];
            title: string;
            table: {
                header: {
                    label: string;
                    field: string;
                    mapping?: Record<string, any> | undefined;
                    customCell?: Record<string, any> | undefined;
                }[];
                actions: ("clone" | "delete" | "edit" | "search")[];
                moreInfo?: {
                    label: string;
                    field: string;
                    mapping?: Record<string, any> | undefined;
                }[] | undefined;
                customRow?: Record<string, any> | undefined;
            };
            options?: {
                saveValidator?: string | undefined;
            } | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
            groups?: {
                label: string;
                fields: string[];
                options?: {
                    isExpandable?: boolean | undefined;
                    expand?: boolean | undefined;
                } | undefined;
            }[] | undefined;
            style?: "page" | "dialog" | undefined;
            hook?: Record<string, any> | undefined;
            conf?: string | undefined;
            restHandlerName?: string | undefined;
            restHandlerModule?: string | undefined;
            restHandlerClass?: string | undefined;
            warning?: {
                clone?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
                create?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
                edit?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
                config?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
            } | undefined;
            formTitle?: string | undefined;
            subTitle?: string | undefined;
            inputHelperModule?: string | undefined;
            disableNewInput?: boolean | undefined;
            description?: string | undefined;
            useInputToggleConfirmation?: boolean | undefined;
        }>, "many">;
        inputsUniqueAcrossSingleService: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
    }, "strict", z.ZodTypeAny, {
        title: string;
        services: {
            name: string;
            entity: ({
                type: "helpLink";
                field: string;
                options?: {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: false | undefined;
            } | {
                type: "text";
                label: string;
                field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                type: "textarea";
                label: string;
                field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    rowsMin?: number | undefined;
                    rowsMax?: number | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                options: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    disableSearch?: boolean | undefined;
                    createSearchChoice?: boolean | undefined;
                    referenceName?: string | undefined;
                    endpointUrl?: string | undefined;
                    allowList?: string | undefined;
                    denyList?: string | undefined;
                    labelField?: string | undefined;
                    valueField?: string | undefined;
                    autoCompleteFields?: ({
                        value: string | number | boolean;
                        label: string;
                    } | {
                        label: string;
                        children: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                    })[] | undefined;
                    dependencies?: string[] | undefined;
                    items?: {
                        value: string | number | boolean;
                        label: string;
                    }[] | undefined;
                };
                type: "singleSelect";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                options: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    disableSearch?: boolean | undefined;
                    createSearchChoice?: boolean | undefined;
                    referenceName?: string | undefined;
                    endpointUrl?: string | undefined;
                    allowList?: string | undefined;
                    denyList?: string | undefined;
                    labelField?: string | undefined;
                    valueField?: string | undefined;
                    autoCompleteFields?: ({
                        value: string | number | boolean;
                        label: string;
                    } | {
                        label: string;
                        children: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                    })[] | undefined;
                    dependencies?: string[] | undefined;
                    items?: {
                        value: string | number | boolean;
                        label: string;
                    }[] | undefined;
                    delimiter?: string | undefined;
                };
                type: "multipleSelect";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                type: "checkbox";
                label: string;
                field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                defaultValue?: number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                options: {
                    rows: {
                        field: string;
                        checkbox?: {
                            label?: string | undefined;
                            defaultValue?: boolean | undefined;
                        } | undefined;
                        input?: {
                            required?: boolean | undefined;
                            validators?: [{
                                type: "number";
                                range: [number, number];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            }] | undefined;
                            defaultValue?: number | undefined;
                        } | undefined;
                    }[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    delimiter?: string | undefined;
                    groups?: {
                        label: string;
                        fields: string[];
                        options?: {
                            isExpandable?: boolean | undefined;
                            expand?: boolean | undefined;
                        } | undefined;
                    }[] | undefined;
                };
                type: "checkboxGroup";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: [{
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }] | undefined;
                defaultValue?: number | boolean | undefined;
            } | {
                options: {
                    rows: {
                        field: string;
                        checkbox?: {
                            label?: string | undefined;
                            defaultValue?: boolean | undefined;
                        } | undefined;
                    }[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    delimiter?: string | undefined;
                    groups?: {
                        label: string;
                        fields: string[];
                        options?: {
                            isExpandable?: boolean | undefined;
                            expand?: boolean | undefined;
                        } | undefined;
                    }[] | undefined;
                };
                type: "checkboxTree";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: [{
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }] | undefined;
                defaultValue?: number | boolean | undefined;
            } | {
                options: {
                    items: {
                        value: string | number | boolean;
                        label: string;
                    }[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                };
                type: "radio";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                type: "file";
                label: string;
                field: string;
                options?: {
                    supportedFileTypes: string[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    maxFileSize?: number | undefined;
                    fileSupportMessage?: string | undefined;
                    useBase64Encoding?: boolean | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                options: {
                    auth_type: ("oauth" | "basic" | "oauth_client_credentials")[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    oauth?: {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }[] | undefined;
                    basic?: {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }[] | undefined;
                    oauth_client_credentials?: {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }[] | undefined;
                    auth_label?: string | undefined;
                    oauth_popup_width?: number | undefined;
                    oauth_popup_height?: number | undefined;
                    oauth_timeout?: number | undefined;
                    auth_code_endpoint?: string | undefined;
                    access_token_endpoint?: string | undefined;
                    oauth_state_enabled?: boolean | undefined;
                    auth_endpoint_token_access_type?: string | undefined;
                };
                type: "oauth";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
            } | {
                options: {
                    type: "external";
                    src: string;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                };
                type: "custom";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
            })[];
            title: string;
            table: {
                header: {
                    label: string;
                    field: string;
                    mapping?: Record<string, any> | undefined;
                    customCell?: Record<string, any> | undefined;
                }[];
                actions: ("clone" | "delete" | "edit" | "search")[];
                moreInfo?: {
                    label: string;
                    field: string;
                    mapping?: Record<string, any> | undefined;
                }[] | undefined;
                customRow?: Record<string, any> | undefined;
            };
            options?: {
                saveValidator?: string | undefined;
            } | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
            groups?: {
                label: string;
                fields: string[];
                options?: {
                    isExpandable?: boolean | undefined;
                    expand?: boolean | undefined;
                } | undefined;
            }[] | undefined;
            style?: "page" | "dialog" | undefined;
            hook?: Record<string, any> | undefined;
            conf?: string | undefined;
            restHandlerName?: string | undefined;
            restHandlerModule?: string | undefined;
            restHandlerClass?: string | undefined;
            warning?: {
                clone?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
                create?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
                edit?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
                config?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
            } | undefined;
            formTitle?: string | undefined;
            subTitle?: string | undefined;
            inputHelperModule?: string | undefined;
            disableNewInput?: boolean | undefined;
            description?: string | undefined;
            useInputToggleConfirmation?: boolean | undefined;
        }[];
        inputsUniqueAcrossSingleService?: boolean | undefined;
    }, {
        title: string;
        services: {
            name: string;
            entity: ({
                type: "helpLink";
                field: string;
                options?: {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: false | undefined;
            } | {
                type: "text";
                label: string;
                field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                type: "textarea";
                label: string;
                field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    rowsMin?: number | undefined;
                    rowsMax?: number | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                options: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    disableSearch?: boolean | undefined;
                    createSearchChoice?: boolean | undefined;
                    referenceName?: string | undefined;
                    endpointUrl?: string | undefined;
                    allowList?: string | undefined;
                    denyList?: string | undefined;
                    labelField?: string | undefined;
                    valueField?: string | undefined;
                    autoCompleteFields?: ({
                        value: string | number | boolean;
                        label: string;
                    } | {
                        label: string;
                        children: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                    })[] | undefined;
                    dependencies?: string[] | undefined;
                    items?: {
                        value: string | number | boolean;
                        label: string;
                    }[] | undefined;
                };
                type: "singleSelect";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                options: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    disableSearch?: boolean | undefined;
                    createSearchChoice?: boolean | undefined;
                    referenceName?: string | undefined;
                    endpointUrl?: string | undefined;
                    allowList?: string | undefined;
                    denyList?: string | undefined;
                    labelField?: string | undefined;
                    valueField?: string | undefined;
                    autoCompleteFields?: ({
                        value: string | number | boolean;
                        label: string;
                    } | {
                        label: string;
                        children: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                    })[] | undefined;
                    dependencies?: string[] | undefined;
                    items?: {
                        value: string | number | boolean;
                        label: string;
                    }[] | undefined;
                    delimiter?: string | undefined;
                };
                type: "multipleSelect";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                type: "checkbox";
                label: string;
                field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                defaultValue?: number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                options: {
                    rows: {
                        field: string;
                        checkbox?: {
                            label?: string | undefined;
                            defaultValue?: boolean | undefined;
                        } | undefined;
                        input?: {
                            required?: boolean | undefined;
                            validators?: [{
                                type: "number";
                                range: [number, number];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            }] | undefined;
                            defaultValue?: number | undefined;
                        } | undefined;
                    }[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    delimiter?: string | undefined;
                    groups?: {
                        label: string;
                        fields: string[];
                        options?: {
                            isExpandable?: boolean | undefined;
                            expand?: boolean | undefined;
                        } | undefined;
                    }[] | undefined;
                };
                type: "checkboxGroup";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: [{
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }] | undefined;
                defaultValue?: number | boolean | undefined;
            } | {
                options: {
                    rows: {
                        field: string;
                        checkbox?: {
                            label?: string | undefined;
                            defaultValue?: boolean | undefined;
                        } | undefined;
                    }[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    delimiter?: string | undefined;
                    groups?: {
                        label: string;
                        fields: string[];
                        options?: {
                            isExpandable?: boolean | undefined;
                            expand?: boolean | undefined;
                        } | undefined;
                    }[] | undefined;
                };
                type: "checkboxTree";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: [{
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }] | undefined;
                defaultValue?: number | boolean | undefined;
            } | {
                options: {
                    items: {
                        value: string | number | boolean;
                        label: string;
                    }[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                };
                type: "radio";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                type: "file";
                label: string;
                field: string;
                options?: {
                    supportedFileTypes: string[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    maxFileSize?: number | undefined;
                    fileSupportMessage?: string | undefined;
                    useBase64Encoding?: boolean | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                options: {
                    auth_type: ("oauth" | "basic" | "oauth_client_credentials")[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    oauth?: {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }[] | undefined;
                    basic?: {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }[] | undefined;
                    oauth_client_credentials?: {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }[] | undefined;
                    auth_label?: string | undefined;
                    oauth_popup_width?: number | undefined;
                    oauth_popup_height?: number | undefined;
                    oauth_timeout?: number | undefined;
                    auth_code_endpoint?: string | undefined;
                    access_token_endpoint?: string | undefined;
                    oauth_state_enabled?: boolean | undefined;
                    auth_endpoint_token_access_type?: string | undefined;
                };
                type: "oauth";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
            } | {
                options: {
                    type: "external";
                    src: string;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                };
                type: "custom";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
            })[];
            title: string;
            table: {
                header: {
                    label: string;
                    field: string;
                    mapping?: Record<string, any> | undefined;
                    customCell?: Record<string, any> | undefined;
                }[];
                actions: ("clone" | "delete" | "edit" | "search")[];
                moreInfo?: {
                    label: string;
                    field: string;
                    mapping?: Record<string, any> | undefined;
                }[] | undefined;
                customRow?: Record<string, any> | undefined;
            };
            options?: {
                saveValidator?: string | undefined;
            } | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
            groups?: {
                label: string;
                fields: string[];
                options?: {
                    isExpandable?: boolean | undefined;
                    expand?: boolean | undefined;
                } | undefined;
            }[] | undefined;
            style?: "page" | "dialog" | undefined;
            hook?: Record<string, any> | undefined;
            conf?: string | undefined;
            restHandlerName?: string | undefined;
            restHandlerModule?: string | undefined;
            restHandlerClass?: string | undefined;
            warning?: {
                clone?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
                create?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
                edit?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
                config?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
            } | undefined;
            formTitle?: string | undefined;
            subTitle?: string | undefined;
            inputHelperModule?: string | undefined;
            disableNewInput?: boolean | undefined;
            description?: string | undefined;
            useInputToggleConfirmation?: boolean | undefined;
        }[];
        inputsUniqueAcrossSingleService?: boolean | undefined;
    }>, z.ZodObject<{
        title: z.ZodString;
        description: z.ZodOptional<z.ZodString>;
        subDescription: z.ZodOptional<z.ZodObject<{
            text: z.ZodString;
            links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                slug: z.ZodString;
                link: z.ZodString;
                linkText: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                slug: string;
                link: string;
                linkText: string;
            }, {
                slug: string;
                link: string;
                linkText: string;
            }>, "many">>;
        }, "strip", z.ZodTypeAny, {
            text: string;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        }, {
            text: string;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        }>>;
        menu: z.ZodOptional<z.ZodObject<{
            type: z.ZodLiteral<"external">;
            src: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            type: "external";
            src: string;
        }, {
            type: "external";
            src: string;
        }>>;
        table: z.ZodObject<{
            moreInfo: z.ZodOptional<z.ZodArray<z.ZodObject<{
                field: z.ZodString;
                label: z.ZodString;
                mapping: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>;
            }, "strip", z.ZodTypeAny, {
                label: string;
                field: string;
                mapping?: Record<string, any> | undefined;
            }, {
                label: string;
                field: string;
                mapping?: Record<string, any> | undefined;
            }>, "many">>;
            header: z.ZodArray<z.ZodObject<{
                field: z.ZodString;
                label: z.ZodString;
                mapping: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>;
                customCell: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>;
            }, "strip", z.ZodTypeAny, {
                label: string;
                field: string;
                mapping?: Record<string, any> | undefined;
                customCell?: Record<string, any> | undefined;
            }, {
                label: string;
                field: string;
                mapping?: Record<string, any> | undefined;
                customCell?: Record<string, any> | undefined;
            }>, "many">;
            customRow: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>;
            actions: z.ZodArray<z.ZodEnum<["edit", "delete", "clone", "search"]>, "many">;
        }, "strip", z.ZodTypeAny, {
            header: {
                label: string;
                field: string;
                mapping?: Record<string, any> | undefined;
                customCell?: Record<string, any> | undefined;
            }[];
            actions: ("clone" | "delete" | "edit" | "search")[];
            moreInfo?: {
                label: string;
                field: string;
                mapping?: Record<string, any> | undefined;
            }[] | undefined;
            customRow?: Record<string, any> | undefined;
        }, {
            header: {
                label: string;
                field: string;
                mapping?: Record<string, any> | undefined;
                customCell?: Record<string, any> | undefined;
            }[];
            actions: ("clone" | "delete" | "edit" | "search")[];
            moreInfo?: {
                label: string;
                field: string;
                mapping?: Record<string, any> | undefined;
            }[] | undefined;
            customRow?: Record<string, any> | undefined;
        }>;
        groupsMenu: z.ZodOptional<z.ZodArray<z.ZodObject<{
            groupName: z.ZodString;
            groupTitle: z.ZodString;
            groupServices: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
        }, "strip", z.ZodTypeAny, {
            groupName: string;
            groupTitle: string;
            groupServices?: string[] | undefined;
        }, {
            groupName: string;
            groupTitle: string;
            groupServices?: string[] | undefined;
        }>, "many">>;
        services: z.ZodArray<z.ZodObject<{
            name: z.ZodString;
            title: z.ZodString;
            subTitle: z.ZodOptional<z.ZodString>;
            entity: z.ZodArray<z.ZodDiscriminatedUnion<"type", [z.ZodObject<{
                field: z.ZodString;
                help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                    text: z.ZodString;
                    links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        slug: z.ZodString;
                        link: z.ZodString;
                        linkText: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }>, "many">>;
                    link: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }>]>>;
                tooltip: z.ZodOptional<z.ZodString>;
            } & {
                type: z.ZodLiteral<"helpLink">;
                label: z.ZodOptional<z.ZodString>;
                options: z.ZodOptional<z.ZodObject<{
                    text: z.ZodString;
                    links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        slug: z.ZodString;
                        link: z.ZodString;
                        linkText: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }>, "many">>;
                    link: z.ZodOptional<z.ZodString>;
                } & {
                    hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                }, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                }>>;
                required: z.ZodOptional<z.ZodDefault<z.ZodLiteral<false>>>;
            }, "strip", z.ZodTypeAny, {
                type: "helpLink";
                field: string;
                options?: {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: false | undefined;
            }, {
                type: "helpLink";
                field: string;
                options?: {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: false | undefined;
            }>, z.ZodObject<{
                field: z.ZodString;
                label: z.ZodString;
                help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                    text: z.ZodString;
                    links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        slug: z.ZodString;
                        link: z.ZodString;
                        linkText: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }>, "many">>;
                    link: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }>]>>;
                tooltip: z.ZodOptional<z.ZodString>;
                required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            } & {
                type: z.ZodLiteral<"text">;
                validators: z.ZodOptional<z.ZodArray<z.ZodUnion<[z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"number">;
                    range: z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>;
                    isInteger: z.ZodOptional<z.ZodBoolean>;
                }, "strip", z.ZodTypeAny, {
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                }, {
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"string">;
                    minLength: z.ZodNumber;
                    maxLength: z.ZodNumber;
                }, "strip", z.ZodTypeAny, {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                }, {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"regex">;
                    pattern: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }, {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"email">;
                }, "strip", z.ZodTypeAny, {
                    type: "email";
                    errorMsg?: string | undefined;
                }, {
                    type: "email";
                    errorMsg?: string | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"ipv4">;
                }, "strip", z.ZodTypeAny, {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                }, {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"url">;
                }, "strip", z.ZodTypeAny, {
                    type: "url";
                    errorMsg?: string | undefined;
                }, {
                    type: "url";
                    errorMsg?: string | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"date">;
                }, "strip", z.ZodTypeAny, {
                    type: "date";
                    errorMsg?: string | undefined;
                }, {
                    type: "date";
                    errorMsg?: string | undefined;
                }>]>, "many">>;
                defaultValue: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodNumber, z.ZodBoolean]>>;
                options: z.ZodOptional<z.ZodObject<{
                    display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
                }, "strip", z.ZodTypeAny, {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                }, {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                }>>;
                modifyFieldsOnValue: z.ZodOptional<z.ZodArray<z.ZodObject<{
                    fieldValue: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                    mode: z.ZodOptional<z.ZodEnum<["create", "edit", "config", "clone"]>>;
                    fieldsToModify: z.ZodArray<z.ZodObject<{
                        fieldId: z.ZodString;
                        display: z.ZodOptional<z.ZodBoolean>;
                        value: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>>;
                        disabled: z.ZodOptional<z.ZodBoolean>;
                        required: z.ZodOptional<z.ZodBoolean>;
                        help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                            text: z.ZodString;
                            links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                slug: z.ZodString;
                                link: z.ZodString;
                                linkText: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                slug: string;
                                link: string;
                                linkText: string;
                            }, {
                                slug: string;
                                link: string;
                                linkText: string;
                            }>, "many">>;
                            link: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        }, {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        }>]>>;
                        label: z.ZodOptional<z.ZodString>;
                        markdownMessage: z.ZodOptional<z.ZodUnion<[z.ZodObject<{
                            markdownType: z.ZodLiteral<"text">;
                            text: z.ZodString;
                            color: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        }, {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        }>, z.ZodObject<{
                            markdownType: z.ZodLiteral<"hybrid">;
                            text: z.ZodString;
                            token: z.ZodString;
                            linkText: z.ZodString;
                            link: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        }, {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        }>, z.ZodObject<{
                            markdownType: z.ZodLiteral<"link">;
                            text: z.ZodString;
                            link: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            link: string;
                            markdownType: "link";
                        }, {
                            text: string;
                            link: string;
                            markdownType: "link";
                        }>, z.ZodObject<{
                            markdownType: z.ZodOptional<z.ZodUndefined>;
                            text: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            markdownType?: undefined;
                        }, {
                            text: string;
                            markdownType?: undefined;
                        }>]>>;
                    }, "strip", z.ZodTypeAny, {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }, {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }>, "many">;
                }, "strip", z.ZodTypeAny, {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }, {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }>, "many">>;
            }, "strip", z.ZodTypeAny, {
                type: "text";
                label: string;
                field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            }, {
                type: "text";
                label: string;
                field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            }>, z.ZodObject<{
                field: z.ZodString;
                label: z.ZodString;
                help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                    text: z.ZodString;
                    links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        slug: z.ZodString;
                        link: z.ZodString;
                        linkText: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }>, "many">>;
                    link: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }>]>>;
                tooltip: z.ZodOptional<z.ZodString>;
                required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            } & {
                type: z.ZodLiteral<"textarea">;
                validators: z.ZodOptional<z.ZodArray<z.ZodUnion<[z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"number">;
                    range: z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>;
                    isInteger: z.ZodOptional<z.ZodBoolean>;
                }, "strip", z.ZodTypeAny, {
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                }, {
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"string">;
                    minLength: z.ZodNumber;
                    maxLength: z.ZodNumber;
                }, "strip", z.ZodTypeAny, {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                }, {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"regex">;
                    pattern: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }, {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"email">;
                }, "strip", z.ZodTypeAny, {
                    type: "email";
                    errorMsg?: string | undefined;
                }, {
                    type: "email";
                    errorMsg?: string | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"ipv4">;
                }, "strip", z.ZodTypeAny, {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                }, {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"url">;
                }, "strip", z.ZodTypeAny, {
                    type: "url";
                    errorMsg?: string | undefined;
                }, {
                    type: "url";
                    errorMsg?: string | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"date">;
                }, "strip", z.ZodTypeAny, {
                    type: "date";
                    errorMsg?: string | undefined;
                }, {
                    type: "date";
                    errorMsg?: string | undefined;
                }>]>, "many">>;
                defaultValue: z.ZodOptional<z.ZodString>;
                options: z.ZodOptional<z.ZodObject<{
                    display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
                } & {
                    rowsMin: z.ZodOptional<z.ZodNumber>;
                    rowsMax: z.ZodOptional<z.ZodNumber>;
                }, "strip", z.ZodTypeAny, {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    rowsMin?: number | undefined;
                    rowsMax?: number | undefined;
                }, {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    rowsMin?: number | undefined;
                    rowsMax?: number | undefined;
                }>>;
                modifyFieldsOnValue: z.ZodOptional<z.ZodArray<z.ZodObject<{
                    fieldValue: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                    mode: z.ZodOptional<z.ZodEnum<["create", "edit", "config", "clone"]>>;
                    fieldsToModify: z.ZodArray<z.ZodObject<{
                        fieldId: z.ZodString;
                        display: z.ZodOptional<z.ZodBoolean>;
                        value: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>>;
                        disabled: z.ZodOptional<z.ZodBoolean>;
                        required: z.ZodOptional<z.ZodBoolean>;
                        help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                            text: z.ZodString;
                            links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                slug: z.ZodString;
                                link: z.ZodString;
                                linkText: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                slug: string;
                                link: string;
                                linkText: string;
                            }, {
                                slug: string;
                                link: string;
                                linkText: string;
                            }>, "many">>;
                            link: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        }, {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        }>]>>;
                        label: z.ZodOptional<z.ZodString>;
                        markdownMessage: z.ZodOptional<z.ZodUnion<[z.ZodObject<{
                            markdownType: z.ZodLiteral<"text">;
                            text: z.ZodString;
                            color: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        }, {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        }>, z.ZodObject<{
                            markdownType: z.ZodLiteral<"hybrid">;
                            text: z.ZodString;
                            token: z.ZodString;
                            linkText: z.ZodString;
                            link: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        }, {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        }>, z.ZodObject<{
                            markdownType: z.ZodLiteral<"link">;
                            text: z.ZodString;
                            link: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            link: string;
                            markdownType: "link";
                        }, {
                            text: string;
                            link: string;
                            markdownType: "link";
                        }>, z.ZodObject<{
                            markdownType: z.ZodOptional<z.ZodUndefined>;
                            text: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            markdownType?: undefined;
                        }, {
                            text: string;
                            markdownType?: undefined;
                        }>]>>;
                    }, "strip", z.ZodTypeAny, {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }, {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }>, "many">;
                }, "strip", z.ZodTypeAny, {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }, {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }>, "many">>;
            }, "strip", z.ZodTypeAny, {
                type: "textarea";
                label: string;
                field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    rowsMin?: number | undefined;
                    rowsMax?: number | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            }, {
                type: "textarea";
                label: string;
                field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    rowsMin?: number | undefined;
                    rowsMax?: number | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            }>, z.ZodObject<{
                field: z.ZodString;
                label: z.ZodString;
                help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                    text: z.ZodString;
                    links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        slug: z.ZodString;
                        link: z.ZodString;
                        linkText: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }>, "many">>;
                    link: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }>]>>;
                tooltip: z.ZodOptional<z.ZodString>;
                required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            } & {
                type: z.ZodLiteral<"singleSelect">;
                validators: z.ZodOptional<z.ZodArray<z.ZodUnion<[z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"number">;
                    range: z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>;
                    isInteger: z.ZodOptional<z.ZodBoolean>;
                }, "strip", z.ZodTypeAny, {
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                }, {
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"string">;
                    minLength: z.ZodNumber;
                    maxLength: z.ZodNumber;
                }, "strip", z.ZodTypeAny, {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                }, {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"regex">;
                    pattern: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }, {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"email">;
                }, "strip", z.ZodTypeAny, {
                    type: "email";
                    errorMsg?: string | undefined;
                }, {
                    type: "email";
                    errorMsg?: string | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"ipv4">;
                }, "strip", z.ZodTypeAny, {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                }, {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"url">;
                }, "strip", z.ZodTypeAny, {
                    type: "url";
                    errorMsg?: string | undefined;
                }, {
                    type: "url";
                    errorMsg?: string | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"date">;
                }, "strip", z.ZodTypeAny, {
                    type: "date";
                    errorMsg?: string | undefined;
                }, {
                    type: "date";
                    errorMsg?: string | undefined;
                }>]>, "many">>;
                defaultValue: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodNumber, z.ZodBoolean]>>;
                options: z.ZodObject<{
                    display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
                } & {
                    disableSearch: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    createSearchChoice: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    referenceName: z.ZodOptional<z.ZodString>;
                    endpointUrl: z.ZodOptional<z.ZodString>;
                    allowList: z.ZodOptional<z.ZodString>;
                    denyList: z.ZodOptional<z.ZodString>;
                    labelField: z.ZodOptional<z.ZodString>;
                    valueField: z.ZodOptional<z.ZodString>;
                    autoCompleteFields: z.ZodOptional<z.ZodArray<z.ZodUnion<[z.ZodObject<{
                        value: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                        label: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        value: string | number | boolean;
                        label: string;
                    }, {
                        value: string | number | boolean;
                        label: string;
                    }>, z.ZodObject<{
                        label: z.ZodString;
                        children: z.ZodArray<z.ZodObject<{
                            value: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                            label: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            value: string | number | boolean;
                            label: string;
                        }, {
                            value: string | number | boolean;
                            label: string;
                        }>, "many">;
                    }, "strip", z.ZodTypeAny, {
                        label: string;
                        children: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                    }, {
                        label: string;
                        children: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                    }>]>, "many">>;
                    dependencies: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                    items: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        value: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                        label: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        value: string | number | boolean;
                        label: string;
                    }, {
                        value: string | number | boolean;
                        label: string;
                    }>, "many">>;
                }, "strip", z.ZodTypeAny, {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    disableSearch?: boolean | undefined;
                    createSearchChoice?: boolean | undefined;
                    referenceName?: string | undefined;
                    endpointUrl?: string | undefined;
                    allowList?: string | undefined;
                    denyList?: string | undefined;
                    labelField?: string | undefined;
                    valueField?: string | undefined;
                    autoCompleteFields?: ({
                        value: string | number | boolean;
                        label: string;
                    } | {
                        label: string;
                        children: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                    })[] | undefined;
                    dependencies?: string[] | undefined;
                    items?: {
                        value: string | number | boolean;
                        label: string;
                    }[] | undefined;
                }, {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    disableSearch?: boolean | undefined;
                    createSearchChoice?: boolean | undefined;
                    referenceName?: string | undefined;
                    endpointUrl?: string | undefined;
                    allowList?: string | undefined;
                    denyList?: string | undefined;
                    labelField?: string | undefined;
                    valueField?: string | undefined;
                    autoCompleteFields?: ({
                        value: string | number | boolean;
                        label: string;
                    } | {
                        label: string;
                        children: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                    })[] | undefined;
                    dependencies?: string[] | undefined;
                    items?: {
                        value: string | number | boolean;
                        label: string;
                    }[] | undefined;
                }>;
                modifyFieldsOnValue: z.ZodOptional<z.ZodArray<z.ZodObject<{
                    fieldValue: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                    mode: z.ZodOptional<z.ZodEnum<["create", "edit", "config", "clone"]>>;
                    fieldsToModify: z.ZodArray<z.ZodObject<{
                        fieldId: z.ZodString;
                        display: z.ZodOptional<z.ZodBoolean>;
                        value: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>>;
                        disabled: z.ZodOptional<z.ZodBoolean>;
                        required: z.ZodOptional<z.ZodBoolean>;
                        help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                            text: z.ZodString;
                            links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                slug: z.ZodString;
                                link: z.ZodString;
                                linkText: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                slug: string;
                                link: string;
                                linkText: string;
                            }, {
                                slug: string;
                                link: string;
                                linkText: string;
                            }>, "many">>;
                            link: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        }, {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        }>]>>;
                        label: z.ZodOptional<z.ZodString>;
                        markdownMessage: z.ZodOptional<z.ZodUnion<[z.ZodObject<{
                            markdownType: z.ZodLiteral<"text">;
                            text: z.ZodString;
                            color: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        }, {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        }>, z.ZodObject<{
                            markdownType: z.ZodLiteral<"hybrid">;
                            text: z.ZodString;
                            token: z.ZodString;
                            linkText: z.ZodString;
                            link: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        }, {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        }>, z.ZodObject<{
                            markdownType: z.ZodLiteral<"link">;
                            text: z.ZodString;
                            link: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            link: string;
                            markdownType: "link";
                        }, {
                            text: string;
                            link: string;
                            markdownType: "link";
                        }>, z.ZodObject<{
                            markdownType: z.ZodOptional<z.ZodUndefined>;
                            text: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            markdownType?: undefined;
                        }, {
                            text: string;
                            markdownType?: undefined;
                        }>]>>;
                    }, "strip", z.ZodTypeAny, {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }, {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }>, "many">;
                }, "strip", z.ZodTypeAny, {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }, {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }>, "many">>;
            }, "strip", z.ZodTypeAny, {
                options: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    disableSearch?: boolean | undefined;
                    createSearchChoice?: boolean | undefined;
                    referenceName?: string | undefined;
                    endpointUrl?: string | undefined;
                    allowList?: string | undefined;
                    denyList?: string | undefined;
                    labelField?: string | undefined;
                    valueField?: string | undefined;
                    autoCompleteFields?: ({
                        value: string | number | boolean;
                        label: string;
                    } | {
                        label: string;
                        children: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                    })[] | undefined;
                    dependencies?: string[] | undefined;
                    items?: {
                        value: string | number | boolean;
                        label: string;
                    }[] | undefined;
                };
                type: "singleSelect";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            }, {
                options: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    disableSearch?: boolean | undefined;
                    createSearchChoice?: boolean | undefined;
                    referenceName?: string | undefined;
                    endpointUrl?: string | undefined;
                    allowList?: string | undefined;
                    denyList?: string | undefined;
                    labelField?: string | undefined;
                    valueField?: string | undefined;
                    autoCompleteFields?: ({
                        value: string | number | boolean;
                        label: string;
                    } | {
                        label: string;
                        children: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                    })[] | undefined;
                    dependencies?: string[] | undefined;
                    items?: {
                        value: string | number | boolean;
                        label: string;
                    }[] | undefined;
                };
                type: "singleSelect";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            }>, z.ZodObject<{
                field: z.ZodString;
                label: z.ZodString;
                help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                    text: z.ZodString;
                    links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        slug: z.ZodString;
                        link: z.ZodString;
                        linkText: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }>, "many">>;
                    link: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }>]>>;
                tooltip: z.ZodOptional<z.ZodString>;
                required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            } & {
                type: z.ZodLiteral<"multipleSelect">;
                validators: z.ZodOptional<z.ZodArray<z.ZodUnion<[z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"number">;
                    range: z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>;
                    isInteger: z.ZodOptional<z.ZodBoolean>;
                }, "strip", z.ZodTypeAny, {
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                }, {
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"string">;
                    minLength: z.ZodNumber;
                    maxLength: z.ZodNumber;
                }, "strip", z.ZodTypeAny, {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                }, {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"regex">;
                    pattern: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }, {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"email">;
                }, "strip", z.ZodTypeAny, {
                    type: "email";
                    errorMsg?: string | undefined;
                }, {
                    type: "email";
                    errorMsg?: string | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"ipv4">;
                }, "strip", z.ZodTypeAny, {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                }, {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"url">;
                }, "strip", z.ZodTypeAny, {
                    type: "url";
                    errorMsg?: string | undefined;
                }, {
                    type: "url";
                    errorMsg?: string | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"date">;
                }, "strip", z.ZodTypeAny, {
                    type: "date";
                    errorMsg?: string | undefined;
                }, {
                    type: "date";
                    errorMsg?: string | undefined;
                }>]>, "many">>;
                defaultValue: z.ZodOptional<z.ZodString>;
                options: z.ZodObject<{
                    display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
                } & {
                    disableSearch: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    createSearchChoice: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    referenceName: z.ZodOptional<z.ZodString>;
                    endpointUrl: z.ZodOptional<z.ZodString>;
                    allowList: z.ZodOptional<z.ZodString>;
                    denyList: z.ZodOptional<z.ZodString>;
                    labelField: z.ZodOptional<z.ZodString>;
                    valueField: z.ZodOptional<z.ZodString>;
                    autoCompleteFields: z.ZodOptional<z.ZodArray<z.ZodUnion<[z.ZodObject<{
                        value: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                        label: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        value: string | number | boolean;
                        label: string;
                    }, {
                        value: string | number | boolean;
                        label: string;
                    }>, z.ZodObject<{
                        label: z.ZodString;
                        children: z.ZodArray<z.ZodObject<{
                            value: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                            label: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            value: string | number | boolean;
                            label: string;
                        }, {
                            value: string | number | boolean;
                            label: string;
                        }>, "many">;
                    }, "strip", z.ZodTypeAny, {
                        label: string;
                        children: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                    }, {
                        label: string;
                        children: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                    }>]>, "many">>;
                    dependencies: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                    items: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        value: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                        label: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        value: string | number | boolean;
                        label: string;
                    }, {
                        value: string | number | boolean;
                        label: string;
                    }>, "many">>;
                } & {
                    delimiter: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    disableSearch?: boolean | undefined;
                    createSearchChoice?: boolean | undefined;
                    referenceName?: string | undefined;
                    endpointUrl?: string | undefined;
                    allowList?: string | undefined;
                    denyList?: string | undefined;
                    labelField?: string | undefined;
                    valueField?: string | undefined;
                    autoCompleteFields?: ({
                        value: string | number | boolean;
                        label: string;
                    } | {
                        label: string;
                        children: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                    })[] | undefined;
                    dependencies?: string[] | undefined;
                    items?: {
                        value: string | number | boolean;
                        label: string;
                    }[] | undefined;
                    delimiter?: string | undefined;
                }, {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    disableSearch?: boolean | undefined;
                    createSearchChoice?: boolean | undefined;
                    referenceName?: string | undefined;
                    endpointUrl?: string | undefined;
                    allowList?: string | undefined;
                    denyList?: string | undefined;
                    labelField?: string | undefined;
                    valueField?: string | undefined;
                    autoCompleteFields?: ({
                        value: string | number | boolean;
                        label: string;
                    } | {
                        label: string;
                        children: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                    })[] | undefined;
                    dependencies?: string[] | undefined;
                    items?: {
                        value: string | number | boolean;
                        label: string;
                    }[] | undefined;
                    delimiter?: string | undefined;
                }>;
                modifyFieldsOnValue: z.ZodOptional<z.ZodArray<z.ZodObject<{
                    fieldValue: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                    mode: z.ZodOptional<z.ZodEnum<["create", "edit", "config", "clone"]>>;
                    fieldsToModify: z.ZodArray<z.ZodObject<{
                        fieldId: z.ZodString;
                        display: z.ZodOptional<z.ZodBoolean>;
                        value: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>>;
                        disabled: z.ZodOptional<z.ZodBoolean>;
                        required: z.ZodOptional<z.ZodBoolean>;
                        help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                            text: z.ZodString;
                            links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                slug: z.ZodString;
                                link: z.ZodString;
                                linkText: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                slug: string;
                                link: string;
                                linkText: string;
                            }, {
                                slug: string;
                                link: string;
                                linkText: string;
                            }>, "many">>;
                            link: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        }, {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        }>]>>;
                        label: z.ZodOptional<z.ZodString>;
                        markdownMessage: z.ZodOptional<z.ZodUnion<[z.ZodObject<{
                            markdownType: z.ZodLiteral<"text">;
                            text: z.ZodString;
                            color: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        }, {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        }>, z.ZodObject<{
                            markdownType: z.ZodLiteral<"hybrid">;
                            text: z.ZodString;
                            token: z.ZodString;
                            linkText: z.ZodString;
                            link: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        }, {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        }>, z.ZodObject<{
                            markdownType: z.ZodLiteral<"link">;
                            text: z.ZodString;
                            link: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            link: string;
                            markdownType: "link";
                        }, {
                            text: string;
                            link: string;
                            markdownType: "link";
                        }>, z.ZodObject<{
                            markdownType: z.ZodOptional<z.ZodUndefined>;
                            text: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            markdownType?: undefined;
                        }, {
                            text: string;
                            markdownType?: undefined;
                        }>]>>;
                    }, "strip", z.ZodTypeAny, {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }, {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }>, "many">;
                }, "strip", z.ZodTypeAny, {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }, {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }>, "many">>;
            }, "strip", z.ZodTypeAny, {
                options: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    disableSearch?: boolean | undefined;
                    createSearchChoice?: boolean | undefined;
                    referenceName?: string | undefined;
                    endpointUrl?: string | undefined;
                    allowList?: string | undefined;
                    denyList?: string | undefined;
                    labelField?: string | undefined;
                    valueField?: string | undefined;
                    autoCompleteFields?: ({
                        value: string | number | boolean;
                        label: string;
                    } | {
                        label: string;
                        children: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                    })[] | undefined;
                    dependencies?: string[] | undefined;
                    items?: {
                        value: string | number | boolean;
                        label: string;
                    }[] | undefined;
                    delimiter?: string | undefined;
                };
                type: "multipleSelect";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            }, {
                options: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    disableSearch?: boolean | undefined;
                    createSearchChoice?: boolean | undefined;
                    referenceName?: string | undefined;
                    endpointUrl?: string | undefined;
                    allowList?: string | undefined;
                    denyList?: string | undefined;
                    labelField?: string | undefined;
                    valueField?: string | undefined;
                    autoCompleteFields?: ({
                        value: string | number | boolean;
                        label: string;
                    } | {
                        label: string;
                        children: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                    })[] | undefined;
                    dependencies?: string[] | undefined;
                    items?: {
                        value: string | number | boolean;
                        label: string;
                    }[] | undefined;
                    delimiter?: string | undefined;
                };
                type: "multipleSelect";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            }>, z.ZodObject<{
                field: z.ZodString;
                label: z.ZodString;
                help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                    text: z.ZodString;
                    links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        slug: z.ZodString;
                        link: z.ZodString;
                        linkText: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }>, "many">>;
                    link: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }>]>>;
                tooltip: z.ZodOptional<z.ZodString>;
                required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            } & {
                type: z.ZodLiteral<"checkbox">;
                defaultValue: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodBoolean]>>;
                options: z.ZodOptional<z.ZodObject<{
                    display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
                }, "strip", z.ZodTypeAny, {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                }, {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                }>>;
                modifyFieldsOnValue: z.ZodOptional<z.ZodArray<z.ZodObject<{
                    fieldValue: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                    mode: z.ZodOptional<z.ZodEnum<["create", "edit", "config", "clone"]>>;
                    fieldsToModify: z.ZodArray<z.ZodObject<{
                        fieldId: z.ZodString;
                        display: z.ZodOptional<z.ZodBoolean>;
                        value: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>>;
                        disabled: z.ZodOptional<z.ZodBoolean>;
                        required: z.ZodOptional<z.ZodBoolean>;
                        help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                            text: z.ZodString;
                            links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                slug: z.ZodString;
                                link: z.ZodString;
                                linkText: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                slug: string;
                                link: string;
                                linkText: string;
                            }, {
                                slug: string;
                                link: string;
                                linkText: string;
                            }>, "many">>;
                            link: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        }, {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        }>]>>;
                        label: z.ZodOptional<z.ZodString>;
                        markdownMessage: z.ZodOptional<z.ZodUnion<[z.ZodObject<{
                            markdownType: z.ZodLiteral<"text">;
                            text: z.ZodString;
                            color: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        }, {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        }>, z.ZodObject<{
                            markdownType: z.ZodLiteral<"hybrid">;
                            text: z.ZodString;
                            token: z.ZodString;
                            linkText: z.ZodString;
                            link: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        }, {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        }>, z.ZodObject<{
                            markdownType: z.ZodLiteral<"link">;
                            text: z.ZodString;
                            link: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            link: string;
                            markdownType: "link";
                        }, {
                            text: string;
                            link: string;
                            markdownType: "link";
                        }>, z.ZodObject<{
                            markdownType: z.ZodOptional<z.ZodUndefined>;
                            text: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            markdownType?: undefined;
                        }, {
                            text: string;
                            markdownType?: undefined;
                        }>]>>;
                    }, "strip", z.ZodTypeAny, {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }, {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }>, "many">;
                }, "strip", z.ZodTypeAny, {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }, {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }>, "many">>;
            }, "strip", z.ZodTypeAny, {
                type: "checkbox";
                label: string;
                field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                defaultValue?: number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            }, {
                type: "checkbox";
                label: string;
                field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                defaultValue?: number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            }>, z.ZodObject<{
                field: z.ZodString;
                label: z.ZodString;
                help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                    text: z.ZodString;
                    links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        slug: z.ZodString;
                        link: z.ZodString;
                        linkText: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }>, "many">>;
                    link: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }>]>>;
                tooltip: z.ZodOptional<z.ZodString>;
                required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            } & {
                type: z.ZodLiteral<"checkboxGroup">;
                validators: z.ZodOptional<z.ZodTuple<[z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"regex">;
                    pattern: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }, {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }>], null>>;
                defaultValue: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodBoolean]>>;
                options: z.ZodObject<{
                    display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
                } & {
                    delimiter: z.ZodOptional<z.ZodString>;
                    groups: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        label: z.ZodString;
                        fields: z.ZodArray<z.ZodString, "many">;
                        options: z.ZodOptional<z.ZodObject<{
                            isExpandable: z.ZodOptional<z.ZodBoolean>;
                            expand: z.ZodOptional<z.ZodBoolean>;
                        }, "strip", z.ZodTypeAny, {
                            isExpandable?: boolean | undefined;
                            expand?: boolean | undefined;
                        }, {
                            isExpandable?: boolean | undefined;
                            expand?: boolean | undefined;
                        }>>;
                    }, "strip", z.ZodTypeAny, {
                        label: string;
                        fields: string[];
                        options?: {
                            isExpandable?: boolean | undefined;
                            expand?: boolean | undefined;
                        } | undefined;
                    }, {
                        label: string;
                        fields: string[];
                        options?: {
                            isExpandable?: boolean | undefined;
                            expand?: boolean | undefined;
                        } | undefined;
                    }>, "many">>;
                    rows: z.ZodArray<z.ZodObject<{
                        field: z.ZodString;
                        checkbox: z.ZodOptional<z.ZodObject<{
                            label: z.ZodOptional<z.ZodString>;
                            defaultValue: z.ZodOptional<z.ZodBoolean>;
                        }, "strip", z.ZodTypeAny, {
                            label?: string | undefined;
                            defaultValue?: boolean | undefined;
                        }, {
                            label?: string | undefined;
                            defaultValue?: boolean | undefined;
                        }>>;
                        input: z.ZodOptional<z.ZodObject<{
                            defaultValue: z.ZodOptional<z.ZodNumber>;
                            validators: z.ZodOptional<z.ZodTuple<[z.ZodObject<{
                                errorMsg: z.ZodOptional<z.ZodString>;
                                type: z.ZodLiteral<"number">;
                                range: z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>;
                                isInteger: z.ZodOptional<z.ZodBoolean>;
                            }, "strip", z.ZodTypeAny, {
                                type: "number";
                                range: [number, number];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            }, {
                                type: "number";
                                range: [number, number];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            }>], null>>;
                            required: z.ZodOptional<z.ZodBoolean>;
                        }, "strip", z.ZodTypeAny, {
                            required?: boolean | undefined;
                            validators?: [{
                                type: "number";
                                range: [number, number];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            }] | undefined;
                            defaultValue?: number | undefined;
                        }, {
                            required?: boolean | undefined;
                            validators?: [{
                                type: "number";
                                range: [number, number];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            }] | undefined;
                            defaultValue?: number | undefined;
                        }>>;
                    }, "strip", z.ZodTypeAny, {
                        field: string;
                        checkbox?: {
                            label?: string | undefined;
                            defaultValue?: boolean | undefined;
                        } | undefined;
                        input?: {
                            required?: boolean | undefined;
                            validators?: [{
                                type: "number";
                                range: [number, number];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            }] | undefined;
                            defaultValue?: number | undefined;
                        } | undefined;
                    }, {
                        field: string;
                        checkbox?: {
                            label?: string | undefined;
                            defaultValue?: boolean | undefined;
                        } | undefined;
                        input?: {
                            required?: boolean | undefined;
                            validators?: [{
                                type: "number";
                                range: [number, number];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            }] | undefined;
                            defaultValue?: number | undefined;
                        } | undefined;
                    }>, "many">;
                }, "strip", z.ZodTypeAny, {
                    rows: {
                        field: string;
                        checkbox?: {
                            label?: string | undefined;
                            defaultValue?: boolean | undefined;
                        } | undefined;
                        input?: {
                            required?: boolean | undefined;
                            validators?: [{
                                type: "number";
                                range: [number, number];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            }] | undefined;
                            defaultValue?: number | undefined;
                        } | undefined;
                    }[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    delimiter?: string | undefined;
                    groups?: {
                        label: string;
                        fields: string[];
                        options?: {
                            isExpandable?: boolean | undefined;
                            expand?: boolean | undefined;
                        } | undefined;
                    }[] | undefined;
                }, {
                    rows: {
                        field: string;
                        checkbox?: {
                            label?: string | undefined;
                            defaultValue?: boolean | undefined;
                        } | undefined;
                        input?: {
                            required?: boolean | undefined;
                            validators?: [{
                                type: "number";
                                range: [number, number];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            }] | undefined;
                            defaultValue?: number | undefined;
                        } | undefined;
                    }[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    delimiter?: string | undefined;
                    groups?: {
                        label: string;
                        fields: string[];
                        options?: {
                            isExpandable?: boolean | undefined;
                            expand?: boolean | undefined;
                        } | undefined;
                    }[] | undefined;
                }>;
            }, "strip", z.ZodTypeAny, {
                options: {
                    rows: {
                        field: string;
                        checkbox?: {
                            label?: string | undefined;
                            defaultValue?: boolean | undefined;
                        } | undefined;
                        input?: {
                            required?: boolean | undefined;
                            validators?: [{
                                type: "number";
                                range: [number, number];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            }] | undefined;
                            defaultValue?: number | undefined;
                        } | undefined;
                    }[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    delimiter?: string | undefined;
                    groups?: {
                        label: string;
                        fields: string[];
                        options?: {
                            isExpandable?: boolean | undefined;
                            expand?: boolean | undefined;
                        } | undefined;
                    }[] | undefined;
                };
                type: "checkboxGroup";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: [{
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }] | undefined;
                defaultValue?: number | boolean | undefined;
            }, {
                options: {
                    rows: {
                        field: string;
                        checkbox?: {
                            label?: string | undefined;
                            defaultValue?: boolean | undefined;
                        } | undefined;
                        input?: {
                            required?: boolean | undefined;
                            validators?: [{
                                type: "number";
                                range: [number, number];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            }] | undefined;
                            defaultValue?: number | undefined;
                        } | undefined;
                    }[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    delimiter?: string | undefined;
                    groups?: {
                        label: string;
                        fields: string[];
                        options?: {
                            isExpandable?: boolean | undefined;
                            expand?: boolean | undefined;
                        } | undefined;
                    }[] | undefined;
                };
                type: "checkboxGroup";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: [{
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }] | undefined;
                defaultValue?: number | boolean | undefined;
            }>, z.ZodObject<{
                field: z.ZodString;
                label: z.ZodString;
                help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                    text: z.ZodString;
                    links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        slug: z.ZodString;
                        link: z.ZodString;
                        linkText: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }>, "many">>;
                    link: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }>]>>;
                tooltip: z.ZodOptional<z.ZodString>;
                required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            } & {
                type: z.ZodLiteral<"checkboxTree">;
                validators: z.ZodOptional<z.ZodTuple<[z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"regex">;
                    pattern: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }, {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }>], null>>;
                defaultValue: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodBoolean]>>;
                options: z.ZodObject<{
                    display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
                } & {
                    delimiter: z.ZodOptional<z.ZodString>;
                    groups: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        label: z.ZodString;
                        fields: z.ZodArray<z.ZodString, "many">;
                        options: z.ZodOptional<z.ZodObject<{
                            isExpandable: z.ZodOptional<z.ZodBoolean>;
                            expand: z.ZodOptional<z.ZodBoolean>;
                        }, "strip", z.ZodTypeAny, {
                            isExpandable?: boolean | undefined;
                            expand?: boolean | undefined;
                        }, {
                            isExpandable?: boolean | undefined;
                            expand?: boolean | undefined;
                        }>>;
                    }, "strip", z.ZodTypeAny, {
                        label: string;
                        fields: string[];
                        options?: {
                            isExpandable?: boolean | undefined;
                            expand?: boolean | undefined;
                        } | undefined;
                    }, {
                        label: string;
                        fields: string[];
                        options?: {
                            isExpandable?: boolean | undefined;
                            expand?: boolean | undefined;
                        } | undefined;
                    }>, "many">>;
                    rows: z.ZodArray<z.ZodObject<{
                        field: z.ZodString;
                        checkbox: z.ZodOptional<z.ZodObject<{
                            label: z.ZodOptional<z.ZodString>;
                            defaultValue: z.ZodOptional<z.ZodBoolean>;
                        }, "strip", z.ZodTypeAny, {
                            label?: string | undefined;
                            defaultValue?: boolean | undefined;
                        }, {
                            label?: string | undefined;
                            defaultValue?: boolean | undefined;
                        }>>;
                    }, "strip", z.ZodTypeAny, {
                        field: string;
                        checkbox?: {
                            label?: string | undefined;
                            defaultValue?: boolean | undefined;
                        } | undefined;
                    }, {
                        field: string;
                        checkbox?: {
                            label?: string | undefined;
                            defaultValue?: boolean | undefined;
                        } | undefined;
                    }>, "many">;
                }, "strip", z.ZodTypeAny, {
                    rows: {
                        field: string;
                        checkbox?: {
                            label?: string | undefined;
                            defaultValue?: boolean | undefined;
                        } | undefined;
                    }[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    delimiter?: string | undefined;
                    groups?: {
                        label: string;
                        fields: string[];
                        options?: {
                            isExpandable?: boolean | undefined;
                            expand?: boolean | undefined;
                        } | undefined;
                    }[] | undefined;
                }, {
                    rows: {
                        field: string;
                        checkbox?: {
                            label?: string | undefined;
                            defaultValue?: boolean | undefined;
                        } | undefined;
                    }[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    delimiter?: string | undefined;
                    groups?: {
                        label: string;
                        fields: string[];
                        options?: {
                            isExpandable?: boolean | undefined;
                            expand?: boolean | undefined;
                        } | undefined;
                    }[] | undefined;
                }>;
            }, "strip", z.ZodTypeAny, {
                options: {
                    rows: {
                        field: string;
                        checkbox?: {
                            label?: string | undefined;
                            defaultValue?: boolean | undefined;
                        } | undefined;
                    }[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    delimiter?: string | undefined;
                    groups?: {
                        label: string;
                        fields: string[];
                        options?: {
                            isExpandable?: boolean | undefined;
                            expand?: boolean | undefined;
                        } | undefined;
                    }[] | undefined;
                };
                type: "checkboxTree";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: [{
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }] | undefined;
                defaultValue?: number | boolean | undefined;
            }, {
                options: {
                    rows: {
                        field: string;
                        checkbox?: {
                            label?: string | undefined;
                            defaultValue?: boolean | undefined;
                        } | undefined;
                    }[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    delimiter?: string | undefined;
                    groups?: {
                        label: string;
                        fields: string[];
                        options?: {
                            isExpandable?: boolean | undefined;
                            expand?: boolean | undefined;
                        } | undefined;
                    }[] | undefined;
                };
                type: "checkboxTree";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: [{
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }] | undefined;
                defaultValue?: number | boolean | undefined;
            }>, z.ZodObject<{
                field: z.ZodString;
                label: z.ZodString;
                help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                    text: z.ZodString;
                    links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        slug: z.ZodString;
                        link: z.ZodString;
                        linkText: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }>, "many">>;
                    link: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }>]>>;
                tooltip: z.ZodOptional<z.ZodString>;
                required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            } & {
                type: z.ZodLiteral<"radio">;
                defaultValue: z.ZodOptional<z.ZodString>;
                options: z.ZodObject<{
                    display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
                } & {
                    items: z.ZodArray<z.ZodObject<{
                        value: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                        label: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        value: string | number | boolean;
                        label: string;
                    }, {
                        value: string | number | boolean;
                        label: string;
                    }>, "many">;
                }, "strip", z.ZodTypeAny, {
                    items: {
                        value: string | number | boolean;
                        label: string;
                    }[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                }, {
                    items: {
                        value: string | number | boolean;
                        label: string;
                    }[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                }>;
                modifyFieldsOnValue: z.ZodOptional<z.ZodArray<z.ZodObject<{
                    fieldValue: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                    mode: z.ZodOptional<z.ZodEnum<["create", "edit", "config", "clone"]>>;
                    fieldsToModify: z.ZodArray<z.ZodObject<{
                        fieldId: z.ZodString;
                        display: z.ZodOptional<z.ZodBoolean>;
                        value: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>>;
                        disabled: z.ZodOptional<z.ZodBoolean>;
                        required: z.ZodOptional<z.ZodBoolean>;
                        help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                            text: z.ZodString;
                            links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                slug: z.ZodString;
                                link: z.ZodString;
                                linkText: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                slug: string;
                                link: string;
                                linkText: string;
                            }, {
                                slug: string;
                                link: string;
                                linkText: string;
                            }>, "many">>;
                            link: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        }, {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        }>]>>;
                        label: z.ZodOptional<z.ZodString>;
                        markdownMessage: z.ZodOptional<z.ZodUnion<[z.ZodObject<{
                            markdownType: z.ZodLiteral<"text">;
                            text: z.ZodString;
                            color: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        }, {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        }>, z.ZodObject<{
                            markdownType: z.ZodLiteral<"hybrid">;
                            text: z.ZodString;
                            token: z.ZodString;
                            linkText: z.ZodString;
                            link: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        }, {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        }>, z.ZodObject<{
                            markdownType: z.ZodLiteral<"link">;
                            text: z.ZodString;
                            link: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            link: string;
                            markdownType: "link";
                        }, {
                            text: string;
                            link: string;
                            markdownType: "link";
                        }>, z.ZodObject<{
                            markdownType: z.ZodOptional<z.ZodUndefined>;
                            text: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            markdownType?: undefined;
                        }, {
                            text: string;
                            markdownType?: undefined;
                        }>]>>;
                    }, "strip", z.ZodTypeAny, {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }, {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }>, "many">;
                }, "strip", z.ZodTypeAny, {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }, {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }>, "many">>;
            }, "strip", z.ZodTypeAny, {
                options: {
                    items: {
                        value: string | number | boolean;
                        label: string;
                    }[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                };
                type: "radio";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            }, {
                options: {
                    items: {
                        value: string | number | boolean;
                        label: string;
                    }[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                };
                type: "radio";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            }>, z.ZodObject<{
                field: z.ZodString;
                label: z.ZodString;
                help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                    text: z.ZodString;
                    links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        slug: z.ZodString;
                        link: z.ZodString;
                        linkText: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }>, "many">>;
                    link: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }>]>>;
                tooltip: z.ZodOptional<z.ZodString>;
                required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            } & {
                type: z.ZodLiteral<"file">;
                defaultValue: z.ZodOptional<z.ZodString>;
                validators: z.ZodOptional<z.ZodArray<z.ZodUnion<[z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"string">;
                    minLength: z.ZodNumber;
                    maxLength: z.ZodNumber;
                }, "strip", z.ZodTypeAny, {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                }, {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"regex">;
                    pattern: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }, {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }>]>, "many">>;
                options: z.ZodOptional<z.ZodObject<{
                    display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
                } & {
                    maxFileSize: z.ZodOptional<z.ZodNumber>;
                    fileSupportMessage: z.ZodOptional<z.ZodString>;
                    supportedFileTypes: z.ZodArray<z.ZodString, "many">;
                    useBase64Encoding: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                }, "strip", z.ZodTypeAny, {
                    supportedFileTypes: string[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    maxFileSize?: number | undefined;
                    fileSupportMessage?: string | undefined;
                    useBase64Encoding?: boolean | undefined;
                }, {
                    supportedFileTypes: string[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    maxFileSize?: number | undefined;
                    fileSupportMessage?: string | undefined;
                    useBase64Encoding?: boolean | undefined;
                }>>;
                modifyFieldsOnValue: z.ZodOptional<z.ZodArray<z.ZodObject<{
                    fieldValue: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                    mode: z.ZodOptional<z.ZodEnum<["create", "edit", "config", "clone"]>>;
                    fieldsToModify: z.ZodArray<z.ZodObject<{
                        fieldId: z.ZodString;
                        display: z.ZodOptional<z.ZodBoolean>;
                        value: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>>;
                        disabled: z.ZodOptional<z.ZodBoolean>;
                        required: z.ZodOptional<z.ZodBoolean>;
                        help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                            text: z.ZodString;
                            links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                slug: z.ZodString;
                                link: z.ZodString;
                                linkText: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                slug: string;
                                link: string;
                                linkText: string;
                            }, {
                                slug: string;
                                link: string;
                                linkText: string;
                            }>, "many">>;
                            link: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        }, {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        }>]>>;
                        label: z.ZodOptional<z.ZodString>;
                        markdownMessage: z.ZodOptional<z.ZodUnion<[z.ZodObject<{
                            markdownType: z.ZodLiteral<"text">;
                            text: z.ZodString;
                            color: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        }, {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        }>, z.ZodObject<{
                            markdownType: z.ZodLiteral<"hybrid">;
                            text: z.ZodString;
                            token: z.ZodString;
                            linkText: z.ZodString;
                            link: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        }, {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        }>, z.ZodObject<{
                            markdownType: z.ZodLiteral<"link">;
                            text: z.ZodString;
                            link: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            link: string;
                            markdownType: "link";
                        }, {
                            text: string;
                            link: string;
                            markdownType: "link";
                        }>, z.ZodObject<{
                            markdownType: z.ZodOptional<z.ZodUndefined>;
                            text: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            markdownType?: undefined;
                        }, {
                            text: string;
                            markdownType?: undefined;
                        }>]>>;
                    }, "strip", z.ZodTypeAny, {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }, {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }>, "many">;
                }, "strip", z.ZodTypeAny, {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }, {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }>, "many">>;
            }, "strip", z.ZodTypeAny, {
                type: "file";
                label: string;
                field: string;
                options?: {
                    supportedFileTypes: string[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    maxFileSize?: number | undefined;
                    fileSupportMessage?: string | undefined;
                    useBase64Encoding?: boolean | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            }, {
                type: "file";
                label: string;
                field: string;
                options?: {
                    supportedFileTypes: string[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    maxFileSize?: number | undefined;
                    fileSupportMessage?: string | undefined;
                    useBase64Encoding?: boolean | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            }>, z.ZodObject<{
                field: z.ZodString;
                label: z.ZodString;
                help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                    text: z.ZodString;
                    links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        slug: z.ZodString;
                        link: z.ZodString;
                        linkText: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }>, "many">>;
                    link: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }>]>>;
                tooltip: z.ZodOptional<z.ZodString>;
                required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            } & {
                type: z.ZodLiteral<"oauth">;
                defaultValue: z.ZodOptional<z.ZodString>;
                validators: z.ZodOptional<z.ZodArray<z.ZodUnion<[z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"string">;
                    minLength: z.ZodNumber;
                    maxLength: z.ZodNumber;
                }, "strip", z.ZodTypeAny, {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                }, {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"regex">;
                    pattern: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }, {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }>]>, "many">>;
                options: z.ZodObject<Omit<{
                    display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
                }, "requiredWhenVisible"> & {
                    auth_type: z.ZodArray<z.ZodUnion<[z.ZodLiteral<"basic">, z.ZodLiteral<"oauth">, z.ZodLiteral<"oauth_client_credentials">]>, "many">;
                    basic: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        oauth_field: z.ZodString;
                        label: z.ZodString;
                        field: z.ZodString;
                        type: z.ZodOptional<z.ZodDefault<z.ZodLiteral<"text">>>;
                        help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                            text: z.ZodString;
                            links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                slug: z.ZodString;
                                link: z.ZodString;
                                linkText: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                slug: string;
                                link: string;
                                linkText: string;
                            }, {
                                slug: string;
                                link: string;
                                linkText: string;
                            }>, "many">>;
                            link: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        }, {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        }>]>>;
                        encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        defaultValue: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodNumber, z.ZodBoolean]>>;
                        options: z.ZodOptional<z.ZodObject<{
                            display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                            disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                            enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                            requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                            hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
                        }, "strip", z.ZodTypeAny, {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        }, {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        }>>;
                        modifyFieldsOnValue: z.ZodOptional<z.ZodArray<z.ZodObject<{
                            fieldValue: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                            mode: z.ZodOptional<z.ZodEnum<["create", "edit", "config", "clone"]>>;
                            fieldsToModify: z.ZodArray<z.ZodObject<{
                                fieldId: z.ZodString;
                                display: z.ZodOptional<z.ZodBoolean>;
                                value: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>>;
                                disabled: z.ZodOptional<z.ZodBoolean>;
                                required: z.ZodOptional<z.ZodBoolean>;
                                help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                                    text: z.ZodString;
                                    links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                        slug: z.ZodString;
                                        link: z.ZodString;
                                        linkText: z.ZodString;
                                    }, "strip", z.ZodTypeAny, {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }, {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }>, "many">>;
                                    link: z.ZodOptional<z.ZodString>;
                                }, "strip", z.ZodTypeAny, {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                }, {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                }>]>>;
                                label: z.ZodOptional<z.ZodString>;
                                markdownMessage: z.ZodOptional<z.ZodUnion<[z.ZodObject<{
                                    markdownType: z.ZodLiteral<"text">;
                                    text: z.ZodString;
                                    color: z.ZodOptional<z.ZodString>;
                                }, "strip", z.ZodTypeAny, {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                }, {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                }>, z.ZodObject<{
                                    markdownType: z.ZodLiteral<"hybrid">;
                                    text: z.ZodString;
                                    token: z.ZodString;
                                    linkText: z.ZodString;
                                    link: z.ZodString;
                                }, "strip", z.ZodTypeAny, {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                }, {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                }>, z.ZodObject<{
                                    markdownType: z.ZodLiteral<"link">;
                                    text: z.ZodString;
                                    link: z.ZodString;
                                }, "strip", z.ZodTypeAny, {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                }, {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                }>, z.ZodObject<{
                                    markdownType: z.ZodOptional<z.ZodUndefined>;
                                    text: z.ZodString;
                                }, "strip", z.ZodTypeAny, {
                                    text: string;
                                    markdownType?: undefined;
                                }, {
                                    text: string;
                                    markdownType?: undefined;
                                }>]>>;
                            }, "strip", z.ZodTypeAny, {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }, {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }>, "many">;
                        }, "strip", z.ZodTypeAny, {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }, {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }>, "many">>;
                        validators: z.ZodOptional<z.ZodArray<z.ZodUnion<[z.ZodObject<{
                            errorMsg: z.ZodOptional<z.ZodString>;
                            type: z.ZodLiteral<"number">;
                            range: z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>;
                            isInteger: z.ZodOptional<z.ZodBoolean>;
                        }, "strip", z.ZodTypeAny, {
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        }, {
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        }>, z.ZodObject<{
                            errorMsg: z.ZodOptional<z.ZodString>;
                            type: z.ZodLiteral<"string">;
                            minLength: z.ZodNumber;
                            maxLength: z.ZodNumber;
                        }, "strip", z.ZodTypeAny, {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        }, {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        }>, z.ZodObject<{
                            errorMsg: z.ZodOptional<z.ZodString>;
                            type: z.ZodLiteral<"regex">;
                            pattern: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        }, {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        }>, z.ZodObject<{
                            errorMsg: z.ZodOptional<z.ZodString>;
                            type: z.ZodLiteral<"email">;
                        }, "strip", z.ZodTypeAny, {
                            type: "email";
                            errorMsg?: string | undefined;
                        }, {
                            type: "email";
                            errorMsg?: string | undefined;
                        }>, z.ZodObject<{
                            errorMsg: z.ZodOptional<z.ZodString>;
                            type: z.ZodLiteral<"ipv4">;
                        }, "strip", z.ZodTypeAny, {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        }, {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        }>, z.ZodObject<{
                            errorMsg: z.ZodOptional<z.ZodString>;
                            type: z.ZodLiteral<"url">;
                        }, "strip", z.ZodTypeAny, {
                            type: "url";
                            errorMsg?: string | undefined;
                        }, {
                            type: "url";
                            errorMsg?: string | undefined;
                        }>, z.ZodObject<{
                            errorMsg: z.ZodOptional<z.ZodString>;
                            type: z.ZodLiteral<"date">;
                        }, "strip", z.ZodTypeAny, {
                            type: "date";
                            errorMsg?: string | undefined;
                        }, {
                            type: "date";
                            errorMsg?: string | undefined;
                        }>]>, "many">>;
                    }, "strip", z.ZodTypeAny, {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }, {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }>, "many">>;
                    oauth: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        oauth_field: z.ZodString;
                        label: z.ZodString;
                        field: z.ZodString;
                        type: z.ZodOptional<z.ZodDefault<z.ZodLiteral<"text">>>;
                        help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                            text: z.ZodString;
                            links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                slug: z.ZodString;
                                link: z.ZodString;
                                linkText: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                slug: string;
                                link: string;
                                linkText: string;
                            }, {
                                slug: string;
                                link: string;
                                linkText: string;
                            }>, "many">>;
                            link: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        }, {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        }>]>>;
                        encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        defaultValue: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodNumber, z.ZodBoolean]>>;
                        options: z.ZodOptional<z.ZodObject<{
                            display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                            disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                            enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                            requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                            hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
                        }, "strip", z.ZodTypeAny, {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        }, {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        }>>;
                        modifyFieldsOnValue: z.ZodOptional<z.ZodArray<z.ZodObject<{
                            fieldValue: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                            mode: z.ZodOptional<z.ZodEnum<["create", "edit", "config", "clone"]>>;
                            fieldsToModify: z.ZodArray<z.ZodObject<{
                                fieldId: z.ZodString;
                                display: z.ZodOptional<z.ZodBoolean>;
                                value: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>>;
                                disabled: z.ZodOptional<z.ZodBoolean>;
                                required: z.ZodOptional<z.ZodBoolean>;
                                help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                                    text: z.ZodString;
                                    links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                        slug: z.ZodString;
                                        link: z.ZodString;
                                        linkText: z.ZodString;
                                    }, "strip", z.ZodTypeAny, {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }, {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }>, "many">>;
                                    link: z.ZodOptional<z.ZodString>;
                                }, "strip", z.ZodTypeAny, {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                }, {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                }>]>>;
                                label: z.ZodOptional<z.ZodString>;
                                markdownMessage: z.ZodOptional<z.ZodUnion<[z.ZodObject<{
                                    markdownType: z.ZodLiteral<"text">;
                                    text: z.ZodString;
                                    color: z.ZodOptional<z.ZodString>;
                                }, "strip", z.ZodTypeAny, {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                }, {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                }>, z.ZodObject<{
                                    markdownType: z.ZodLiteral<"hybrid">;
                                    text: z.ZodString;
                                    token: z.ZodString;
                                    linkText: z.ZodString;
                                    link: z.ZodString;
                                }, "strip", z.ZodTypeAny, {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                }, {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                }>, z.ZodObject<{
                                    markdownType: z.ZodLiteral<"link">;
                                    text: z.ZodString;
                                    link: z.ZodString;
                                }, "strip", z.ZodTypeAny, {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                }, {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                }>, z.ZodObject<{
                                    markdownType: z.ZodOptional<z.ZodUndefined>;
                                    text: z.ZodString;
                                }, "strip", z.ZodTypeAny, {
                                    text: string;
                                    markdownType?: undefined;
                                }, {
                                    text: string;
                                    markdownType?: undefined;
                                }>]>>;
                            }, "strip", z.ZodTypeAny, {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }, {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }>, "many">;
                        }, "strip", z.ZodTypeAny, {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }, {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }>, "many">>;
                        validators: z.ZodOptional<z.ZodArray<z.ZodUnion<[z.ZodObject<{
                            errorMsg: z.ZodOptional<z.ZodString>;
                            type: z.ZodLiteral<"number">;
                            range: z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>;
                            isInteger: z.ZodOptional<z.ZodBoolean>;
                        }, "strip", z.ZodTypeAny, {
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        }, {
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        }>, z.ZodObject<{
                            errorMsg: z.ZodOptional<z.ZodString>;
                            type: z.ZodLiteral<"string">;
                            minLength: z.ZodNumber;
                            maxLength: z.ZodNumber;
                        }, "strip", z.ZodTypeAny, {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        }, {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        }>, z.ZodObject<{
                            errorMsg: z.ZodOptional<z.ZodString>;
                            type: z.ZodLiteral<"regex">;
                            pattern: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        }, {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        }>, z.ZodObject<{
                            errorMsg: z.ZodOptional<z.ZodString>;
                            type: z.ZodLiteral<"email">;
                        }, "strip", z.ZodTypeAny, {
                            type: "email";
                            errorMsg?: string | undefined;
                        }, {
                            type: "email";
                            errorMsg?: string | undefined;
                        }>, z.ZodObject<{
                            errorMsg: z.ZodOptional<z.ZodString>;
                            type: z.ZodLiteral<"ipv4">;
                        }, "strip", z.ZodTypeAny, {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        }, {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        }>, z.ZodObject<{
                            errorMsg: z.ZodOptional<z.ZodString>;
                            type: z.ZodLiteral<"url">;
                        }, "strip", z.ZodTypeAny, {
                            type: "url";
                            errorMsg?: string | undefined;
                        }, {
                            type: "url";
                            errorMsg?: string | undefined;
                        }>, z.ZodObject<{
                            errorMsg: z.ZodOptional<z.ZodString>;
                            type: z.ZodLiteral<"date">;
                        }, "strip", z.ZodTypeAny, {
                            type: "date";
                            errorMsg?: string | undefined;
                        }, {
                            type: "date";
                            errorMsg?: string | undefined;
                        }>]>, "many">>;
                    }, "strip", z.ZodTypeAny, {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }, {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }>, "many">>;
                    oauth_client_credentials: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        oauth_field: z.ZodString;
                        label: z.ZodString;
                        field: z.ZodString;
                        type: z.ZodOptional<z.ZodDefault<z.ZodLiteral<"text">>>;
                        help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                            text: z.ZodString;
                            links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                slug: z.ZodString;
                                link: z.ZodString;
                                linkText: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                slug: string;
                                link: string;
                                linkText: string;
                            }, {
                                slug: string;
                                link: string;
                                linkText: string;
                            }>, "many">>;
                            link: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        }, {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        }>]>>;
                        encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                        defaultValue: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodNumber, z.ZodBoolean]>>;
                        options: z.ZodOptional<z.ZodObject<{
                            display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                            disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                            enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                            requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                            hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
                        }, "strip", z.ZodTypeAny, {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        }, {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        }>>;
                        modifyFieldsOnValue: z.ZodOptional<z.ZodArray<z.ZodObject<{
                            fieldValue: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                            mode: z.ZodOptional<z.ZodEnum<["create", "edit", "config", "clone"]>>;
                            fieldsToModify: z.ZodArray<z.ZodObject<{
                                fieldId: z.ZodString;
                                display: z.ZodOptional<z.ZodBoolean>;
                                value: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>>;
                                disabled: z.ZodOptional<z.ZodBoolean>;
                                required: z.ZodOptional<z.ZodBoolean>;
                                help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                                    text: z.ZodString;
                                    links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                        slug: z.ZodString;
                                        link: z.ZodString;
                                        linkText: z.ZodString;
                                    }, "strip", z.ZodTypeAny, {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }, {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }>, "many">>;
                                    link: z.ZodOptional<z.ZodString>;
                                }, "strip", z.ZodTypeAny, {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                }, {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                }>]>>;
                                label: z.ZodOptional<z.ZodString>;
                                markdownMessage: z.ZodOptional<z.ZodUnion<[z.ZodObject<{
                                    markdownType: z.ZodLiteral<"text">;
                                    text: z.ZodString;
                                    color: z.ZodOptional<z.ZodString>;
                                }, "strip", z.ZodTypeAny, {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                }, {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                }>, z.ZodObject<{
                                    markdownType: z.ZodLiteral<"hybrid">;
                                    text: z.ZodString;
                                    token: z.ZodString;
                                    linkText: z.ZodString;
                                    link: z.ZodString;
                                }, "strip", z.ZodTypeAny, {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                }, {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                }>, z.ZodObject<{
                                    markdownType: z.ZodLiteral<"link">;
                                    text: z.ZodString;
                                    link: z.ZodString;
                                }, "strip", z.ZodTypeAny, {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                }, {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                }>, z.ZodObject<{
                                    markdownType: z.ZodOptional<z.ZodUndefined>;
                                    text: z.ZodString;
                                }, "strip", z.ZodTypeAny, {
                                    text: string;
                                    markdownType?: undefined;
                                }, {
                                    text: string;
                                    markdownType?: undefined;
                                }>]>>;
                            }, "strip", z.ZodTypeAny, {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }, {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }>, "many">;
                        }, "strip", z.ZodTypeAny, {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }, {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }>, "many">>;
                        validators: z.ZodOptional<z.ZodArray<z.ZodUnion<[z.ZodObject<{
                            errorMsg: z.ZodOptional<z.ZodString>;
                            type: z.ZodLiteral<"number">;
                            range: z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>;
                            isInteger: z.ZodOptional<z.ZodBoolean>;
                        }, "strip", z.ZodTypeAny, {
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        }, {
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        }>, z.ZodObject<{
                            errorMsg: z.ZodOptional<z.ZodString>;
                            type: z.ZodLiteral<"string">;
                            minLength: z.ZodNumber;
                            maxLength: z.ZodNumber;
                        }, "strip", z.ZodTypeAny, {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        }, {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        }>, z.ZodObject<{
                            errorMsg: z.ZodOptional<z.ZodString>;
                            type: z.ZodLiteral<"regex">;
                            pattern: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        }, {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        }>, z.ZodObject<{
                            errorMsg: z.ZodOptional<z.ZodString>;
                            type: z.ZodLiteral<"email">;
                        }, "strip", z.ZodTypeAny, {
                            type: "email";
                            errorMsg?: string | undefined;
                        }, {
                            type: "email";
                            errorMsg?: string | undefined;
                        }>, z.ZodObject<{
                            errorMsg: z.ZodOptional<z.ZodString>;
                            type: z.ZodLiteral<"ipv4">;
                        }, "strip", z.ZodTypeAny, {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        }, {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        }>, z.ZodObject<{
                            errorMsg: z.ZodOptional<z.ZodString>;
                            type: z.ZodLiteral<"url">;
                        }, "strip", z.ZodTypeAny, {
                            type: "url";
                            errorMsg?: string | undefined;
                        }, {
                            type: "url";
                            errorMsg?: string | undefined;
                        }>, z.ZodObject<{
                            errorMsg: z.ZodOptional<z.ZodString>;
                            type: z.ZodLiteral<"date">;
                        }, "strip", z.ZodTypeAny, {
                            type: "date";
                            errorMsg?: string | undefined;
                        }, {
                            type: "date";
                            errorMsg?: string | undefined;
                        }>]>, "many">>;
                    }, "strip", z.ZodTypeAny, {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }, {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }>, "many">>;
                    auth_label: z.ZodOptional<z.ZodString>;
                    oauth_popup_width: z.ZodOptional<z.ZodNumber>;
                    oauth_popup_height: z.ZodOptional<z.ZodNumber>;
                    oauth_timeout: z.ZodOptional<z.ZodNumber>;
                    auth_code_endpoint: z.ZodOptional<z.ZodString>;
                    access_token_endpoint: z.ZodOptional<z.ZodString>;
                    oauth_state_enabled: z.ZodOptional<z.ZodBoolean>;
                    auth_endpoint_token_access_type: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    auth_type: ("oauth" | "basic" | "oauth_client_credentials")[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    oauth?: {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }[] | undefined;
                    basic?: {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }[] | undefined;
                    oauth_client_credentials?: {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }[] | undefined;
                    auth_label?: string | undefined;
                    oauth_popup_width?: number | undefined;
                    oauth_popup_height?: number | undefined;
                    oauth_timeout?: number | undefined;
                    auth_code_endpoint?: string | undefined;
                    access_token_endpoint?: string | undefined;
                    oauth_state_enabled?: boolean | undefined;
                    auth_endpoint_token_access_type?: string | undefined;
                }, {
                    auth_type: ("oauth" | "basic" | "oauth_client_credentials")[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    oauth?: {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }[] | undefined;
                    basic?: {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }[] | undefined;
                    oauth_client_credentials?: {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }[] | undefined;
                    auth_label?: string | undefined;
                    oauth_popup_width?: number | undefined;
                    oauth_popup_height?: number | undefined;
                    oauth_timeout?: number | undefined;
                    auth_code_endpoint?: string | undefined;
                    access_token_endpoint?: string | undefined;
                    oauth_state_enabled?: boolean | undefined;
                    auth_endpoint_token_access_type?: string | undefined;
                }>;
            }, "strip", z.ZodTypeAny, {
                options: {
                    auth_type: ("oauth" | "basic" | "oauth_client_credentials")[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    oauth?: {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }[] | undefined;
                    basic?: {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }[] | undefined;
                    oauth_client_credentials?: {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }[] | undefined;
                    auth_label?: string | undefined;
                    oauth_popup_width?: number | undefined;
                    oauth_popup_height?: number | undefined;
                    oauth_timeout?: number | undefined;
                    auth_code_endpoint?: string | undefined;
                    access_token_endpoint?: string | undefined;
                    oauth_state_enabled?: boolean | undefined;
                    auth_endpoint_token_access_type?: string | undefined;
                };
                type: "oauth";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
            }, {
                options: {
                    auth_type: ("oauth" | "basic" | "oauth_client_credentials")[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    oauth?: {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }[] | undefined;
                    basic?: {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }[] | undefined;
                    oauth_client_credentials?: {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }[] | undefined;
                    auth_label?: string | undefined;
                    oauth_popup_width?: number | undefined;
                    oauth_popup_height?: number | undefined;
                    oauth_timeout?: number | undefined;
                    auth_code_endpoint?: string | undefined;
                    access_token_endpoint?: string | undefined;
                    oauth_state_enabled?: boolean | undefined;
                    auth_endpoint_token_access_type?: string | undefined;
                };
                type: "oauth";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
            }>, z.ZodObject<{
                field: z.ZodString;
                label: z.ZodString;
                help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                    text: z.ZodString;
                    links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        slug: z.ZodString;
                        link: z.ZodString;
                        linkText: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }>, "many">>;
                    link: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }>]>>;
                tooltip: z.ZodOptional<z.ZodString>;
                required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            } & {
                type: z.ZodLiteral<"custom">;
                options: z.ZodObject<{
                    type: z.ZodLiteral<"external">;
                    src: z.ZodString;
                    hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
                }, "strip", z.ZodTypeAny, {
                    type: "external";
                    src: string;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                }, {
                    type: "external";
                    src: string;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                }>;
            }, "strip", z.ZodTypeAny, {
                options: {
                    type: "external";
                    src: string;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                };
                type: "custom";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
            }, {
                options: {
                    type: "external";
                    src: string;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                };
                type: "custom";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
            }>]>, "many">;
            options: z.ZodOptional<z.ZodObject<{
                saveValidator: z.ZodOptional<z.ZodString>;
            }, "strip", z.ZodTypeAny, {
                saveValidator?: string | undefined;
            }, {
                saveValidator?: string | undefined;
            }>>;
            groups: z.ZodOptional<z.ZodArray<z.ZodObject<{
                options: z.ZodOptional<z.ZodObject<{
                    isExpandable: z.ZodOptional<z.ZodBoolean>;
                    expand: z.ZodOptional<z.ZodBoolean>;
                }, "strip", z.ZodTypeAny, {
                    isExpandable?: boolean | undefined;
                    expand?: boolean | undefined;
                }, {
                    isExpandable?: boolean | undefined;
                    expand?: boolean | undefined;
                }>>;
                label: z.ZodString;
                fields: z.ZodArray<z.ZodString, "many">;
            }, "strip", z.ZodTypeAny, {
                label: string;
                fields: string[];
                options?: {
                    isExpandable?: boolean | undefined;
                    expand?: boolean | undefined;
                } | undefined;
            }, {
                label: string;
                fields: string[];
                options?: {
                    isExpandable?: boolean | undefined;
                    expand?: boolean | undefined;
                } | undefined;
            }>, "many">>;
            style: z.ZodOptional<z.ZodEnum<["page", "dialog"]>>;
            hook: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>;
            conf: z.ZodOptional<z.ZodString>;
            restHandlerName: z.ZodOptional<z.ZodString>;
            restHandlerModule: z.ZodOptional<z.ZodString>;
            restHandlerClass: z.ZodOptional<z.ZodString>;
            warning: z.ZodOptional<z.ZodObject<{
                create: z.ZodOptional<z.ZodObject<{
                    message: z.ZodString;
                    alwaysDisplay: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                }, "strip", z.ZodTypeAny, {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                }, {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                }>>;
                edit: z.ZodOptional<z.ZodObject<{
                    message: z.ZodString;
                    alwaysDisplay: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                }, "strip", z.ZodTypeAny, {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                }, {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                }>>;
                config: z.ZodOptional<z.ZodObject<{
                    message: z.ZodString;
                    alwaysDisplay: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                }, "strip", z.ZodTypeAny, {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                }, {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                }>>;
                clone: z.ZodOptional<z.ZodObject<{
                    message: z.ZodString;
                    alwaysDisplay: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                }, "strip", z.ZodTypeAny, {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                }, {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                }>>;
            }, "strip", z.ZodTypeAny, {
                clone?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
                create?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
                edit?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
                config?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
            }, {
                clone?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
                create?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
                edit?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
                config?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
            }>>;
            inputHelperModule: z.ZodOptional<z.ZodString>;
            disableNewInput: z.ZodOptional<z.ZodBoolean>;
            hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
            formTitle: z.ZodOptional<z.ZodString>;
        }, "strict", z.ZodTypeAny, {
            name: string;
            entity: ({
                type: "helpLink";
                field: string;
                options?: {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: false | undefined;
            } | {
                type: "text";
                label: string;
                field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                type: "textarea";
                label: string;
                field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    rowsMin?: number | undefined;
                    rowsMax?: number | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                options: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    disableSearch?: boolean | undefined;
                    createSearchChoice?: boolean | undefined;
                    referenceName?: string | undefined;
                    endpointUrl?: string | undefined;
                    allowList?: string | undefined;
                    denyList?: string | undefined;
                    labelField?: string | undefined;
                    valueField?: string | undefined;
                    autoCompleteFields?: ({
                        value: string | number | boolean;
                        label: string;
                    } | {
                        label: string;
                        children: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                    })[] | undefined;
                    dependencies?: string[] | undefined;
                    items?: {
                        value: string | number | boolean;
                        label: string;
                    }[] | undefined;
                };
                type: "singleSelect";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                options: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    disableSearch?: boolean | undefined;
                    createSearchChoice?: boolean | undefined;
                    referenceName?: string | undefined;
                    endpointUrl?: string | undefined;
                    allowList?: string | undefined;
                    denyList?: string | undefined;
                    labelField?: string | undefined;
                    valueField?: string | undefined;
                    autoCompleteFields?: ({
                        value: string | number | boolean;
                        label: string;
                    } | {
                        label: string;
                        children: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                    })[] | undefined;
                    dependencies?: string[] | undefined;
                    items?: {
                        value: string | number | boolean;
                        label: string;
                    }[] | undefined;
                    delimiter?: string | undefined;
                };
                type: "multipleSelect";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                type: "checkbox";
                label: string;
                field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                defaultValue?: number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                options: {
                    rows: {
                        field: string;
                        checkbox?: {
                            label?: string | undefined;
                            defaultValue?: boolean | undefined;
                        } | undefined;
                        input?: {
                            required?: boolean | undefined;
                            validators?: [{
                                type: "number";
                                range: [number, number];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            }] | undefined;
                            defaultValue?: number | undefined;
                        } | undefined;
                    }[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    delimiter?: string | undefined;
                    groups?: {
                        label: string;
                        fields: string[];
                        options?: {
                            isExpandable?: boolean | undefined;
                            expand?: boolean | undefined;
                        } | undefined;
                    }[] | undefined;
                };
                type: "checkboxGroup";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: [{
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }] | undefined;
                defaultValue?: number | boolean | undefined;
            } | {
                options: {
                    rows: {
                        field: string;
                        checkbox?: {
                            label?: string | undefined;
                            defaultValue?: boolean | undefined;
                        } | undefined;
                    }[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    delimiter?: string | undefined;
                    groups?: {
                        label: string;
                        fields: string[];
                        options?: {
                            isExpandable?: boolean | undefined;
                            expand?: boolean | undefined;
                        } | undefined;
                    }[] | undefined;
                };
                type: "checkboxTree";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: [{
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }] | undefined;
                defaultValue?: number | boolean | undefined;
            } | {
                options: {
                    items: {
                        value: string | number | boolean;
                        label: string;
                    }[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                };
                type: "radio";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                type: "file";
                label: string;
                field: string;
                options?: {
                    supportedFileTypes: string[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    maxFileSize?: number | undefined;
                    fileSupportMessage?: string | undefined;
                    useBase64Encoding?: boolean | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                options: {
                    auth_type: ("oauth" | "basic" | "oauth_client_credentials")[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    oauth?: {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }[] | undefined;
                    basic?: {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }[] | undefined;
                    oauth_client_credentials?: {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }[] | undefined;
                    auth_label?: string | undefined;
                    oauth_popup_width?: number | undefined;
                    oauth_popup_height?: number | undefined;
                    oauth_timeout?: number | undefined;
                    auth_code_endpoint?: string | undefined;
                    access_token_endpoint?: string | undefined;
                    oauth_state_enabled?: boolean | undefined;
                    auth_endpoint_token_access_type?: string | undefined;
                };
                type: "oauth";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
            } | {
                options: {
                    type: "external";
                    src: string;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                };
                type: "custom";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
            })[];
            title: string;
            options?: {
                saveValidator?: string | undefined;
            } | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
            groups?: {
                label: string;
                fields: string[];
                options?: {
                    isExpandable?: boolean | undefined;
                    expand?: boolean | undefined;
                } | undefined;
            }[] | undefined;
            style?: "page" | "dialog" | undefined;
            hook?: Record<string, any> | undefined;
            conf?: string | undefined;
            restHandlerName?: string | undefined;
            restHandlerModule?: string | undefined;
            restHandlerClass?: string | undefined;
            warning?: {
                clone?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
                create?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
                edit?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
                config?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
            } | undefined;
            formTitle?: string | undefined;
            subTitle?: string | undefined;
            inputHelperModule?: string | undefined;
            disableNewInput?: boolean | undefined;
        }, {
            name: string;
            entity: ({
                type: "helpLink";
                field: string;
                options?: {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: false | undefined;
            } | {
                type: "text";
                label: string;
                field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                type: "textarea";
                label: string;
                field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    rowsMin?: number | undefined;
                    rowsMax?: number | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                options: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    disableSearch?: boolean | undefined;
                    createSearchChoice?: boolean | undefined;
                    referenceName?: string | undefined;
                    endpointUrl?: string | undefined;
                    allowList?: string | undefined;
                    denyList?: string | undefined;
                    labelField?: string | undefined;
                    valueField?: string | undefined;
                    autoCompleteFields?: ({
                        value: string | number | boolean;
                        label: string;
                    } | {
                        label: string;
                        children: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                    })[] | undefined;
                    dependencies?: string[] | undefined;
                    items?: {
                        value: string | number | boolean;
                        label: string;
                    }[] | undefined;
                };
                type: "singleSelect";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                options: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    disableSearch?: boolean | undefined;
                    createSearchChoice?: boolean | undefined;
                    referenceName?: string | undefined;
                    endpointUrl?: string | undefined;
                    allowList?: string | undefined;
                    denyList?: string | undefined;
                    labelField?: string | undefined;
                    valueField?: string | undefined;
                    autoCompleteFields?: ({
                        value: string | number | boolean;
                        label: string;
                    } | {
                        label: string;
                        children: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                    })[] | undefined;
                    dependencies?: string[] | undefined;
                    items?: {
                        value: string | number | boolean;
                        label: string;
                    }[] | undefined;
                    delimiter?: string | undefined;
                };
                type: "multipleSelect";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                type: "checkbox";
                label: string;
                field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                defaultValue?: number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                options: {
                    rows: {
                        field: string;
                        checkbox?: {
                            label?: string | undefined;
                            defaultValue?: boolean | undefined;
                        } | undefined;
                        input?: {
                            required?: boolean | undefined;
                            validators?: [{
                                type: "number";
                                range: [number, number];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            }] | undefined;
                            defaultValue?: number | undefined;
                        } | undefined;
                    }[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    delimiter?: string | undefined;
                    groups?: {
                        label: string;
                        fields: string[];
                        options?: {
                            isExpandable?: boolean | undefined;
                            expand?: boolean | undefined;
                        } | undefined;
                    }[] | undefined;
                };
                type: "checkboxGroup";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: [{
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }] | undefined;
                defaultValue?: number | boolean | undefined;
            } | {
                options: {
                    rows: {
                        field: string;
                        checkbox?: {
                            label?: string | undefined;
                            defaultValue?: boolean | undefined;
                        } | undefined;
                    }[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    delimiter?: string | undefined;
                    groups?: {
                        label: string;
                        fields: string[];
                        options?: {
                            isExpandable?: boolean | undefined;
                            expand?: boolean | undefined;
                        } | undefined;
                    }[] | undefined;
                };
                type: "checkboxTree";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: [{
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }] | undefined;
                defaultValue?: number | boolean | undefined;
            } | {
                options: {
                    items: {
                        value: string | number | boolean;
                        label: string;
                    }[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                };
                type: "radio";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                type: "file";
                label: string;
                field: string;
                options?: {
                    supportedFileTypes: string[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    maxFileSize?: number | undefined;
                    fileSupportMessage?: string | undefined;
                    useBase64Encoding?: boolean | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                options: {
                    auth_type: ("oauth" | "basic" | "oauth_client_credentials")[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    oauth?: {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }[] | undefined;
                    basic?: {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }[] | undefined;
                    oauth_client_credentials?: {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }[] | undefined;
                    auth_label?: string | undefined;
                    oauth_popup_width?: number | undefined;
                    oauth_popup_height?: number | undefined;
                    oauth_timeout?: number | undefined;
                    auth_code_endpoint?: string | undefined;
                    access_token_endpoint?: string | undefined;
                    oauth_state_enabled?: boolean | undefined;
                    auth_endpoint_token_access_type?: string | undefined;
                };
                type: "oauth";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
            } | {
                options: {
                    type: "external";
                    src: string;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                };
                type: "custom";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
            })[];
            title: string;
            options?: {
                saveValidator?: string | undefined;
            } | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
            groups?: {
                label: string;
                fields: string[];
                options?: {
                    isExpandable?: boolean | undefined;
                    expand?: boolean | undefined;
                } | undefined;
            }[] | undefined;
            style?: "page" | "dialog" | undefined;
            hook?: Record<string, any> | undefined;
            conf?: string | undefined;
            restHandlerName?: string | undefined;
            restHandlerModule?: string | undefined;
            restHandlerClass?: string | undefined;
            warning?: {
                clone?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
                create?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
                edit?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
                config?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
            } | undefined;
            formTitle?: string | undefined;
            subTitle?: string | undefined;
            inputHelperModule?: string | undefined;
            disableNewInput?: boolean | undefined;
        }>, "many">;
        hideFieldId: z.ZodOptional<z.ZodString>;
        readonlyFieldId: z.ZodOptional<z.ZodString>;
        useInputToggleConfirmation: z.ZodOptional<z.ZodBoolean>;
        inputsUniqueAcrossSingleService: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
    }, "strict", z.ZodTypeAny, {
        title: string;
        table: {
            header: {
                label: string;
                field: string;
                mapping?: Record<string, any> | undefined;
                customCell?: Record<string, any> | undefined;
            }[];
            actions: ("clone" | "delete" | "edit" | "search")[];
            moreInfo?: {
                label: string;
                field: string;
                mapping?: Record<string, any> | undefined;
            }[] | undefined;
            customRow?: Record<string, any> | undefined;
        };
        services: {
            name: string;
            entity: ({
                type: "helpLink";
                field: string;
                options?: {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: false | undefined;
            } | {
                type: "text";
                label: string;
                field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                type: "textarea";
                label: string;
                field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    rowsMin?: number | undefined;
                    rowsMax?: number | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                options: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    disableSearch?: boolean | undefined;
                    createSearchChoice?: boolean | undefined;
                    referenceName?: string | undefined;
                    endpointUrl?: string | undefined;
                    allowList?: string | undefined;
                    denyList?: string | undefined;
                    labelField?: string | undefined;
                    valueField?: string | undefined;
                    autoCompleteFields?: ({
                        value: string | number | boolean;
                        label: string;
                    } | {
                        label: string;
                        children: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                    })[] | undefined;
                    dependencies?: string[] | undefined;
                    items?: {
                        value: string | number | boolean;
                        label: string;
                    }[] | undefined;
                };
                type: "singleSelect";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                options: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    disableSearch?: boolean | undefined;
                    createSearchChoice?: boolean | undefined;
                    referenceName?: string | undefined;
                    endpointUrl?: string | undefined;
                    allowList?: string | undefined;
                    denyList?: string | undefined;
                    labelField?: string | undefined;
                    valueField?: string | undefined;
                    autoCompleteFields?: ({
                        value: string | number | boolean;
                        label: string;
                    } | {
                        label: string;
                        children: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                    })[] | undefined;
                    dependencies?: string[] | undefined;
                    items?: {
                        value: string | number | boolean;
                        label: string;
                    }[] | undefined;
                    delimiter?: string | undefined;
                };
                type: "multipleSelect";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                type: "checkbox";
                label: string;
                field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                defaultValue?: number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                options: {
                    rows: {
                        field: string;
                        checkbox?: {
                            label?: string | undefined;
                            defaultValue?: boolean | undefined;
                        } | undefined;
                        input?: {
                            required?: boolean | undefined;
                            validators?: [{
                                type: "number";
                                range: [number, number];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            }] | undefined;
                            defaultValue?: number | undefined;
                        } | undefined;
                    }[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    delimiter?: string | undefined;
                    groups?: {
                        label: string;
                        fields: string[];
                        options?: {
                            isExpandable?: boolean | undefined;
                            expand?: boolean | undefined;
                        } | undefined;
                    }[] | undefined;
                };
                type: "checkboxGroup";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: [{
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }] | undefined;
                defaultValue?: number | boolean | undefined;
            } | {
                options: {
                    rows: {
                        field: string;
                        checkbox?: {
                            label?: string | undefined;
                            defaultValue?: boolean | undefined;
                        } | undefined;
                    }[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    delimiter?: string | undefined;
                    groups?: {
                        label: string;
                        fields: string[];
                        options?: {
                            isExpandable?: boolean | undefined;
                            expand?: boolean | undefined;
                        } | undefined;
                    }[] | undefined;
                };
                type: "checkboxTree";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: [{
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }] | undefined;
                defaultValue?: number | boolean | undefined;
            } | {
                options: {
                    items: {
                        value: string | number | boolean;
                        label: string;
                    }[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                };
                type: "radio";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                type: "file";
                label: string;
                field: string;
                options?: {
                    supportedFileTypes: string[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    maxFileSize?: number | undefined;
                    fileSupportMessage?: string | undefined;
                    useBase64Encoding?: boolean | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                options: {
                    auth_type: ("oauth" | "basic" | "oauth_client_credentials")[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    oauth?: {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }[] | undefined;
                    basic?: {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }[] | undefined;
                    oauth_client_credentials?: {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }[] | undefined;
                    auth_label?: string | undefined;
                    oauth_popup_width?: number | undefined;
                    oauth_popup_height?: number | undefined;
                    oauth_timeout?: number | undefined;
                    auth_code_endpoint?: string | undefined;
                    access_token_endpoint?: string | undefined;
                    oauth_state_enabled?: boolean | undefined;
                    auth_endpoint_token_access_type?: string | undefined;
                };
                type: "oauth";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
            } | {
                options: {
                    type: "external";
                    src: string;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                };
                type: "custom";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
            })[];
            title: string;
            options?: {
                saveValidator?: string | undefined;
            } | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
            groups?: {
                label: string;
                fields: string[];
                options?: {
                    isExpandable?: boolean | undefined;
                    expand?: boolean | undefined;
                } | undefined;
            }[] | undefined;
            style?: "page" | "dialog" | undefined;
            hook?: Record<string, any> | undefined;
            conf?: string | undefined;
            restHandlerName?: string | undefined;
            restHandlerModule?: string | undefined;
            restHandlerClass?: string | undefined;
            warning?: {
                clone?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
                create?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
                edit?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
                config?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
            } | undefined;
            formTitle?: string | undefined;
            subTitle?: string | undefined;
            inputHelperModule?: string | undefined;
            disableNewInput?: boolean | undefined;
        }[];
        description?: string | undefined;
        useInputToggleConfirmation?: boolean | undefined;
        inputsUniqueAcrossSingleService?: boolean | undefined;
        subDescription?: {
            text: string;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        } | undefined;
        menu?: {
            type: "external";
            src: string;
        } | undefined;
        groupsMenu?: {
            groupName: string;
            groupTitle: string;
            groupServices?: string[] | undefined;
        }[] | undefined;
        hideFieldId?: string | undefined;
        readonlyFieldId?: string | undefined;
    }, {
        title: string;
        table: {
            header: {
                label: string;
                field: string;
                mapping?: Record<string, any> | undefined;
                customCell?: Record<string, any> | undefined;
            }[];
            actions: ("clone" | "delete" | "edit" | "search")[];
            moreInfo?: {
                label: string;
                field: string;
                mapping?: Record<string, any> | undefined;
            }[] | undefined;
            customRow?: Record<string, any> | undefined;
        };
        services: {
            name: string;
            entity: ({
                type: "helpLink";
                field: string;
                options?: {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: false | undefined;
            } | {
                type: "text";
                label: string;
                field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                type: "textarea";
                label: string;
                field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    rowsMin?: number | undefined;
                    rowsMax?: number | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                options: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    disableSearch?: boolean | undefined;
                    createSearchChoice?: boolean | undefined;
                    referenceName?: string | undefined;
                    endpointUrl?: string | undefined;
                    allowList?: string | undefined;
                    denyList?: string | undefined;
                    labelField?: string | undefined;
                    valueField?: string | undefined;
                    autoCompleteFields?: ({
                        value: string | number | boolean;
                        label: string;
                    } | {
                        label: string;
                        children: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                    })[] | undefined;
                    dependencies?: string[] | undefined;
                    items?: {
                        value: string | number | boolean;
                        label: string;
                    }[] | undefined;
                };
                type: "singleSelect";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                options: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    disableSearch?: boolean | undefined;
                    createSearchChoice?: boolean | undefined;
                    referenceName?: string | undefined;
                    endpointUrl?: string | undefined;
                    allowList?: string | undefined;
                    denyList?: string | undefined;
                    labelField?: string | undefined;
                    valueField?: string | undefined;
                    autoCompleteFields?: ({
                        value: string | number | boolean;
                        label: string;
                    } | {
                        label: string;
                        children: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                    })[] | undefined;
                    dependencies?: string[] | undefined;
                    items?: {
                        value: string | number | boolean;
                        label: string;
                    }[] | undefined;
                    delimiter?: string | undefined;
                };
                type: "multipleSelect";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                type: "checkbox";
                label: string;
                field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                defaultValue?: number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                options: {
                    rows: {
                        field: string;
                        checkbox?: {
                            label?: string | undefined;
                            defaultValue?: boolean | undefined;
                        } | undefined;
                        input?: {
                            required?: boolean | undefined;
                            validators?: [{
                                type: "number";
                                range: [number, number];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            }] | undefined;
                            defaultValue?: number | undefined;
                        } | undefined;
                    }[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    delimiter?: string | undefined;
                    groups?: {
                        label: string;
                        fields: string[];
                        options?: {
                            isExpandable?: boolean | undefined;
                            expand?: boolean | undefined;
                        } | undefined;
                    }[] | undefined;
                };
                type: "checkboxGroup";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: [{
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }] | undefined;
                defaultValue?: number | boolean | undefined;
            } | {
                options: {
                    rows: {
                        field: string;
                        checkbox?: {
                            label?: string | undefined;
                            defaultValue?: boolean | undefined;
                        } | undefined;
                    }[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    delimiter?: string | undefined;
                    groups?: {
                        label: string;
                        fields: string[];
                        options?: {
                            isExpandable?: boolean | undefined;
                            expand?: boolean | undefined;
                        } | undefined;
                    }[] | undefined;
                };
                type: "checkboxTree";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: [{
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }] | undefined;
                defaultValue?: number | boolean | undefined;
            } | {
                options: {
                    items: {
                        value: string | number | boolean;
                        label: string;
                    }[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                };
                type: "radio";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                type: "file";
                label: string;
                field: string;
                options?: {
                    supportedFileTypes: string[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    maxFileSize?: number | undefined;
                    fileSupportMessage?: string | undefined;
                    useBase64Encoding?: boolean | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                options: {
                    auth_type: ("oauth" | "basic" | "oauth_client_credentials")[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    oauth?: {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }[] | undefined;
                    basic?: {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }[] | undefined;
                    oauth_client_credentials?: {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }[] | undefined;
                    auth_label?: string | undefined;
                    oauth_popup_width?: number | undefined;
                    oauth_popup_height?: number | undefined;
                    oauth_timeout?: number | undefined;
                    auth_code_endpoint?: string | undefined;
                    access_token_endpoint?: string | undefined;
                    oauth_state_enabled?: boolean | undefined;
                    auth_endpoint_token_access_type?: string | undefined;
                };
                type: "oauth";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
            } | {
                options: {
                    type: "external";
                    src: string;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                };
                type: "custom";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
            })[];
            title: string;
            options?: {
                saveValidator?: string | undefined;
            } | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
            groups?: {
                label: string;
                fields: string[];
                options?: {
                    isExpandable?: boolean | undefined;
                    expand?: boolean | undefined;
                } | undefined;
            }[] | undefined;
            style?: "page" | "dialog" | undefined;
            hook?: Record<string, any> | undefined;
            conf?: string | undefined;
            restHandlerName?: string | undefined;
            restHandlerModule?: string | undefined;
            restHandlerClass?: string | undefined;
            warning?: {
                clone?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
                create?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
                edit?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
                config?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
            } | undefined;
            formTitle?: string | undefined;
            subTitle?: string | undefined;
            inputHelperModule?: string | undefined;
            disableNewInput?: boolean | undefined;
        }[];
        description?: string | undefined;
        useInputToggleConfirmation?: boolean | undefined;
        inputsUniqueAcrossSingleService?: boolean | undefined;
        subDescription?: {
            text: string;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        } | undefined;
        menu?: {
            type: "external";
            src: string;
        } | undefined;
        groupsMenu?: {
            groupName: string;
            groupTitle: string;
            groupServices?: string[] | undefined;
        }[] | undefined;
        hideFieldId?: string | undefined;
        readonlyFieldId?: string | undefined;
    }>]>>;
    dashboard: z.ZodOptional<z.ZodObject<{
        panels: z.ZodArray<z.ZodObject<{
            name: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            name: string;
        }, {
            name: string;
        }>, "many">;
        troubleshooting_url: z.ZodOptional<z.ZodString>;
        settings: z.ZodOptional<z.ZodObject<{
            custom_tab_name: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            custom_tab_name?: string | undefined;
        }, {
            custom_tab_name?: string | undefined;
        }>>;
    }, "strip", z.ZodTypeAny, {
        panels: {
            name: string;
        }[];
        troubleshooting_url?: string | undefined;
        settings?: {
            custom_tab_name?: string | undefined;
        } | undefined;
    }, {
        panels: {
            name: string;
        }[];
        troubleshooting_url?: string | undefined;
        settings?: {
            custom_tab_name?: string | undefined;
        } | undefined;
    }>>;
}, "strip", z.ZodTypeAny, {
    configuration?: {
        title: string;
        tabs: {
            name: string;
            title: string;
            options?: {
                saveValidator?: string | undefined;
            } | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
            groups?: {
                label: string;
                fields: string[];
                options?: {
                    isExpandable?: boolean | undefined;
                    expand?: boolean | undefined;
                } | undefined;
            }[] | undefined;
            entity?: ({
                type: "helpLink";
                field: string;
                options?: {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: false | undefined;
            } | {
                type: "text";
                label: string;
                field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                type: "textarea";
                label: string;
                field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    rowsMin?: number | undefined;
                    rowsMax?: number | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                options: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    disableSearch?: boolean | undefined;
                    createSearchChoice?: boolean | undefined;
                    referenceName?: string | undefined;
                    endpointUrl?: string | undefined;
                    allowList?: string | undefined;
                    denyList?: string | undefined;
                    labelField?: string | undefined;
                    valueField?: string | undefined;
                    autoCompleteFields?: ({
                        value: string | number | boolean;
                        label: string;
                    } | {
                        label: string;
                        children: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                    })[] | undefined;
                    dependencies?: string[] | undefined;
                    items?: {
                        value: string | number | boolean;
                        label: string;
                    }[] | undefined;
                };
                type: "singleSelect";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                options: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    disableSearch?: boolean | undefined;
                    createSearchChoice?: boolean | undefined;
                    referenceName?: string | undefined;
                    endpointUrl?: string | undefined;
                    allowList?: string | undefined;
                    denyList?: string | undefined;
                    labelField?: string | undefined;
                    valueField?: string | undefined;
                    autoCompleteFields?: ({
                        value: string | number | boolean;
                        label: string;
                    } | {
                        label: string;
                        children: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                    })[] | undefined;
                    dependencies?: string[] | undefined;
                    items?: {
                        value: string | number | boolean;
                        label: string;
                    }[] | undefined;
                    delimiter?: string | undefined;
                };
                type: "multipleSelect";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                type: "checkbox";
                label: string;
                field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                defaultValue?: number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                options: {
                    rows: {
                        field: string;
                        checkbox?: {
                            label?: string | undefined;
                            defaultValue?: boolean | undefined;
                        } | undefined;
                        input?: {
                            required?: boolean | undefined;
                            validators?: [{
                                type: "number";
                                range: [number, number];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            }] | undefined;
                            defaultValue?: number | undefined;
                        } | undefined;
                    }[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    delimiter?: string | undefined;
                    groups?: {
                        label: string;
                        fields: string[];
                        options?: {
                            isExpandable?: boolean | undefined;
                            expand?: boolean | undefined;
                        } | undefined;
                    }[] | undefined;
                };
                type: "checkboxGroup";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: [{
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }] | undefined;
                defaultValue?: number | boolean | undefined;
            } | {
                options: {
                    rows: {
                        field: string;
                        checkbox?: {
                            label?: string | undefined;
                            defaultValue?: boolean | undefined;
                        } | undefined;
                    }[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    delimiter?: string | undefined;
                    groups?: {
                        label: string;
                        fields: string[];
                        options?: {
                            isExpandable?: boolean | undefined;
                            expand?: boolean | undefined;
                        } | undefined;
                    }[] | undefined;
                };
                type: "checkboxTree";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: [{
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }] | undefined;
                defaultValue?: number | boolean | undefined;
            } | {
                options: {
                    items: {
                        value: string | number | boolean;
                        label: string;
                    }[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                };
                type: "radio";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                type: "file";
                label: string;
                field: string;
                options?: {
                    supportedFileTypes: string[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    maxFileSize?: number | undefined;
                    fileSupportMessage?: string | undefined;
                    useBase64Encoding?: boolean | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                options: {
                    auth_type: ("oauth" | "basic" | "oauth_client_credentials")[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    oauth?: {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }[] | undefined;
                    basic?: {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }[] | undefined;
                    oauth_client_credentials?: {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }[] | undefined;
                    auth_label?: string | undefined;
                    oauth_popup_width?: number | undefined;
                    oauth_popup_height?: number | undefined;
                    oauth_timeout?: number | undefined;
                    auth_code_endpoint?: string | undefined;
                    access_token_endpoint?: string | undefined;
                    oauth_state_enabled?: boolean | undefined;
                    auth_endpoint_token_access_type?: string | undefined;
                };
                type: "oauth";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
            } | {
                options: {
                    type: "external";
                    src: string;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                };
                type: "custom";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
            })[] | undefined;
            table?: {
                header: {
                    label: string;
                    field: string;
                    mapping?: Record<string, any> | undefined;
                    customCell?: Record<string, any> | undefined;
                }[];
                actions: ("clone" | "delete" | "edit")[];
                moreInfo?: {
                    label: string;
                    field: string;
                    mapping?: Record<string, any> | undefined;
                }[] | undefined;
                customRow?: Record<string, any> | undefined;
            } | undefined;
            style?: "page" | "dialog" | undefined;
            hook?: Record<string, any> | undefined;
            conf?: string | undefined;
            restHandlerName?: string | undefined;
            restHandlerModule?: string | undefined;
            restHandlerClass?: string | undefined;
            customTab?: Record<string, any> | undefined;
            warning?: {
                clone?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
                create?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
                edit?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
                config?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
            } | undefined;
            formTitle?: string | undefined;
        }[];
        description?: string | undefined;
        subDescription?: {
            text: string;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        } | undefined;
    } | undefined;
    inputs?: {
        title: string;
        services: {
            name: string;
            entity: ({
                type: "helpLink";
                field: string;
                options?: {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: false | undefined;
            } | {
                type: "text";
                label: string;
                field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                type: "textarea";
                label: string;
                field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    rowsMin?: number | undefined;
                    rowsMax?: number | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                options: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    disableSearch?: boolean | undefined;
                    createSearchChoice?: boolean | undefined;
                    referenceName?: string | undefined;
                    endpointUrl?: string | undefined;
                    allowList?: string | undefined;
                    denyList?: string | undefined;
                    labelField?: string | undefined;
                    valueField?: string | undefined;
                    autoCompleteFields?: ({
                        value: string | number | boolean;
                        label: string;
                    } | {
                        label: string;
                        children: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                    })[] | undefined;
                    dependencies?: string[] | undefined;
                    items?: {
                        value: string | number | boolean;
                        label: string;
                    }[] | undefined;
                };
                type: "singleSelect";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                options: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    disableSearch?: boolean | undefined;
                    createSearchChoice?: boolean | undefined;
                    referenceName?: string | undefined;
                    endpointUrl?: string | undefined;
                    allowList?: string | undefined;
                    denyList?: string | undefined;
                    labelField?: string | undefined;
                    valueField?: string | undefined;
                    autoCompleteFields?: ({
                        value: string | number | boolean;
                        label: string;
                    } | {
                        label: string;
                        children: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                    })[] | undefined;
                    dependencies?: string[] | undefined;
                    items?: {
                        value: string | number | boolean;
                        label: string;
                    }[] | undefined;
                    delimiter?: string | undefined;
                };
                type: "multipleSelect";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                type: "checkbox";
                label: string;
                field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                defaultValue?: number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                options: {
                    rows: {
                        field: string;
                        checkbox?: {
                            label?: string | undefined;
                            defaultValue?: boolean | undefined;
                        } | undefined;
                        input?: {
                            required?: boolean | undefined;
                            validators?: [{
                                type: "number";
                                range: [number, number];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            }] | undefined;
                            defaultValue?: number | undefined;
                        } | undefined;
                    }[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    delimiter?: string | undefined;
                    groups?: {
                        label: string;
                        fields: string[];
                        options?: {
                            isExpandable?: boolean | undefined;
                            expand?: boolean | undefined;
                        } | undefined;
                    }[] | undefined;
                };
                type: "checkboxGroup";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: [{
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }] | undefined;
                defaultValue?: number | boolean | undefined;
            } | {
                options: {
                    rows: {
                        field: string;
                        checkbox?: {
                            label?: string | undefined;
                            defaultValue?: boolean | undefined;
                        } | undefined;
                    }[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    delimiter?: string | undefined;
                    groups?: {
                        label: string;
                        fields: string[];
                        options?: {
                            isExpandable?: boolean | undefined;
                            expand?: boolean | undefined;
                        } | undefined;
                    }[] | undefined;
                };
                type: "checkboxTree";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: [{
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }] | undefined;
                defaultValue?: number | boolean | undefined;
            } | {
                options: {
                    items: {
                        value: string | number | boolean;
                        label: string;
                    }[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                };
                type: "radio";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                type: "file";
                label: string;
                field: string;
                options?: {
                    supportedFileTypes: string[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    maxFileSize?: number | undefined;
                    fileSupportMessage?: string | undefined;
                    useBase64Encoding?: boolean | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                options: {
                    auth_type: ("oauth" | "basic" | "oauth_client_credentials")[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    oauth?: {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }[] | undefined;
                    basic?: {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }[] | undefined;
                    oauth_client_credentials?: {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }[] | undefined;
                    auth_label?: string | undefined;
                    oauth_popup_width?: number | undefined;
                    oauth_popup_height?: number | undefined;
                    oauth_timeout?: number | undefined;
                    auth_code_endpoint?: string | undefined;
                    access_token_endpoint?: string | undefined;
                    oauth_state_enabled?: boolean | undefined;
                    auth_endpoint_token_access_type?: string | undefined;
                };
                type: "oauth";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
            } | {
                options: {
                    type: "external";
                    src: string;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                };
                type: "custom";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
            })[];
            title: string;
            table: {
                header: {
                    label: string;
                    field: string;
                    mapping?: Record<string, any> | undefined;
                    customCell?: Record<string, any> | undefined;
                }[];
                actions: ("clone" | "delete" | "edit" | "search")[];
                moreInfo?: {
                    label: string;
                    field: string;
                    mapping?: Record<string, any> | undefined;
                }[] | undefined;
                customRow?: Record<string, any> | undefined;
            };
            options?: {
                saveValidator?: string | undefined;
            } | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
            groups?: {
                label: string;
                fields: string[];
                options?: {
                    isExpandable?: boolean | undefined;
                    expand?: boolean | undefined;
                } | undefined;
            }[] | undefined;
            style?: "page" | "dialog" | undefined;
            hook?: Record<string, any> | undefined;
            conf?: string | undefined;
            restHandlerName?: string | undefined;
            restHandlerModule?: string | undefined;
            restHandlerClass?: string | undefined;
            warning?: {
                clone?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
                create?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
                edit?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
                config?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
            } | undefined;
            formTitle?: string | undefined;
            subTitle?: string | undefined;
            inputHelperModule?: string | undefined;
            disableNewInput?: boolean | undefined;
            description?: string | undefined;
            useInputToggleConfirmation?: boolean | undefined;
        }[];
        inputsUniqueAcrossSingleService?: boolean | undefined;
    } | {
        title: string;
        table: {
            header: {
                label: string;
                field: string;
                mapping?: Record<string, any> | undefined;
                customCell?: Record<string, any> | undefined;
            }[];
            actions: ("clone" | "delete" | "edit" | "search")[];
            moreInfo?: {
                label: string;
                field: string;
                mapping?: Record<string, any> | undefined;
            }[] | undefined;
            customRow?: Record<string, any> | undefined;
        };
        services: {
            name: string;
            entity: ({
                type: "helpLink";
                field: string;
                options?: {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: false | undefined;
            } | {
                type: "text";
                label: string;
                field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                type: "textarea";
                label: string;
                field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    rowsMin?: number | undefined;
                    rowsMax?: number | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                options: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    disableSearch?: boolean | undefined;
                    createSearchChoice?: boolean | undefined;
                    referenceName?: string | undefined;
                    endpointUrl?: string | undefined;
                    allowList?: string | undefined;
                    denyList?: string | undefined;
                    labelField?: string | undefined;
                    valueField?: string | undefined;
                    autoCompleteFields?: ({
                        value: string | number | boolean;
                        label: string;
                    } | {
                        label: string;
                        children: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                    })[] | undefined;
                    dependencies?: string[] | undefined;
                    items?: {
                        value: string | number | boolean;
                        label: string;
                    }[] | undefined;
                };
                type: "singleSelect";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                options: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    disableSearch?: boolean | undefined;
                    createSearchChoice?: boolean | undefined;
                    referenceName?: string | undefined;
                    endpointUrl?: string | undefined;
                    allowList?: string | undefined;
                    denyList?: string | undefined;
                    labelField?: string | undefined;
                    valueField?: string | undefined;
                    autoCompleteFields?: ({
                        value: string | number | boolean;
                        label: string;
                    } | {
                        label: string;
                        children: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                    })[] | undefined;
                    dependencies?: string[] | undefined;
                    items?: {
                        value: string | number | boolean;
                        label: string;
                    }[] | undefined;
                    delimiter?: string | undefined;
                };
                type: "multipleSelect";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                type: "checkbox";
                label: string;
                field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                defaultValue?: number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                options: {
                    rows: {
                        field: string;
                        checkbox?: {
                            label?: string | undefined;
                            defaultValue?: boolean | undefined;
                        } | undefined;
                        input?: {
                            required?: boolean | undefined;
                            validators?: [{
                                type: "number";
                                range: [number, number];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            }] | undefined;
                            defaultValue?: number | undefined;
                        } | undefined;
                    }[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    delimiter?: string | undefined;
                    groups?: {
                        label: string;
                        fields: string[];
                        options?: {
                            isExpandable?: boolean | undefined;
                            expand?: boolean | undefined;
                        } | undefined;
                    }[] | undefined;
                };
                type: "checkboxGroup";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: [{
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }] | undefined;
                defaultValue?: number | boolean | undefined;
            } | {
                options: {
                    rows: {
                        field: string;
                        checkbox?: {
                            label?: string | undefined;
                            defaultValue?: boolean | undefined;
                        } | undefined;
                    }[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    delimiter?: string | undefined;
                    groups?: {
                        label: string;
                        fields: string[];
                        options?: {
                            isExpandable?: boolean | undefined;
                            expand?: boolean | undefined;
                        } | undefined;
                    }[] | undefined;
                };
                type: "checkboxTree";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: [{
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }] | undefined;
                defaultValue?: number | boolean | undefined;
            } | {
                options: {
                    items: {
                        value: string | number | boolean;
                        label: string;
                    }[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                };
                type: "radio";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                type: "file";
                label: string;
                field: string;
                options?: {
                    supportedFileTypes: string[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    maxFileSize?: number | undefined;
                    fileSupportMessage?: string | undefined;
                    useBase64Encoding?: boolean | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                options: {
                    auth_type: ("oauth" | "basic" | "oauth_client_credentials")[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    oauth?: {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }[] | undefined;
                    basic?: {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }[] | undefined;
                    oauth_client_credentials?: {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }[] | undefined;
                    auth_label?: string | undefined;
                    oauth_popup_width?: number | undefined;
                    oauth_popup_height?: number | undefined;
                    oauth_timeout?: number | undefined;
                    auth_code_endpoint?: string | undefined;
                    access_token_endpoint?: string | undefined;
                    oauth_state_enabled?: boolean | undefined;
                    auth_endpoint_token_access_type?: string | undefined;
                };
                type: "oauth";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
            } | {
                options: {
                    type: "external";
                    src: string;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                };
                type: "custom";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
            })[];
            title: string;
            options?: {
                saveValidator?: string | undefined;
            } | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
            groups?: {
                label: string;
                fields: string[];
                options?: {
                    isExpandable?: boolean | undefined;
                    expand?: boolean | undefined;
                } | undefined;
            }[] | undefined;
            style?: "page" | "dialog" | undefined;
            hook?: Record<string, any> | undefined;
            conf?: string | undefined;
            restHandlerName?: string | undefined;
            restHandlerModule?: string | undefined;
            restHandlerClass?: string | undefined;
            warning?: {
                clone?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
                create?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
                edit?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
                config?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
            } | undefined;
            formTitle?: string | undefined;
            subTitle?: string | undefined;
            inputHelperModule?: string | undefined;
            disableNewInput?: boolean | undefined;
        }[];
        description?: string | undefined;
        useInputToggleConfirmation?: boolean | undefined;
        inputsUniqueAcrossSingleService?: boolean | undefined;
        subDescription?: {
            text: string;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        } | undefined;
        menu?: {
            type: "external";
            src: string;
        } | undefined;
        groupsMenu?: {
            groupName: string;
            groupTitle: string;
            groupServices?: string[] | undefined;
        }[] | undefined;
        hideFieldId?: string | undefined;
        readonlyFieldId?: string | undefined;
    } | undefined;
    dashboard?: {
        panels: {
            name: string;
        }[];
        troubleshooting_url?: string | undefined;
        settings?: {
            custom_tab_name?: string | undefined;
        } | undefined;
    } | undefined;
}, {
    configuration?: {
        title: string;
        tabs: {
            name: string;
            title: string;
            options?: {
                saveValidator?: string | undefined;
            } | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
            groups?: {
                label: string;
                fields: string[];
                options?: {
                    isExpandable?: boolean | undefined;
                    expand?: boolean | undefined;
                } | undefined;
            }[] | undefined;
            entity?: ({
                type: "helpLink";
                field: string;
                options?: {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: false | undefined;
            } | {
                type: "text";
                label: string;
                field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                type: "textarea";
                label: string;
                field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    rowsMin?: number | undefined;
                    rowsMax?: number | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                options: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    disableSearch?: boolean | undefined;
                    createSearchChoice?: boolean | undefined;
                    referenceName?: string | undefined;
                    endpointUrl?: string | undefined;
                    allowList?: string | undefined;
                    denyList?: string | undefined;
                    labelField?: string | undefined;
                    valueField?: string | undefined;
                    autoCompleteFields?: ({
                        value: string | number | boolean;
                        label: string;
                    } | {
                        label: string;
                        children: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                    })[] | undefined;
                    dependencies?: string[] | undefined;
                    items?: {
                        value: string | number | boolean;
                        label: string;
                    }[] | undefined;
                };
                type: "singleSelect";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                options: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    disableSearch?: boolean | undefined;
                    createSearchChoice?: boolean | undefined;
                    referenceName?: string | undefined;
                    endpointUrl?: string | undefined;
                    allowList?: string | undefined;
                    denyList?: string | undefined;
                    labelField?: string | undefined;
                    valueField?: string | undefined;
                    autoCompleteFields?: ({
                        value: string | number | boolean;
                        label: string;
                    } | {
                        label: string;
                        children: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                    })[] | undefined;
                    dependencies?: string[] | undefined;
                    items?: {
                        value: string | number | boolean;
                        label: string;
                    }[] | undefined;
                    delimiter?: string | undefined;
                };
                type: "multipleSelect";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                type: "checkbox";
                label: string;
                field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                defaultValue?: number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                options: {
                    rows: {
                        field: string;
                        checkbox?: {
                            label?: string | undefined;
                            defaultValue?: boolean | undefined;
                        } | undefined;
                        input?: {
                            required?: boolean | undefined;
                            validators?: [{
                                type: "number";
                                range: [number, number];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            }] | undefined;
                            defaultValue?: number | undefined;
                        } | undefined;
                    }[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    delimiter?: string | undefined;
                    groups?: {
                        label: string;
                        fields: string[];
                        options?: {
                            isExpandable?: boolean | undefined;
                            expand?: boolean | undefined;
                        } | undefined;
                    }[] | undefined;
                };
                type: "checkboxGroup";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: [{
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }] | undefined;
                defaultValue?: number | boolean | undefined;
            } | {
                options: {
                    rows: {
                        field: string;
                        checkbox?: {
                            label?: string | undefined;
                            defaultValue?: boolean | undefined;
                        } | undefined;
                    }[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    delimiter?: string | undefined;
                    groups?: {
                        label: string;
                        fields: string[];
                        options?: {
                            isExpandable?: boolean | undefined;
                            expand?: boolean | undefined;
                        } | undefined;
                    }[] | undefined;
                };
                type: "checkboxTree";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: [{
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }] | undefined;
                defaultValue?: number | boolean | undefined;
            } | {
                options: {
                    items: {
                        value: string | number | boolean;
                        label: string;
                    }[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                };
                type: "radio";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                type: "file";
                label: string;
                field: string;
                options?: {
                    supportedFileTypes: string[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    maxFileSize?: number | undefined;
                    fileSupportMessage?: string | undefined;
                    useBase64Encoding?: boolean | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                options: {
                    auth_type: ("oauth" | "basic" | "oauth_client_credentials")[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    oauth?: {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }[] | undefined;
                    basic?: {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }[] | undefined;
                    oauth_client_credentials?: {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }[] | undefined;
                    auth_label?: string | undefined;
                    oauth_popup_width?: number | undefined;
                    oauth_popup_height?: number | undefined;
                    oauth_timeout?: number | undefined;
                    auth_code_endpoint?: string | undefined;
                    access_token_endpoint?: string | undefined;
                    oauth_state_enabled?: boolean | undefined;
                    auth_endpoint_token_access_type?: string | undefined;
                };
                type: "oauth";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
            } | {
                options: {
                    type: "external";
                    src: string;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                };
                type: "custom";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
            })[] | undefined;
            table?: {
                header: {
                    label: string;
                    field: string;
                    mapping?: Record<string, any> | undefined;
                    customCell?: Record<string, any> | undefined;
                }[];
                actions: ("clone" | "delete" | "edit")[];
                moreInfo?: {
                    label: string;
                    field: string;
                    mapping?: Record<string, any> | undefined;
                }[] | undefined;
                customRow?: Record<string, any> | undefined;
            } | undefined;
            style?: "page" | "dialog" | undefined;
            hook?: Record<string, any> | undefined;
            conf?: string | undefined;
            restHandlerName?: string | undefined;
            restHandlerModule?: string | undefined;
            restHandlerClass?: string | undefined;
            customTab?: Record<string, any> | undefined;
            warning?: {
                clone?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
                create?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
                edit?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
                config?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
            } | undefined;
            formTitle?: string | undefined;
        }[];
        description?: string | undefined;
        subDescription?: {
            text: string;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        } | undefined;
    } | undefined;
    inputs?: {
        title: string;
        services: {
            name: string;
            entity: ({
                type: "helpLink";
                field: string;
                options?: {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: false | undefined;
            } | {
                type: "text";
                label: string;
                field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                type: "textarea";
                label: string;
                field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    rowsMin?: number | undefined;
                    rowsMax?: number | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                options: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    disableSearch?: boolean | undefined;
                    createSearchChoice?: boolean | undefined;
                    referenceName?: string | undefined;
                    endpointUrl?: string | undefined;
                    allowList?: string | undefined;
                    denyList?: string | undefined;
                    labelField?: string | undefined;
                    valueField?: string | undefined;
                    autoCompleteFields?: ({
                        value: string | number | boolean;
                        label: string;
                    } | {
                        label: string;
                        children: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                    })[] | undefined;
                    dependencies?: string[] | undefined;
                    items?: {
                        value: string | number | boolean;
                        label: string;
                    }[] | undefined;
                };
                type: "singleSelect";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                options: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    disableSearch?: boolean | undefined;
                    createSearchChoice?: boolean | undefined;
                    referenceName?: string | undefined;
                    endpointUrl?: string | undefined;
                    allowList?: string | undefined;
                    denyList?: string | undefined;
                    labelField?: string | undefined;
                    valueField?: string | undefined;
                    autoCompleteFields?: ({
                        value: string | number | boolean;
                        label: string;
                    } | {
                        label: string;
                        children: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                    })[] | undefined;
                    dependencies?: string[] | undefined;
                    items?: {
                        value: string | number | boolean;
                        label: string;
                    }[] | undefined;
                    delimiter?: string | undefined;
                };
                type: "multipleSelect";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                type: "checkbox";
                label: string;
                field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                defaultValue?: number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                options: {
                    rows: {
                        field: string;
                        checkbox?: {
                            label?: string | undefined;
                            defaultValue?: boolean | undefined;
                        } | undefined;
                        input?: {
                            required?: boolean | undefined;
                            validators?: [{
                                type: "number";
                                range: [number, number];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            }] | undefined;
                            defaultValue?: number | undefined;
                        } | undefined;
                    }[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    delimiter?: string | undefined;
                    groups?: {
                        label: string;
                        fields: string[];
                        options?: {
                            isExpandable?: boolean | undefined;
                            expand?: boolean | undefined;
                        } | undefined;
                    }[] | undefined;
                };
                type: "checkboxGroup";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: [{
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }] | undefined;
                defaultValue?: number | boolean | undefined;
            } | {
                options: {
                    rows: {
                        field: string;
                        checkbox?: {
                            label?: string | undefined;
                            defaultValue?: boolean | undefined;
                        } | undefined;
                    }[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    delimiter?: string | undefined;
                    groups?: {
                        label: string;
                        fields: string[];
                        options?: {
                            isExpandable?: boolean | undefined;
                            expand?: boolean | undefined;
                        } | undefined;
                    }[] | undefined;
                };
                type: "checkboxTree";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: [{
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }] | undefined;
                defaultValue?: number | boolean | undefined;
            } | {
                options: {
                    items: {
                        value: string | number | boolean;
                        label: string;
                    }[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                };
                type: "radio";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                type: "file";
                label: string;
                field: string;
                options?: {
                    supportedFileTypes: string[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    maxFileSize?: number | undefined;
                    fileSupportMessage?: string | undefined;
                    useBase64Encoding?: boolean | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                options: {
                    auth_type: ("oauth" | "basic" | "oauth_client_credentials")[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    oauth?: {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }[] | undefined;
                    basic?: {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }[] | undefined;
                    oauth_client_credentials?: {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }[] | undefined;
                    auth_label?: string | undefined;
                    oauth_popup_width?: number | undefined;
                    oauth_popup_height?: number | undefined;
                    oauth_timeout?: number | undefined;
                    auth_code_endpoint?: string | undefined;
                    access_token_endpoint?: string | undefined;
                    oauth_state_enabled?: boolean | undefined;
                    auth_endpoint_token_access_type?: string | undefined;
                };
                type: "oauth";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
            } | {
                options: {
                    type: "external";
                    src: string;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                };
                type: "custom";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
            })[];
            title: string;
            table: {
                header: {
                    label: string;
                    field: string;
                    mapping?: Record<string, any> | undefined;
                    customCell?: Record<string, any> | undefined;
                }[];
                actions: ("clone" | "delete" | "edit" | "search")[];
                moreInfo?: {
                    label: string;
                    field: string;
                    mapping?: Record<string, any> | undefined;
                }[] | undefined;
                customRow?: Record<string, any> | undefined;
            };
            options?: {
                saveValidator?: string | undefined;
            } | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
            groups?: {
                label: string;
                fields: string[];
                options?: {
                    isExpandable?: boolean | undefined;
                    expand?: boolean | undefined;
                } | undefined;
            }[] | undefined;
            style?: "page" | "dialog" | undefined;
            hook?: Record<string, any> | undefined;
            conf?: string | undefined;
            restHandlerName?: string | undefined;
            restHandlerModule?: string | undefined;
            restHandlerClass?: string | undefined;
            warning?: {
                clone?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
                create?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
                edit?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
                config?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
            } | undefined;
            formTitle?: string | undefined;
            subTitle?: string | undefined;
            inputHelperModule?: string | undefined;
            disableNewInput?: boolean | undefined;
            description?: string | undefined;
            useInputToggleConfirmation?: boolean | undefined;
        }[];
        inputsUniqueAcrossSingleService?: boolean | undefined;
    } | {
        title: string;
        table: {
            header: {
                label: string;
                field: string;
                mapping?: Record<string, any> | undefined;
                customCell?: Record<string, any> | undefined;
            }[];
            actions: ("clone" | "delete" | "edit" | "search")[];
            moreInfo?: {
                label: string;
                field: string;
                mapping?: Record<string, any> | undefined;
            }[] | undefined;
            customRow?: Record<string, any> | undefined;
        };
        services: {
            name: string;
            entity: ({
                type: "helpLink";
                field: string;
                options?: {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: false | undefined;
            } | {
                type: "text";
                label: string;
                field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                type: "textarea";
                label: string;
                field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    rowsMin?: number | undefined;
                    rowsMax?: number | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                options: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    disableSearch?: boolean | undefined;
                    createSearchChoice?: boolean | undefined;
                    referenceName?: string | undefined;
                    endpointUrl?: string | undefined;
                    allowList?: string | undefined;
                    denyList?: string | undefined;
                    labelField?: string | undefined;
                    valueField?: string | undefined;
                    autoCompleteFields?: ({
                        value: string | number | boolean;
                        label: string;
                    } | {
                        label: string;
                        children: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                    })[] | undefined;
                    dependencies?: string[] | undefined;
                    items?: {
                        value: string | number | boolean;
                        label: string;
                    }[] | undefined;
                };
                type: "singleSelect";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                options: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    disableSearch?: boolean | undefined;
                    createSearchChoice?: boolean | undefined;
                    referenceName?: string | undefined;
                    endpointUrl?: string | undefined;
                    allowList?: string | undefined;
                    denyList?: string | undefined;
                    labelField?: string | undefined;
                    valueField?: string | undefined;
                    autoCompleteFields?: ({
                        value: string | number | boolean;
                        label: string;
                    } | {
                        label: string;
                        children: {
                            value: string | number | boolean;
                            label: string;
                        }[];
                    })[] | undefined;
                    dependencies?: string[] | undefined;
                    items?: {
                        value: string | number | boolean;
                        label: string;
                    }[] | undefined;
                    delimiter?: string | undefined;
                };
                type: "multipleSelect";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                type: "checkbox";
                label: string;
                field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                defaultValue?: number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                options: {
                    rows: {
                        field: string;
                        checkbox?: {
                            label?: string | undefined;
                            defaultValue?: boolean | undefined;
                        } | undefined;
                        input?: {
                            required?: boolean | undefined;
                            validators?: [{
                                type: "number";
                                range: [number, number];
                                errorMsg?: string | undefined;
                                isInteger?: boolean | undefined;
                            }] | undefined;
                            defaultValue?: number | undefined;
                        } | undefined;
                    }[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    delimiter?: string | undefined;
                    groups?: {
                        label: string;
                        fields: string[];
                        options?: {
                            isExpandable?: boolean | undefined;
                            expand?: boolean | undefined;
                        } | undefined;
                    }[] | undefined;
                };
                type: "checkboxGroup";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: [{
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }] | undefined;
                defaultValue?: number | boolean | undefined;
            } | {
                options: {
                    rows: {
                        field: string;
                        checkbox?: {
                            label?: string | undefined;
                            defaultValue?: boolean | undefined;
                        } | undefined;
                    }[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    delimiter?: string | undefined;
                    groups?: {
                        label: string;
                        fields: string[];
                        options?: {
                            isExpandable?: boolean | undefined;
                            expand?: boolean | undefined;
                        } | undefined;
                    }[] | undefined;
                };
                type: "checkboxTree";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: [{
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }] | undefined;
                defaultValue?: number | boolean | undefined;
            } | {
                options: {
                    items: {
                        value: string | number | boolean;
                        label: string;
                    }[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                };
                type: "radio";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                type: "file";
                label: string;
                field: string;
                options?: {
                    supportedFileTypes: string[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    maxFileSize?: number | undefined;
                    fileSupportMessage?: string | undefined;
                    useBase64Encoding?: boolean | undefined;
                } | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            } | {
                options: {
                    auth_type: ("oauth" | "basic" | "oauth_client_credentials")[];
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                    oauth?: {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }[] | undefined;
                    basic?: {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }[] | undefined;
                    oauth_client_credentials?: {
                        label: string;
                        field: string;
                        oauth_field: string;
                        options?: {
                            display?: boolean | undefined;
                            disableonEdit?: boolean | undefined;
                            enable?: boolean | undefined;
                            requiredWhenVisible?: boolean | undefined;
                            hideForPlatform?: "cloud" | "enterprise" | undefined;
                        } | undefined;
                        type?: "text" | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        encrypted?: boolean | undefined;
                        validators?: ({
                            type: "number";
                            range: [number, number];
                            errorMsg?: string | undefined;
                            isInteger?: boolean | undefined;
                        } | {
                            type: "string";
                            minLength: number;
                            maxLength: number;
                            errorMsg?: string | undefined;
                        } | {
                            type: "regex";
                            pattern: string;
                            errorMsg?: string | undefined;
                        } | {
                            type: "email";
                            errorMsg?: string | undefined;
                        } | {
                            type: "ipv4";
                            errorMsg?: string | undefined;
                        } | {
                            type: "url";
                            errorMsg?: string | undefined;
                        } | {
                            type: "date";
                            errorMsg?: string | undefined;
                        })[] | undefined;
                        defaultValue?: string | number | boolean | undefined;
                        modifyFieldsOnValue?: {
                            fieldValue: string | number | boolean;
                            fieldsToModify: {
                                fieldId: string;
                                value?: string | number | boolean | undefined;
                                label?: string | undefined;
                                help?: string | {
                                    text: string;
                                    link?: string | undefined;
                                    links?: {
                                        slug: string;
                                        link: string;
                                        linkText: string;
                                    }[] | undefined;
                                } | undefined;
                                required?: boolean | undefined;
                                display?: boolean | undefined;
                                disabled?: boolean | undefined;
                                markdownMessage?: {
                                    text: string;
                                    markdownType: "text";
                                    color?: string | undefined;
                                } | {
                                    text: string;
                                    link: string;
                                    linkText: string;
                                    markdownType: "hybrid";
                                    token: string;
                                } | {
                                    text: string;
                                    link: string;
                                    markdownType: "link";
                                } | {
                                    text: string;
                                    markdownType?: undefined;
                                } | undefined;
                            }[];
                            mode?: "clone" | "create" | "edit" | "config" | undefined;
                        }[] | undefined;
                    }[] | undefined;
                    auth_label?: string | undefined;
                    oauth_popup_width?: number | undefined;
                    oauth_popup_height?: number | undefined;
                    oauth_timeout?: number | undefined;
                    auth_code_endpoint?: string | undefined;
                    access_token_endpoint?: string | undefined;
                    oauth_state_enabled?: boolean | undefined;
                    auth_endpoint_token_access_type?: string | undefined;
                };
                type: "oauth";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | undefined;
            } | {
                options: {
                    type: "external";
                    src: string;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                };
                type: "custom";
                label: string;
                field: string;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                tooltip?: string | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
            })[];
            title: string;
            options?: {
                saveValidator?: string | undefined;
            } | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
            groups?: {
                label: string;
                fields: string[];
                options?: {
                    isExpandable?: boolean | undefined;
                    expand?: boolean | undefined;
                } | undefined;
            }[] | undefined;
            style?: "page" | "dialog" | undefined;
            hook?: Record<string, any> | undefined;
            conf?: string | undefined;
            restHandlerName?: string | undefined;
            restHandlerModule?: string | undefined;
            restHandlerClass?: string | undefined;
            warning?: {
                clone?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
                create?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
                edit?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
                config?: {
                    message: string;
                    alwaysDisplay?: boolean | undefined;
                } | undefined;
            } | undefined;
            formTitle?: string | undefined;
            subTitle?: string | undefined;
            inputHelperModule?: string | undefined;
            disableNewInput?: boolean | undefined;
        }[];
        description?: string | undefined;
        useInputToggleConfirmation?: boolean | undefined;
        inputsUniqueAcrossSingleService?: boolean | undefined;
        subDescription?: {
            text: string;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        } | undefined;
        menu?: {
            type: "external";
            src: string;
        } | undefined;
        groupsMenu?: {
            groupName: string;
            groupTitle: string;
            groupServices?: string[] | undefined;
        }[] | undefined;
        hideFieldId?: string | undefined;
        readonlyFieldId?: string | undefined;
    } | undefined;
    dashboard?: {
        panels: {
            name: string;
        }[];
        troubleshooting_url?: string | undefined;
        settings?: {
            custom_tab_name?: string | undefined;
        } | undefined;
    } | undefined;
}>;

declare type RowDataFields = {
    name: string;
    serviceName: string;
    serviceTitle: string;
    disabled?: boolean;
    id?: string;
    index?: string;
    __toggleShowSpinner?: boolean;
} & AcceptableFormRecord;

declare type StandardPages = 'configuration' | 'inputs';

export declare type Tab = z.infer<typeof TabSchema>;

declare const TabSchema: z.ZodObject<{
    entity: z.ZodOptional<z.ZodArray<z.ZodDiscriminatedUnion<"type", [z.ZodObject<{
        field: z.ZodString;
        help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
            text: z.ZodString;
            links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                slug: z.ZodString;
                link: z.ZodString;
                linkText: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                slug: string;
                link: string;
                linkText: string;
            }, {
                slug: string;
                link: string;
                linkText: string;
            }>, "many">>;
            link: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        }, {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        }>]>>;
        tooltip: z.ZodOptional<z.ZodString>;
    } & {
        type: z.ZodLiteral<"helpLink">;
        label: z.ZodOptional<z.ZodString>;
        options: z.ZodOptional<z.ZodObject<{
            text: z.ZodString;
            links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                slug: z.ZodString;
                link: z.ZodString;
                linkText: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                slug: string;
                link: string;
                linkText: string;
            }, {
                slug: string;
                link: string;
                linkText: string;
            }>, "many">>;
            link: z.ZodOptional<z.ZodString>;
        } & {
            hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
        }, "strip", z.ZodTypeAny, {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
        }, {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
        }>>;
        required: z.ZodOptional<z.ZodDefault<z.ZodLiteral<false>>>;
    }, "strip", z.ZodTypeAny, {
        type: "helpLink";
        field: string;
        options?: {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
        } | undefined;
        label?: string | undefined;
        help?: string | {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        } | undefined;
        tooltip?: string | undefined;
        required?: false | undefined;
    }, {
        type: "helpLink";
        field: string;
        options?: {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
        } | undefined;
        label?: string | undefined;
        help?: string | {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        } | undefined;
        tooltip?: string | undefined;
        required?: false | undefined;
    }>, z.ZodObject<{
        field: z.ZodString;
        label: z.ZodString;
        help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
            text: z.ZodString;
            links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                slug: z.ZodString;
                link: z.ZodString;
                linkText: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                slug: string;
                link: string;
                linkText: string;
            }, {
                slug: string;
                link: string;
                linkText: string;
            }>, "many">>;
            link: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        }, {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        }>]>>;
        tooltip: z.ZodOptional<z.ZodString>;
        required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
        encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
    } & {
        type: z.ZodLiteral<"text">;
        validators: z.ZodOptional<z.ZodArray<z.ZodUnion<[z.ZodObject<{
            errorMsg: z.ZodOptional<z.ZodString>;
            type: z.ZodLiteral<"number">;
            range: z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>;
            isInteger: z.ZodOptional<z.ZodBoolean>;
        }, "strip", z.ZodTypeAny, {
            type: "number";
            range: [number, number];
            errorMsg?: string | undefined;
            isInteger?: boolean | undefined;
        }, {
            type: "number";
            range: [number, number];
            errorMsg?: string | undefined;
            isInteger?: boolean | undefined;
        }>, z.ZodObject<{
            errorMsg: z.ZodOptional<z.ZodString>;
            type: z.ZodLiteral<"string">;
            minLength: z.ZodNumber;
            maxLength: z.ZodNumber;
        }, "strip", z.ZodTypeAny, {
            type: "string";
            minLength: number;
            maxLength: number;
            errorMsg?: string | undefined;
        }, {
            type: "string";
            minLength: number;
            maxLength: number;
            errorMsg?: string | undefined;
        }>, z.ZodObject<{
            errorMsg: z.ZodOptional<z.ZodString>;
            type: z.ZodLiteral<"regex">;
            pattern: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            type: "regex";
            pattern: string;
            errorMsg?: string | undefined;
        }, {
            type: "regex";
            pattern: string;
            errorMsg?: string | undefined;
        }>, z.ZodObject<{
            errorMsg: z.ZodOptional<z.ZodString>;
            type: z.ZodLiteral<"email">;
        }, "strip", z.ZodTypeAny, {
            type: "email";
            errorMsg?: string | undefined;
        }, {
            type: "email";
            errorMsg?: string | undefined;
        }>, z.ZodObject<{
            errorMsg: z.ZodOptional<z.ZodString>;
            type: z.ZodLiteral<"ipv4">;
        }, "strip", z.ZodTypeAny, {
            type: "ipv4";
            errorMsg?: string | undefined;
        }, {
            type: "ipv4";
            errorMsg?: string | undefined;
        }>, z.ZodObject<{
            errorMsg: z.ZodOptional<z.ZodString>;
            type: z.ZodLiteral<"url">;
        }, "strip", z.ZodTypeAny, {
            type: "url";
            errorMsg?: string | undefined;
        }, {
            type: "url";
            errorMsg?: string | undefined;
        }>, z.ZodObject<{
            errorMsg: z.ZodOptional<z.ZodString>;
            type: z.ZodLiteral<"date">;
        }, "strip", z.ZodTypeAny, {
            type: "date";
            errorMsg?: string | undefined;
        }, {
            type: "date";
            errorMsg?: string | undefined;
        }>]>, "many">>;
        defaultValue: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodNumber, z.ZodBoolean]>>;
        options: z.ZodOptional<z.ZodObject<{
            display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
        }, "strip", z.ZodTypeAny, {
            display?: boolean | undefined;
            disableonEdit?: boolean | undefined;
            enable?: boolean | undefined;
            requiredWhenVisible?: boolean | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
        }, {
            display?: boolean | undefined;
            disableonEdit?: boolean | undefined;
            enable?: boolean | undefined;
            requiredWhenVisible?: boolean | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
        }>>;
        modifyFieldsOnValue: z.ZodOptional<z.ZodArray<z.ZodObject<{
            fieldValue: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
            mode: z.ZodOptional<z.ZodEnum<["create", "edit", "config", "clone"]>>;
            fieldsToModify: z.ZodArray<z.ZodObject<{
                fieldId: z.ZodString;
                display: z.ZodOptional<z.ZodBoolean>;
                value: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>>;
                disabled: z.ZodOptional<z.ZodBoolean>;
                required: z.ZodOptional<z.ZodBoolean>;
                help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                    text: z.ZodString;
                    links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        slug: z.ZodString;
                        link: z.ZodString;
                        linkText: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }>, "many">>;
                    link: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }>]>>;
                label: z.ZodOptional<z.ZodString>;
                markdownMessage: z.ZodOptional<z.ZodUnion<[z.ZodObject<{
                    markdownType: z.ZodLiteral<"text">;
                    text: z.ZodString;
                    color: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                }, {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                }>, z.ZodObject<{
                    markdownType: z.ZodLiteral<"hybrid">;
                    text: z.ZodString;
                    token: z.ZodString;
                    linkText: z.ZodString;
                    link: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                }, {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                }>, z.ZodObject<{
                    markdownType: z.ZodLiteral<"link">;
                    text: z.ZodString;
                    link: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    link: string;
                    markdownType: "link";
                }, {
                    text: string;
                    link: string;
                    markdownType: "link";
                }>, z.ZodObject<{
                    markdownType: z.ZodOptional<z.ZodUndefined>;
                    text: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    markdownType?: undefined;
                }, {
                    text: string;
                    markdownType?: undefined;
                }>]>>;
            }, "strip", z.ZodTypeAny, {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }, {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }>, "many">;
        }, "strip", z.ZodTypeAny, {
            fieldValue: string | number | boolean;
            fieldsToModify: {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }[];
            mode?: "clone" | "create" | "edit" | "config" | undefined;
        }, {
            fieldValue: string | number | boolean;
            fieldsToModify: {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }[];
            mode?: "clone" | "create" | "edit" | "config" | undefined;
        }>, "many">>;
    }, "strip", z.ZodTypeAny, {
        type: "text";
        label: string;
        field: string;
        options?: {
            display?: boolean | undefined;
            disableonEdit?: boolean | undefined;
            enable?: boolean | undefined;
            requiredWhenVisible?: boolean | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
        } | undefined;
        help?: string | {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        } | undefined;
        tooltip?: string | undefined;
        required?: boolean | undefined;
        encrypted?: boolean | undefined;
        validators?: ({
            type: "number";
            range: [number, number];
            errorMsg?: string | undefined;
            isInteger?: boolean | undefined;
        } | {
            type: "string";
            minLength: number;
            maxLength: number;
            errorMsg?: string | undefined;
        } | {
            type: "regex";
            pattern: string;
            errorMsg?: string | undefined;
        } | {
            type: "email";
            errorMsg?: string | undefined;
        } | {
            type: "ipv4";
            errorMsg?: string | undefined;
        } | {
            type: "url";
            errorMsg?: string | undefined;
        } | {
            type: "date";
            errorMsg?: string | undefined;
        })[] | undefined;
        defaultValue?: string | number | boolean | undefined;
        modifyFieldsOnValue?: {
            fieldValue: string | number | boolean;
            fieldsToModify: {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }[];
            mode?: "clone" | "create" | "edit" | "config" | undefined;
        }[] | undefined;
    }, {
        type: "text";
        label: string;
        field: string;
        options?: {
            display?: boolean | undefined;
            disableonEdit?: boolean | undefined;
            enable?: boolean | undefined;
            requiredWhenVisible?: boolean | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
        } | undefined;
        help?: string | {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        } | undefined;
        tooltip?: string | undefined;
        required?: boolean | undefined;
        encrypted?: boolean | undefined;
        validators?: ({
            type: "number";
            range: [number, number];
            errorMsg?: string | undefined;
            isInteger?: boolean | undefined;
        } | {
            type: "string";
            minLength: number;
            maxLength: number;
            errorMsg?: string | undefined;
        } | {
            type: "regex";
            pattern: string;
            errorMsg?: string | undefined;
        } | {
            type: "email";
            errorMsg?: string | undefined;
        } | {
            type: "ipv4";
            errorMsg?: string | undefined;
        } | {
            type: "url";
            errorMsg?: string | undefined;
        } | {
            type: "date";
            errorMsg?: string | undefined;
        })[] | undefined;
        defaultValue?: string | number | boolean | undefined;
        modifyFieldsOnValue?: {
            fieldValue: string | number | boolean;
            fieldsToModify: {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }[];
            mode?: "clone" | "create" | "edit" | "config" | undefined;
        }[] | undefined;
    }>, z.ZodObject<{
        field: z.ZodString;
        label: z.ZodString;
        help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
            text: z.ZodString;
            links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                slug: z.ZodString;
                link: z.ZodString;
                linkText: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                slug: string;
                link: string;
                linkText: string;
            }, {
                slug: string;
                link: string;
                linkText: string;
            }>, "many">>;
            link: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        }, {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        }>]>>;
        tooltip: z.ZodOptional<z.ZodString>;
        required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
        encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
    } & {
        type: z.ZodLiteral<"textarea">;
        validators: z.ZodOptional<z.ZodArray<z.ZodUnion<[z.ZodObject<{
            errorMsg: z.ZodOptional<z.ZodString>;
            type: z.ZodLiteral<"number">;
            range: z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>;
            isInteger: z.ZodOptional<z.ZodBoolean>;
        }, "strip", z.ZodTypeAny, {
            type: "number";
            range: [number, number];
            errorMsg?: string | undefined;
            isInteger?: boolean | undefined;
        }, {
            type: "number";
            range: [number, number];
            errorMsg?: string | undefined;
            isInteger?: boolean | undefined;
        }>, z.ZodObject<{
            errorMsg: z.ZodOptional<z.ZodString>;
            type: z.ZodLiteral<"string">;
            minLength: z.ZodNumber;
            maxLength: z.ZodNumber;
        }, "strip", z.ZodTypeAny, {
            type: "string";
            minLength: number;
            maxLength: number;
            errorMsg?: string | undefined;
        }, {
            type: "string";
            minLength: number;
            maxLength: number;
            errorMsg?: string | undefined;
        }>, z.ZodObject<{
            errorMsg: z.ZodOptional<z.ZodString>;
            type: z.ZodLiteral<"regex">;
            pattern: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            type: "regex";
            pattern: string;
            errorMsg?: string | undefined;
        }, {
            type: "regex";
            pattern: string;
            errorMsg?: string | undefined;
        }>, z.ZodObject<{
            errorMsg: z.ZodOptional<z.ZodString>;
            type: z.ZodLiteral<"email">;
        }, "strip", z.ZodTypeAny, {
            type: "email";
            errorMsg?: string | undefined;
        }, {
            type: "email";
            errorMsg?: string | undefined;
        }>, z.ZodObject<{
            errorMsg: z.ZodOptional<z.ZodString>;
            type: z.ZodLiteral<"ipv4">;
        }, "strip", z.ZodTypeAny, {
            type: "ipv4";
            errorMsg?: string | undefined;
        }, {
            type: "ipv4";
            errorMsg?: string | undefined;
        }>, z.ZodObject<{
            errorMsg: z.ZodOptional<z.ZodString>;
            type: z.ZodLiteral<"url">;
        }, "strip", z.ZodTypeAny, {
            type: "url";
            errorMsg?: string | undefined;
        }, {
            type: "url";
            errorMsg?: string | undefined;
        }>, z.ZodObject<{
            errorMsg: z.ZodOptional<z.ZodString>;
            type: z.ZodLiteral<"date">;
        }, "strip", z.ZodTypeAny, {
            type: "date";
            errorMsg?: string | undefined;
        }, {
            type: "date";
            errorMsg?: string | undefined;
        }>]>, "many">>;
        defaultValue: z.ZodOptional<z.ZodString>;
        options: z.ZodOptional<z.ZodObject<{
            display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
        } & {
            rowsMin: z.ZodOptional<z.ZodNumber>;
            rowsMax: z.ZodOptional<z.ZodNumber>;
        }, "strip", z.ZodTypeAny, {
            display?: boolean | undefined;
            disableonEdit?: boolean | undefined;
            enable?: boolean | undefined;
            requiredWhenVisible?: boolean | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
            rowsMin?: number | undefined;
            rowsMax?: number | undefined;
        }, {
            display?: boolean | undefined;
            disableonEdit?: boolean | undefined;
            enable?: boolean | undefined;
            requiredWhenVisible?: boolean | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
            rowsMin?: number | undefined;
            rowsMax?: number | undefined;
        }>>;
        modifyFieldsOnValue: z.ZodOptional<z.ZodArray<z.ZodObject<{
            fieldValue: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
            mode: z.ZodOptional<z.ZodEnum<["create", "edit", "config", "clone"]>>;
            fieldsToModify: z.ZodArray<z.ZodObject<{
                fieldId: z.ZodString;
                display: z.ZodOptional<z.ZodBoolean>;
                value: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>>;
                disabled: z.ZodOptional<z.ZodBoolean>;
                required: z.ZodOptional<z.ZodBoolean>;
                help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                    text: z.ZodString;
                    links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        slug: z.ZodString;
                        link: z.ZodString;
                        linkText: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }>, "many">>;
                    link: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }>]>>;
                label: z.ZodOptional<z.ZodString>;
                markdownMessage: z.ZodOptional<z.ZodUnion<[z.ZodObject<{
                    markdownType: z.ZodLiteral<"text">;
                    text: z.ZodString;
                    color: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                }, {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                }>, z.ZodObject<{
                    markdownType: z.ZodLiteral<"hybrid">;
                    text: z.ZodString;
                    token: z.ZodString;
                    linkText: z.ZodString;
                    link: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                }, {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                }>, z.ZodObject<{
                    markdownType: z.ZodLiteral<"link">;
                    text: z.ZodString;
                    link: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    link: string;
                    markdownType: "link";
                }, {
                    text: string;
                    link: string;
                    markdownType: "link";
                }>, z.ZodObject<{
                    markdownType: z.ZodOptional<z.ZodUndefined>;
                    text: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    markdownType?: undefined;
                }, {
                    text: string;
                    markdownType?: undefined;
                }>]>>;
            }, "strip", z.ZodTypeAny, {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }, {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }>, "many">;
        }, "strip", z.ZodTypeAny, {
            fieldValue: string | number | boolean;
            fieldsToModify: {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }[];
            mode?: "clone" | "create" | "edit" | "config" | undefined;
        }, {
            fieldValue: string | number | boolean;
            fieldsToModify: {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }[];
            mode?: "clone" | "create" | "edit" | "config" | undefined;
        }>, "many">>;
    }, "strip", z.ZodTypeAny, {
        type: "textarea";
        label: string;
        field: string;
        options?: {
            display?: boolean | undefined;
            disableonEdit?: boolean | undefined;
            enable?: boolean | undefined;
            requiredWhenVisible?: boolean | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
            rowsMin?: number | undefined;
            rowsMax?: number | undefined;
        } | undefined;
        help?: string | {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        } | undefined;
        tooltip?: string | undefined;
        required?: boolean | undefined;
        encrypted?: boolean | undefined;
        validators?: ({
            type: "number";
            range: [number, number];
            errorMsg?: string | undefined;
            isInteger?: boolean | undefined;
        } | {
            type: "string";
            minLength: number;
            maxLength: number;
            errorMsg?: string | undefined;
        } | {
            type: "regex";
            pattern: string;
            errorMsg?: string | undefined;
        } | {
            type: "email";
            errorMsg?: string | undefined;
        } | {
            type: "ipv4";
            errorMsg?: string | undefined;
        } | {
            type: "url";
            errorMsg?: string | undefined;
        } | {
            type: "date";
            errorMsg?: string | undefined;
        })[] | undefined;
        defaultValue?: string | undefined;
        modifyFieldsOnValue?: {
            fieldValue: string | number | boolean;
            fieldsToModify: {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }[];
            mode?: "clone" | "create" | "edit" | "config" | undefined;
        }[] | undefined;
    }, {
        type: "textarea";
        label: string;
        field: string;
        options?: {
            display?: boolean | undefined;
            disableonEdit?: boolean | undefined;
            enable?: boolean | undefined;
            requiredWhenVisible?: boolean | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
            rowsMin?: number | undefined;
            rowsMax?: number | undefined;
        } | undefined;
        help?: string | {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        } | undefined;
        tooltip?: string | undefined;
        required?: boolean | undefined;
        encrypted?: boolean | undefined;
        validators?: ({
            type: "number";
            range: [number, number];
            errorMsg?: string | undefined;
            isInteger?: boolean | undefined;
        } | {
            type: "string";
            minLength: number;
            maxLength: number;
            errorMsg?: string | undefined;
        } | {
            type: "regex";
            pattern: string;
            errorMsg?: string | undefined;
        } | {
            type: "email";
            errorMsg?: string | undefined;
        } | {
            type: "ipv4";
            errorMsg?: string | undefined;
        } | {
            type: "url";
            errorMsg?: string | undefined;
        } | {
            type: "date";
            errorMsg?: string | undefined;
        })[] | undefined;
        defaultValue?: string | undefined;
        modifyFieldsOnValue?: {
            fieldValue: string | number | boolean;
            fieldsToModify: {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }[];
            mode?: "clone" | "create" | "edit" | "config" | undefined;
        }[] | undefined;
    }>, z.ZodObject<{
        field: z.ZodString;
        label: z.ZodString;
        help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
            text: z.ZodString;
            links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                slug: z.ZodString;
                link: z.ZodString;
                linkText: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                slug: string;
                link: string;
                linkText: string;
            }, {
                slug: string;
                link: string;
                linkText: string;
            }>, "many">>;
            link: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        }, {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        }>]>>;
        tooltip: z.ZodOptional<z.ZodString>;
        required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
        encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
    } & {
        type: z.ZodLiteral<"singleSelect">;
        validators: z.ZodOptional<z.ZodArray<z.ZodUnion<[z.ZodObject<{
            errorMsg: z.ZodOptional<z.ZodString>;
            type: z.ZodLiteral<"number">;
            range: z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>;
            isInteger: z.ZodOptional<z.ZodBoolean>;
        }, "strip", z.ZodTypeAny, {
            type: "number";
            range: [number, number];
            errorMsg?: string | undefined;
            isInteger?: boolean | undefined;
        }, {
            type: "number";
            range: [number, number];
            errorMsg?: string | undefined;
            isInteger?: boolean | undefined;
        }>, z.ZodObject<{
            errorMsg: z.ZodOptional<z.ZodString>;
            type: z.ZodLiteral<"string">;
            minLength: z.ZodNumber;
            maxLength: z.ZodNumber;
        }, "strip", z.ZodTypeAny, {
            type: "string";
            minLength: number;
            maxLength: number;
            errorMsg?: string | undefined;
        }, {
            type: "string";
            minLength: number;
            maxLength: number;
            errorMsg?: string | undefined;
        }>, z.ZodObject<{
            errorMsg: z.ZodOptional<z.ZodString>;
            type: z.ZodLiteral<"regex">;
            pattern: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            type: "regex";
            pattern: string;
            errorMsg?: string | undefined;
        }, {
            type: "regex";
            pattern: string;
            errorMsg?: string | undefined;
        }>, z.ZodObject<{
            errorMsg: z.ZodOptional<z.ZodString>;
            type: z.ZodLiteral<"email">;
        }, "strip", z.ZodTypeAny, {
            type: "email";
            errorMsg?: string | undefined;
        }, {
            type: "email";
            errorMsg?: string | undefined;
        }>, z.ZodObject<{
            errorMsg: z.ZodOptional<z.ZodString>;
            type: z.ZodLiteral<"ipv4">;
        }, "strip", z.ZodTypeAny, {
            type: "ipv4";
            errorMsg?: string | undefined;
        }, {
            type: "ipv4";
            errorMsg?: string | undefined;
        }>, z.ZodObject<{
            errorMsg: z.ZodOptional<z.ZodString>;
            type: z.ZodLiteral<"url">;
        }, "strip", z.ZodTypeAny, {
            type: "url";
            errorMsg?: string | undefined;
        }, {
            type: "url";
            errorMsg?: string | undefined;
        }>, z.ZodObject<{
            errorMsg: z.ZodOptional<z.ZodString>;
            type: z.ZodLiteral<"date">;
        }, "strip", z.ZodTypeAny, {
            type: "date";
            errorMsg?: string | undefined;
        }, {
            type: "date";
            errorMsg?: string | undefined;
        }>]>, "many">>;
        defaultValue: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodNumber, z.ZodBoolean]>>;
        options: z.ZodObject<{
            display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
        } & {
            disableSearch: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            createSearchChoice: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            referenceName: z.ZodOptional<z.ZodString>;
            endpointUrl: z.ZodOptional<z.ZodString>;
            allowList: z.ZodOptional<z.ZodString>;
            denyList: z.ZodOptional<z.ZodString>;
            labelField: z.ZodOptional<z.ZodString>;
            valueField: z.ZodOptional<z.ZodString>;
            autoCompleteFields: z.ZodOptional<z.ZodArray<z.ZodUnion<[z.ZodObject<{
                value: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                label: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                value: string | number | boolean;
                label: string;
            }, {
                value: string | number | boolean;
                label: string;
            }>, z.ZodObject<{
                label: z.ZodString;
                children: z.ZodArray<z.ZodObject<{
                    value: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                    label: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    value: string | number | boolean;
                    label: string;
                }, {
                    value: string | number | boolean;
                    label: string;
                }>, "many">;
            }, "strip", z.ZodTypeAny, {
                label: string;
                children: {
                    value: string | number | boolean;
                    label: string;
                }[];
            }, {
                label: string;
                children: {
                    value: string | number | boolean;
                    label: string;
                }[];
            }>]>, "many">>;
            dependencies: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
            items: z.ZodOptional<z.ZodArray<z.ZodObject<{
                value: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                label: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                value: string | number | boolean;
                label: string;
            }, {
                value: string | number | boolean;
                label: string;
            }>, "many">>;
        }, "strip", z.ZodTypeAny, {
            display?: boolean | undefined;
            disableonEdit?: boolean | undefined;
            enable?: boolean | undefined;
            requiredWhenVisible?: boolean | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
            disableSearch?: boolean | undefined;
            createSearchChoice?: boolean | undefined;
            referenceName?: string | undefined;
            endpointUrl?: string | undefined;
            allowList?: string | undefined;
            denyList?: string | undefined;
            labelField?: string | undefined;
            valueField?: string | undefined;
            autoCompleteFields?: ({
                value: string | number | boolean;
                label: string;
            } | {
                label: string;
                children: {
                    value: string | number | boolean;
                    label: string;
                }[];
            })[] | undefined;
            dependencies?: string[] | undefined;
            items?: {
                value: string | number | boolean;
                label: string;
            }[] | undefined;
        }, {
            display?: boolean | undefined;
            disableonEdit?: boolean | undefined;
            enable?: boolean | undefined;
            requiredWhenVisible?: boolean | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
            disableSearch?: boolean | undefined;
            createSearchChoice?: boolean | undefined;
            referenceName?: string | undefined;
            endpointUrl?: string | undefined;
            allowList?: string | undefined;
            denyList?: string | undefined;
            labelField?: string | undefined;
            valueField?: string | undefined;
            autoCompleteFields?: ({
                value: string | number | boolean;
                label: string;
            } | {
                label: string;
                children: {
                    value: string | number | boolean;
                    label: string;
                }[];
            })[] | undefined;
            dependencies?: string[] | undefined;
            items?: {
                value: string | number | boolean;
                label: string;
            }[] | undefined;
        }>;
        modifyFieldsOnValue: z.ZodOptional<z.ZodArray<z.ZodObject<{
            fieldValue: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
            mode: z.ZodOptional<z.ZodEnum<["create", "edit", "config", "clone"]>>;
            fieldsToModify: z.ZodArray<z.ZodObject<{
                fieldId: z.ZodString;
                display: z.ZodOptional<z.ZodBoolean>;
                value: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>>;
                disabled: z.ZodOptional<z.ZodBoolean>;
                required: z.ZodOptional<z.ZodBoolean>;
                help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                    text: z.ZodString;
                    links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        slug: z.ZodString;
                        link: z.ZodString;
                        linkText: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }>, "many">>;
                    link: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }>]>>;
                label: z.ZodOptional<z.ZodString>;
                markdownMessage: z.ZodOptional<z.ZodUnion<[z.ZodObject<{
                    markdownType: z.ZodLiteral<"text">;
                    text: z.ZodString;
                    color: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                }, {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                }>, z.ZodObject<{
                    markdownType: z.ZodLiteral<"hybrid">;
                    text: z.ZodString;
                    token: z.ZodString;
                    linkText: z.ZodString;
                    link: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                }, {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                }>, z.ZodObject<{
                    markdownType: z.ZodLiteral<"link">;
                    text: z.ZodString;
                    link: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    link: string;
                    markdownType: "link";
                }, {
                    text: string;
                    link: string;
                    markdownType: "link";
                }>, z.ZodObject<{
                    markdownType: z.ZodOptional<z.ZodUndefined>;
                    text: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    markdownType?: undefined;
                }, {
                    text: string;
                    markdownType?: undefined;
                }>]>>;
            }, "strip", z.ZodTypeAny, {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }, {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }>, "many">;
        }, "strip", z.ZodTypeAny, {
            fieldValue: string | number | boolean;
            fieldsToModify: {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }[];
            mode?: "clone" | "create" | "edit" | "config" | undefined;
        }, {
            fieldValue: string | number | boolean;
            fieldsToModify: {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }[];
            mode?: "clone" | "create" | "edit" | "config" | undefined;
        }>, "many">>;
    }, "strip", z.ZodTypeAny, {
        options: {
            display?: boolean | undefined;
            disableonEdit?: boolean | undefined;
            enable?: boolean | undefined;
            requiredWhenVisible?: boolean | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
            disableSearch?: boolean | undefined;
            createSearchChoice?: boolean | undefined;
            referenceName?: string | undefined;
            endpointUrl?: string | undefined;
            allowList?: string | undefined;
            denyList?: string | undefined;
            labelField?: string | undefined;
            valueField?: string | undefined;
            autoCompleteFields?: ({
                value: string | number | boolean;
                label: string;
            } | {
                label: string;
                children: {
                    value: string | number | boolean;
                    label: string;
                }[];
            })[] | undefined;
            dependencies?: string[] | undefined;
            items?: {
                value: string | number | boolean;
                label: string;
            }[] | undefined;
        };
        type: "singleSelect";
        label: string;
        field: string;
        help?: string | {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        } | undefined;
        tooltip?: string | undefined;
        required?: boolean | undefined;
        encrypted?: boolean | undefined;
        validators?: ({
            type: "number";
            range: [number, number];
            errorMsg?: string | undefined;
            isInteger?: boolean | undefined;
        } | {
            type: "string";
            minLength: number;
            maxLength: number;
            errorMsg?: string | undefined;
        } | {
            type: "regex";
            pattern: string;
            errorMsg?: string | undefined;
        } | {
            type: "email";
            errorMsg?: string | undefined;
        } | {
            type: "ipv4";
            errorMsg?: string | undefined;
        } | {
            type: "url";
            errorMsg?: string | undefined;
        } | {
            type: "date";
            errorMsg?: string | undefined;
        })[] | undefined;
        defaultValue?: string | number | boolean | undefined;
        modifyFieldsOnValue?: {
            fieldValue: string | number | boolean;
            fieldsToModify: {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }[];
            mode?: "clone" | "create" | "edit" | "config" | undefined;
        }[] | undefined;
    }, {
        options: {
            display?: boolean | undefined;
            disableonEdit?: boolean | undefined;
            enable?: boolean | undefined;
            requiredWhenVisible?: boolean | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
            disableSearch?: boolean | undefined;
            createSearchChoice?: boolean | undefined;
            referenceName?: string | undefined;
            endpointUrl?: string | undefined;
            allowList?: string | undefined;
            denyList?: string | undefined;
            labelField?: string | undefined;
            valueField?: string | undefined;
            autoCompleteFields?: ({
                value: string | number | boolean;
                label: string;
            } | {
                label: string;
                children: {
                    value: string | number | boolean;
                    label: string;
                }[];
            })[] | undefined;
            dependencies?: string[] | undefined;
            items?: {
                value: string | number | boolean;
                label: string;
            }[] | undefined;
        };
        type: "singleSelect";
        label: string;
        field: string;
        help?: string | {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        } | undefined;
        tooltip?: string | undefined;
        required?: boolean | undefined;
        encrypted?: boolean | undefined;
        validators?: ({
            type: "number";
            range: [number, number];
            errorMsg?: string | undefined;
            isInteger?: boolean | undefined;
        } | {
            type: "string";
            minLength: number;
            maxLength: number;
            errorMsg?: string | undefined;
        } | {
            type: "regex";
            pattern: string;
            errorMsg?: string | undefined;
        } | {
            type: "email";
            errorMsg?: string | undefined;
        } | {
            type: "ipv4";
            errorMsg?: string | undefined;
        } | {
            type: "url";
            errorMsg?: string | undefined;
        } | {
            type: "date";
            errorMsg?: string | undefined;
        })[] | undefined;
        defaultValue?: string | number | boolean | undefined;
        modifyFieldsOnValue?: {
            fieldValue: string | number | boolean;
            fieldsToModify: {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }[];
            mode?: "clone" | "create" | "edit" | "config" | undefined;
        }[] | undefined;
    }>, z.ZodObject<{
        field: z.ZodString;
        label: z.ZodString;
        help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
            text: z.ZodString;
            links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                slug: z.ZodString;
                link: z.ZodString;
                linkText: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                slug: string;
                link: string;
                linkText: string;
            }, {
                slug: string;
                link: string;
                linkText: string;
            }>, "many">>;
            link: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        }, {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        }>]>>;
        tooltip: z.ZodOptional<z.ZodString>;
        required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
        encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
    } & {
        type: z.ZodLiteral<"multipleSelect">;
        validators: z.ZodOptional<z.ZodArray<z.ZodUnion<[z.ZodObject<{
            errorMsg: z.ZodOptional<z.ZodString>;
            type: z.ZodLiteral<"number">;
            range: z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>;
            isInteger: z.ZodOptional<z.ZodBoolean>;
        }, "strip", z.ZodTypeAny, {
            type: "number";
            range: [number, number];
            errorMsg?: string | undefined;
            isInteger?: boolean | undefined;
        }, {
            type: "number";
            range: [number, number];
            errorMsg?: string | undefined;
            isInteger?: boolean | undefined;
        }>, z.ZodObject<{
            errorMsg: z.ZodOptional<z.ZodString>;
            type: z.ZodLiteral<"string">;
            minLength: z.ZodNumber;
            maxLength: z.ZodNumber;
        }, "strip", z.ZodTypeAny, {
            type: "string";
            minLength: number;
            maxLength: number;
            errorMsg?: string | undefined;
        }, {
            type: "string";
            minLength: number;
            maxLength: number;
            errorMsg?: string | undefined;
        }>, z.ZodObject<{
            errorMsg: z.ZodOptional<z.ZodString>;
            type: z.ZodLiteral<"regex">;
            pattern: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            type: "regex";
            pattern: string;
            errorMsg?: string | undefined;
        }, {
            type: "regex";
            pattern: string;
            errorMsg?: string | undefined;
        }>, z.ZodObject<{
            errorMsg: z.ZodOptional<z.ZodString>;
            type: z.ZodLiteral<"email">;
        }, "strip", z.ZodTypeAny, {
            type: "email";
            errorMsg?: string | undefined;
        }, {
            type: "email";
            errorMsg?: string | undefined;
        }>, z.ZodObject<{
            errorMsg: z.ZodOptional<z.ZodString>;
            type: z.ZodLiteral<"ipv4">;
        }, "strip", z.ZodTypeAny, {
            type: "ipv4";
            errorMsg?: string | undefined;
        }, {
            type: "ipv4";
            errorMsg?: string | undefined;
        }>, z.ZodObject<{
            errorMsg: z.ZodOptional<z.ZodString>;
            type: z.ZodLiteral<"url">;
        }, "strip", z.ZodTypeAny, {
            type: "url";
            errorMsg?: string | undefined;
        }, {
            type: "url";
            errorMsg?: string | undefined;
        }>, z.ZodObject<{
            errorMsg: z.ZodOptional<z.ZodString>;
            type: z.ZodLiteral<"date">;
        }, "strip", z.ZodTypeAny, {
            type: "date";
            errorMsg?: string | undefined;
        }, {
            type: "date";
            errorMsg?: string | undefined;
        }>]>, "many">>;
        defaultValue: z.ZodOptional<z.ZodString>;
        options: z.ZodObject<{
            display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
        } & {
            disableSearch: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            createSearchChoice: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            referenceName: z.ZodOptional<z.ZodString>;
            endpointUrl: z.ZodOptional<z.ZodString>;
            allowList: z.ZodOptional<z.ZodString>;
            denyList: z.ZodOptional<z.ZodString>;
            labelField: z.ZodOptional<z.ZodString>;
            valueField: z.ZodOptional<z.ZodString>;
            autoCompleteFields: z.ZodOptional<z.ZodArray<z.ZodUnion<[z.ZodObject<{
                value: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                label: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                value: string | number | boolean;
                label: string;
            }, {
                value: string | number | boolean;
                label: string;
            }>, z.ZodObject<{
                label: z.ZodString;
                children: z.ZodArray<z.ZodObject<{
                    value: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                    label: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    value: string | number | boolean;
                    label: string;
                }, {
                    value: string | number | boolean;
                    label: string;
                }>, "many">;
            }, "strip", z.ZodTypeAny, {
                label: string;
                children: {
                    value: string | number | boolean;
                    label: string;
                }[];
            }, {
                label: string;
                children: {
                    value: string | number | boolean;
                    label: string;
                }[];
            }>]>, "many">>;
            dependencies: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
            items: z.ZodOptional<z.ZodArray<z.ZodObject<{
                value: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                label: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                value: string | number | boolean;
                label: string;
            }, {
                value: string | number | boolean;
                label: string;
            }>, "many">>;
        } & {
            delimiter: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            display?: boolean | undefined;
            disableonEdit?: boolean | undefined;
            enable?: boolean | undefined;
            requiredWhenVisible?: boolean | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
            disableSearch?: boolean | undefined;
            createSearchChoice?: boolean | undefined;
            referenceName?: string | undefined;
            endpointUrl?: string | undefined;
            allowList?: string | undefined;
            denyList?: string | undefined;
            labelField?: string | undefined;
            valueField?: string | undefined;
            autoCompleteFields?: ({
                value: string | number | boolean;
                label: string;
            } | {
                label: string;
                children: {
                    value: string | number | boolean;
                    label: string;
                }[];
            })[] | undefined;
            dependencies?: string[] | undefined;
            items?: {
                value: string | number | boolean;
                label: string;
            }[] | undefined;
            delimiter?: string | undefined;
        }, {
            display?: boolean | undefined;
            disableonEdit?: boolean | undefined;
            enable?: boolean | undefined;
            requiredWhenVisible?: boolean | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
            disableSearch?: boolean | undefined;
            createSearchChoice?: boolean | undefined;
            referenceName?: string | undefined;
            endpointUrl?: string | undefined;
            allowList?: string | undefined;
            denyList?: string | undefined;
            labelField?: string | undefined;
            valueField?: string | undefined;
            autoCompleteFields?: ({
                value: string | number | boolean;
                label: string;
            } | {
                label: string;
                children: {
                    value: string | number | boolean;
                    label: string;
                }[];
            })[] | undefined;
            dependencies?: string[] | undefined;
            items?: {
                value: string | number | boolean;
                label: string;
            }[] | undefined;
            delimiter?: string | undefined;
        }>;
        modifyFieldsOnValue: z.ZodOptional<z.ZodArray<z.ZodObject<{
            fieldValue: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
            mode: z.ZodOptional<z.ZodEnum<["create", "edit", "config", "clone"]>>;
            fieldsToModify: z.ZodArray<z.ZodObject<{
                fieldId: z.ZodString;
                display: z.ZodOptional<z.ZodBoolean>;
                value: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>>;
                disabled: z.ZodOptional<z.ZodBoolean>;
                required: z.ZodOptional<z.ZodBoolean>;
                help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                    text: z.ZodString;
                    links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        slug: z.ZodString;
                        link: z.ZodString;
                        linkText: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }>, "many">>;
                    link: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }>]>>;
                label: z.ZodOptional<z.ZodString>;
                markdownMessage: z.ZodOptional<z.ZodUnion<[z.ZodObject<{
                    markdownType: z.ZodLiteral<"text">;
                    text: z.ZodString;
                    color: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                }, {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                }>, z.ZodObject<{
                    markdownType: z.ZodLiteral<"hybrid">;
                    text: z.ZodString;
                    token: z.ZodString;
                    linkText: z.ZodString;
                    link: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                }, {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                }>, z.ZodObject<{
                    markdownType: z.ZodLiteral<"link">;
                    text: z.ZodString;
                    link: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    link: string;
                    markdownType: "link";
                }, {
                    text: string;
                    link: string;
                    markdownType: "link";
                }>, z.ZodObject<{
                    markdownType: z.ZodOptional<z.ZodUndefined>;
                    text: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    markdownType?: undefined;
                }, {
                    text: string;
                    markdownType?: undefined;
                }>]>>;
            }, "strip", z.ZodTypeAny, {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }, {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }>, "many">;
        }, "strip", z.ZodTypeAny, {
            fieldValue: string | number | boolean;
            fieldsToModify: {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }[];
            mode?: "clone" | "create" | "edit" | "config" | undefined;
        }, {
            fieldValue: string | number | boolean;
            fieldsToModify: {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }[];
            mode?: "clone" | "create" | "edit" | "config" | undefined;
        }>, "many">>;
    }, "strip", z.ZodTypeAny, {
        options: {
            display?: boolean | undefined;
            disableonEdit?: boolean | undefined;
            enable?: boolean | undefined;
            requiredWhenVisible?: boolean | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
            disableSearch?: boolean | undefined;
            createSearchChoice?: boolean | undefined;
            referenceName?: string | undefined;
            endpointUrl?: string | undefined;
            allowList?: string | undefined;
            denyList?: string | undefined;
            labelField?: string | undefined;
            valueField?: string | undefined;
            autoCompleteFields?: ({
                value: string | number | boolean;
                label: string;
            } | {
                label: string;
                children: {
                    value: string | number | boolean;
                    label: string;
                }[];
            })[] | undefined;
            dependencies?: string[] | undefined;
            items?: {
                value: string | number | boolean;
                label: string;
            }[] | undefined;
            delimiter?: string | undefined;
        };
        type: "multipleSelect";
        label: string;
        field: string;
        help?: string | {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        } | undefined;
        tooltip?: string | undefined;
        required?: boolean | undefined;
        encrypted?: boolean | undefined;
        validators?: ({
            type: "number";
            range: [number, number];
            errorMsg?: string | undefined;
            isInteger?: boolean | undefined;
        } | {
            type: "string";
            minLength: number;
            maxLength: number;
            errorMsg?: string | undefined;
        } | {
            type: "regex";
            pattern: string;
            errorMsg?: string | undefined;
        } | {
            type: "email";
            errorMsg?: string | undefined;
        } | {
            type: "ipv4";
            errorMsg?: string | undefined;
        } | {
            type: "url";
            errorMsg?: string | undefined;
        } | {
            type: "date";
            errorMsg?: string | undefined;
        })[] | undefined;
        defaultValue?: string | undefined;
        modifyFieldsOnValue?: {
            fieldValue: string | number | boolean;
            fieldsToModify: {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }[];
            mode?: "clone" | "create" | "edit" | "config" | undefined;
        }[] | undefined;
    }, {
        options: {
            display?: boolean | undefined;
            disableonEdit?: boolean | undefined;
            enable?: boolean | undefined;
            requiredWhenVisible?: boolean | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
            disableSearch?: boolean | undefined;
            createSearchChoice?: boolean | undefined;
            referenceName?: string | undefined;
            endpointUrl?: string | undefined;
            allowList?: string | undefined;
            denyList?: string | undefined;
            labelField?: string | undefined;
            valueField?: string | undefined;
            autoCompleteFields?: ({
                value: string | number | boolean;
                label: string;
            } | {
                label: string;
                children: {
                    value: string | number | boolean;
                    label: string;
                }[];
            })[] | undefined;
            dependencies?: string[] | undefined;
            items?: {
                value: string | number | boolean;
                label: string;
            }[] | undefined;
            delimiter?: string | undefined;
        };
        type: "multipleSelect";
        label: string;
        field: string;
        help?: string | {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        } | undefined;
        tooltip?: string | undefined;
        required?: boolean | undefined;
        encrypted?: boolean | undefined;
        validators?: ({
            type: "number";
            range: [number, number];
            errorMsg?: string | undefined;
            isInteger?: boolean | undefined;
        } | {
            type: "string";
            minLength: number;
            maxLength: number;
            errorMsg?: string | undefined;
        } | {
            type: "regex";
            pattern: string;
            errorMsg?: string | undefined;
        } | {
            type: "email";
            errorMsg?: string | undefined;
        } | {
            type: "ipv4";
            errorMsg?: string | undefined;
        } | {
            type: "url";
            errorMsg?: string | undefined;
        } | {
            type: "date";
            errorMsg?: string | undefined;
        })[] | undefined;
        defaultValue?: string | undefined;
        modifyFieldsOnValue?: {
            fieldValue: string | number | boolean;
            fieldsToModify: {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }[];
            mode?: "clone" | "create" | "edit" | "config" | undefined;
        }[] | undefined;
    }>, z.ZodObject<{
        field: z.ZodString;
        label: z.ZodString;
        help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
            text: z.ZodString;
            links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                slug: z.ZodString;
                link: z.ZodString;
                linkText: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                slug: string;
                link: string;
                linkText: string;
            }, {
                slug: string;
                link: string;
                linkText: string;
            }>, "many">>;
            link: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        }, {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        }>]>>;
        tooltip: z.ZodOptional<z.ZodString>;
        required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
        encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
    } & {
        type: z.ZodLiteral<"checkbox">;
        defaultValue: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodBoolean]>>;
        options: z.ZodOptional<z.ZodObject<{
            display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
        }, "strip", z.ZodTypeAny, {
            display?: boolean | undefined;
            disableonEdit?: boolean | undefined;
            enable?: boolean | undefined;
            requiredWhenVisible?: boolean | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
        }, {
            display?: boolean | undefined;
            disableonEdit?: boolean | undefined;
            enable?: boolean | undefined;
            requiredWhenVisible?: boolean | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
        }>>;
        modifyFieldsOnValue: z.ZodOptional<z.ZodArray<z.ZodObject<{
            fieldValue: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
            mode: z.ZodOptional<z.ZodEnum<["create", "edit", "config", "clone"]>>;
            fieldsToModify: z.ZodArray<z.ZodObject<{
                fieldId: z.ZodString;
                display: z.ZodOptional<z.ZodBoolean>;
                value: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>>;
                disabled: z.ZodOptional<z.ZodBoolean>;
                required: z.ZodOptional<z.ZodBoolean>;
                help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                    text: z.ZodString;
                    links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        slug: z.ZodString;
                        link: z.ZodString;
                        linkText: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }>, "many">>;
                    link: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }>]>>;
                label: z.ZodOptional<z.ZodString>;
                markdownMessage: z.ZodOptional<z.ZodUnion<[z.ZodObject<{
                    markdownType: z.ZodLiteral<"text">;
                    text: z.ZodString;
                    color: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                }, {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                }>, z.ZodObject<{
                    markdownType: z.ZodLiteral<"hybrid">;
                    text: z.ZodString;
                    token: z.ZodString;
                    linkText: z.ZodString;
                    link: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                }, {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                }>, z.ZodObject<{
                    markdownType: z.ZodLiteral<"link">;
                    text: z.ZodString;
                    link: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    link: string;
                    markdownType: "link";
                }, {
                    text: string;
                    link: string;
                    markdownType: "link";
                }>, z.ZodObject<{
                    markdownType: z.ZodOptional<z.ZodUndefined>;
                    text: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    markdownType?: undefined;
                }, {
                    text: string;
                    markdownType?: undefined;
                }>]>>;
            }, "strip", z.ZodTypeAny, {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }, {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }>, "many">;
        }, "strip", z.ZodTypeAny, {
            fieldValue: string | number | boolean;
            fieldsToModify: {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }[];
            mode?: "clone" | "create" | "edit" | "config" | undefined;
        }, {
            fieldValue: string | number | boolean;
            fieldsToModify: {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }[];
            mode?: "clone" | "create" | "edit" | "config" | undefined;
        }>, "many">>;
    }, "strip", z.ZodTypeAny, {
        type: "checkbox";
        label: string;
        field: string;
        options?: {
            display?: boolean | undefined;
            disableonEdit?: boolean | undefined;
            enable?: boolean | undefined;
            requiredWhenVisible?: boolean | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
        } | undefined;
        help?: string | {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        } | undefined;
        tooltip?: string | undefined;
        required?: boolean | undefined;
        encrypted?: boolean | undefined;
        defaultValue?: number | boolean | undefined;
        modifyFieldsOnValue?: {
            fieldValue: string | number | boolean;
            fieldsToModify: {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }[];
            mode?: "clone" | "create" | "edit" | "config" | undefined;
        }[] | undefined;
    }, {
        type: "checkbox";
        label: string;
        field: string;
        options?: {
            display?: boolean | undefined;
            disableonEdit?: boolean | undefined;
            enable?: boolean | undefined;
            requiredWhenVisible?: boolean | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
        } | undefined;
        help?: string | {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        } | undefined;
        tooltip?: string | undefined;
        required?: boolean | undefined;
        encrypted?: boolean | undefined;
        defaultValue?: number | boolean | undefined;
        modifyFieldsOnValue?: {
            fieldValue: string | number | boolean;
            fieldsToModify: {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }[];
            mode?: "clone" | "create" | "edit" | "config" | undefined;
        }[] | undefined;
    }>, z.ZodObject<{
        field: z.ZodString;
        label: z.ZodString;
        help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
            text: z.ZodString;
            links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                slug: z.ZodString;
                link: z.ZodString;
                linkText: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                slug: string;
                link: string;
                linkText: string;
            }, {
                slug: string;
                link: string;
                linkText: string;
            }>, "many">>;
            link: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        }, {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        }>]>>;
        tooltip: z.ZodOptional<z.ZodString>;
        required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
        encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
    } & {
        type: z.ZodLiteral<"checkboxGroup">;
        validators: z.ZodOptional<z.ZodTuple<[z.ZodObject<{
            errorMsg: z.ZodOptional<z.ZodString>;
            type: z.ZodLiteral<"regex">;
            pattern: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            type: "regex";
            pattern: string;
            errorMsg?: string | undefined;
        }, {
            type: "regex";
            pattern: string;
            errorMsg?: string | undefined;
        }>], null>>;
        defaultValue: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodBoolean]>>;
        options: z.ZodObject<{
            display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
        } & {
            delimiter: z.ZodOptional<z.ZodString>;
            groups: z.ZodOptional<z.ZodArray<z.ZodObject<{
                label: z.ZodString;
                fields: z.ZodArray<z.ZodString, "many">;
                options: z.ZodOptional<z.ZodObject<{
                    isExpandable: z.ZodOptional<z.ZodBoolean>;
                    expand: z.ZodOptional<z.ZodBoolean>;
                }, "strip", z.ZodTypeAny, {
                    isExpandable?: boolean | undefined;
                    expand?: boolean | undefined;
                }, {
                    isExpandable?: boolean | undefined;
                    expand?: boolean | undefined;
                }>>;
            }, "strip", z.ZodTypeAny, {
                label: string;
                fields: string[];
                options?: {
                    isExpandable?: boolean | undefined;
                    expand?: boolean | undefined;
                } | undefined;
            }, {
                label: string;
                fields: string[];
                options?: {
                    isExpandable?: boolean | undefined;
                    expand?: boolean | undefined;
                } | undefined;
            }>, "many">>;
            rows: z.ZodArray<z.ZodObject<{
                field: z.ZodString;
                checkbox: z.ZodOptional<z.ZodObject<{
                    label: z.ZodOptional<z.ZodString>;
                    defaultValue: z.ZodOptional<z.ZodBoolean>;
                }, "strip", z.ZodTypeAny, {
                    label?: string | undefined;
                    defaultValue?: boolean | undefined;
                }, {
                    label?: string | undefined;
                    defaultValue?: boolean | undefined;
                }>>;
                input: z.ZodOptional<z.ZodObject<{
                    defaultValue: z.ZodOptional<z.ZodNumber>;
                    validators: z.ZodOptional<z.ZodTuple<[z.ZodObject<{
                        errorMsg: z.ZodOptional<z.ZodString>;
                        type: z.ZodLiteral<"number">;
                        range: z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>;
                        isInteger: z.ZodOptional<z.ZodBoolean>;
                    }, "strip", z.ZodTypeAny, {
                        type: "number";
                        range: [number, number];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    }, {
                        type: "number";
                        range: [number, number];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    }>], null>>;
                    required: z.ZodOptional<z.ZodBoolean>;
                }, "strip", z.ZodTypeAny, {
                    required?: boolean | undefined;
                    validators?: [{
                        type: "number";
                        range: [number, number];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    }] | undefined;
                    defaultValue?: number | undefined;
                }, {
                    required?: boolean | undefined;
                    validators?: [{
                        type: "number";
                        range: [number, number];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    }] | undefined;
                    defaultValue?: number | undefined;
                }>>;
            }, "strip", z.ZodTypeAny, {
                field: string;
                checkbox?: {
                    label?: string | undefined;
                    defaultValue?: boolean | undefined;
                } | undefined;
                input?: {
                    required?: boolean | undefined;
                    validators?: [{
                        type: "number";
                        range: [number, number];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    }] | undefined;
                    defaultValue?: number | undefined;
                } | undefined;
            }, {
                field: string;
                checkbox?: {
                    label?: string | undefined;
                    defaultValue?: boolean | undefined;
                } | undefined;
                input?: {
                    required?: boolean | undefined;
                    validators?: [{
                        type: "number";
                        range: [number, number];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    }] | undefined;
                    defaultValue?: number | undefined;
                } | undefined;
            }>, "many">;
        }, "strip", z.ZodTypeAny, {
            rows: {
                field: string;
                checkbox?: {
                    label?: string | undefined;
                    defaultValue?: boolean | undefined;
                } | undefined;
                input?: {
                    required?: boolean | undefined;
                    validators?: [{
                        type: "number";
                        range: [number, number];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    }] | undefined;
                    defaultValue?: number | undefined;
                } | undefined;
            }[];
            display?: boolean | undefined;
            disableonEdit?: boolean | undefined;
            enable?: boolean | undefined;
            requiredWhenVisible?: boolean | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
            delimiter?: string | undefined;
            groups?: {
                label: string;
                fields: string[];
                options?: {
                    isExpandable?: boolean | undefined;
                    expand?: boolean | undefined;
                } | undefined;
            }[] | undefined;
        }, {
            rows: {
                field: string;
                checkbox?: {
                    label?: string | undefined;
                    defaultValue?: boolean | undefined;
                } | undefined;
                input?: {
                    required?: boolean | undefined;
                    validators?: [{
                        type: "number";
                        range: [number, number];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    }] | undefined;
                    defaultValue?: number | undefined;
                } | undefined;
            }[];
            display?: boolean | undefined;
            disableonEdit?: boolean | undefined;
            enable?: boolean | undefined;
            requiredWhenVisible?: boolean | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
            delimiter?: string | undefined;
            groups?: {
                label: string;
                fields: string[];
                options?: {
                    isExpandable?: boolean | undefined;
                    expand?: boolean | undefined;
                } | undefined;
            }[] | undefined;
        }>;
    }, "strip", z.ZodTypeAny, {
        options: {
            rows: {
                field: string;
                checkbox?: {
                    label?: string | undefined;
                    defaultValue?: boolean | undefined;
                } | undefined;
                input?: {
                    required?: boolean | undefined;
                    validators?: [{
                        type: "number";
                        range: [number, number];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    }] | undefined;
                    defaultValue?: number | undefined;
                } | undefined;
            }[];
            display?: boolean | undefined;
            disableonEdit?: boolean | undefined;
            enable?: boolean | undefined;
            requiredWhenVisible?: boolean | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
            delimiter?: string | undefined;
            groups?: {
                label: string;
                fields: string[];
                options?: {
                    isExpandable?: boolean | undefined;
                    expand?: boolean | undefined;
                } | undefined;
            }[] | undefined;
        };
        type: "checkboxGroup";
        label: string;
        field: string;
        help?: string | {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        } | undefined;
        tooltip?: string | undefined;
        required?: boolean | undefined;
        encrypted?: boolean | undefined;
        validators?: [{
            type: "regex";
            pattern: string;
            errorMsg?: string | undefined;
        }] | undefined;
        defaultValue?: number | boolean | undefined;
    }, {
        options: {
            rows: {
                field: string;
                checkbox?: {
                    label?: string | undefined;
                    defaultValue?: boolean | undefined;
                } | undefined;
                input?: {
                    required?: boolean | undefined;
                    validators?: [{
                        type: "number";
                        range: [number, number];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    }] | undefined;
                    defaultValue?: number | undefined;
                } | undefined;
            }[];
            display?: boolean | undefined;
            disableonEdit?: boolean | undefined;
            enable?: boolean | undefined;
            requiredWhenVisible?: boolean | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
            delimiter?: string | undefined;
            groups?: {
                label: string;
                fields: string[];
                options?: {
                    isExpandable?: boolean | undefined;
                    expand?: boolean | undefined;
                } | undefined;
            }[] | undefined;
        };
        type: "checkboxGroup";
        label: string;
        field: string;
        help?: string | {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        } | undefined;
        tooltip?: string | undefined;
        required?: boolean | undefined;
        encrypted?: boolean | undefined;
        validators?: [{
            type: "regex";
            pattern: string;
            errorMsg?: string | undefined;
        }] | undefined;
        defaultValue?: number | boolean | undefined;
    }>, z.ZodObject<{
        field: z.ZodString;
        label: z.ZodString;
        help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
            text: z.ZodString;
            links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                slug: z.ZodString;
                link: z.ZodString;
                linkText: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                slug: string;
                link: string;
                linkText: string;
            }, {
                slug: string;
                link: string;
                linkText: string;
            }>, "many">>;
            link: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        }, {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        }>]>>;
        tooltip: z.ZodOptional<z.ZodString>;
        required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
        encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
    } & {
        type: z.ZodLiteral<"checkboxTree">;
        validators: z.ZodOptional<z.ZodTuple<[z.ZodObject<{
            errorMsg: z.ZodOptional<z.ZodString>;
            type: z.ZodLiteral<"regex">;
            pattern: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            type: "regex";
            pattern: string;
            errorMsg?: string | undefined;
        }, {
            type: "regex";
            pattern: string;
            errorMsg?: string | undefined;
        }>], null>>;
        defaultValue: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodBoolean]>>;
        options: z.ZodObject<{
            display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
        } & {
            delimiter: z.ZodOptional<z.ZodString>;
            groups: z.ZodOptional<z.ZodArray<z.ZodObject<{
                label: z.ZodString;
                fields: z.ZodArray<z.ZodString, "many">;
                options: z.ZodOptional<z.ZodObject<{
                    isExpandable: z.ZodOptional<z.ZodBoolean>;
                    expand: z.ZodOptional<z.ZodBoolean>;
                }, "strip", z.ZodTypeAny, {
                    isExpandable?: boolean | undefined;
                    expand?: boolean | undefined;
                }, {
                    isExpandable?: boolean | undefined;
                    expand?: boolean | undefined;
                }>>;
            }, "strip", z.ZodTypeAny, {
                label: string;
                fields: string[];
                options?: {
                    isExpandable?: boolean | undefined;
                    expand?: boolean | undefined;
                } | undefined;
            }, {
                label: string;
                fields: string[];
                options?: {
                    isExpandable?: boolean | undefined;
                    expand?: boolean | undefined;
                } | undefined;
            }>, "many">>;
            rows: z.ZodArray<z.ZodObject<{
                field: z.ZodString;
                checkbox: z.ZodOptional<z.ZodObject<{
                    label: z.ZodOptional<z.ZodString>;
                    defaultValue: z.ZodOptional<z.ZodBoolean>;
                }, "strip", z.ZodTypeAny, {
                    label?: string | undefined;
                    defaultValue?: boolean | undefined;
                }, {
                    label?: string | undefined;
                    defaultValue?: boolean | undefined;
                }>>;
            }, "strip", z.ZodTypeAny, {
                field: string;
                checkbox?: {
                    label?: string | undefined;
                    defaultValue?: boolean | undefined;
                } | undefined;
            }, {
                field: string;
                checkbox?: {
                    label?: string | undefined;
                    defaultValue?: boolean | undefined;
                } | undefined;
            }>, "many">;
        }, "strip", z.ZodTypeAny, {
            rows: {
                field: string;
                checkbox?: {
                    label?: string | undefined;
                    defaultValue?: boolean | undefined;
                } | undefined;
            }[];
            display?: boolean | undefined;
            disableonEdit?: boolean | undefined;
            enable?: boolean | undefined;
            requiredWhenVisible?: boolean | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
            delimiter?: string | undefined;
            groups?: {
                label: string;
                fields: string[];
                options?: {
                    isExpandable?: boolean | undefined;
                    expand?: boolean | undefined;
                } | undefined;
            }[] | undefined;
        }, {
            rows: {
                field: string;
                checkbox?: {
                    label?: string | undefined;
                    defaultValue?: boolean | undefined;
                } | undefined;
            }[];
            display?: boolean | undefined;
            disableonEdit?: boolean | undefined;
            enable?: boolean | undefined;
            requiredWhenVisible?: boolean | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
            delimiter?: string | undefined;
            groups?: {
                label: string;
                fields: string[];
                options?: {
                    isExpandable?: boolean | undefined;
                    expand?: boolean | undefined;
                } | undefined;
            }[] | undefined;
        }>;
    }, "strip", z.ZodTypeAny, {
        options: {
            rows: {
                field: string;
                checkbox?: {
                    label?: string | undefined;
                    defaultValue?: boolean | undefined;
                } | undefined;
            }[];
            display?: boolean | undefined;
            disableonEdit?: boolean | undefined;
            enable?: boolean | undefined;
            requiredWhenVisible?: boolean | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
            delimiter?: string | undefined;
            groups?: {
                label: string;
                fields: string[];
                options?: {
                    isExpandable?: boolean | undefined;
                    expand?: boolean | undefined;
                } | undefined;
            }[] | undefined;
        };
        type: "checkboxTree";
        label: string;
        field: string;
        help?: string | {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        } | undefined;
        tooltip?: string | undefined;
        required?: boolean | undefined;
        encrypted?: boolean | undefined;
        validators?: [{
            type: "regex";
            pattern: string;
            errorMsg?: string | undefined;
        }] | undefined;
        defaultValue?: number | boolean | undefined;
    }, {
        options: {
            rows: {
                field: string;
                checkbox?: {
                    label?: string | undefined;
                    defaultValue?: boolean | undefined;
                } | undefined;
            }[];
            display?: boolean | undefined;
            disableonEdit?: boolean | undefined;
            enable?: boolean | undefined;
            requiredWhenVisible?: boolean | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
            delimiter?: string | undefined;
            groups?: {
                label: string;
                fields: string[];
                options?: {
                    isExpandable?: boolean | undefined;
                    expand?: boolean | undefined;
                } | undefined;
            }[] | undefined;
        };
        type: "checkboxTree";
        label: string;
        field: string;
        help?: string | {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        } | undefined;
        tooltip?: string | undefined;
        required?: boolean | undefined;
        encrypted?: boolean | undefined;
        validators?: [{
            type: "regex";
            pattern: string;
            errorMsg?: string | undefined;
        }] | undefined;
        defaultValue?: number | boolean | undefined;
    }>, z.ZodObject<{
        field: z.ZodString;
        label: z.ZodString;
        help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
            text: z.ZodString;
            links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                slug: z.ZodString;
                link: z.ZodString;
                linkText: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                slug: string;
                link: string;
                linkText: string;
            }, {
                slug: string;
                link: string;
                linkText: string;
            }>, "many">>;
            link: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        }, {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        }>]>>;
        tooltip: z.ZodOptional<z.ZodString>;
        required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
        encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
    } & {
        type: z.ZodLiteral<"radio">;
        defaultValue: z.ZodOptional<z.ZodString>;
        options: z.ZodObject<{
            display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
        } & {
            items: z.ZodArray<z.ZodObject<{
                value: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                label: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                value: string | number | boolean;
                label: string;
            }, {
                value: string | number | boolean;
                label: string;
            }>, "many">;
        }, "strip", z.ZodTypeAny, {
            items: {
                value: string | number | boolean;
                label: string;
            }[];
            display?: boolean | undefined;
            disableonEdit?: boolean | undefined;
            enable?: boolean | undefined;
            requiredWhenVisible?: boolean | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
        }, {
            items: {
                value: string | number | boolean;
                label: string;
            }[];
            display?: boolean | undefined;
            disableonEdit?: boolean | undefined;
            enable?: boolean | undefined;
            requiredWhenVisible?: boolean | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
        }>;
        modifyFieldsOnValue: z.ZodOptional<z.ZodArray<z.ZodObject<{
            fieldValue: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
            mode: z.ZodOptional<z.ZodEnum<["create", "edit", "config", "clone"]>>;
            fieldsToModify: z.ZodArray<z.ZodObject<{
                fieldId: z.ZodString;
                display: z.ZodOptional<z.ZodBoolean>;
                value: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>>;
                disabled: z.ZodOptional<z.ZodBoolean>;
                required: z.ZodOptional<z.ZodBoolean>;
                help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                    text: z.ZodString;
                    links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        slug: z.ZodString;
                        link: z.ZodString;
                        linkText: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }>, "many">>;
                    link: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }>]>>;
                label: z.ZodOptional<z.ZodString>;
                markdownMessage: z.ZodOptional<z.ZodUnion<[z.ZodObject<{
                    markdownType: z.ZodLiteral<"text">;
                    text: z.ZodString;
                    color: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                }, {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                }>, z.ZodObject<{
                    markdownType: z.ZodLiteral<"hybrid">;
                    text: z.ZodString;
                    token: z.ZodString;
                    linkText: z.ZodString;
                    link: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                }, {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                }>, z.ZodObject<{
                    markdownType: z.ZodLiteral<"link">;
                    text: z.ZodString;
                    link: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    link: string;
                    markdownType: "link";
                }, {
                    text: string;
                    link: string;
                    markdownType: "link";
                }>, z.ZodObject<{
                    markdownType: z.ZodOptional<z.ZodUndefined>;
                    text: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    markdownType?: undefined;
                }, {
                    text: string;
                    markdownType?: undefined;
                }>]>>;
            }, "strip", z.ZodTypeAny, {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }, {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }>, "many">;
        }, "strip", z.ZodTypeAny, {
            fieldValue: string | number | boolean;
            fieldsToModify: {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }[];
            mode?: "clone" | "create" | "edit" | "config" | undefined;
        }, {
            fieldValue: string | number | boolean;
            fieldsToModify: {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }[];
            mode?: "clone" | "create" | "edit" | "config" | undefined;
        }>, "many">>;
    }, "strip", z.ZodTypeAny, {
        options: {
            items: {
                value: string | number | boolean;
                label: string;
            }[];
            display?: boolean | undefined;
            disableonEdit?: boolean | undefined;
            enable?: boolean | undefined;
            requiredWhenVisible?: boolean | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
        };
        type: "radio";
        label: string;
        field: string;
        help?: string | {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        } | undefined;
        tooltip?: string | undefined;
        required?: boolean | undefined;
        encrypted?: boolean | undefined;
        defaultValue?: string | undefined;
        modifyFieldsOnValue?: {
            fieldValue: string | number | boolean;
            fieldsToModify: {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }[];
            mode?: "clone" | "create" | "edit" | "config" | undefined;
        }[] | undefined;
    }, {
        options: {
            items: {
                value: string | number | boolean;
                label: string;
            }[];
            display?: boolean | undefined;
            disableonEdit?: boolean | undefined;
            enable?: boolean | undefined;
            requiredWhenVisible?: boolean | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
        };
        type: "radio";
        label: string;
        field: string;
        help?: string | {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        } | undefined;
        tooltip?: string | undefined;
        required?: boolean | undefined;
        encrypted?: boolean | undefined;
        defaultValue?: string | undefined;
        modifyFieldsOnValue?: {
            fieldValue: string | number | boolean;
            fieldsToModify: {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }[];
            mode?: "clone" | "create" | "edit" | "config" | undefined;
        }[] | undefined;
    }>, z.ZodObject<{
        field: z.ZodString;
        label: z.ZodString;
        help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
            text: z.ZodString;
            links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                slug: z.ZodString;
                link: z.ZodString;
                linkText: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                slug: string;
                link: string;
                linkText: string;
            }, {
                slug: string;
                link: string;
                linkText: string;
            }>, "many">>;
            link: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        }, {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        }>]>>;
        tooltip: z.ZodOptional<z.ZodString>;
        required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
        encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
    } & {
        type: z.ZodLiteral<"file">;
        defaultValue: z.ZodOptional<z.ZodString>;
        validators: z.ZodOptional<z.ZodArray<z.ZodUnion<[z.ZodObject<{
            errorMsg: z.ZodOptional<z.ZodString>;
            type: z.ZodLiteral<"string">;
            minLength: z.ZodNumber;
            maxLength: z.ZodNumber;
        }, "strip", z.ZodTypeAny, {
            type: "string";
            minLength: number;
            maxLength: number;
            errorMsg?: string | undefined;
        }, {
            type: "string";
            minLength: number;
            maxLength: number;
            errorMsg?: string | undefined;
        }>, z.ZodObject<{
            errorMsg: z.ZodOptional<z.ZodString>;
            type: z.ZodLiteral<"regex">;
            pattern: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            type: "regex";
            pattern: string;
            errorMsg?: string | undefined;
        }, {
            type: "regex";
            pattern: string;
            errorMsg?: string | undefined;
        }>]>, "many">>;
        options: z.ZodOptional<z.ZodObject<{
            display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
        } & {
            maxFileSize: z.ZodOptional<z.ZodNumber>;
            fileSupportMessage: z.ZodOptional<z.ZodString>;
            supportedFileTypes: z.ZodArray<z.ZodString, "many">;
            useBase64Encoding: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
        }, "strip", z.ZodTypeAny, {
            supportedFileTypes: string[];
            display?: boolean | undefined;
            disableonEdit?: boolean | undefined;
            enable?: boolean | undefined;
            requiredWhenVisible?: boolean | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
            maxFileSize?: number | undefined;
            fileSupportMessage?: string | undefined;
            useBase64Encoding?: boolean | undefined;
        }, {
            supportedFileTypes: string[];
            display?: boolean | undefined;
            disableonEdit?: boolean | undefined;
            enable?: boolean | undefined;
            requiredWhenVisible?: boolean | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
            maxFileSize?: number | undefined;
            fileSupportMessage?: string | undefined;
            useBase64Encoding?: boolean | undefined;
        }>>;
        modifyFieldsOnValue: z.ZodOptional<z.ZodArray<z.ZodObject<{
            fieldValue: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
            mode: z.ZodOptional<z.ZodEnum<["create", "edit", "config", "clone"]>>;
            fieldsToModify: z.ZodArray<z.ZodObject<{
                fieldId: z.ZodString;
                display: z.ZodOptional<z.ZodBoolean>;
                value: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>>;
                disabled: z.ZodOptional<z.ZodBoolean>;
                required: z.ZodOptional<z.ZodBoolean>;
                help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                    text: z.ZodString;
                    links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        slug: z.ZodString;
                        link: z.ZodString;
                        linkText: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }>, "many">>;
                    link: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }>]>>;
                label: z.ZodOptional<z.ZodString>;
                markdownMessage: z.ZodOptional<z.ZodUnion<[z.ZodObject<{
                    markdownType: z.ZodLiteral<"text">;
                    text: z.ZodString;
                    color: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                }, {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                }>, z.ZodObject<{
                    markdownType: z.ZodLiteral<"hybrid">;
                    text: z.ZodString;
                    token: z.ZodString;
                    linkText: z.ZodString;
                    link: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                }, {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                }>, z.ZodObject<{
                    markdownType: z.ZodLiteral<"link">;
                    text: z.ZodString;
                    link: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    link: string;
                    markdownType: "link";
                }, {
                    text: string;
                    link: string;
                    markdownType: "link";
                }>, z.ZodObject<{
                    markdownType: z.ZodOptional<z.ZodUndefined>;
                    text: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    markdownType?: undefined;
                }, {
                    text: string;
                    markdownType?: undefined;
                }>]>>;
            }, "strip", z.ZodTypeAny, {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }, {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }>, "many">;
        }, "strip", z.ZodTypeAny, {
            fieldValue: string | number | boolean;
            fieldsToModify: {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }[];
            mode?: "clone" | "create" | "edit" | "config" | undefined;
        }, {
            fieldValue: string | number | boolean;
            fieldsToModify: {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }[];
            mode?: "clone" | "create" | "edit" | "config" | undefined;
        }>, "many">>;
    }, "strip", z.ZodTypeAny, {
        type: "file";
        label: string;
        field: string;
        options?: {
            supportedFileTypes: string[];
            display?: boolean | undefined;
            disableonEdit?: boolean | undefined;
            enable?: boolean | undefined;
            requiredWhenVisible?: boolean | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
            maxFileSize?: number | undefined;
            fileSupportMessage?: string | undefined;
            useBase64Encoding?: boolean | undefined;
        } | undefined;
        help?: string | {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        } | undefined;
        tooltip?: string | undefined;
        required?: boolean | undefined;
        encrypted?: boolean | undefined;
        validators?: ({
            type: "string";
            minLength: number;
            maxLength: number;
            errorMsg?: string | undefined;
        } | {
            type: "regex";
            pattern: string;
            errorMsg?: string | undefined;
        })[] | undefined;
        defaultValue?: string | undefined;
        modifyFieldsOnValue?: {
            fieldValue: string | number | boolean;
            fieldsToModify: {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }[];
            mode?: "clone" | "create" | "edit" | "config" | undefined;
        }[] | undefined;
    }, {
        type: "file";
        label: string;
        field: string;
        options?: {
            supportedFileTypes: string[];
            display?: boolean | undefined;
            disableonEdit?: boolean | undefined;
            enable?: boolean | undefined;
            requiredWhenVisible?: boolean | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
            maxFileSize?: number | undefined;
            fileSupportMessage?: string | undefined;
            useBase64Encoding?: boolean | undefined;
        } | undefined;
        help?: string | {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        } | undefined;
        tooltip?: string | undefined;
        required?: boolean | undefined;
        encrypted?: boolean | undefined;
        validators?: ({
            type: "string";
            minLength: number;
            maxLength: number;
            errorMsg?: string | undefined;
        } | {
            type: "regex";
            pattern: string;
            errorMsg?: string | undefined;
        })[] | undefined;
        defaultValue?: string | undefined;
        modifyFieldsOnValue?: {
            fieldValue: string | number | boolean;
            fieldsToModify: {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }[];
            mode?: "clone" | "create" | "edit" | "config" | undefined;
        }[] | undefined;
    }>, z.ZodObject<{
        field: z.ZodString;
        label: z.ZodString;
        help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
            text: z.ZodString;
            links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                slug: z.ZodString;
                link: z.ZodString;
                linkText: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                slug: string;
                link: string;
                linkText: string;
            }, {
                slug: string;
                link: string;
                linkText: string;
            }>, "many">>;
            link: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        }, {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        }>]>>;
        tooltip: z.ZodOptional<z.ZodString>;
        required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
        encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
    } & {
        type: z.ZodLiteral<"oauth">;
        defaultValue: z.ZodOptional<z.ZodString>;
        validators: z.ZodOptional<z.ZodArray<z.ZodUnion<[z.ZodObject<{
            errorMsg: z.ZodOptional<z.ZodString>;
            type: z.ZodLiteral<"string">;
            minLength: z.ZodNumber;
            maxLength: z.ZodNumber;
        }, "strip", z.ZodTypeAny, {
            type: "string";
            minLength: number;
            maxLength: number;
            errorMsg?: string | undefined;
        }, {
            type: "string";
            minLength: number;
            maxLength: number;
            errorMsg?: string | undefined;
        }>, z.ZodObject<{
            errorMsg: z.ZodOptional<z.ZodString>;
            type: z.ZodLiteral<"regex">;
            pattern: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            type: "regex";
            pattern: string;
            errorMsg?: string | undefined;
        }, {
            type: "regex";
            pattern: string;
            errorMsg?: string | undefined;
        }>]>, "many">>;
        options: z.ZodObject<Omit<{
            display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
            hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
        }, "requiredWhenVisible"> & {
            auth_type: z.ZodArray<z.ZodUnion<[z.ZodLiteral<"basic">, z.ZodLiteral<"oauth">, z.ZodLiteral<"oauth_client_credentials">]>, "many">;
            basic: z.ZodOptional<z.ZodArray<z.ZodObject<{
                oauth_field: z.ZodString;
                label: z.ZodString;
                field: z.ZodString;
                type: z.ZodOptional<z.ZodDefault<z.ZodLiteral<"text">>>;
                help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                    text: z.ZodString;
                    links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        slug: z.ZodString;
                        link: z.ZodString;
                        linkText: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }>, "many">>;
                    link: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }>]>>;
                encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                defaultValue: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodNumber, z.ZodBoolean]>>;
                options: z.ZodOptional<z.ZodObject<{
                    display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
                }, "strip", z.ZodTypeAny, {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                }, {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                }>>;
                modifyFieldsOnValue: z.ZodOptional<z.ZodArray<z.ZodObject<{
                    fieldValue: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                    mode: z.ZodOptional<z.ZodEnum<["create", "edit", "config", "clone"]>>;
                    fieldsToModify: z.ZodArray<z.ZodObject<{
                        fieldId: z.ZodString;
                        display: z.ZodOptional<z.ZodBoolean>;
                        value: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>>;
                        disabled: z.ZodOptional<z.ZodBoolean>;
                        required: z.ZodOptional<z.ZodBoolean>;
                        help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                            text: z.ZodString;
                            links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                slug: z.ZodString;
                                link: z.ZodString;
                                linkText: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                slug: string;
                                link: string;
                                linkText: string;
                            }, {
                                slug: string;
                                link: string;
                                linkText: string;
                            }>, "many">>;
                            link: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        }, {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        }>]>>;
                        label: z.ZodOptional<z.ZodString>;
                        markdownMessage: z.ZodOptional<z.ZodUnion<[z.ZodObject<{
                            markdownType: z.ZodLiteral<"text">;
                            text: z.ZodString;
                            color: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        }, {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        }>, z.ZodObject<{
                            markdownType: z.ZodLiteral<"hybrid">;
                            text: z.ZodString;
                            token: z.ZodString;
                            linkText: z.ZodString;
                            link: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        }, {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        }>, z.ZodObject<{
                            markdownType: z.ZodLiteral<"link">;
                            text: z.ZodString;
                            link: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            link: string;
                            markdownType: "link";
                        }, {
                            text: string;
                            link: string;
                            markdownType: "link";
                        }>, z.ZodObject<{
                            markdownType: z.ZodOptional<z.ZodUndefined>;
                            text: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            markdownType?: undefined;
                        }, {
                            text: string;
                            markdownType?: undefined;
                        }>]>>;
                    }, "strip", z.ZodTypeAny, {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }, {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }>, "many">;
                }, "strip", z.ZodTypeAny, {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }, {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }>, "many">>;
                validators: z.ZodOptional<z.ZodArray<z.ZodUnion<[z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"number">;
                    range: z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>;
                    isInteger: z.ZodOptional<z.ZodBoolean>;
                }, "strip", z.ZodTypeAny, {
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                }, {
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"string">;
                    minLength: z.ZodNumber;
                    maxLength: z.ZodNumber;
                }, "strip", z.ZodTypeAny, {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                }, {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"regex">;
                    pattern: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }, {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"email">;
                }, "strip", z.ZodTypeAny, {
                    type: "email";
                    errorMsg?: string | undefined;
                }, {
                    type: "email";
                    errorMsg?: string | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"ipv4">;
                }, "strip", z.ZodTypeAny, {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                }, {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"url">;
                }, "strip", z.ZodTypeAny, {
                    type: "url";
                    errorMsg?: string | undefined;
                }, {
                    type: "url";
                    errorMsg?: string | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"date">;
                }, "strip", z.ZodTypeAny, {
                    type: "date";
                    errorMsg?: string | undefined;
                }, {
                    type: "date";
                    errorMsg?: string | undefined;
                }>]>, "many">>;
            }, "strip", z.ZodTypeAny, {
                label: string;
                field: string;
                oauth_field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                type?: "text" | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            }, {
                label: string;
                field: string;
                oauth_field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                type?: "text" | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            }>, "many">>;
            oauth: z.ZodOptional<z.ZodArray<z.ZodObject<{
                oauth_field: z.ZodString;
                label: z.ZodString;
                field: z.ZodString;
                type: z.ZodOptional<z.ZodDefault<z.ZodLiteral<"text">>>;
                help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                    text: z.ZodString;
                    links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        slug: z.ZodString;
                        link: z.ZodString;
                        linkText: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }>, "many">>;
                    link: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }>]>>;
                encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                defaultValue: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodNumber, z.ZodBoolean]>>;
                options: z.ZodOptional<z.ZodObject<{
                    display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
                }, "strip", z.ZodTypeAny, {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                }, {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                }>>;
                modifyFieldsOnValue: z.ZodOptional<z.ZodArray<z.ZodObject<{
                    fieldValue: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                    mode: z.ZodOptional<z.ZodEnum<["create", "edit", "config", "clone"]>>;
                    fieldsToModify: z.ZodArray<z.ZodObject<{
                        fieldId: z.ZodString;
                        display: z.ZodOptional<z.ZodBoolean>;
                        value: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>>;
                        disabled: z.ZodOptional<z.ZodBoolean>;
                        required: z.ZodOptional<z.ZodBoolean>;
                        help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                            text: z.ZodString;
                            links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                slug: z.ZodString;
                                link: z.ZodString;
                                linkText: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                slug: string;
                                link: string;
                                linkText: string;
                            }, {
                                slug: string;
                                link: string;
                                linkText: string;
                            }>, "many">>;
                            link: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        }, {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        }>]>>;
                        label: z.ZodOptional<z.ZodString>;
                        markdownMessage: z.ZodOptional<z.ZodUnion<[z.ZodObject<{
                            markdownType: z.ZodLiteral<"text">;
                            text: z.ZodString;
                            color: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        }, {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        }>, z.ZodObject<{
                            markdownType: z.ZodLiteral<"hybrid">;
                            text: z.ZodString;
                            token: z.ZodString;
                            linkText: z.ZodString;
                            link: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        }, {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        }>, z.ZodObject<{
                            markdownType: z.ZodLiteral<"link">;
                            text: z.ZodString;
                            link: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            link: string;
                            markdownType: "link";
                        }, {
                            text: string;
                            link: string;
                            markdownType: "link";
                        }>, z.ZodObject<{
                            markdownType: z.ZodOptional<z.ZodUndefined>;
                            text: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            markdownType?: undefined;
                        }, {
                            text: string;
                            markdownType?: undefined;
                        }>]>>;
                    }, "strip", z.ZodTypeAny, {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }, {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }>, "many">;
                }, "strip", z.ZodTypeAny, {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }, {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }>, "many">>;
                validators: z.ZodOptional<z.ZodArray<z.ZodUnion<[z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"number">;
                    range: z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>;
                    isInteger: z.ZodOptional<z.ZodBoolean>;
                }, "strip", z.ZodTypeAny, {
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                }, {
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"string">;
                    minLength: z.ZodNumber;
                    maxLength: z.ZodNumber;
                }, "strip", z.ZodTypeAny, {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                }, {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"regex">;
                    pattern: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }, {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"email">;
                }, "strip", z.ZodTypeAny, {
                    type: "email";
                    errorMsg?: string | undefined;
                }, {
                    type: "email";
                    errorMsg?: string | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"ipv4">;
                }, "strip", z.ZodTypeAny, {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                }, {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"url">;
                }, "strip", z.ZodTypeAny, {
                    type: "url";
                    errorMsg?: string | undefined;
                }, {
                    type: "url";
                    errorMsg?: string | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"date">;
                }, "strip", z.ZodTypeAny, {
                    type: "date";
                    errorMsg?: string | undefined;
                }, {
                    type: "date";
                    errorMsg?: string | undefined;
                }>]>, "many">>;
            }, "strip", z.ZodTypeAny, {
                label: string;
                field: string;
                oauth_field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                type?: "text" | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            }, {
                label: string;
                field: string;
                oauth_field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                type?: "text" | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            }>, "many">>;
            oauth_client_credentials: z.ZodOptional<z.ZodArray<z.ZodObject<{
                oauth_field: z.ZodString;
                label: z.ZodString;
                field: z.ZodString;
                type: z.ZodOptional<z.ZodDefault<z.ZodLiteral<"text">>>;
                help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                    text: z.ZodString;
                    links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        slug: z.ZodString;
                        link: z.ZodString;
                        linkText: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }, {
                        slug: string;
                        link: string;
                        linkText: string;
                    }>, "many">>;
                    link: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }, {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                }>]>>;
                encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                defaultValue: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodNumber, z.ZodBoolean]>>;
                options: z.ZodOptional<z.ZodObject<{
                    display: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    disableonEdit: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    enable: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    requiredWhenVisible: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
                    hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
                }, "strip", z.ZodTypeAny, {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                }, {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                }>>;
                modifyFieldsOnValue: z.ZodOptional<z.ZodArray<z.ZodObject<{
                    fieldValue: z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>;
                    mode: z.ZodOptional<z.ZodEnum<["create", "edit", "config", "clone"]>>;
                    fieldsToModify: z.ZodArray<z.ZodObject<{
                        fieldId: z.ZodString;
                        display: z.ZodOptional<z.ZodBoolean>;
                        value: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean]>>;
                        disabled: z.ZodOptional<z.ZodBoolean>;
                        required: z.ZodOptional<z.ZodBoolean>;
                        help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
                            text: z.ZodString;
                            links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                slug: z.ZodString;
                                link: z.ZodString;
                                linkText: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                slug: string;
                                link: string;
                                linkText: string;
                            }, {
                                slug: string;
                                link: string;
                                linkText: string;
                            }>, "many">>;
                            link: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        }, {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        }>]>>;
                        label: z.ZodOptional<z.ZodString>;
                        markdownMessage: z.ZodOptional<z.ZodUnion<[z.ZodObject<{
                            markdownType: z.ZodLiteral<"text">;
                            text: z.ZodString;
                            color: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        }, {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        }>, z.ZodObject<{
                            markdownType: z.ZodLiteral<"hybrid">;
                            text: z.ZodString;
                            token: z.ZodString;
                            linkText: z.ZodString;
                            link: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        }, {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        }>, z.ZodObject<{
                            markdownType: z.ZodLiteral<"link">;
                            text: z.ZodString;
                            link: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            link: string;
                            markdownType: "link";
                        }, {
                            text: string;
                            link: string;
                            markdownType: "link";
                        }>, z.ZodObject<{
                            markdownType: z.ZodOptional<z.ZodUndefined>;
                            text: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            text: string;
                            markdownType?: undefined;
                        }, {
                            text: string;
                            markdownType?: undefined;
                        }>]>>;
                    }, "strip", z.ZodTypeAny, {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }, {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }>, "many">;
                }, "strip", z.ZodTypeAny, {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }, {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }>, "many">>;
                validators: z.ZodOptional<z.ZodArray<z.ZodUnion<[z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"number">;
                    range: z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>;
                    isInteger: z.ZodOptional<z.ZodBoolean>;
                }, "strip", z.ZodTypeAny, {
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                }, {
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"string">;
                    minLength: z.ZodNumber;
                    maxLength: z.ZodNumber;
                }, "strip", z.ZodTypeAny, {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                }, {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"regex">;
                    pattern: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }, {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"email">;
                }, "strip", z.ZodTypeAny, {
                    type: "email";
                    errorMsg?: string | undefined;
                }, {
                    type: "email";
                    errorMsg?: string | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"ipv4">;
                }, "strip", z.ZodTypeAny, {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                }, {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"url">;
                }, "strip", z.ZodTypeAny, {
                    type: "url";
                    errorMsg?: string | undefined;
                }, {
                    type: "url";
                    errorMsg?: string | undefined;
                }>, z.ZodObject<{
                    errorMsg: z.ZodOptional<z.ZodString>;
                    type: z.ZodLiteral<"date">;
                }, "strip", z.ZodTypeAny, {
                    type: "date";
                    errorMsg?: string | undefined;
                }, {
                    type: "date";
                    errorMsg?: string | undefined;
                }>]>, "many">>;
            }, "strip", z.ZodTypeAny, {
                label: string;
                field: string;
                oauth_field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                type?: "text" | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            }, {
                label: string;
                field: string;
                oauth_field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                type?: "text" | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            }>, "many">>;
            auth_label: z.ZodOptional<z.ZodString>;
            oauth_popup_width: z.ZodOptional<z.ZodNumber>;
            oauth_popup_height: z.ZodOptional<z.ZodNumber>;
            oauth_timeout: z.ZodOptional<z.ZodNumber>;
            auth_code_endpoint: z.ZodOptional<z.ZodString>;
            access_token_endpoint: z.ZodOptional<z.ZodString>;
            oauth_state_enabled: z.ZodOptional<z.ZodBoolean>;
            auth_endpoint_token_access_type: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            auth_type: ("oauth" | "basic" | "oauth_client_credentials")[];
            display?: boolean | undefined;
            disableonEdit?: boolean | undefined;
            enable?: boolean | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
            oauth?: {
                label: string;
                field: string;
                oauth_field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                type?: "text" | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            }[] | undefined;
            basic?: {
                label: string;
                field: string;
                oauth_field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                type?: "text" | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            }[] | undefined;
            oauth_client_credentials?: {
                label: string;
                field: string;
                oauth_field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                type?: "text" | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            }[] | undefined;
            auth_label?: string | undefined;
            oauth_popup_width?: number | undefined;
            oauth_popup_height?: number | undefined;
            oauth_timeout?: number | undefined;
            auth_code_endpoint?: string | undefined;
            access_token_endpoint?: string | undefined;
            oauth_state_enabled?: boolean | undefined;
            auth_endpoint_token_access_type?: string | undefined;
        }, {
            auth_type: ("oauth" | "basic" | "oauth_client_credentials")[];
            display?: boolean | undefined;
            disableonEdit?: boolean | undefined;
            enable?: boolean | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
            oauth?: {
                label: string;
                field: string;
                oauth_field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                type?: "text" | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            }[] | undefined;
            basic?: {
                label: string;
                field: string;
                oauth_field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                type?: "text" | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            }[] | undefined;
            oauth_client_credentials?: {
                label: string;
                field: string;
                oauth_field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                type?: "text" | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            }[] | undefined;
            auth_label?: string | undefined;
            oauth_popup_width?: number | undefined;
            oauth_popup_height?: number | undefined;
            oauth_timeout?: number | undefined;
            auth_code_endpoint?: string | undefined;
            access_token_endpoint?: string | undefined;
            oauth_state_enabled?: boolean | undefined;
            auth_endpoint_token_access_type?: string | undefined;
        }>;
    }, "strip", z.ZodTypeAny, {
        options: {
            auth_type: ("oauth" | "basic" | "oauth_client_credentials")[];
            display?: boolean | undefined;
            disableonEdit?: boolean | undefined;
            enable?: boolean | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
            oauth?: {
                label: string;
                field: string;
                oauth_field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                type?: "text" | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            }[] | undefined;
            basic?: {
                label: string;
                field: string;
                oauth_field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                type?: "text" | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            }[] | undefined;
            oauth_client_credentials?: {
                label: string;
                field: string;
                oauth_field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                type?: "text" | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            }[] | undefined;
            auth_label?: string | undefined;
            oauth_popup_width?: number | undefined;
            oauth_popup_height?: number | undefined;
            oauth_timeout?: number | undefined;
            auth_code_endpoint?: string | undefined;
            access_token_endpoint?: string | undefined;
            oauth_state_enabled?: boolean | undefined;
            auth_endpoint_token_access_type?: string | undefined;
        };
        type: "oauth";
        label: string;
        field: string;
        help?: string | {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        } | undefined;
        tooltip?: string | undefined;
        required?: boolean | undefined;
        encrypted?: boolean | undefined;
        validators?: ({
            type: "string";
            minLength: number;
            maxLength: number;
            errorMsg?: string | undefined;
        } | {
            type: "regex";
            pattern: string;
            errorMsg?: string | undefined;
        })[] | undefined;
        defaultValue?: string | undefined;
    }, {
        options: {
            auth_type: ("oauth" | "basic" | "oauth_client_credentials")[];
            display?: boolean | undefined;
            disableonEdit?: boolean | undefined;
            enable?: boolean | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
            oauth?: {
                label: string;
                field: string;
                oauth_field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                type?: "text" | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            }[] | undefined;
            basic?: {
                label: string;
                field: string;
                oauth_field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                type?: "text" | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            }[] | undefined;
            oauth_client_credentials?: {
                label: string;
                field: string;
                oauth_field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                type?: "text" | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            }[] | undefined;
            auth_label?: string | undefined;
            oauth_popup_width?: number | undefined;
            oauth_popup_height?: number | undefined;
            oauth_timeout?: number | undefined;
            auth_code_endpoint?: string | undefined;
            access_token_endpoint?: string | undefined;
            oauth_state_enabled?: boolean | undefined;
            auth_endpoint_token_access_type?: string | undefined;
        };
        type: "oauth";
        label: string;
        field: string;
        help?: string | {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        } | undefined;
        tooltip?: string | undefined;
        required?: boolean | undefined;
        encrypted?: boolean | undefined;
        validators?: ({
            type: "string";
            minLength: number;
            maxLength: number;
            errorMsg?: string | undefined;
        } | {
            type: "regex";
            pattern: string;
            errorMsg?: string | undefined;
        })[] | undefined;
        defaultValue?: string | undefined;
    }>, z.ZodObject<{
        field: z.ZodString;
        label: z.ZodString;
        help: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodObject<{
            text: z.ZodString;
            links: z.ZodOptional<z.ZodArray<z.ZodObject<{
                slug: z.ZodString;
                link: z.ZodString;
                linkText: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                slug: string;
                link: string;
                linkText: string;
            }, {
                slug: string;
                link: string;
                linkText: string;
            }>, "many">>;
            link: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        }, {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        }>]>>;
        tooltip: z.ZodOptional<z.ZodString>;
        required: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
        encrypted: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
    } & {
        type: z.ZodLiteral<"custom">;
        options: z.ZodObject<{
            type: z.ZodLiteral<"external">;
            src: z.ZodString;
            hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
        }, "strip", z.ZodTypeAny, {
            type: "external";
            src: string;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
        }, {
            type: "external";
            src: string;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
        }>;
    }, "strip", z.ZodTypeAny, {
        options: {
            type: "external";
            src: string;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
        };
        type: "custom";
        label: string;
        field: string;
        help?: string | {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        } | undefined;
        tooltip?: string | undefined;
        required?: boolean | undefined;
        encrypted?: boolean | undefined;
    }, {
        options: {
            type: "external";
            src: string;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
        };
        type: "custom";
        label: string;
        field: string;
        help?: string | {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        } | undefined;
        tooltip?: string | undefined;
        required?: boolean | undefined;
        encrypted?: boolean | undefined;
    }>]>, "many">>;
    name: z.ZodString;
    title: z.ZodString;
    options: z.ZodOptional<z.ZodObject<{
        saveValidator: z.ZodOptional<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        saveValidator?: string | undefined;
    }, {
        saveValidator?: string | undefined;
    }>>;
    table: z.ZodOptional<z.ZodObject<{
        moreInfo: z.ZodOptional<z.ZodArray<z.ZodObject<{
            field: z.ZodString;
            label: z.ZodString;
            mapping: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>;
        }, "strip", z.ZodTypeAny, {
            label: string;
            field: string;
            mapping?: Record<string, any> | undefined;
        }, {
            label: string;
            field: string;
            mapping?: Record<string, any> | undefined;
        }>, "many">>;
        header: z.ZodArray<z.ZodObject<{
            field: z.ZodString;
            label: z.ZodString;
            mapping: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>;
            customCell: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>;
        }, "strip", z.ZodTypeAny, {
            label: string;
            field: string;
            mapping?: Record<string, any> | undefined;
            customCell?: Record<string, any> | undefined;
        }, {
            label: string;
            field: string;
            mapping?: Record<string, any> | undefined;
            customCell?: Record<string, any> | undefined;
        }>, "many">;
        customRow: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>;
    } & {
        actions: z.ZodArray<z.ZodEnum<["edit", "delete", "clone"]>, "many">;
    }, "strip", z.ZodTypeAny, {
        header: {
            label: string;
            field: string;
            mapping?: Record<string, any> | undefined;
            customCell?: Record<string, any> | undefined;
        }[];
        actions: ("clone" | "delete" | "edit")[];
        moreInfo?: {
            label: string;
            field: string;
            mapping?: Record<string, any> | undefined;
        }[] | undefined;
        customRow?: Record<string, any> | undefined;
    }, {
        header: {
            label: string;
            field: string;
            mapping?: Record<string, any> | undefined;
            customCell?: Record<string, any> | undefined;
        }[];
        actions: ("clone" | "delete" | "edit")[];
        moreInfo?: {
            label: string;
            field: string;
            mapping?: Record<string, any> | undefined;
        }[] | undefined;
        customRow?: Record<string, any> | undefined;
    }>>;
    style: z.ZodOptional<z.ZodEnum<["page", "dialog"]>>;
    hook: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>;
    conf: z.ZodOptional<z.ZodString>;
    restHandlerName: z.ZodOptional<z.ZodString>;
    restHandlerModule: z.ZodOptional<z.ZodString>;
    restHandlerClass: z.ZodOptional<z.ZodString>;
    customTab: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>;
    warning: z.ZodOptional<z.ZodObject<{
        create: z.ZodOptional<z.ZodObject<{
            message: z.ZodString;
            alwaysDisplay: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
        }, "strip", z.ZodTypeAny, {
            message: string;
            alwaysDisplay?: boolean | undefined;
        }, {
            message: string;
            alwaysDisplay?: boolean | undefined;
        }>>;
        edit: z.ZodOptional<z.ZodObject<{
            message: z.ZodString;
            alwaysDisplay: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
        }, "strip", z.ZodTypeAny, {
            message: string;
            alwaysDisplay?: boolean | undefined;
        }, {
            message: string;
            alwaysDisplay?: boolean | undefined;
        }>>;
        config: z.ZodOptional<z.ZodObject<{
            message: z.ZodString;
            alwaysDisplay: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
        }, "strip", z.ZodTypeAny, {
            message: string;
            alwaysDisplay?: boolean | undefined;
        }, {
            message: string;
            alwaysDisplay?: boolean | undefined;
        }>>;
        clone: z.ZodOptional<z.ZodObject<{
            message: z.ZodString;
            alwaysDisplay: z.ZodOptional<z.ZodDefault<z.ZodBoolean>>;
        }, "strip", z.ZodTypeAny, {
            message: string;
            alwaysDisplay?: boolean | undefined;
        }, {
            message: string;
            alwaysDisplay?: boolean | undefined;
        }>>;
    }, "strip", z.ZodTypeAny, {
        clone?: {
            message: string;
            alwaysDisplay?: boolean | undefined;
        } | undefined;
        create?: {
            message: string;
            alwaysDisplay?: boolean | undefined;
        } | undefined;
        edit?: {
            message: string;
            alwaysDisplay?: boolean | undefined;
        } | undefined;
        config?: {
            message: string;
            alwaysDisplay?: boolean | undefined;
        } | undefined;
    }, {
        clone?: {
            message: string;
            alwaysDisplay?: boolean | undefined;
        } | undefined;
        create?: {
            message: string;
            alwaysDisplay?: boolean | undefined;
        } | undefined;
        edit?: {
            message: string;
            alwaysDisplay?: boolean | undefined;
        } | undefined;
        config?: {
            message: string;
            alwaysDisplay?: boolean | undefined;
        } | undefined;
    }>>;
    hideForPlatform: z.ZodOptional<z.ZodEnum<["cloud", "enterprise"]>>;
    groups: z.ZodOptional<z.ZodArray<z.ZodObject<{
        options: z.ZodOptional<z.ZodObject<{
            isExpandable: z.ZodOptional<z.ZodBoolean>;
            expand: z.ZodOptional<z.ZodBoolean>;
        }, "strip", z.ZodTypeAny, {
            isExpandable?: boolean | undefined;
            expand?: boolean | undefined;
        }, {
            isExpandable?: boolean | undefined;
            expand?: boolean | undefined;
        }>>;
        label: z.ZodString;
        fields: z.ZodArray<z.ZodString, "many">;
    }, "strip", z.ZodTypeAny, {
        label: string;
        fields: string[];
        options?: {
            isExpandable?: boolean | undefined;
            expand?: boolean | undefined;
        } | undefined;
    }, {
        label: string;
        fields: string[];
        options?: {
            isExpandable?: boolean | undefined;
            expand?: boolean | undefined;
        } | undefined;
    }>, "many">>;
    formTitle: z.ZodOptional<z.ZodString>;
}, "strip", z.ZodTypeAny, {
    name: string;
    title: string;
    options?: {
        saveValidator?: string | undefined;
    } | undefined;
    hideForPlatform?: "cloud" | "enterprise" | undefined;
    groups?: {
        label: string;
        fields: string[];
        options?: {
            isExpandable?: boolean | undefined;
            expand?: boolean | undefined;
        } | undefined;
    }[] | undefined;
    entity?: ({
        type: "helpLink";
        field: string;
        options?: {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
        } | undefined;
        label?: string | undefined;
        help?: string | {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        } | undefined;
        tooltip?: string | undefined;
        required?: false | undefined;
    } | {
        type: "text";
        label: string;
        field: string;
        options?: {
            display?: boolean | undefined;
            disableonEdit?: boolean | undefined;
            enable?: boolean | undefined;
            requiredWhenVisible?: boolean | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
        } | undefined;
        help?: string | {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        } | undefined;
        tooltip?: string | undefined;
        required?: boolean | undefined;
        encrypted?: boolean | undefined;
        validators?: ({
            type: "number";
            range: [number, number];
            errorMsg?: string | undefined;
            isInteger?: boolean | undefined;
        } | {
            type: "string";
            minLength: number;
            maxLength: number;
            errorMsg?: string | undefined;
        } | {
            type: "regex";
            pattern: string;
            errorMsg?: string | undefined;
        } | {
            type: "email";
            errorMsg?: string | undefined;
        } | {
            type: "ipv4";
            errorMsg?: string | undefined;
        } | {
            type: "url";
            errorMsg?: string | undefined;
        } | {
            type: "date";
            errorMsg?: string | undefined;
        })[] | undefined;
        defaultValue?: string | number | boolean | undefined;
        modifyFieldsOnValue?: {
            fieldValue: string | number | boolean;
            fieldsToModify: {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }[];
            mode?: "clone" | "create" | "edit" | "config" | undefined;
        }[] | undefined;
    } | {
        type: "textarea";
        label: string;
        field: string;
        options?: {
            display?: boolean | undefined;
            disableonEdit?: boolean | undefined;
            enable?: boolean | undefined;
            requiredWhenVisible?: boolean | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
            rowsMin?: number | undefined;
            rowsMax?: number | undefined;
        } | undefined;
        help?: string | {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        } | undefined;
        tooltip?: string | undefined;
        required?: boolean | undefined;
        encrypted?: boolean | undefined;
        validators?: ({
            type: "number";
            range: [number, number];
            errorMsg?: string | undefined;
            isInteger?: boolean | undefined;
        } | {
            type: "string";
            minLength: number;
            maxLength: number;
            errorMsg?: string | undefined;
        } | {
            type: "regex";
            pattern: string;
            errorMsg?: string | undefined;
        } | {
            type: "email";
            errorMsg?: string | undefined;
        } | {
            type: "ipv4";
            errorMsg?: string | undefined;
        } | {
            type: "url";
            errorMsg?: string | undefined;
        } | {
            type: "date";
            errorMsg?: string | undefined;
        })[] | undefined;
        defaultValue?: string | undefined;
        modifyFieldsOnValue?: {
            fieldValue: string | number | boolean;
            fieldsToModify: {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }[];
            mode?: "clone" | "create" | "edit" | "config" | undefined;
        }[] | undefined;
    } | {
        options: {
            display?: boolean | undefined;
            disableonEdit?: boolean | undefined;
            enable?: boolean | undefined;
            requiredWhenVisible?: boolean | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
            disableSearch?: boolean | undefined;
            createSearchChoice?: boolean | undefined;
            referenceName?: string | undefined;
            endpointUrl?: string | undefined;
            allowList?: string | undefined;
            denyList?: string | undefined;
            labelField?: string | undefined;
            valueField?: string | undefined;
            autoCompleteFields?: ({
                value: string | number | boolean;
                label: string;
            } | {
                label: string;
                children: {
                    value: string | number | boolean;
                    label: string;
                }[];
            })[] | undefined;
            dependencies?: string[] | undefined;
            items?: {
                value: string | number | boolean;
                label: string;
            }[] | undefined;
        };
        type: "singleSelect";
        label: string;
        field: string;
        help?: string | {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        } | undefined;
        tooltip?: string | undefined;
        required?: boolean | undefined;
        encrypted?: boolean | undefined;
        validators?: ({
            type: "number";
            range: [number, number];
            errorMsg?: string | undefined;
            isInteger?: boolean | undefined;
        } | {
            type: "string";
            minLength: number;
            maxLength: number;
            errorMsg?: string | undefined;
        } | {
            type: "regex";
            pattern: string;
            errorMsg?: string | undefined;
        } | {
            type: "email";
            errorMsg?: string | undefined;
        } | {
            type: "ipv4";
            errorMsg?: string | undefined;
        } | {
            type: "url";
            errorMsg?: string | undefined;
        } | {
            type: "date";
            errorMsg?: string | undefined;
        })[] | undefined;
        defaultValue?: string | number | boolean | undefined;
        modifyFieldsOnValue?: {
            fieldValue: string | number | boolean;
            fieldsToModify: {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }[];
            mode?: "clone" | "create" | "edit" | "config" | undefined;
        }[] | undefined;
    } | {
        options: {
            display?: boolean | undefined;
            disableonEdit?: boolean | undefined;
            enable?: boolean | undefined;
            requiredWhenVisible?: boolean | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
            disableSearch?: boolean | undefined;
            createSearchChoice?: boolean | undefined;
            referenceName?: string | undefined;
            endpointUrl?: string | undefined;
            allowList?: string | undefined;
            denyList?: string | undefined;
            labelField?: string | undefined;
            valueField?: string | undefined;
            autoCompleteFields?: ({
                value: string | number | boolean;
                label: string;
            } | {
                label: string;
                children: {
                    value: string | number | boolean;
                    label: string;
                }[];
            })[] | undefined;
            dependencies?: string[] | undefined;
            items?: {
                value: string | number | boolean;
                label: string;
            }[] | undefined;
            delimiter?: string | undefined;
        };
        type: "multipleSelect";
        label: string;
        field: string;
        help?: string | {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        } | undefined;
        tooltip?: string | undefined;
        required?: boolean | undefined;
        encrypted?: boolean | undefined;
        validators?: ({
            type: "number";
            range: [number, number];
            errorMsg?: string | undefined;
            isInteger?: boolean | undefined;
        } | {
            type: "string";
            minLength: number;
            maxLength: number;
            errorMsg?: string | undefined;
        } | {
            type: "regex";
            pattern: string;
            errorMsg?: string | undefined;
        } | {
            type: "email";
            errorMsg?: string | undefined;
        } | {
            type: "ipv4";
            errorMsg?: string | undefined;
        } | {
            type: "url";
            errorMsg?: string | undefined;
        } | {
            type: "date";
            errorMsg?: string | undefined;
        })[] | undefined;
        defaultValue?: string | undefined;
        modifyFieldsOnValue?: {
            fieldValue: string | number | boolean;
            fieldsToModify: {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }[];
            mode?: "clone" | "create" | "edit" | "config" | undefined;
        }[] | undefined;
    } | {
        type: "checkbox";
        label: string;
        field: string;
        options?: {
            display?: boolean | undefined;
            disableonEdit?: boolean | undefined;
            enable?: boolean | undefined;
            requiredWhenVisible?: boolean | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
        } | undefined;
        help?: string | {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        } | undefined;
        tooltip?: string | undefined;
        required?: boolean | undefined;
        encrypted?: boolean | undefined;
        defaultValue?: number | boolean | undefined;
        modifyFieldsOnValue?: {
            fieldValue: string | number | boolean;
            fieldsToModify: {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }[];
            mode?: "clone" | "create" | "edit" | "config" | undefined;
        }[] | undefined;
    } | {
        options: {
            rows: {
                field: string;
                checkbox?: {
                    label?: string | undefined;
                    defaultValue?: boolean | undefined;
                } | undefined;
                input?: {
                    required?: boolean | undefined;
                    validators?: [{
                        type: "number";
                        range: [number, number];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    }] | undefined;
                    defaultValue?: number | undefined;
                } | undefined;
            }[];
            display?: boolean | undefined;
            disableonEdit?: boolean | undefined;
            enable?: boolean | undefined;
            requiredWhenVisible?: boolean | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
            delimiter?: string | undefined;
            groups?: {
                label: string;
                fields: string[];
                options?: {
                    isExpandable?: boolean | undefined;
                    expand?: boolean | undefined;
                } | undefined;
            }[] | undefined;
        };
        type: "checkboxGroup";
        label: string;
        field: string;
        help?: string | {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        } | undefined;
        tooltip?: string | undefined;
        required?: boolean | undefined;
        encrypted?: boolean | undefined;
        validators?: [{
            type: "regex";
            pattern: string;
            errorMsg?: string | undefined;
        }] | undefined;
        defaultValue?: number | boolean | undefined;
    } | {
        options: {
            rows: {
                field: string;
                checkbox?: {
                    label?: string | undefined;
                    defaultValue?: boolean | undefined;
                } | undefined;
            }[];
            display?: boolean | undefined;
            disableonEdit?: boolean | undefined;
            enable?: boolean | undefined;
            requiredWhenVisible?: boolean | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
            delimiter?: string | undefined;
            groups?: {
                label: string;
                fields: string[];
                options?: {
                    isExpandable?: boolean | undefined;
                    expand?: boolean | undefined;
                } | undefined;
            }[] | undefined;
        };
        type: "checkboxTree";
        label: string;
        field: string;
        help?: string | {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        } | undefined;
        tooltip?: string | undefined;
        required?: boolean | undefined;
        encrypted?: boolean | undefined;
        validators?: [{
            type: "regex";
            pattern: string;
            errorMsg?: string | undefined;
        }] | undefined;
        defaultValue?: number | boolean | undefined;
    } | {
        options: {
            items: {
                value: string | number | boolean;
                label: string;
            }[];
            display?: boolean | undefined;
            disableonEdit?: boolean | undefined;
            enable?: boolean | undefined;
            requiredWhenVisible?: boolean | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
        };
        type: "radio";
        label: string;
        field: string;
        help?: string | {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        } | undefined;
        tooltip?: string | undefined;
        required?: boolean | undefined;
        encrypted?: boolean | undefined;
        defaultValue?: string | undefined;
        modifyFieldsOnValue?: {
            fieldValue: string | number | boolean;
            fieldsToModify: {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }[];
            mode?: "clone" | "create" | "edit" | "config" | undefined;
        }[] | undefined;
    } | {
        type: "file";
        label: string;
        field: string;
        options?: {
            supportedFileTypes: string[];
            display?: boolean | undefined;
            disableonEdit?: boolean | undefined;
            enable?: boolean | undefined;
            requiredWhenVisible?: boolean | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
            maxFileSize?: number | undefined;
            fileSupportMessage?: string | undefined;
            useBase64Encoding?: boolean | undefined;
        } | undefined;
        help?: string | {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        } | undefined;
        tooltip?: string | undefined;
        required?: boolean | undefined;
        encrypted?: boolean | undefined;
        validators?: ({
            type: "string";
            minLength: number;
            maxLength: number;
            errorMsg?: string | undefined;
        } | {
            type: "regex";
            pattern: string;
            errorMsg?: string | undefined;
        })[] | undefined;
        defaultValue?: string | undefined;
        modifyFieldsOnValue?: {
            fieldValue: string | number | boolean;
            fieldsToModify: {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }[];
            mode?: "clone" | "create" | "edit" | "config" | undefined;
        }[] | undefined;
    } | {
        options: {
            auth_type: ("oauth" | "basic" | "oauth_client_credentials")[];
            display?: boolean | undefined;
            disableonEdit?: boolean | undefined;
            enable?: boolean | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
            oauth?: {
                label: string;
                field: string;
                oauth_field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                type?: "text" | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            }[] | undefined;
            basic?: {
                label: string;
                field: string;
                oauth_field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                type?: "text" | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            }[] | undefined;
            oauth_client_credentials?: {
                label: string;
                field: string;
                oauth_field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                type?: "text" | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            }[] | undefined;
            auth_label?: string | undefined;
            oauth_popup_width?: number | undefined;
            oauth_popup_height?: number | undefined;
            oauth_timeout?: number | undefined;
            auth_code_endpoint?: string | undefined;
            access_token_endpoint?: string | undefined;
            oauth_state_enabled?: boolean | undefined;
            auth_endpoint_token_access_type?: string | undefined;
        };
        type: "oauth";
        label: string;
        field: string;
        help?: string | {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        } | undefined;
        tooltip?: string | undefined;
        required?: boolean | undefined;
        encrypted?: boolean | undefined;
        validators?: ({
            type: "string";
            minLength: number;
            maxLength: number;
            errorMsg?: string | undefined;
        } | {
            type: "regex";
            pattern: string;
            errorMsg?: string | undefined;
        })[] | undefined;
        defaultValue?: string | undefined;
    } | {
        options: {
            type: "external";
            src: string;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
        };
        type: "custom";
        label: string;
        field: string;
        help?: string | {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        } | undefined;
        tooltip?: string | undefined;
        required?: boolean | undefined;
        encrypted?: boolean | undefined;
    })[] | undefined;
    table?: {
        header: {
            label: string;
            field: string;
            mapping?: Record<string, any> | undefined;
            customCell?: Record<string, any> | undefined;
        }[];
        actions: ("clone" | "delete" | "edit")[];
        moreInfo?: {
            label: string;
            field: string;
            mapping?: Record<string, any> | undefined;
        }[] | undefined;
        customRow?: Record<string, any> | undefined;
    } | undefined;
    style?: "page" | "dialog" | undefined;
    hook?: Record<string, any> | undefined;
    conf?: string | undefined;
    restHandlerName?: string | undefined;
    restHandlerModule?: string | undefined;
    restHandlerClass?: string | undefined;
    customTab?: Record<string, any> | undefined;
    warning?: {
        clone?: {
            message: string;
            alwaysDisplay?: boolean | undefined;
        } | undefined;
        create?: {
            message: string;
            alwaysDisplay?: boolean | undefined;
        } | undefined;
        edit?: {
            message: string;
            alwaysDisplay?: boolean | undefined;
        } | undefined;
        config?: {
            message: string;
            alwaysDisplay?: boolean | undefined;
        } | undefined;
    } | undefined;
    formTitle?: string | undefined;
}, {
    name: string;
    title: string;
    options?: {
        saveValidator?: string | undefined;
    } | undefined;
    hideForPlatform?: "cloud" | "enterprise" | undefined;
    groups?: {
        label: string;
        fields: string[];
        options?: {
            isExpandable?: boolean | undefined;
            expand?: boolean | undefined;
        } | undefined;
    }[] | undefined;
    entity?: ({
        type: "helpLink";
        field: string;
        options?: {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
        } | undefined;
        label?: string | undefined;
        help?: string | {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        } | undefined;
        tooltip?: string | undefined;
        required?: false | undefined;
    } | {
        type: "text";
        label: string;
        field: string;
        options?: {
            display?: boolean | undefined;
            disableonEdit?: boolean | undefined;
            enable?: boolean | undefined;
            requiredWhenVisible?: boolean | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
        } | undefined;
        help?: string | {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        } | undefined;
        tooltip?: string | undefined;
        required?: boolean | undefined;
        encrypted?: boolean | undefined;
        validators?: ({
            type: "number";
            range: [number, number];
            errorMsg?: string | undefined;
            isInteger?: boolean | undefined;
        } | {
            type: "string";
            minLength: number;
            maxLength: number;
            errorMsg?: string | undefined;
        } | {
            type: "regex";
            pattern: string;
            errorMsg?: string | undefined;
        } | {
            type: "email";
            errorMsg?: string | undefined;
        } | {
            type: "ipv4";
            errorMsg?: string | undefined;
        } | {
            type: "url";
            errorMsg?: string | undefined;
        } | {
            type: "date";
            errorMsg?: string | undefined;
        })[] | undefined;
        defaultValue?: string | number | boolean | undefined;
        modifyFieldsOnValue?: {
            fieldValue: string | number | boolean;
            fieldsToModify: {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }[];
            mode?: "clone" | "create" | "edit" | "config" | undefined;
        }[] | undefined;
    } | {
        type: "textarea";
        label: string;
        field: string;
        options?: {
            display?: boolean | undefined;
            disableonEdit?: boolean | undefined;
            enable?: boolean | undefined;
            requiredWhenVisible?: boolean | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
            rowsMin?: number | undefined;
            rowsMax?: number | undefined;
        } | undefined;
        help?: string | {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        } | undefined;
        tooltip?: string | undefined;
        required?: boolean | undefined;
        encrypted?: boolean | undefined;
        validators?: ({
            type: "number";
            range: [number, number];
            errorMsg?: string | undefined;
            isInteger?: boolean | undefined;
        } | {
            type: "string";
            minLength: number;
            maxLength: number;
            errorMsg?: string | undefined;
        } | {
            type: "regex";
            pattern: string;
            errorMsg?: string | undefined;
        } | {
            type: "email";
            errorMsg?: string | undefined;
        } | {
            type: "ipv4";
            errorMsg?: string | undefined;
        } | {
            type: "url";
            errorMsg?: string | undefined;
        } | {
            type: "date";
            errorMsg?: string | undefined;
        })[] | undefined;
        defaultValue?: string | undefined;
        modifyFieldsOnValue?: {
            fieldValue: string | number | boolean;
            fieldsToModify: {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }[];
            mode?: "clone" | "create" | "edit" | "config" | undefined;
        }[] | undefined;
    } | {
        options: {
            display?: boolean | undefined;
            disableonEdit?: boolean | undefined;
            enable?: boolean | undefined;
            requiredWhenVisible?: boolean | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
            disableSearch?: boolean | undefined;
            createSearchChoice?: boolean | undefined;
            referenceName?: string | undefined;
            endpointUrl?: string | undefined;
            allowList?: string | undefined;
            denyList?: string | undefined;
            labelField?: string | undefined;
            valueField?: string | undefined;
            autoCompleteFields?: ({
                value: string | number | boolean;
                label: string;
            } | {
                label: string;
                children: {
                    value: string | number | boolean;
                    label: string;
                }[];
            })[] | undefined;
            dependencies?: string[] | undefined;
            items?: {
                value: string | number | boolean;
                label: string;
            }[] | undefined;
        };
        type: "singleSelect";
        label: string;
        field: string;
        help?: string | {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        } | undefined;
        tooltip?: string | undefined;
        required?: boolean | undefined;
        encrypted?: boolean | undefined;
        validators?: ({
            type: "number";
            range: [number, number];
            errorMsg?: string | undefined;
            isInteger?: boolean | undefined;
        } | {
            type: "string";
            minLength: number;
            maxLength: number;
            errorMsg?: string | undefined;
        } | {
            type: "regex";
            pattern: string;
            errorMsg?: string | undefined;
        } | {
            type: "email";
            errorMsg?: string | undefined;
        } | {
            type: "ipv4";
            errorMsg?: string | undefined;
        } | {
            type: "url";
            errorMsg?: string | undefined;
        } | {
            type: "date";
            errorMsg?: string | undefined;
        })[] | undefined;
        defaultValue?: string | number | boolean | undefined;
        modifyFieldsOnValue?: {
            fieldValue: string | number | boolean;
            fieldsToModify: {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }[];
            mode?: "clone" | "create" | "edit" | "config" | undefined;
        }[] | undefined;
    } | {
        options: {
            display?: boolean | undefined;
            disableonEdit?: boolean | undefined;
            enable?: boolean | undefined;
            requiredWhenVisible?: boolean | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
            disableSearch?: boolean | undefined;
            createSearchChoice?: boolean | undefined;
            referenceName?: string | undefined;
            endpointUrl?: string | undefined;
            allowList?: string | undefined;
            denyList?: string | undefined;
            labelField?: string | undefined;
            valueField?: string | undefined;
            autoCompleteFields?: ({
                value: string | number | boolean;
                label: string;
            } | {
                label: string;
                children: {
                    value: string | number | boolean;
                    label: string;
                }[];
            })[] | undefined;
            dependencies?: string[] | undefined;
            items?: {
                value: string | number | boolean;
                label: string;
            }[] | undefined;
            delimiter?: string | undefined;
        };
        type: "multipleSelect";
        label: string;
        field: string;
        help?: string | {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        } | undefined;
        tooltip?: string | undefined;
        required?: boolean | undefined;
        encrypted?: boolean | undefined;
        validators?: ({
            type: "number";
            range: [number, number];
            errorMsg?: string | undefined;
            isInteger?: boolean | undefined;
        } | {
            type: "string";
            minLength: number;
            maxLength: number;
            errorMsg?: string | undefined;
        } | {
            type: "regex";
            pattern: string;
            errorMsg?: string | undefined;
        } | {
            type: "email";
            errorMsg?: string | undefined;
        } | {
            type: "ipv4";
            errorMsg?: string | undefined;
        } | {
            type: "url";
            errorMsg?: string | undefined;
        } | {
            type: "date";
            errorMsg?: string | undefined;
        })[] | undefined;
        defaultValue?: string | undefined;
        modifyFieldsOnValue?: {
            fieldValue: string | number | boolean;
            fieldsToModify: {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }[];
            mode?: "clone" | "create" | "edit" | "config" | undefined;
        }[] | undefined;
    } | {
        type: "checkbox";
        label: string;
        field: string;
        options?: {
            display?: boolean | undefined;
            disableonEdit?: boolean | undefined;
            enable?: boolean | undefined;
            requiredWhenVisible?: boolean | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
        } | undefined;
        help?: string | {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        } | undefined;
        tooltip?: string | undefined;
        required?: boolean | undefined;
        encrypted?: boolean | undefined;
        defaultValue?: number | boolean | undefined;
        modifyFieldsOnValue?: {
            fieldValue: string | number | boolean;
            fieldsToModify: {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }[];
            mode?: "clone" | "create" | "edit" | "config" | undefined;
        }[] | undefined;
    } | {
        options: {
            rows: {
                field: string;
                checkbox?: {
                    label?: string | undefined;
                    defaultValue?: boolean | undefined;
                } | undefined;
                input?: {
                    required?: boolean | undefined;
                    validators?: [{
                        type: "number";
                        range: [number, number];
                        errorMsg?: string | undefined;
                        isInteger?: boolean | undefined;
                    }] | undefined;
                    defaultValue?: number | undefined;
                } | undefined;
            }[];
            display?: boolean | undefined;
            disableonEdit?: boolean | undefined;
            enable?: boolean | undefined;
            requiredWhenVisible?: boolean | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
            delimiter?: string | undefined;
            groups?: {
                label: string;
                fields: string[];
                options?: {
                    isExpandable?: boolean | undefined;
                    expand?: boolean | undefined;
                } | undefined;
            }[] | undefined;
        };
        type: "checkboxGroup";
        label: string;
        field: string;
        help?: string | {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        } | undefined;
        tooltip?: string | undefined;
        required?: boolean | undefined;
        encrypted?: boolean | undefined;
        validators?: [{
            type: "regex";
            pattern: string;
            errorMsg?: string | undefined;
        }] | undefined;
        defaultValue?: number | boolean | undefined;
    } | {
        options: {
            rows: {
                field: string;
                checkbox?: {
                    label?: string | undefined;
                    defaultValue?: boolean | undefined;
                } | undefined;
            }[];
            display?: boolean | undefined;
            disableonEdit?: boolean | undefined;
            enable?: boolean | undefined;
            requiredWhenVisible?: boolean | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
            delimiter?: string | undefined;
            groups?: {
                label: string;
                fields: string[];
                options?: {
                    isExpandable?: boolean | undefined;
                    expand?: boolean | undefined;
                } | undefined;
            }[] | undefined;
        };
        type: "checkboxTree";
        label: string;
        field: string;
        help?: string | {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        } | undefined;
        tooltip?: string | undefined;
        required?: boolean | undefined;
        encrypted?: boolean | undefined;
        validators?: [{
            type: "regex";
            pattern: string;
            errorMsg?: string | undefined;
        }] | undefined;
        defaultValue?: number | boolean | undefined;
    } | {
        options: {
            items: {
                value: string | number | boolean;
                label: string;
            }[];
            display?: boolean | undefined;
            disableonEdit?: boolean | undefined;
            enable?: boolean | undefined;
            requiredWhenVisible?: boolean | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
        };
        type: "radio";
        label: string;
        field: string;
        help?: string | {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        } | undefined;
        tooltip?: string | undefined;
        required?: boolean | undefined;
        encrypted?: boolean | undefined;
        defaultValue?: string | undefined;
        modifyFieldsOnValue?: {
            fieldValue: string | number | boolean;
            fieldsToModify: {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }[];
            mode?: "clone" | "create" | "edit" | "config" | undefined;
        }[] | undefined;
    } | {
        type: "file";
        label: string;
        field: string;
        options?: {
            supportedFileTypes: string[];
            display?: boolean | undefined;
            disableonEdit?: boolean | undefined;
            enable?: boolean | undefined;
            requiredWhenVisible?: boolean | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
            maxFileSize?: number | undefined;
            fileSupportMessage?: string | undefined;
            useBase64Encoding?: boolean | undefined;
        } | undefined;
        help?: string | {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        } | undefined;
        tooltip?: string | undefined;
        required?: boolean | undefined;
        encrypted?: boolean | undefined;
        validators?: ({
            type: "string";
            minLength: number;
            maxLength: number;
            errorMsg?: string | undefined;
        } | {
            type: "regex";
            pattern: string;
            errorMsg?: string | undefined;
        })[] | undefined;
        defaultValue?: string | undefined;
        modifyFieldsOnValue?: {
            fieldValue: string | number | boolean;
            fieldsToModify: {
                fieldId: string;
                value?: string | number | boolean | undefined;
                label?: string | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                display?: boolean | undefined;
                disabled?: boolean | undefined;
                markdownMessage?: {
                    text: string;
                    markdownType: "text";
                    color?: string | undefined;
                } | {
                    text: string;
                    link: string;
                    linkText: string;
                    markdownType: "hybrid";
                    token: string;
                } | {
                    text: string;
                    link: string;
                    markdownType: "link";
                } | {
                    text: string;
                    markdownType?: undefined;
                } | undefined;
            }[];
            mode?: "clone" | "create" | "edit" | "config" | undefined;
        }[] | undefined;
    } | {
        options: {
            auth_type: ("oauth" | "basic" | "oauth_client_credentials")[];
            display?: boolean | undefined;
            disableonEdit?: boolean | undefined;
            enable?: boolean | undefined;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
            oauth?: {
                label: string;
                field: string;
                oauth_field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                type?: "text" | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            }[] | undefined;
            basic?: {
                label: string;
                field: string;
                oauth_field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                type?: "text" | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            }[] | undefined;
            oauth_client_credentials?: {
                label: string;
                field: string;
                oauth_field: string;
                options?: {
                    display?: boolean | undefined;
                    disableonEdit?: boolean | undefined;
                    enable?: boolean | undefined;
                    requiredWhenVisible?: boolean | undefined;
                    hideForPlatform?: "cloud" | "enterprise" | undefined;
                } | undefined;
                type?: "text" | undefined;
                help?: string | {
                    text: string;
                    link?: string | undefined;
                    links?: {
                        slug: string;
                        link: string;
                        linkText: string;
                    }[] | undefined;
                } | undefined;
                required?: boolean | undefined;
                encrypted?: boolean | undefined;
                validators?: ({
                    type: "number";
                    range: [number, number];
                    errorMsg?: string | undefined;
                    isInteger?: boolean | undefined;
                } | {
                    type: "string";
                    minLength: number;
                    maxLength: number;
                    errorMsg?: string | undefined;
                } | {
                    type: "regex";
                    pattern: string;
                    errorMsg?: string | undefined;
                } | {
                    type: "email";
                    errorMsg?: string | undefined;
                } | {
                    type: "ipv4";
                    errorMsg?: string | undefined;
                } | {
                    type: "url";
                    errorMsg?: string | undefined;
                } | {
                    type: "date";
                    errorMsg?: string | undefined;
                })[] | undefined;
                defaultValue?: string | number | boolean | undefined;
                modifyFieldsOnValue?: {
                    fieldValue: string | number | boolean;
                    fieldsToModify: {
                        fieldId: string;
                        value?: string | number | boolean | undefined;
                        label?: string | undefined;
                        help?: string | {
                            text: string;
                            link?: string | undefined;
                            links?: {
                                slug: string;
                                link: string;
                                linkText: string;
                            }[] | undefined;
                        } | undefined;
                        required?: boolean | undefined;
                        display?: boolean | undefined;
                        disabled?: boolean | undefined;
                        markdownMessage?: {
                            text: string;
                            markdownType: "text";
                            color?: string | undefined;
                        } | {
                            text: string;
                            link: string;
                            linkText: string;
                            markdownType: "hybrid";
                            token: string;
                        } | {
                            text: string;
                            link: string;
                            markdownType: "link";
                        } | {
                            text: string;
                            markdownType?: undefined;
                        } | undefined;
                    }[];
                    mode?: "clone" | "create" | "edit" | "config" | undefined;
                }[] | undefined;
            }[] | undefined;
            auth_label?: string | undefined;
            oauth_popup_width?: number | undefined;
            oauth_popup_height?: number | undefined;
            oauth_timeout?: number | undefined;
            auth_code_endpoint?: string | undefined;
            access_token_endpoint?: string | undefined;
            oauth_state_enabled?: boolean | undefined;
            auth_endpoint_token_access_type?: string | undefined;
        };
        type: "oauth";
        label: string;
        field: string;
        help?: string | {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        } | undefined;
        tooltip?: string | undefined;
        required?: boolean | undefined;
        encrypted?: boolean | undefined;
        validators?: ({
            type: "string";
            minLength: number;
            maxLength: number;
            errorMsg?: string | undefined;
        } | {
            type: "regex";
            pattern: string;
            errorMsg?: string | undefined;
        })[] | undefined;
        defaultValue?: string | undefined;
    } | {
        options: {
            type: "external";
            src: string;
            hideForPlatform?: "cloud" | "enterprise" | undefined;
        };
        type: "custom";
        label: string;
        field: string;
        help?: string | {
            text: string;
            link?: string | undefined;
            links?: {
                slug: string;
                link: string;
                linkText: string;
            }[] | undefined;
        } | undefined;
        tooltip?: string | undefined;
        required?: boolean | undefined;
        encrypted?: boolean | undefined;
    })[] | undefined;
    table?: {
        header: {
            label: string;
            field: string;
            mapping?: Record<string, any> | undefined;
            customCell?: Record<string, any> | undefined;
        }[];
        actions: ("clone" | "delete" | "edit")[];
        moreInfo?: {
            label: string;
            field: string;
            mapping?: Record<string, any> | undefined;
        }[] | undefined;
        customRow?: Record<string, any> | undefined;
    } | undefined;
    style?: "page" | "dialog" | undefined;
    hook?: Record<string, any> | undefined;
    conf?: string | undefined;
    restHandlerName?: string | undefined;
    restHandlerModule?: string | undefined;
    restHandlerClass?: string | undefined;
    customTab?: Record<string, any> | undefined;
    warning?: {
        clone?: {
            message: string;
            alwaysDisplay?: boolean | undefined;
        } | undefined;
        create?: {
            message: string;
            alwaysDisplay?: boolean | undefined;
        } | undefined;
        edit?: {
            message: string;
            alwaysDisplay?: boolean | undefined;
        } | undefined;
        config?: {
            message: string;
            alwaysDisplay?: boolean | undefined;
        } | undefined;
    } | undefined;
    formTitle?: string | undefined;
}>;

export declare function uccInit(components?: CustomElementsMap): Promise<void>;

export declare interface UtilBaseForm {
    setState: (callback: (prevState: BaseFormState) => BaseFormState) => void;
    setErrorFieldMsg: (field: string, msg: string) => void;
    clearAllErrorMsg: (state: BaseFormState) => BaseFormState;
    setErrorMsg: (msg: string) => void;
}

export declare interface UtilControlWrapper {
    handleChange: (field: string, targetValue: AcceptableFormValueOrNullish) => void;
    addCustomValidator: (field: string, validatorFunc: CustomValidatorFunc) => void;
    utilCustomFunctions: UtilBaseForm;
}

declare type ValueSetter = (newValue: AcceptableFormValueOrNullish) => void;

export { }
